@@ -159,8 +159,5 @@ namespace Simd
                 RgbToBgra<false>(rgb, width, height, rgbStride, bgra, bgraStride, alpha);
         }
     }
-#else
-    // Work arround to avoid warning: libvisp_simdlib.a(SimdAvx2BgrToBgra.cpp.o) has no symbols
-    void dummy_SimdAvx2BgrToBgra(){};
 #endif//SIMD_AVX2_ENABLE
 }
