@@ -142,8 +142,5 @@ namespace Simd
                 RgbaToGray<false>(rgba, width, height, rgbaStride, gray, grayStride);
         }
     }
-#else
-    // Work arround to avoid warning: libvisp_simdlib.a(SimdAvx2BgraToGray.cpp.o) has no symbols
-    void dummy_SimdAvx2BgraToGray(){};
 #endif// SIMD_AVX2_ENABLE
 }
