@@ -1,7 +1,7 @@
 /*
 * Simd Library (http://ermig1979.github.io/Simd).
 *
-* Copyright (c) 2011-2021 Yermalayeu Ihar.
+* Copyright (c) 2011-2022 Yermalayeu Ihar.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
@@ -26,6 +26,7 @@
 #include "Simd/SimdStore.h"
 #include "Simd/SimdGaussianBlur.h"
 #include "Simd/SimdExtract.h"
+#include "Simd/SimdUnpack.h"
 
 namespace Simd
 {
@@ -476,8 +477,5 @@ namespace Simd
                 GaussianBlur3x3<false>(src, srcStride, width, height, channelCount, dst, dstStride);
         }
     }
-#else
-    // Work arround to avoid warning: libvisp_simdlib.a(SimdAvx2GaussianBlur.cpp.o) has no symbols
-    void dummy_SimdAvx2GaussianBlur(){};
 #endif// SIMD_AVX2_ENABLE
 }
