@@ -250,8 +250,5 @@ namespace Simd
                 ReduceColor2x2<false>(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride, channelCount);
         }
     }
-#else
-    // Work arround to avoid warning: libvisp_simdlib.a(SimdAvx2Reduce.cpp.o) has no symbols
-    void dummy_SimdAvx2Reduce(){};
 #endif// SIMD_AVX2_ENABLE
 }
