@@ -1,7 +1,7 @@
 /*
 * Simd Library (http://ermig1979.github.io/Simd).
 *
-* Copyright (c) 2011-2021 Yermalayeu Ihar,
+* Copyright (c) 2011-2022 Yermalayeu Ihar,
 *               2014-2018 Antonenka Mikhail,
 *               2018-2018 Radchenko Andrey,
 *               2019-2019 Facundo Galan.
@@ -60,6 +60,7 @@ BOOL APIENTRY DllMain(HMODULE hModule, DWORD dwReasonForCall, LPVOID lpReserved)
 #include "Simd/SimdAlignment.h"
 #include "Simd/SimdConst.h"
 #include "Simd/SimdLog.h"
+#include "Simd/SimdEmpty.h"
 
 #include "Simd/SimdGaussianBlur.h"
 #include "Simd/SimdImageLoad.h"
@@ -67,7 +68,6 @@ BOOL APIENTRY DllMain(HMODULE hModule, DWORD dwReasonForCall, LPVOID lpReserved)
 #include "Simd/SimdResizer.h"
 
 #include "Simd/SimdBase.h"
-#include "Simd/SimdSse2.h"
 #include "Simd/SimdSse41.h"
 #include "Simd/SimdAvx1.h"
 #include "Simd/SimdAvx2.h"
@@ -89,9 +89,38 @@ SIMD_API const char * SimdVersion()
 
 using namespace Simd;
 
+SIMD_API size_t SimdCpuInfo(SimdCpuInfoType type)
+{
+    switch (type)
+    {
+    case SimdCpuInfoSockets: return Cpu::SOCKET_NUMBER;
+    case SimdCpuInfoCores: return Cpu::CORE_NUMBER;
+#ifdef SIMD_CPP_2011_ENABLE
+    case SimdCpuInfoThreads: return Cpu::THREAD_NUMBER;
+#endif
+    case SimdCpuInfoCacheL1: return Cpu::L1_CACHE_SIZE;
+    case SimdCpuInfoCacheL2: return Cpu::L2_CACHE_SIZE;
+    case SimdCpuInfoCacheL3: return Cpu::L3_CACHE_SIZE;
+#ifdef SIMD_SSE41_ENABLE
+    case SimdCpuInfoSse41: return Sse41::Enable ? 1 : 0;
+#endif
+#ifdef SIMD_AVX_ENABLE
+    case SimdCpuInfoAvx: return Avx::Enable ? 1 : 0;
+#endif
+#ifdef SIMD_AVX2_ENABLE
+    case SimdCpuInfoAvx2: return Avx2::Enable ? 1 : 0;
+#endif
+#ifdef SIMD_NEON_ENABLE
+    case SimdCpuInfoNeon: return Neon::Enable ? 1 : 0;
+#endif
+    default:
+        return 0;
+    }
+}
+
 SIMD_API const char * SimdPerformanceStatistic()
 {
-#if defined(SIMD_PERFORMANCE_STATISTIC) && defined(NDEBUG)
+#if defined(SIMD_PERFORMANCE_STATISTIC) && (defined(NDEBUG) || defined(SIMD_PERF_STAT_IN_DEBUG))
     return Base::PerformanceMeasurerStorage::s_storage.PerformanceStatistic();
 #else
     return "";
@@ -125,9 +154,9 @@ SIMD_API void SimdRelease(void * context)
 
 SIMD_API SimdBool SimdGetFastMode()
 {
-#ifdef SIMD_SSE2_ENABLE
-    if (Sse2::Enable)
-        return Sse2::GetFastMode();
+#ifdef SIMD_SSE41_ENABLE
+    if (Sse41::Enable)
+        return Sse41::GetFastMode();
     else
 #endif
 #ifdef SIMD_NEON_ENABLE
@@ -140,9 +169,9 @@ SIMD_API SimdBool SimdGetFastMode()
 
 SIMD_API void SimdSetFastMode(SimdBool value)
 {
-#ifdef SIMD_SSE2_ENABLE
-    if (Sse2::Enable)
-        Sse2::SetFastMode(value);
+#ifdef SIMD_SSE41_ENABLE
+    if (Sse41::Enable)
+        Sse41::SetFastMode(value);
 #endif
 #ifdef SIMD_NEON_ENABLE
     if (Neon::Enable)
@@ -153,7 +182,7 @@ SIMD_API void SimdSetFastMode(SimdBool value)
 SIMD_API void SimdBgraToBgr(const uint8_t * bgra, size_t width, size_t height, size_t bgraStride, uint8_t * bgr, size_t bgrStride)
 {
 #ifdef SIMD_AVX2_ENABLE
-    if (Avx2::Enable && width >= Avx2::A)
+    if (Avx2::Enable && width >= Avx2::F)
         Avx2::BgraToBgr(bgra, width, height, bgraStride, bgr, bgrStride);
     else
 #endif
@@ -177,9 +206,9 @@ SIMD_API void SimdBgraToGray(const uint8_t *bgra, size_t width, size_t height, s
         Avx2::BgraToGray(bgra, width, height, bgraStride, gray, grayStride);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if(Sse2::Enable && width >= Sse2::A)
-        Sse2::BgraToGray(bgra, width, height, bgraStride, gray, grayStride);
+#ifdef SIMD_SSE41_ENABLE
+    if(Sse41::Enable && width >= Sse41::A)
+        Sse41::BgraToGray(bgra, width, height, bgraStride, gray, grayStride);
     else
 #endif
 #ifdef SIMD_NEON_ENABLE
@@ -193,7 +222,7 @@ SIMD_API void SimdBgraToGray(const uint8_t *bgra, size_t width, size_t height, s
 SIMD_API void SimdBgraToRgb(const uint8_t* bgra, size_t width, size_t height, size_t bgraStride, uint8_t* rgb, size_t rgbStride)
 {
 #ifdef SIMD_AVX2_ENABLE
-    if (Avx2::Enable && width >= Avx2::A)
+    if (Avx2::Enable && width >= Avx2::F)
         Avx2::BgraToRgb(bgra, width, height, bgraStride, rgb, rgbStride);
     else
 #endif
@@ -263,9 +292,9 @@ SIMD_API void SimdBgr48pToBgra32(const uint8_t * blue, size_t blueStride, size_t
         Avx2::Bgr48pToBgra32(blue, blueStride, width, height, green, greenStride, red, redStride, bgra, bgraStride, alpha);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if(Sse2::Enable && width >= Sse2::HA)
-        Sse2::Bgr48pToBgra32(blue, blueStride, width, height, green, greenStride, red, redStride, bgra, bgraStride, alpha);
+#ifdef SIMD_SSE41_ENABLE
+    if(Sse41::Enable && width >= Sse41::HA)
+        Sse41::Bgr48pToBgra32(blue, blueStride, width, height, green, greenStride, red, redStride, bgra, bgraStride, alpha);
     else
 #endif
 #ifdef SIMD_NEON_ENABLE
@@ -288,11 +317,6 @@ SIMD_API void SimdBgrToGray(const uint8_t *bgr, size_t width, size_t height, siz
         Sse41::BgrToGray(bgr, width, height, bgrStride, gray, grayStride);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if(Sse2::Enable && width >= Sse2::A)
-        Sse2::BgrToGray(bgr, width, height, bgrStride, gray, grayStride);
-    else
-#endif
 #ifdef SIMD_NEON_ENABLE
     if (Neon::Enable && width >= Neon::A)
         Neon::BgrToGray(bgr, width, height, bgrStride, gray, grayStride);
@@ -303,6 +327,7 @@ SIMD_API void SimdBgrToGray(const uint8_t *bgr, size_t width, size_t height, siz
 
 SIMD_API void SimdBgrToRgb(const uint8_t *bgr, size_t width, size_t height, size_t bgrStride, uint8_t * rgb, size_t rgbStride)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX512BW_ENABLE
     if (Avx512bw::Enable)
         Avx512bw::BgrToRgb(bgr, width, height, bgrStride, rgb, rgbStride);
@@ -328,12 +353,14 @@ SIMD_API void SimdBgrToRgb(const uint8_t *bgr, size_t width, size_t height, size
 
 SIMD_API void SimdCopy(const uint8_t * src, size_t srcStride, size_t width, size_t height, size_t pixelSize, uint8_t * dst, size_t dstStride)
 {
+    SIMD_EMPTY();
     Base::Copy(src, srcStride, width, height, pixelSize, dst, dstStride);
 }
 
 SIMD_API void SimdCopyFrame(const uint8_t * src, size_t srcStride, size_t width, size_t height, size_t pixelSize,
                            size_t frameLeft, size_t frameTop, size_t frameRight, size_t frameBottom, uint8_t * dst, size_t dstStride)
 {
+    SIMD_EMPTY();
     Base::CopyFrame(src, srcStride, width, height, pixelSize, frameLeft, frameTop, frameRight, frameBottom, dst, dstStride);
 }
 
@@ -361,6 +388,7 @@ SIMD_API void SimdDeinterleaveBgr(const uint8_t * bgr, size_t bgrStride, size_t
 SIMD_API void SimdDeinterleaveBgra(const uint8_t * bgra, size_t bgraStride, size_t width, size_t height,
     uint8_t * b, size_t bStride, uint8_t * g, size_t gStride, uint8_t * r, size_t rStride, uint8_t * a, size_t aStride)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX2_ENABLE
     if (Avx2::Enable && width >= Avx2::A)
         Avx2::DeinterleaveBgra(bgra, bgraStride, width, height, b, bStride, g, gStride, r, rStride, a, aStride);
@@ -392,11 +420,6 @@ SIMD_API void SimdGaussianBlur3x3(const uint8_t * src, size_t srcStride, size_t
         Sse41::GaussianBlur3x3(src, srcStride, width, height, channelCount, dst, dstStride);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if(Sse2::Enable && (width - 1)*channelCount >= Sse2::A)
-        Sse2::GaussianBlur3x3(src, srcStride, width, height, channelCount, dst, dstStride);
-    else
-#endif
 #ifdef SIMD_NEON_ENABLE
     if (Neon::Enable && (width - 1)*channelCount >= Neon::A)
         Neon::GaussianBlur3x3(src, srcStride, width, height, channelCount, dst, dstStride);
@@ -407,6 +430,7 @@ SIMD_API void SimdGaussianBlur3x3(const uint8_t * src, size_t srcStride, size_t
 
 SIMD_API void* SimdGaussianBlurInit(size_t width, size_t height, size_t channels, const float* sigma, const float* epsilon)
 {
+    SIMD_EMPTY();
     typedef void* (*SimdGaussianBlurInitPtr) (size_t width, size_t height, size_t channels, const float* sigma, const float* epsilon);
     const static SimdGaussianBlurInitPtr simdGaussianBlurInit = SIMD_FUNC3(GaussianBlurInit, SIMD_AVX2_FUNC, SIMD_SSE41_FUNC, SIMD_NEON_FUNC);
 
@@ -415,11 +439,13 @@ SIMD_API void* SimdGaussianBlurInit(size_t width, size_t height, size_t channels
 
 SIMD_API void SimdGaussianBlurRun(const void* filter, const uint8_t* src, size_t srcStride, uint8_t* dst, size_t dstStride)
 {
+    SIMD_EMPTY();
     ((GaussianBlur*)filter)->Run(src, srcStride, dst, dstStride);
 }
 
 SIMD_API void SimdGrayToBgr(const uint8_t * gray, size_t width, size_t height, size_t grayStride, uint8_t * bgr, size_t bgrStride)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX2_ENABLE
     if(Avx2::Enable && width >= Avx2::A)
         Avx2::GrayToBgr(gray, width, height, grayStride, bgr, bgrStride);
@@ -440,14 +466,15 @@ SIMD_API void SimdGrayToBgr(const uint8_t * gray, size_t width, size_t height, s
 
 SIMD_API void SimdGrayToBgra(const uint8_t * gray, size_t width, size_t height, size_t grayStride, uint8_t * bgra, size_t bgraStride, uint8_t alpha)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX2_ENABLE
     if(Avx2::Enable && width >= Avx2::A)
         Avx2::GrayToBgra(gray, width, height, grayStride, bgra, bgraStride, alpha);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if(Sse2::Enable && width >= Sse2::A)
-        Sse2::GrayToBgra(gray, width, height, grayStride, bgra, bgraStride, alpha);
+#ifdef SIMD_SSE41_ENABLE
+    if(Sse41::Enable && width >= Sse41::A)
+        Sse41::GrayToBgra(gray, width, height, grayStride, bgra, bgraStride, alpha);
     else
 #endif
 #ifdef SIMD_NEON_ENABLE
@@ -460,6 +487,7 @@ SIMD_API void SimdGrayToBgra(const uint8_t * gray, size_t width, size_t height,
 
 SIMD_API uint8_t* SimdImageSaveToMemory(const uint8_t* src, size_t stride, size_t width, size_t height, SimdPixelFormatType format, SimdImageFileType file, int quality, size_t* size)
 {
+    SIMD_EMPTY();
     const static Simd::ImageSaveToMemoryPtr imageSaveToMemory = SIMD_FUNC3(ImageSaveToMemory, SIMD_AVX2_FUNC, SIMD_SSE41_FUNC, SIMD_NEON_FUNC);
 
     return imageSaveToMemory(src, stride, width, height, format, file, quality, size);
@@ -467,6 +495,7 @@ SIMD_API uint8_t* SimdImageSaveToMemory(const uint8_t* src, size_t stride, size_
 
 SIMD_API SimdBool SimdImageSaveToFile(const uint8_t* src, size_t stride, size_t width, size_t height, SimdPixelFormatType format, SimdImageFileType file, int quality, const char* path)
 {
+    SIMD_EMPTY();
     const static Simd::ImageSaveToMemoryPtr imageSaveToMemory = SIMD_FUNC3(ImageSaveToMemory, SIMD_AVX2_FUNC, SIMD_SSE41_FUNC, SIMD_NEON_FUNC);
 
     return ImageSaveToFile(imageSaveToMemory, src, stride, width, height, format, file, quality, path);
@@ -474,6 +503,7 @@ SIMD_API SimdBool SimdImageSaveToFile(const uint8_t* src, size_t stride, size_t
 
 SIMD_API uint8_t* SimdImageLoadFromMemory(const uint8_t* data, size_t size, size_t* stride, size_t* width, size_t* height, SimdPixelFormatType* format)
 {
+    SIMD_EMPTY();
     const static Simd::ImageLoadFromMemoryPtr imageLoadFromMemory = SIMD_FUNC3(ImageLoadFromMemory, SIMD_AVX2_FUNC, SIMD_SSE41_FUNC, SIMD_NEON_FUNC);
 
     return imageLoadFromMemory(data, size, stride, width, height, format);
@@ -481,6 +511,7 @@ SIMD_API uint8_t* SimdImageLoadFromMemory(const uint8_t* data, size_t size, size
 
 SIMD_API uint8_t* SimdImageLoadFromFile(const char* path, size_t* stride, size_t* width, size_t* height, SimdPixelFormatType* format)
 {
+    SIMD_EMPTY();
     const static Simd::ImageLoadFromMemoryPtr imageLoadFromMemory = SIMD_FUNC3(ImageLoadFromMemory, SIMD_AVX2_FUNC, SIMD_SSE41_FUNC, SIMD_NEON_FUNC);
 
     return ImageLoadFromFile(imageLoadFromMemory, path, stride, width, height, format);
@@ -489,6 +520,7 @@ SIMD_API uint8_t* SimdImageLoadFromFile(const char* path, size_t* stride, size_t
 SIMD_API void SimdInterleaveBgr(const uint8_t * b, size_t bStride, const uint8_t * g, size_t gStride, const uint8_t * r, size_t rStride,
     size_t width, size_t height, uint8_t * bgr, size_t bgrStride)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX2_ENABLE
     if (Avx2::Enable && width >= Avx2::A)
         Avx2::InterleaveBgr(b, bStride, g, gStride, r, rStride, width, height, bgr, bgrStride);
@@ -510,6 +542,7 @@ SIMD_API void SimdInterleaveBgr(const uint8_t * b, size_t bStride, const uint8_t
 SIMD_API void SimdInterleaveBgra(const uint8_t * b, size_t bStride, const uint8_t * g, size_t gStride, const uint8_t * r, size_t rStride, const uint8_t * a, size_t aStride,
     size_t width, size_t height, uint8_t * bgra, size_t bgraStride)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX2_ENABLE
     if (Avx2::Enable && width >= Avx2::A)
         Avx2::InterleaveBgra(b, bStride, g, gStride, r, rStride, a, aStride, width, height, bgra, bgraStride);
@@ -536,9 +569,9 @@ SIMD_API void SimdOperationBinary8u(const uint8_t * a, size_t aStride, const uin
         Avx2::OperationBinary8u(a, aStride, b, bStride, width, height, channelCount, dst, dstStride, type);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if(Sse2::Enable && width*channelCount >= Sse2::A)
-        Sse2::OperationBinary8u(a, aStride, b, bStride, width, height, channelCount, dst, dstStride, type);
+#ifdef SIMD_SSE41_ENABLE
+    if(Sse41::Enable && width*channelCount >= Sse41::A)
+        Sse41::OperationBinary8u(a, aStride, b, bStride, width, height, channelCount, dst, dstStride, type);
     else
 #endif
 #ifdef SIMD_NEON_ENABLE
@@ -552,6 +585,7 @@ SIMD_API void SimdOperationBinary8u(const uint8_t * a, size_t aStride, const uin
 SIMD_API void SimdReduceColor2x2(const uint8_t *src, size_t srcWidth, size_t srcHeight, size_t srcStride,
     uint8_t *dst, size_t dstWidth, size_t dstHeight, size_t dstStride, size_t channelCount)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX2_ENABLE
     if (Avx2::Enable && srcWidth >= Avx2::DA)
         Avx2::ReduceColor2x2(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride, channelCount);
@@ -562,11 +596,6 @@ SIMD_API void SimdReduceColor2x2(const uint8_t *src, size_t srcWidth, size_t src
         Sse41::ReduceColor2x2(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride, channelCount);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if (Sse2::Enable && srcWidth >= Sse2::DA)
-        Sse2::ReduceColor2x2(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride, channelCount);
-    else
-#endif
 #ifdef SIMD_NEON_ENABLE
     if (Neon::Enable && srcWidth >= Neon::DA)
         Neon::ReduceColor2x2(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride, channelCount);
@@ -578,6 +607,7 @@ SIMD_API void SimdReduceColor2x2(const uint8_t *src, size_t srcWidth, size_t src
 SIMD_API void SimdReduceGray2x2(const uint8_t *src, size_t srcWidth, size_t srcHeight, size_t srcStride,
                    uint8_t *dst, size_t dstWidth, size_t dstHeight, size_t dstStride)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX2_ENABLE
     if(Avx2::Enable && srcWidth >= Avx2::DA)
         Avx2::ReduceGray2x2(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride);
@@ -588,11 +618,6 @@ SIMD_API void SimdReduceGray2x2(const uint8_t *src, size_t srcWidth, size_t srcH
         Sse41::ReduceGray2x2(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if(Sse2::Enable && srcWidth >= Sse2::DA)
-        Sse2::ReduceGray2x2(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride);
-    else
-#endif
 #ifdef SIMD_NEON_ENABLE
     if (Neon::Enable && srcWidth >= Neon::DA)
         Neon::ReduceGray2x2(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride);
@@ -604,14 +629,15 @@ SIMD_API void SimdReduceGray2x2(const uint8_t *src, size_t srcWidth, size_t srcH
 SIMD_API void SimdReduceGray3x3(const uint8_t *src, size_t srcWidth, size_t srcHeight, size_t srcStride,
                    uint8_t *dst, size_t dstWidth, size_t dstHeight, size_t dstStride, int compensation)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX2_ENABLE
     if(Avx2::Enable && srcWidth >= Avx2::DA)
         Avx2::ReduceGray3x3(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride, compensation);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if(Sse2::Enable && srcWidth >= Sse2::A)
-        Sse2::ReduceGray3x3(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride, compensation);
+#ifdef SIMD_SSE41_ENABLE
+    if(Sse41::Enable && srcWidth >= Sse41::A)
+        Sse41::ReduceGray3x3(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride, compensation);
     else
 #endif
 #ifdef SIMD_NEON_ENABLE
@@ -625,6 +651,7 @@ SIMD_API void SimdReduceGray3x3(const uint8_t *src, size_t srcWidth, size_t srcH
 SIMD_API void SimdReduceGray4x4(const uint8_t *src, size_t srcWidth, size_t srcHeight, size_t srcStride,
                    uint8_t *dst, size_t dstWidth, size_t dstHeight, size_t dstStride)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX2_ENABLE
     if(Avx2::Enable && srcWidth > Avx2::DA)
         Avx2::ReduceGray4x4(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride);
@@ -635,11 +662,6 @@ SIMD_API void SimdReduceGray4x4(const uint8_t *src, size_t srcWidth, size_t srcH
         Sse41::ReduceGray4x4(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if(Sse2::Enable && srcWidth > Sse2::A)
-        Sse2::ReduceGray4x4(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride);
-    else
-#endif
 #ifdef SIMD_NEON_ENABLE
     if (Neon::Enable && srcWidth > Neon::DA)
         Neon::ReduceGray4x4(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride);
@@ -651,14 +673,15 @@ SIMD_API void SimdReduceGray4x4(const uint8_t *src, size_t srcWidth, size_t srcH
 SIMD_API void SimdReduceGray5x5(const uint8_t *src, size_t srcWidth, size_t srcHeight, size_t srcStride,
                    uint8_t *dst, size_t dstWidth, size_t dstHeight, size_t dstStride, int compensation)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX2_ENABLE
     if(Avx2::Enable && srcWidth >= Avx2::DA)
         Avx2::ReduceGray5x5(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride, compensation);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if(Sse2::Enable && srcWidth >= Sse2::A)
-        Sse2::ReduceGray5x5(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride, compensation);
+#ifdef SIMD_SSE41_ENABLE
+    if(Sse41::Enable && srcWidth >= Sse41::A)
+        Sse41::ReduceGray5x5(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride, compensation);
     else
 #endif
 #ifdef SIMD_NEON_ENABLE
@@ -727,11 +750,13 @@ SIMD_API void * SimdResizerInit(size_t srcX, size_t srcY, size_t dstX, size_t ds
 
 SIMD_API void SimdResizerRun(const void * resizer, const uint8_t * src, size_t srcStride, uint8_t * dst, size_t dstStride)
 {
+    SIMD_EMPTY();
     ((Resizer*)resizer)->Run(src, srcStride, dst, dstStride);
 }
 
 SIMD_API void SimdRgbToBgra(const uint8_t* rgb, size_t width, size_t height, size_t rgbStride, uint8_t* bgra, size_t bgraStride, uint8_t alpha)
 {
+    SIMD_EMPTY();
 #if defined(SIMD_AVX2_ENABLE) && !defined(SIMD_CLANG_AVX2_BGR_TO_BGRA_ERROR)
     if (Avx2::Enable && width >= Avx2::A)
         Avx2::RgbToBgra(rgb, width, height, rgbStride, bgra, bgraStride, alpha);
@@ -752,6 +777,7 @@ SIMD_API void SimdRgbToBgra(const uint8_t* rgb, size_t width, size_t height, siz
 
 SIMD_API void SimdRgbToGray(const uint8_t* rgb, size_t width, size_t height, size_t rgbStride, uint8_t* gray, size_t grayStride)
 {
+    SIMD_EMPTY();
 #if defined(SIMD_AVX2_ENABLE) && !defined(SIMD_CLANG_AVX2_BGR_TO_BGRA_ERROR)
     if (Avx2::Enable && width >= Avx2::A)
         Avx2::RgbToGray(rgb, width, height, rgbStride, gray, grayStride);
@@ -772,14 +798,15 @@ SIMD_API void SimdRgbToGray(const uint8_t* rgb, size_t width, size_t height, siz
 
 SIMD_API void SimdRgbaToGray(const uint8_t* rgba, size_t width, size_t height, size_t rgbaStride, uint8_t* gray, size_t grayStride)
 {
+    SIMD_EMPTY();
 #if defined(SIMD_AVX2_ENABLE)
     if (Avx2::Enable && width >= Avx2::A)
         Avx2::RgbaToGray(rgba, width, height, rgbaStride, gray, grayStride);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if (Sse2::Enable && width >= Sse2::A)
-        Sse2::RgbaToGray(rgba, width, height, rgbaStride, gray, grayStride);
+#ifdef SIMD_SSE41_ENABLE
+    if (Sse41::Enable && width >= Sse41::A)
+        Sse41::RgbaToGray(rgba, width, height, rgbaStride, gray, grayStride);
     else
 #endif
 #ifdef SIMD_NEON_ENABLE
@@ -793,14 +820,15 @@ SIMD_API void SimdRgbaToGray(const uint8_t* rgba, size_t width, size_t height, s
 SIMD_API void SimdStretchGray2x2(const uint8_t *src, size_t srcWidth, size_t srcHeight, size_t srcStride,
                     uint8_t *dst, size_t dstWidth, size_t dstHeight, size_t dstStride)
 {
+    SIMD_EMPTY();
 #ifdef SIMD_AVX2_ENABLE
     if(Avx2::Enable && srcWidth >= Avx2::A)
         Avx2::StretchGray2x2(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride);
     else
 #endif
-#ifdef SIMD_SSE2_ENABLE
-    if(Sse2::Enable && srcWidth >= Sse2::A)
-        Sse2::StretchGray2x2(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride);
+#ifdef SIMD_SSE41_ENABLE
+    if(Sse41::Enable && srcWidth >= Sse41::A)
+        Sse41::StretchGray2x2(src, srcWidth, srcHeight, srcStride, dst, dstWidth, dstHeight, dstStride);
     else
 #endif
 #ifdef SIMD_NEON_ENABLE
@@ -814,9 +842,9 @@ SIMD_API void SimdStretchGray2x2(const uint8_t *src, size_t srcWidth, size_t src
 /* ViSP custom SIMD code */
 SIMD_API void SimdImageErosion(uint8_t * img, const uint8_t * buff, size_t width, size_t height, SimdImageConnexityType connexityType)
 {
-#ifdef SIMD_SSE2_ENABLE
-    if (Sse2::Enable && width >= Sse2::A)
-        Sse2::ImageErosion(img, buff, width, height, connexityType);
+#ifdef SIMD_SSE41_ENABLE
+    if (Sse41::Enable && width >= Sse41::A)
+        Sse41::ImageErosion(img, buff, width, height, connexityType);
     else
 #endif
         Base::ImageErosion(img, buff, width, height, connexityType);
@@ -824,9 +852,9 @@ SIMD_API void SimdImageErosion(uint8_t * img, const uint8_t * buff, size_t width
 
 SIMD_API void SimdImageDilatation(uint8_t * img, const uint8_t * buff, size_t width, size_t height, SimdImageConnexityType connexityType)
 {
-#ifdef SIMD_SSE2_ENABLE
-    if (Sse2::Enable && width >= Sse2::A)
-        Sse2::ImageDilatation(img, buff, width, height, connexityType);
+#ifdef SIMD_SSE41_ENABLE
+    if (Sse41::Enable && width >= Sse41::A)
+        Sse41::ImageDilatation(img, buff, width, height, connexityType);
     else
 #endif
         Base::ImageDilatation(img, buff, width, height, connexityType);
@@ -834,10 +862,10 @@ SIMD_API void SimdImageDilatation(uint8_t * img, const uint8_t * buff, size_t wi
 
 SIMD_API double SimdVectorSum(const double * vec, size_t size)
 {
-#ifdef SIMD_SSE2_ENABLE
+#ifdef SIMD_SSE41_ENABLE
     const int unrollLoopSize = 2;
-    if (Sse2::Enable && size*sizeof(double) >= unrollLoopSize*Sse2::A)
-        return Sse2::SimdVectorSum(vec, size);
+    if (Sse41::Enable && size*sizeof(double) >= unrollLoopSize*Sse41::A)
+        return Sse41::SimdVectorSum(vec, size);
     else
 #endif
         return Base::SimdVectorSum(vec, size);
@@ -845,10 +873,10 @@ SIMD_API double SimdVectorSum(const double * vec, size_t size)
 
 SIMD_API double SimdVectorSumSquare(const double * vec, size_t size)
 {
-#ifdef SIMD_SSE2_ENABLE
+#ifdef SIMD_SSE41_ENABLE
     const int unrollLoopSize = 2;
-    if (Sse2::Enable && size*sizeof(double) >= unrollLoopSize*Sse2::A)
-        return Sse2::SimdVectorSumSquare(vec, size);
+    if (Sse41::Enable && size*sizeof(double) >= unrollLoopSize*Sse41::A)
+        return Sse41::SimdVectorSumSquare(vec, size);
     else
 #endif
         return Base::SimdVectorSumSquare(vec, size);
@@ -856,10 +884,10 @@ SIMD_API double SimdVectorSumSquare(const double * vec, size_t size)
 
 SIMD_API double SimdVectorStdev(const double * vec, size_t size, bool useBesselCorrection)
 {
-#ifdef SIMD_SSE2_ENABLE
+#ifdef SIMD_SSE41_ENABLE
     const int unrollLoopSize = 2;
-    if (Sse2::Enable && size*sizeof(double) >= unrollLoopSize*Sse2::A)
-        return Sse2::SimdVectorStdev(vec, size, useBesselCorrection);
+    if (Sse41::Enable && size*sizeof(double) >= unrollLoopSize*Sse41::A)
+        return Sse41::SimdVectorStdev(vec, size, useBesselCorrection);
     else
 #endif
         return Base::SimdVectorStdev(vec, size, useBesselCorrection);
@@ -867,9 +895,9 @@ SIMD_API double SimdVectorStdev(const double * vec, size_t size, bool useBesselC
 
 SIMD_API void SimdVectorHadamard(const double * src1, const double * src2, size_t size, double * dst)
 {
-#ifdef SIMD_SSE2_ENABLE
-    if (Sse2::Enable && size*sizeof(double) >= Sse2::A)
-        Sse2::SimdVectorHadamard(src1, src2, size, dst);
+#ifdef SIMD_SSE41_ENABLE
+    if (Sse41::Enable && size*sizeof(double) >= Sse41::A)
+        Sse41::SimdVectorHadamard(src1, src2, size, dst);
     else
 #endif
         Base::SimdVectorHadamard(src1, src2, size, dst);
@@ -877,9 +905,14 @@ SIMD_API void SimdVectorHadamard(const double * src1, const double * src2, size_
 
 SIMD_API void SimdMatMulTwist(const double * mat, size_t rows, const double * twist, double * dst)
 {
-#ifdef SIMD_SSE2_ENABLE
-    if (Sse2::Enable)
-        Sse2::SimdMatMulTwist(mat, rows, twist, dst);
+#ifdef SIMD_SSE41_ENABLE
+    if (Sse41::Enable)
+        Sse41::SimdMatMulTwist(mat, rows, twist, dst);
+    else
+#endif
+#if defined(SIMD_NEON_ENABLE) && defined(SIMD_ARM64_ENABLE)
+    if (Neon::Enable)
+        Neon::SimdMatMulTwist(mat, rows, twist, dst);
     else
 #endif
         Base::SimdMatMulTwist(mat, rows, twist, dst);
@@ -909,9 +942,9 @@ SIMD_API void SimdNormalizedCorrelation(const double * img1, double mean1, const
                                         double& a2, double& b2, double& ab, bool useOptimized)
 {
     if (useOptimized) {
-#ifdef SIMD_SSE2_ENABLE
-        if (Sse2::Enable && size*sizeof(double) >= Sse2::A)
-            Sse2::SimdNormalizedCorrelation(img1, mean1, img2, mean2, size, a2, b2, ab);
+#ifdef SIMD_SSE41_ENABLE
+        if (Sse41::Enable && size*sizeof(double) >= Sse41::A)
+            Sse41::SimdNormalizedCorrelation(img1, mean1, img2, mean2, size, a2, b2, ab);
         else
 #endif
             Base::SimdNormalizedCorrelation(img1, mean1, img2, mean2, size, a2, b2, ab);
@@ -923,9 +956,9 @@ SIMD_API void SimdNormalizedCorrelation(const double * img1, double mean1, const
 SIMD_API void SimdNormalizedCorrelation2(const double * img1, size_t width1, const double * img2,
                                          size_t width2, size_t height2, size_t i0, size_t j0, double& ab)
 {
-#ifdef SIMD_SSE2_ENABLE
-    if (Sse2::Enable && width2*sizeof(double) >= Sse2::A)
-        Sse2::SimdNormalizedCorrelation2(img1, width1, img2, width2, height2, i0, j0, ab);
+#ifdef SIMD_SSE41_ENABLE
+    if (Sse41::Enable && width2*sizeof(double) >= Sse41::A)
+        Sse41::SimdNormalizedCorrelation2(img1, width1, img2, width2, height2, i0, j0, ab);
     else
 #endif
         Base::SimdNormalizedCorrelation2(img1, width1, img2, width2, height2, i0, j0, ab);
@@ -934,9 +967,9 @@ SIMD_API void SimdNormalizedCorrelation2(const double * img1, size_t width1, con
 SIMD_API void SimdRemap(const unsigned char * src, size_t channels, size_t width, size_t height, size_t offset,
                         const int * mapU, const int * mapV, const float * mapDu, const float * mapDv, unsigned char * dst)
 {
-#ifdef SIMD_SSE2_ENABLE
-    if (Sse2::Enable && channels >= 4)
-        Sse2::SimdRemap(src, channels, width, height, offset, mapU, mapV, mapDu, mapDv, dst);
+#ifdef SIMD_SSE41_ENABLE
+    if (Sse41::Enable && channels >= 4)
+        Sse41::SimdRemap(src, channels, width, height, offset, mapU, mapV, mapDu, mapDv, dst);
     else
 #endif
         Base::SimdRemap(src, channels, width, height, offset, mapU, mapV, mapDu, mapDv, dst);
@@ -944,9 +977,14 @@ SIMD_API void SimdRemap(const unsigned char * src, size_t channels, size_t width
 
 SIMD_API void SimdComputeJtR(const double * J, size_t rows, const double * R, double * dst)
 {
-#ifdef SIMD_SSE2_ENABLE
-    if (Sse2::Enable)
-        Sse2::SimdComputeJtR(J, rows, R, dst);
+#ifdef SIMD_SSE41_ENABLE
+    if (Sse41::Enable)
+        Sse41::SimdComputeJtR(J, rows, R, dst);
+    else
+#endif
+#if defined(SIMD_NEON_ENABLE) && defined(SIMD_ARM64_ENABLE)
+    if (Neon::Enable)
+        Neon::SimdComputeJtR(J, rows, R, dst);
     else
 #endif
         Base::SimdComputeJtR(J, rows, R, dst);
