@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,15 +31,12 @@
  * Description:
  * Camera calibration with chessboard or circle calibration grid.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 #include <iostream>
 
 #include <visp3/core/vpConfig.h>
 
-#if VISP_HAVE_OPENCV_VERSION >= 0x020300
+#if (VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_CALIB3D) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC)
 
 #include <map>
 
@@ -71,25 +68,33 @@ void usage(const char *argv[], int error)
 {
   std::cout << "Synopsis" << std::endl
             << "  " << argv[0] << " <configuration file>.cfg [--init-from-xml <camera-init.xml>]"
-            << " [--camera-name <name>] [--aspect-ratio <ratio>] [--output <file.xml>] [--help] [-h]" << std::endl << std::endl;
+            << " [--camera-name <name>] [--aspect-ratio <ratio>] [--output <file.xml>] [--help] [-h]" << std::endl
+            << std::endl;
   std::cout << "Description" << std::endl
             << "  <configuration file>.cfg  Configuration file. See example in" << std::endl
             << "    \"default-chessboard.cfg\" or in \"default-circles.cfg\"." << std::endl
-            << "    Default: \"default.cfg\"." << std::endl << std::endl
+            << "    Default: \"default.cfg\"." << std::endl
+            << std::endl
             << "  --init-from-xml <camera-init.xml>  XML file that contains camera parameters" << std::endl
-            << "    used to initialize the calibration process." << std::endl << std::endl
+            << "    used to initialize the calibration process." << std::endl
+            << std::endl
             << "  --camera-name <name>  Camera name in the XML file set using \"--init-from-xml\" option." << std::endl
-            << "    Default: \"Camera\"." << std::endl << std::endl
+            << "    Default: \"Camera\"." << std::endl
+            << std::endl
             << "  --aspect-ratio <ratio>  Pixel aspect ratio. " << std::endl
             << "    To estimate px = py, use \"--aspect-ratio 1\" option. Set to -1" << std::endl
             << "    to unset any constraint for px and py parameters. " << std::endl
-            << "    Default: -1." << std::endl << std::endl
+            << "    Default: -1." << std::endl
+            << std::endl
             << "  --output <file.xml>  XML file containing estimated camera parameters." << std::endl
-            << "    Default: \"camera.xml\"." << std::endl << std::endl
-            << "  --help, -h  Print this helper message." << std::endl << std::endl;
+            << "    Default: \"camera.xml\"." << std::endl
+            << std::endl
+            << "  --help, -h  Print this helper message." << std::endl
+            << std::endl;
   if (error) {
     std::cout << "Error" << std::endl
-              << "  " << "Unsupported parameter " << argv[error] << std::endl;
+              << "  "
+              << "Unsupported parameter " << argv[error] << std::endl;
   }
 }
 
@@ -108,27 +113,22 @@ int main(int argc, const char *argv[])
     double opt_aspect_ratio = -1; // Not used
 
     for (int i = 2; i < argc; i++) {
-      if (std::string(argv[i]) == "--init-from-xml" && i+1 < argc) {
+      if (std::string(argv[i]) == "--init-from-xml" && i + 1 < argc) {
         opt_init_camera_xml_file = std::string(argv[i + 1]);
-        i ++;
-      }
-      else if (std::string(argv[i]) == "--camera-name" && i+1 < argc) {
+        i++;
+      } else if (std::string(argv[i]) == "--camera-name" && i + 1 < argc) {
         opt_camera_name = std::string(argv[i + 1]);
-        i ++;
-      }
-      else if (std::string(argv[i]) == "--output" && i+1 < argc) {
+        i++;
+      } else if (std::string(argv[i]) == "--output" && i + 1 < argc) {
         opt_output_file_name = std::string(argv[i + 1]);
-        i ++;
-      }
-      else if (std::string(argv[i]) == "--aspect-ratio" && i+1 < argc) {
+        i++;
+      } else if (std::string(argv[i]) == "--aspect-ratio" && i + 1 < argc) {
         opt_aspect_ratio = std::atof(argv[i + 1]);
-        i ++;
-      }
-      else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
+        i++;
+      } else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
         usage(argv, 0);
         return EXIT_SUCCESS;
-      }
-      else {
+      } else {
         usage(argv, i);
         return EXIT_FAILURE;
       }
@@ -174,13 +174,13 @@ int main(int argc, const char *argv[])
       return EXIT_FAILURE;
     }
 
-#ifdef VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     vpDisplayX d(I, vpDisplay::SCALE_AUTO);
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI d(I, vpDisplay::SCALE_AUTO);
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK d(I, vpDisplay::SCALE_AUTO);
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV d(I, vpDisplay::SCALE_AUTO);
 #endif
 
@@ -235,7 +235,7 @@ int main(int argc, const char *argv[])
       reader.acquire(I);
       long frame_index = reader.getFrameIndex();
       char filename[FILENAME_MAX];
-      sprintf(filename, s.input.c_str(), frame_index);
+      snprintf(filename, FILENAME_MAX, s.input.c_str(), frame_index);
       std::string frame_name = vpIoTools::getName(filename);
       vpDisplay::display(I);
       vpDisplay::flush(I);
@@ -319,19 +319,53 @@ int main(int argc, const char *argv[])
     // Calibrate by a non linear method based on virtual visual servoing
     if (calibrator.empty()) {
       std::cerr << "Unable to calibrate. Image processing failed !" << std::endl;
-      return 0;
+      return EXIT_FAILURE;
     }
 
     // Display calibration pattern occupancy
     drawCalibrationOccupancy(I, calib_info, s.boardSize.width);
-    vpDisplay::setTitle(I, "Calibration pattern occupancy");
-    vpDisplay::display(I);
-    vpDisplay::displayText(I, 15 * vpDisplay::getDownScalingFactor(I), 15 * vpDisplay::getDownScalingFactor(I),
-                           "Calibration pattern occupancy in the image", vpColor::red);
-    vpDisplay::displayText(I, I.getHeight() - 15 * vpDisplay::getDownScalingFactor(I),
-                           15 * vpDisplay::getDownScalingFactor(I), "Click to continue...", vpColor::red);
-    vpDisplay::flush(I);
-    vpDisplay::getClick(I);
+
+    cv::Mat1b img(I.getHeight(), I.getWidth());
+    vpImageConvert::convert(I, img);
+    cv::Mat3b imgColor(I.getHeight(), I.getWidth());
+    cv::applyColorMap(img, imgColor, cv::COLORMAP_JET);
+
+    // Draw calibration board corners
+    for (size_t idx1 = 0; idx1 < calib_info.size(); idx1++) {
+      const CalibInfo &calib = calib_info[idx1];
+
+      for (size_t idx2 = 0; idx2 < calib.m_imPts.size(); idx2++) {
+        const vpImagePoint &imPt = calib.m_imPts[idx2];
+        cv::rectangle(imgColor,
+                      cv::Rect(static_cast<int>(imPt.get_u() - 2), static_cast<int>(imPt.get_v() - 2),
+                               4 * vpDisplay::getDownScalingFactor(I), 4 * vpDisplay::getDownScalingFactor(I)),
+                      cv::Scalar(0, 0, 0), -1);
+      }
+    }
+
+    vpImage<vpRGBa> I_color;
+    vpImageConvert::convert(imgColor, I_color);
+    d.close(I);
+    d.init(I_color, 0, 0, "Calibration pattern occupancy");
+
+    vpDisplay::display(I_color);
+    vpDisplay::displayText(I_color, 15 * vpDisplay::getDownScalingFactor(I_color),
+                           15 * vpDisplay::getDownScalingFactor(I_color), "Calibration pattern occupancy in the image",
+                           vpColor::red);
+
+    if (s.tempo > 10.f) {
+      vpDisplay::displayText(I_color, I_color.getHeight() - 20 * vpDisplay::getDownScalingFactor(I_color),
+                            15 * vpDisplay::getDownScalingFactor(I_color), "Click to continue...", vpColor::red);
+      vpDisplay::flush(I_color);
+      vpDisplay::getClick(I_color);
+    }
+    else {
+      vpDisplay::flush(I_color);
+      vpTime::wait(s.tempo * 1000);
+    }
+
+    d.close(I_color);
+    d.init(I);
 
     std::stringstream ss_additional_info;
     ss_additional_info << "<date>" << vpTime::getDateTime() << "</date>";
@@ -363,7 +397,7 @@ int main(int argc, const char *argv[])
     if (vpCalibration::computeCalibrationMulti(vpCalibration::CALIB_VIRTUAL_VS, calibrator, cam, error, false) ==
         EXIT_SUCCESS) {
       std::cout << cam << std::endl;
-      vpDisplay::setTitle(I, "Without distorsion results");
+      vpDisplay::setTitle(I, "Without distortion results");
 
       for (size_t i = 0; i < calibrator.size(); i++) {
         double reproj_error = sqrt(calibrator[i].getResidual() / calibrator[i].get_npt());
@@ -394,10 +428,16 @@ int main(int argc, const char *argv[])
           vpDisplay::displayCross(I, imPt, 12 * vpDisplay::getDownScalingFactor(I), vpColor::green);
         }
 
-        vpDisplay::displayText(I, I.getHeight() - 15 * vpDisplay::getDownScalingFactor(I),
+        if (s.tempo > 10.f) {
+          vpDisplay::displayText(I, I.getHeight() - 20 * vpDisplay::getDownScalingFactor(I),
                                15 * vpDisplay::getDownScalingFactor(I), "Click to continue...", vpColor::red);
-        vpDisplay::flush(I);
-        vpDisplay::getClick(I);
+          vpDisplay::flush(I);
+          vpDisplay::getClick(I);
+        }
+        else {
+          vpDisplay::flush(I);
+          vpTime::wait(s.tempo * 1000);
+        }
       }
 
       std::cout << "\nGlobal reprojection error: " << error << std::endl;
@@ -427,7 +467,7 @@ int main(int argc, const char *argv[])
     if (vpCalibration::computeCalibrationMulti(vpCalibration::CALIB_VIRTUAL_VS_DIST, calibrator, cam, error, false) ==
         EXIT_SUCCESS) {
       std::cout << cam << std::endl;
-      vpDisplay::setTitle(I, "With distorsion results");
+      vpDisplay::setTitle(I, "With distortion results");
 
       for (size_t i = 0; i < calibrator.size(); i++) {
         double reproj_error = sqrt(calibrator[i].getResidual_dist() / calibrator[i].get_npt());
@@ -458,32 +498,26 @@ int main(int argc, const char *argv[])
           vpDisplay::displayCross(I, imPt, 12 * vpDisplay::getDownScalingFactor(I), vpColor::green);
         }
 
-        vpDisplay::displayText(I, I.getHeight() - 15 * vpDisplay::getDownScalingFactor(I),
+        if (s.tempo > 10.f) {
+          vpDisplay::displayText(I, I.getHeight() - 20 * vpDisplay::getDownScalingFactor(I),
                                15 * vpDisplay::getDownScalingFactor(I), "Click to continue...", vpColor::red);
-        vpDisplay::flush(I);
-        vpDisplay::getClick(I);
+          vpDisplay::flush(I);
+          vpDisplay::getClick(I);
+        }
+        else {
+          vpDisplay::flush(I);
+          vpTime::wait(s.tempo * 1000);
+        }
       }
 
       std::cout << "\nGlobal reprojection error: " << error << std::endl;
       ss_additional_info << "<with_distortion>" << error << "</with_distortion></global_reprojection_error>";
 
-      vpImage<unsigned char> I_undist = I;
-#ifdef VISP_HAVE_X11
-      vpDisplayX d_undist(I_undist, I.getWidth() / vpDisplay::getDownScalingFactor(I) + 100, 0, "Undistorted image",
-                          vpDisplay::SCALE_AUTO);
-#elif defined VISP_HAVE_GDI
-      vpDisplayGDI d_undist(I_undist, I.getWidth() / vpDisplay::getDownScalingFactor(I) + 100, 0, "Undistorted image",
-                            vpDisplay::SCALE_AUTO);
-#elif defined VISP_HAVE_GTK
-      vpDisplayGTK d_undist(I_undist, I.getWidth() / vpDisplay::getDownScalingFactor(I) + 100, 0, "Undistorted image",
-                            vpDisplay::SCALE_AUTO);
-#elif defined VISP_HAVE_OPENCV
-      vpDisplayOpenCV d_undist(I_undist, I.getWidth() / vpDisplay::getDownScalingFactor(I) + 100, 0,
-                               "Undistorted image", vpDisplay::SCALE_AUTO);
-#endif
+      vpImage<unsigned char> I_undist;
+      vpImage<unsigned char> I_dist_undist(I.getHeight(), 2 * I.getWidth());
+      d.close(I);
+      d.init(I_dist_undist, 0, 0, "Straight lines have to be straight - distorted image / undistorted image");
 
-      vpDisplay::setTitle(I, "Straight lines have to be straight (distorted image)");
-      vpDisplay::setTitle(I_undist, "Straight lines have to be straight (undistorted image)");
       for (size_t idx = 0; idx < calib_info.size(); idx++) {
         std::cout << "\nThis tool computes the line fitting error (mean distance error) on image points extracted from "
                      "the raw distorted image."
@@ -492,12 +526,15 @@ int main(int argc, const char *argv[])
         I = calib_info[idx].m_img;
         vpImageTools::undistort(I, cam, I_undist);
 
-        vpDisplay::display(I);
-        vpDisplay::display(I_undist);
+        I_dist_undist.insert(I, vpImagePoint(0, 0));
+        I_dist_undist.insert(I_undist, vpImagePoint(0, I.getWidth()));
+        vpDisplay::display(I_dist_undist);
 
-        vpDisplay::displayText(I, 15 * vpDisplay::getDownScalingFactor(I), 15 * vpDisplay::getDownScalingFactor(I),
-                               calib_info[idx].m_frame_name, vpColor::red);
-        vpDisplay::displayText(I, 30 * vpDisplay::getDownScalingFactor(I), 15 * vpDisplay::getDownScalingFactor(I),
+        vpDisplay::displayText(I_dist_undist, 15 * vpDisplay::getDownScalingFactor(I_dist_undist),
+                               15 * vpDisplay::getDownScalingFactor(I_dist_undist),
+                               calib_info[idx].m_frame_name + std::string(" distorted"), vpColor::red);
+        vpDisplay::displayText(I_dist_undist, 30 * vpDisplay::getDownScalingFactor(I_dist_undist),
+                               15 * vpDisplay::getDownScalingFactor(I_dist_undist),
                                "Draw lines from first / last points.", vpColor::red);
         std::vector<vpImagePoint> grid_points = calib_info[idx].m_imPts;
         for (int i = 0; i < s.boardSize.height; i++) {
@@ -514,7 +551,7 @@ int main(int argc, const char *argv[])
 
           vpImagePoint ip1 = current_line.front();
           vpImagePoint ip2 = current_line.back();
-          vpDisplay::displayLine(I, ip1, ip2, vpColor::red);
+          vpDisplay::displayLine(I_dist_undist, ip1, ip2, vpColor::red);
         }
 
         std::cout << "\nThis tool computes the line fitting error (mean distance error) on image points extracted from "
@@ -532,12 +569,9 @@ int main(int argc, const char *argv[])
             grid_points.push_back(ip);
           }
 
-          vpDisplay::displayText(I_undist, 15 * vpDisplay::getDownScalingFactor(I_undist),
-                                 15 * vpDisplay::getDownScalingFactor(I_undist),
+          vpDisplay::displayText(I_dist_undist, 15 * vpDisplay::getDownScalingFactor(I_dist_undist),
+                                 I.getWidth() + 15 * vpDisplay::getDownScalingFactor(I_dist_undist),
                                  calib_info[idx].m_frame_name + std::string(" undistorted"), vpColor::red);
-          vpDisplay::displayText(I_undist, 30 * vpDisplay::getDownScalingFactor(I_undist),
-                                 15 * vpDisplay::getDownScalingFactor(I_undist), "Draw lines from first / last points.",
-                                 vpColor::red);
           for (int i = 0; i < s.boardSize.height; i++) {
             std::vector<vpImagePoint> current_line(grid_points.begin() + i * s.boardSize.width,
                                                    grid_points.begin() + (i + 1) * s.boardSize.width);
@@ -547,26 +581,32 @@ int main(int argc, const char *argv[])
             std::cout << calib_info[idx].m_frame_name << " undistorted image, line " << i + 1
                       << " fitting error: " << line_fitting_error << std::endl;
 
-            vpImagePoint ip1 = current_line.front();
-            vpImagePoint ip2 = current_line.back();
-            vpDisplay::displayLine(I_undist, ip1, ip2, vpColor::red);
+            vpImagePoint ip1 = current_line.front() + vpImagePoint(0, I.getWidth());
+            vpImagePoint ip2 = current_line.back() + vpImagePoint(0, I.getWidth());
+            vpDisplay::displayLine(I_dist_undist, ip1, ip2, vpColor::red);
           }
         } else {
           std::string msg("Unable to detect grid on undistorted image");
           std::cout << msg << std::endl;
           std::cout << "Check that the grid is not too close to the image edges" << std::endl;
-          vpDisplay::displayText(I_undist, 15 * vpDisplay::getDownScalingFactor(I_undist),
-                                 15 * vpDisplay::getDownScalingFactor(I_undist),
+          vpDisplay::displayText(I_dist_undist, 15 * vpDisplay::getDownScalingFactor(I_dist_undist),
+                                 15 * vpDisplay::getDownScalingFactor(I_dist_undist),
                                  calib_info[idx].m_frame_name + std::string(" undistorted"), vpColor::red);
-          vpDisplay::displayText(I_undist, 30 * vpDisplay::getDownScalingFactor(I_undist),
-                                 15 * vpDisplay::getDownScalingFactor(I_undist), msg, vpColor::red);
+          vpDisplay::displayText(I_dist_undist, 30 * vpDisplay::getDownScalingFactor(I_dist_undist),
+                                 15 * vpDisplay::getDownScalingFactor(I_dist_undist), msg, vpColor::red);
         }
 
-        vpDisplay::displayText(I, I.getHeight() - 15 * vpDisplay::getDownScalingFactor(I),
-                               15 * vpDisplay::getDownScalingFactor(I), "Click to continue...", vpColor::red);
-        vpDisplay::flush(I);
-        vpDisplay::flush(I_undist);
-        vpDisplay::getClick(I);
+        if (s.tempo > 10.f) {
+          vpDisplay::displayText(
+              I_dist_undist, I_dist_undist.getHeight() - 20 * vpDisplay::getDownScalingFactor(I_dist_undist),
+              15 * vpDisplay::getDownScalingFactor(I_dist_undist), "Click to continue...", vpColor::red);
+          vpDisplay::flush(I_dist_undist);
+          vpDisplay::getClick(I_dist_undist);
+        }
+        else {
+          vpDisplay::flush(I_dist_undist);
+          vpTime::wait(s.tempo * 1000);
+        }
       }
 
       std::cout << std::endl;
@@ -607,6 +647,7 @@ int main(int argc, const char *argv[])
       return EXIT_FAILURE;
     }
 
+    std::cout << "\nCamera calibration succeeded. Results are savec in " << "\"" << opt_output_file_name << "\"" << std::endl;
     return EXIT_SUCCESS;
   } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
