@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * Simulation of a visual servoing with visualization.
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file simulateCircle2DCamVelocity.cpp
@@ -85,7 +81,8 @@ void usage(const char *name, const char *badparam, std::string ipath)
 Simulation Servo Circle\n\
           \n\
 SYNOPSIS\n\
-  %s [-i <input image path>] [-d] [-h]\n", name);
+  %s [-i <input image path>] [-d] [-h]\n",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
@@ -103,7 +100,8 @@ OPTIONS:                                               Default\n\
      using the task manager under Windows.\n\
                   \n\
   -h\n\
-     Print the help.\n\n", ipath.c_str());
+     Print the help.\n\n",
+          ipath.c_str());
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
@@ -267,10 +265,10 @@ static void *mainLoop(void *_simu)
 
       if (SAVE == 1) {
         char name[FILENAME_MAX];
-        sprintf(name, "/tmp/image.%04d.external.png", it);
+        snprintf(name, FILENAME_MAX, "/tmp/image.%04d.external.png", it);
         std::cout << "Save " << name << std::endl;
         simu->write(name);
-        sprintf(name, "/tmp/image.%04u.internal.png", iter);
+        snprintf(name, FILENAME_MAX, "/tmp/image.%04u.internal.png", iter);
         std::cout << "Save " << name << std::endl;
         simu->write(name);
         it++;
@@ -307,7 +305,7 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, opt_ipath, opt_display) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Get the option values
@@ -333,7 +331,7 @@ int main(int argc, const char **argv)
                 << "  environment variable to specify the location of the " << std::endl
                 << "  image path where test images are located." << std::endl
                 << std::endl;
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     vpCameraParameters cam;
@@ -371,7 +369,9 @@ int main()
 {
   std::cout << "You do not have Coin3D and SoQT or SoWin or SoXt functionalities enabled..." << std::endl;
   std::cout << "Tip:" << std::endl;
-  std::cout << "- Install Coin3D and SoQT or SoWin or SoXt, configure ViSP again using cmake and build again this example" << std::endl;
+  std::cout
+      << "- Install Coin3D and SoQT or SoWin or SoXt, configure ViSP again using cmake and build again this example"
+      << std::endl;
   return EXIT_SUCCESS;
 }
 #endif
