@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,16 +31,12 @@
  * Description:
  * Windows' D3D Display Test
  *
- * Authors:
- * Bruno Renier
- * Anthony Saunier
- *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \file displayD3D.cpp
 
   \brief Read an image on the disk, display it using vpDisplayD3D class,
-  display some features (line, circle, caracters) in overlay and finaly write
+  display some features (line, circle, characters) in overlay and finally write
   the image and the overlayed features in an image on the disk.
 
 */
@@ -62,7 +58,7 @@
   \example displayD3D.cpp
 
   Read an image on the disk, display it using vpDisplayGDI class, display some
-  features (line, circle, caracters) in overlay and finaly write the image and
+  features (line, circle, characters) in overlay and finally write the image and
   the overlayed features in an image on the disk.
 
 */
@@ -87,13 +83,14 @@ void usage(const char *name, const char *badparam, std::string ipath, std::strin
 {
   fprintf(stdout, "\n\
 Read an image on the disk, display it using D3D, display some\n\
-features (line, circle, caracters) in overlay and finaly write \n\
+features (line, circle, characters) in overlay and finally write \n\
 the image and the overlayed features in an image on the disk\n\
 \n\
 SYNOPSIS\n\
   %s [-i <input image path>] [-o <output image path>]\n\
-     [-c] [-d] [-h]\n						      \
-", name);
+     [-c] [-d] [-h]\n \
+",
+name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
@@ -113,7 +110,7 @@ OPTIONS:                                               Default\n\
 \n\
   -c\n\
      Disable the mouse click. Useful to automate the \n\
-     execution of this program without humain intervention.\n\
+     execution of this program without human intervention.\n\
 \n\
   -d                                             \n\
      Disable the image display. This can be useful \n\
@@ -121,7 +118,8 @@ OPTIONS:                                               Default\n\
      Windows.\n\
 \n\
   -h\n\
-     Print the help.\n\n", ipath.c_str(), opath.c_str(), user.c_str());
+     Print the help.\n\n",
+          ipath.c_str(), opath.c_str(), user.c_str());
   if (badparam) {
     fprintf(stderr, "ERROR: \n");
     fprintf(stderr, "\nBad parameter [%s]\n", badparam);
@@ -215,7 +213,7 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, opt_ipath, opt_opath, opt_click_allowed, username, opt_display) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Get the option values
@@ -232,12 +230,13 @@ int main(int argc, const char **argv)
       try {
         // Create the dirname
         vpIoTools::makeDirectory(odirname);
-      } catch (...) {
+      }
+      catch (...) {
         usage(argv[0], NULL, ipath, opath, username);
         std::cerr << std::endl << "ERROR:" << std::endl;
         std::cerr << "  Cannot create " << odirname << std::endl;
         std::cerr << "  Check your -o " << opath << " option " << std::endl;
-        exit(-1);
+        return EXIT_FAILURE;
       }
     }
 
@@ -247,8 +246,8 @@ int main(int argc, const char **argv)
       if (ipath != env_ipath) {
         std::cout << std::endl << "WARNING: " << std::endl;
         std::cout << "  Since -i <visp image path=" << ipath << "> "
-                  << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
-                  << "  we skip the environment variable." << std::endl;
+          << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
+          << "  we skip the environment variable." << std::endl;
       }
     }
 
@@ -257,10 +256,10 @@ int main(int argc, const char **argv)
       usage(argv[0], NULL, ipath, opath, username);
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH " << std::endl
-                << "  environment variable to specify the location of the " << std::endl
-                << "  image path where test images are located." << std::endl
-                << std::endl;
-      exit(-1);
+        << "  environment variable to specify the location of the " << std::endl
+        << "  image path where test images are located." << std::endl
+        << std::endl;
+      return EXIT_FAILURE;
     }
 
     // Create a grey level image
@@ -398,7 +397,8 @@ int main(int argc, const char **argv)
         // Display a red cross on the click pixel position
         std::cout << "Cross position: " << ip << std::endl;
         vpDisplay::displayCross(Irgba, ip, 15, vpColor::red);
-      } else {
+      }
+      else {
         ip.set_i(10);
         ip.set_j(20);
         // Display a red cross at position i, j (i correspond to the row
@@ -428,7 +428,8 @@ int main(int argc, const char **argv)
       }
     }
     return EXIT_SUCCESS;
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return EXIT_FAILURE;
   }
