@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,12 +31,7 @@
  * Description:
  * Read an image sequence from the disk and display it.
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- * Anthony Saunier
- *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \file displaySequence.cpp
 
@@ -59,11 +54,9 @@
 
 #include <visp3/core/vpImage.h>
 #include <visp3/io/vpImageIo.h>
-
 #include <visp3/gui/vpDisplayGDI.h>
 #include <visp3/gui/vpDisplayGTK.h>
 #include <visp3/gui/vpDisplayX.h>
-
 #include <visp3/core/vpTime.h>
 
 /*!
@@ -77,12 +70,7 @@
 */
 
 // List of allowed command line options
-#define GETOPTARGS "di:p:hf:n:s:w"
-
-void usage(const char *name, const char *badparam, std::string ipath, std::string ppath, unsigned first,
-           unsigned nimages, unsigned step);
-bool getOptions(int argc, const char **argv, std::string &ipath, std::string &ppath, unsigned &first, unsigned &nimages,
-                unsigned &step, bool &display, bool &wait);
+#define GETOPTARGS "di:p:hf:l:s:w"
 
 /*!
 
@@ -93,13 +81,18 @@ bool getOptions(int argc, const char **argv, std::string &ipath, std::string &pp
   \param ipath : Input image path.
   \param ppath : Personal image path.
   \param first : First image.
-  \param nimages : Number of images to manipulate.
+  \param last : Last image.
   \param step : Step between two images.
 
  */
 void usage(const char *name, const char *badparam, std::string ipath, std::string ppath, unsigned first,
-           unsigned nimages, unsigned step)
+           unsigned last, unsigned step)
 {
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+  std::string ext("png");
+#else
+  std::string ext("pgm");
+#endif
   fprintf(stdout, "\n\
 Read an image sequence from the disk and display it.\n\
 The sequence is made of separate images. Each image corresponds\n\
@@ -107,15 +100,14 @@ to a PGM file.\n\
 \n\
 SYNOPSIS\n\
   %s [-i <test image path>] [-p <personal image path>]\n\
-     [-f <first image>] [-n <number of images>] [-s <step>] \n\
-     [-w] [-d] [-h]\n						      \
- ", name);
+     [-f <first image>] [-l <last image>] [-s <step>] \n\
+     [-w] [-d] [-h]\n", name);
 
   fprintf(stdout, "\n\
  OPTIONS:                                               Default\n\
   -i <test image path>                                %s\n\
      Set image input path.\n\
-     From this path read \"cube/image.%%04d.pgm\"\n\
+     From this path read \"cube/image.%%04d.%s\"\n\
      images. These images come from ViSP-images-x.y.z.tar.gz\n\
      available on the ViSP website.\n\
      Setting the VISP_INPUT_IMAGE_PATH environment\n\
@@ -126,17 +118,15 @@ SYNOPSIS\n\
      Specify a personal sequence containing images \n\
      to process.\n\
      By image sequence, we mean one file per image.\n\
-     The following image file formats PNM (PGM P5, PPM P6)\n\
-     are supported. The format is selected by analysing \n\
-     the filename extension.\n\
-     Example : \"/Temp/ViSP-images/cube/image.%%04d.pgm\"\n\
+     The format is selected by analysing the filename extension.\n\
+     Example : \"/Temp/visp-images/cube/image.%%04d.%s\"\n\
      %%04d is for the image numbering.\n\
  \n\
   -f <first image>                                     %u\n\
      First image number of the sequence.\n\
  \n\
-  -n <number of images>                                %u\n\
-     Number of images to load from the sequence.\n\
+  -l <last image>                                      %u\n\
+     last image number of the sequence.\n\
  \n\
   -s <step>                                            %u\n\
      Step between two images.\n\
@@ -152,7 +142,8 @@ SYNOPSIS\n\
      this option is without effect.\n\
 \n\
   -h\n\
-     Print the help.\n\n", ipath.c_str(), ppath.c_str(), first, nimages, step);
+     Print the help.\n\n",
+          ipath.c_str(), ext.c_str(), ppath.c_str(), ext.c_str(), first, last, step);
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
@@ -166,7 +157,7 @@ SYNOPSIS\n\
   \param ipath : Input image path.
   \param ppath : Personal image path.
   \param first : First image.
-  \param nimages : Number of images to display.
+  \param last : Last image.
   \param step : Step between two images.
   \param display : Set as true, activates the image display. This is
   the default configuration. When set to false, the display is
@@ -178,7 +169,7 @@ SYNOPSIS\n\
   \return false if the program has to be stopped, true otherwise.
 
 */
-bool getOptions(int argc, const char **argv, std::string &ipath, std::string &ppath, unsigned &first, unsigned &nimages,
+bool getOptions(int argc, const char **argv, std::string &ipath, std::string &ppath, unsigned &first, unsigned &last,
                 unsigned &step, bool &display, bool &wait)
 {
   const char *optarg_;
@@ -198,8 +189,8 @@ bool getOptions(int argc, const char **argv, std::string &ipath, std::string &pp
     case 'f':
       first = (unsigned)atoi(optarg_);
       break;
-    case 'n':
-      nimages = (unsigned)atoi(optarg_);
+    case 'l':
+      last = (unsigned)atoi(optarg_);
       break;
     case 's':
       step = (unsigned)atoi(optarg_);
@@ -208,12 +199,12 @@ bool getOptions(int argc, const char **argv, std::string &ipath, std::string &pp
       wait = true;
       break;
     case 'h':
-      usage(argv[0], NULL, ipath, ppath, first, nimages, step);
+      usage(argv[0], NULL, ipath, ppath, first, last, step);
       return false;
       break;
 
     default:
-      usage(argv[0], optarg_, ipath, ppath, first, nimages, step);
+      usage(argv[0], optarg_, ipath, ppath, first, last, step);
       return false;
       break;
     }
@@ -221,7 +212,7 @@ bool getOptions(int argc, const char **argv, std::string &ipath, std::string &pp
 
   if ((c == 1) || (c == -1)) {
     // standalone param or error
-    usage(argv[0], NULL, ipath, ppath, first, nimages, step);
+    usage(argv[0], NULL, ipath, ppath, first, last, step);
     std::cerr << "ERROR: " << std::endl;
     std::cerr << "  Bad argument " << optarg_ << std::endl << std::endl;
     return false;
@@ -240,11 +231,17 @@ int main(int argc, const char **argv)
     std::string dirname;
     std::string filename;
     unsigned opt_first = 0;
-    unsigned opt_nimages = 80;
+    unsigned opt_last = 80;
     unsigned opt_step = 1;
     bool opt_display = true;
     bool opt_wait = false;
 
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+    std::string ext("png");
+#else
+    std::string ext("pgm");
+#endif
+
     // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH
     // environment variable value
     env_ipath = vpIoTools::getViSPImagesDataPath();
@@ -254,9 +251,9 @@ int main(int argc, const char **argv)
       ipath = env_ipath;
 
     // Read the command line options
-    if (getOptions(argc, argv, opt_ipath, opt_ppath, opt_first, opt_nimages, opt_step, opt_display, opt_wait) ==
+    if (getOptions(argc, argv, opt_ipath, opt_ppath, opt_first, opt_last, opt_step, opt_display, opt_wait) ==
         false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     if (!opt_display)
@@ -279,7 +276,7 @@ int main(int argc, const char **argv)
 
     // Test if an input path is set
     if (opt_ipath.empty() && env_ipath.empty() && opt_ppath.empty()) {
-      usage(argv[0], NULL, ipath, opt_ppath, opt_first, opt_nimages, opt_step);
+      usage(argv[0], NULL, ipath, opt_ppath, opt_first, opt_last, opt_step);
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH " << std::endl
                 << "  environment variable to specify the location of the " << std::endl
@@ -288,7 +285,7 @@ int main(int argc, const char **argv)
                 << "  use personal images." << std::endl
                 << std::endl;
 
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Declare an image, this is a gray level image (unsigned char)
@@ -301,57 +298,35 @@ int main(int argc, const char **argv)
     char cfilename[FILENAME_MAX];
 
     if (opt_ppath.empty()) {
-
-      // Warning :
-      // the image sequence is not provided with the ViSP package
-      // therefore the program will return you an error :
-      //  !!    vpImageIoPnm.cpp: readPGM(#210) :couldn't read file
-      //        ViSP-images/cube/image.0001.pgm
-      //  !!    vpDotExample.cpp: main(#95) :Error while reading the image
-      //  terminate called after throwing an instance of 'vpImageException'
-      //
-      //  The sequence is available on the visp www site
-      //  https://visp.inria.fr/download/
-      //  in the download section. It is named "ViSP-images.tar.gz"
-
-      // Set the path location of the image sequence
+      // Warning : the daset is available https://visp.inria.fr/download/
       dirname = vpIoTools::createFilePath(ipath, "cube");
 
       // Build the name of the image file
 
       s.setf(std::ios::right, std::ios::adjustfield);
-      s << "image." << std::setw(4) << std::setfill('0') << iter << ".pgm";
+      s << "image." << std::setw(4) << std::setfill('0') << iter << "." << ext;
       filename = vpIoTools::createFilePath(dirname, s.str());
     } else {
-      sprintf(cfilename, opt_ppath.c_str(), iter);
+      snprintf(cfilename, FILENAME_MAX, opt_ppath.c_str(), iter);
       filename = cfilename;
     }
-    // Read the PGM image named "filename" on the disk, and put the
-    // bitmap into the image structure I.  I is initialized to the
-    // correct size
-    //
-    // exception readPGM may throw various exception if, for example,
-    // the file does not exist, or if the memory cannot be allocated
+    // Read image named "filename" and put the bitmap in I
     try {
       vpImageIo::read(I, filename);
     } catch (...) {
-      // an exception is throwned if an exception from readPGM has been
-      // catched here this will result in the end of the program Note that
-      // another error message has been printed from readPGM to give more
-      // information about the error
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Cannot read " << filename << std::endl;
       std::cerr << "  Check your -i " << ipath << " option, " << std::endl
                 << "  or your -p " << opt_ppath << " option " << std::endl
                 << "  or VISP_INPUT_IMAGE_PATH environment variable" << std::endl;
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
-#if defined VISP_HAVE_GTK
+#if defined(VISP_HAVE_GTK)
     vpDisplayGTK display;
-#elif defined VISP_HAVE_X11
+#elif defined(VISP_HAVE_X11)
     vpDisplayX display;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display;
 #endif
     if (opt_display) {
@@ -363,26 +338,23 @@ int main(int argc, const char **argv)
       // Display the image
       // The image class has a member that specify a pointer toward
       // the display that has been initialized in the display declaration
-      // therefore is is no longuer necessary to make a reference to the
+      // therefore is is no longer necessary to make a reference to the
       // display variable.
       vpDisplay::display(I);
       vpDisplay::flush(I);
     }
 
-    //  double tms_1 = vpTime::measureTimeMs() ;
-    unsigned niter = 0;
     // this is the loop over the image sequence
-    while (iter < opt_first + opt_nimages * opt_step) {
+    while (iter < opt_last) {
       double tms = vpTime::measureTimeMs();
 
       // set the new image name
-
       if (opt_ppath.empty()) {
         s.str("");
-        s << "image." << std::setw(4) << std::setfill('0') << iter << ".pgm";
+        s << "image." << std::setw(4) << std::setfill('0') << iter << "." << ext;
         filename = vpIoTools::createFilePath(dirname, s.str());
       } else {
-        sprintf(cfilename, opt_ppath.c_str(), iter);
+        snprintf(cfilename, FILENAME_MAX, opt_ppath.c_str(), iter);
         filename = cfilename;
       }
 
@@ -403,7 +375,6 @@ int main(int argc, const char **argv)
         // Synchronise the loop to 40 ms
         vpTime::wait(tms, 40);
       }
-      niter++;
 
       iter += opt_step;
     }
@@ -417,8 +388,10 @@ int main(int argc, const char **argv)
   }
 }
 #else
-int main() {
-  std::cout << "You do not have X11, or GDI (Graphical Device Interface), or GTK functionalities to display images..." << std::endl;
+int main()
+{
+  std::cout << "You do not have X11, or GDI (Graphical Device Interface), or GTK functionalities to display images..."
+            << std::endl;
   std::cout << "Tip if you are on a unix-like system:" << std::endl;
   std::cout << "- Install X11, configure again ViSP using cmake and build again this example" << std::endl;
   std::cout << "Tip if you are on a windows-like system:" << std::endl;
