@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -32,12 +32,7 @@
  * Acquire images using DirectShow (under Windows only) and display it
  * using GTK or GDI.
  *
- * Authors:
- * Bruno Renier
- * Fabien Spindler
- * Anthony Saunier
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpConfig.h>
 #include <visp3/core/vpDebug.h>
@@ -49,10 +44,9 @@
 
 */
 
-#include <vector>
-
 #include <iostream>
 #include <sstream>
+#include <vector>
 
 #if defined(VISP_HAVE_DIRECTSHOW)
 #if (defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI))
@@ -66,7 +60,6 @@
 #include <visp3/sensor/vpDirectShowGrabber.h>
 
 // List of allowed command line options
-//#define GETOPTARGS	"dhn:o:"
 #define GETOPTARGS "c:df:hmn:io:st:?"
 
 #define GRAB_COLOR
@@ -109,7 +102,8 @@ OPTIONS                                                    Default\n\
 \n\
   -f [%%d] \n\
      Framerate to set for the active camera.\n\
-     You can select the active camera using -c option.\n", name);
+     You can select the active camera using -c option.\n",
+          name);
 
   fprintf(stdout, "\n\
   -c [%%u]                                                    %u\n\
@@ -141,7 +135,8 @@ OPTIONS                                                    Default\n\
 \n\
   -h \n\
      Print the help.\n\
-\n", camera, nframes, opath.c_str());
+\n",
+          camera, nframes, opath.c_str());
 
   exit(0);
 }
@@ -257,9 +252,10 @@ int main(int argc, const char **argv)
     vpImage<unsigned char> *I;
     std::string opath = "C:/temp/I%d-%04d.pgm";
 #endif
-#if defined VISP_HAVE_GDI
+#if defined(VISP_HAVE_GDI)
+
     vpDisplayGDI *d;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK *d;
 #endif
     read_options(argc, argv, multi, camera, nframes, verbose_info, verbose_settings, mediatype_is_set, mediatypeID,
@@ -279,7 +275,7 @@ int main(int argc, const char **argv)
         std::cout << "cameras on the bus." << std::endl;
         g->close();
         delete g;
-        return (0);
+        return EXIT_FAILURE;
       }
     }
     if (camera >= ncameras) {
@@ -289,7 +285,7 @@ int main(int argc, const char **argv)
       std::cout << "Check your -c <camera> command line option." << std::endl;
       g->close();
       delete g;
-      return (0);
+      return EXIT_FAILURE;
     }
     if (multi) {
       camera = 0; // to over write a bad option usage
@@ -380,7 +376,7 @@ int main(int argc, const char **argv)
       if (display)
         delete[] d;
 
-      return 0;
+      return EXIT_SUCCESS;
     }
 
     // Do a first acquisition to initialise the display
@@ -398,9 +394,10 @@ int main(int argc, const char **argv)
 
       if (display) {
         // Initialise the display
-        char title[100];
-        sprintf(title, "Images captured by camera %u", c);
-        d[i].init(I[i], 100 + i * 50, 100 + i * 50, title);
+        std::stringstream title;
+        title << "Images captured by camera ";
+        title << c;
+        d[i].init(I[i], 100 + i * 50, 100 + i * 50, title.c_str());
       }
     }
 
@@ -422,7 +419,7 @@ int main(int argc, const char **argv)
         }
         if (save) {
           char buf[FILENAME_MAX];
-          sprintf(buf, opath.c_str(), c, i);
+          snprintf(buf, FILENAME_MAX, opath.c_str(), c, i);
           std::string filename(buf);
           std::cout << "Write: " << filename << std::endl;
           vpImageIo::write(I[c], filename);
@@ -455,7 +452,8 @@ int main(int argc, const char **argv)
 #else  // (defined (VISP_HAVE_GTK) || defined(VISP_HAVE_GDI))
 int main()
 {
-  std::cout << "You do not have GDI (Graphical Device Interface), or GTK functionalities to display images..." << std::endl;
+  std::cout << "You do not have GDI (Graphical Device Interface), or GTK functionalities to display images..."
+            << std::endl;
   std::cout << "Tip if you are on a windows-like system:" << std::endl;
   std::cout << "- Install GDI, configure again ViSP using cmake and build again this example" << std::endl;
   return EXIT_SUCCESS;
