@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * Read an image sequence from the disk and display it.
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <stdlib.h>
 #include <visp3/core/vpConfig.h>
@@ -62,12 +58,7 @@
 */
 
 // List of allowed command line options
-#define GETOPTARGS "b:de:f:i:hn:s:z:"
-
-void usage(const char *name, const char *badparam, std::string ipath, std::string basename, std::string ext, int first,
-           unsigned int nimages, int step, unsigned int nzero);
-bool getOptions(int argc, const char **argv, std::string &ipath, std::string &basename, std::string &ext, int &first,
-                unsigned int &nimages, int &step, unsigned int &nzero, bool &display);
+#define GETOPTARGS "b:de:f:hi:l:s:z:"
 
 /*
 
@@ -79,13 +70,13 @@ bool getOptions(int argc, const char **argv, std::string &ipath, std::string &ba
   \param basename : Input image base name.
   \param ext : Input image extension.
   \param first : First image number to read.
-  \param nimages : Number of images to read.
+  \param last : Number of images to read.
   \param step : Step between two successive images to read.
   \param nzero : Number of zero for the image number coding.
 
  */
-void usage(const char *name, const char *badparam, std::string ipath, std::string basename, std::string ext, int first,
-           unsigned int nimages, int step, unsigned int nzero)
+void usage(const char *name, const char *badparam, std::string ipath, std::string basename, std::string ext, long first,
+           long last, long step, unsigned int nzero)
 {
   fprintf(stdout, "\n\
 Read an image sequence from the disk. Display it using X11 or GTK.\n\
@@ -94,14 +85,15 @@ to a PGM file.\n\
 \n\
 SYNOPSIS\n\
   %s [-i <input image path>] [-b <base name>] [-e <extension>] \n\
-   [-f <first frame>] [-n <number of images> [-s <step>] \n\
-   [-z <number of zero>] [-d] [-h]\n", name);
+   [-f <first frame>] [-l <last image> [-s <step>] \n\
+   [-z <number of zero>] [-d] [-h]\n",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
   -i <input image path>                                     %s\n\
      Set image input path.\n\
-     From this path read \"cube/image.%%04d.pgm\"\n\
+     From this path read \"cube/image.%%04d.%s\"\n\
      images.\n\
      Setting the VISP_INPUT_IMAGE_PATH environment\n\
      variable produces the same behaviour than using\n\
@@ -111,22 +103,20 @@ OPTIONS:                                               Default\n\
      Specify the base name of the files of the sequence\n\
      containing the images to process. \n\
      By image sequence, we mean one file per image.\n\
-     The following image file formats PNM (PGM P5, PPM P6)\n\
-     are supported. The format is selected by analysing \n\
-     the filename extension.\n\
+     The format is selected by analysing the filename extension.\n\
 \n\
   -e <extension>                                            %s\n\
      Specify the extension of the files.\n\
      Not taken into account for the moment. Will be a\n\
      future feature...\n\
 \n\
-  -f <first frame>                                          %d\n\
-     First frame number of the sequence\n\
+  -f <first frame>                                          %ld\n\
+     First frame number of the sequence.\n\
 \n\
-  -n <number of images>                                     %u\n\
-     Number of images to load from the sequence.\n\
+  -l <last image      >                                     %ld\n\
+     Last frame number of the sequence.\n\
 \n\
-  -s <step>                                                 %d\n\
+  -s <step>                                                 %ld\n\
      Step between two images.\n\
 \n\
   -z <number of zero>                                       %u\n\
@@ -136,7 +126,8 @@ OPTIONS:                                               Default\n\
      Turn off the display.\n\
 \n\
   -h \n\
-     Print the help.\n\n", ipath.c_str(), basename.c_str(), ext.c_str(), first, nimages, step, nzero);
+     Print the help.\n\n",
+          ipath.c_str(), ext.c_str(), basename.c_str(), ext.c_str(), first, last, step, nzero);
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
@@ -151,7 +142,7 @@ OPTIONS:                                               Default\n\
   \param basename : Input image base name.
   \param ext : Input image extension.
   \param first : First image number to read.
-  \param nimages : Number of images to read.
+  \param last : Last images to read.
   \param step : Step between two successive images to read.
   \param nzero : Number of zero for the image number coding.
   \param display : Display activation.
@@ -159,8 +150,8 @@ OPTIONS:                                               Default\n\
   \return false if the program has to be stopped, true otherwise.
 
 */
-bool getOptions(int argc, const char **argv, std::string &ipath, std::string &basename, std::string &ext, int &first,
-                unsigned int &nimages, int &step, unsigned int &nzero, bool &display)
+bool getOptions(int argc, const char **argv, std::string &ipath, std::string &basename, std::string &ext, long &first,
+                long &last, long &step, unsigned int &nzero, bool &display)
 {
   const char *optarg_;
   int c;
@@ -177,27 +168,27 @@ bool getOptions(int argc, const char **argv, std::string &ipath, std::string &ba
       ext = optarg_;
       break;
     case 'f':
-      first = atoi(optarg_);
+      first = atol(optarg_);
       break;
     case 'i':
       ipath = optarg_;
       break;
-    case 'n':
-      nimages = (unsigned)atoi(optarg_);
+    case 'l':
+      last = std::atol(optarg_);
       break;
     case 's':
-      step = atoi(optarg_);
+      step = atol(optarg_);
       break;
     case 'z':
       nzero = (unsigned)atoi(optarg_);
       break;
     case 'h':
-      usage(argv[0], NULL, ipath, basename, ext, first, nimages, step, nzero);
+      usage(argv[0], NULL, ipath, basename, ext, first, last, step, nzero);
       return false;
       break;
 
     default:
-      usage(argv[0], optarg_, ipath, basename, ext, first, nimages, step, nzero);
+      usage(argv[0], optarg_, ipath, basename, ext, first, last, step, nzero);
       return false;
       break;
     }
@@ -205,7 +196,7 @@ bool getOptions(int argc, const char **argv, std::string &ipath, std::string &ba
 
   if ((c == 1) || (c == -1)) {
     // standalone param or error
-    usage(argv[0], NULL, ipath, basename, ext, first, nimages, step, nzero);
+    usage(argv[0], NULL, ipath, basename, ext, first, last, step, nzero);
     std::cerr << "ERROR: " << std::endl;
     std::cerr << "  Bad argument " << optarg_ << std::endl << std::endl;
     return false;
@@ -230,12 +221,17 @@ int main(int argc, const char **argv)
     std::string opt_ipath;
     std::string ipath;
     std::string opt_basename = "cube/image.";
-    std::string opt_ext = "pgm";
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+    std::string opt_ext("png");
+#else
+    std::string opt_ext("pgm");
+#endif
+
     bool opt_display = true;
 
-    int opt_first = 5;
-    unsigned int opt_nimages = 70;
-    int opt_step = 1;
+    long opt_first = 5;
+    long opt_last = 70;
+    long opt_step = 1;
     unsigned int opt_nzero = 4;
 
     // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH
@@ -247,9 +243,9 @@ int main(int argc, const char **argv)
       ipath = env_ipath;
 
     // Read the command line options
-    if (getOptions(argc, argv, opt_ipath, opt_basename, opt_ext, opt_first, opt_nimages, opt_step, opt_nzero,
+    if (getOptions(argc, argv, opt_ipath, opt_basename, opt_ext, opt_first, opt_last, opt_step, opt_nzero,
                    opt_display) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Get the option values
@@ -262,20 +258,20 @@ int main(int argc, const char **argv)
       if (ipath != env_ipath) {
         std::cout << std::endl << "WARNING: " << std::endl;
         std::cout << "  Since -i <visp image path=" << ipath << "> "
-                  << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
-                  << "  we skip the environment variable." << std::endl;
+          << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
+          << "  we skip the environment variable." << std::endl;
       }
     }
 
     // Test if an input path is set
     if (opt_ipath.empty() && env_ipath.empty()) {
-      usage(argv[0], NULL, ipath, opt_basename, opt_ext, opt_first, opt_nimages, opt_step, opt_nzero);
+      usage(argv[0], NULL, ipath, opt_basename, opt_ext, opt_first, opt_last, opt_step, opt_nzero);
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH " << std::endl
-                << "  environment variable to specify the location of the " << std::endl
-                << "  image path where test images are located." << std::endl
-                << std::endl;
-      exit(-1);
+        << "  environment variable to specify the location of the " << std::endl
+        << "  image path where test images are located." << std::endl
+        << std::endl;
+      return EXIT_FAILURE;
     }
 
     // Declare an image, this is a gray level image (unsigned char)
@@ -306,8 +302,8 @@ int main(int argc, const char **argv)
 
     std::cout << "Image size: width : " << I.getWidth() << " height: " << I.getHeight() << std::endl;
 
-// We open a window using either X11 or GDI.
-// Its size is automatically defined by the image (I) size
+    // We open a window using either X11 or GDI.
+    // Its size is automatically defined by the image (I) size
 #if defined(VISP_HAVE_X11)
     vpDisplayX display(I);
 #elif defined(VISP_HAVE_GDI)
@@ -322,16 +318,14 @@ int main(int argc, const char **argv)
       // display the image
       // The image class has a member that specify a pointer toward
       // the display that has been initialized in the display declaration
-      // therefore is is no longuer necessary to make a reference to the
+      // therefore is is no longer necessary to make a reference to the
       // display variable.
       vpDisplay::display(I);
       vpDisplay::flush(I);
     }
 
-    unsigned cpt = 1;
     // this is the loop over the image sequence
-
-    while (cpt++ < opt_nimages) {
+    while (g.getImageNumber() < opt_last) {
       double tms = vpTime::measureTimeMs();
       // read the image and then increment the image counter so that the next
       // call to acquire(I) will get the next image
@@ -346,7 +340,8 @@ int main(int argc, const char **argv)
       vpTime::wait(tms, 40);
     }
     return EXIT_SUCCESS;
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return EXIT_FAILURE;
   }
@@ -355,7 +350,8 @@ int main(int argc, const char **argv)
 #else
 int main()
 {
-  std::cout << "You do not have X11, or GDI (Graphical Device Interface) functionalities to display images..." << std::endl;
+  std::cout << "You do not have X11, or GDI (Graphical Device Interface) functionalities to display images..."
+    << std::endl;
   std::cout << "Tip if you are on a unix-like system:" << std::endl;
   std::cout << "- Install X11, configure again ViSP using cmake and build again this example" << std::endl;
   std::cout << "Tip if you are on a windows-like system:" << std::endl;
