@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -32,10 +32,7 @@
  * Acquire images using 1394 device with cfox (MAC OSX) and display it
  * using GTK or GTK.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <stdlib.h>
 #include <visp3/core/vpConfig.h>
@@ -85,7 +82,7 @@ typedef enum {
 
 */
 void usage(const char *name, const char *badparam, unsigned fps, unsigned input, unsigned scale, long niter,
-           char *device, vpV4l2Grabber::vpV4l2PixelFormatType pixelformat, const vpImage_type &image_type,
+           const std::string &device, vpV4l2Grabber::vpV4l2PixelFormatType pixelformat, const vpImage_type &image_type,
            const std::string &opath)
 {
   fprintf(stdout, "\n\
@@ -95,7 +92,8 @@ Display these images using X11 or GTK.\n\
 SYNOPSIS\n\
   %s [-v <video device>] [-f <fps=25|50>] \n\
      [-i <input=0|1|2|3> [-s <scale=1|2|4>] [-p <pixel format>]\n\
-     [-n <niter>] [-t <image type>] [-o <filename>] [-x] [-d] [-h]\n", name);
+     [-n <niter>] [-t <image type>] [-o <filename>] [-x] [-d] [-h]\n",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                                  Default\n\
@@ -144,7 +142,8 @@ OPTIONS:                                                  Default\n\
      by the extension of the file (ex .png, .pgm, ...) \n\
                     \n\
   -h \n\
-     Print the help.\n\n", device, fps, input, pixelformat, vpV4l2Grabber::V4L2_MAX_FORMAT - 1, image_type, scale, niter,
+     Print the help.\n\n",
+          device.c_str(), fps, input, pixelformat, vpV4l2Grabber::V4L2_MAX_FORMAT - 1, image_type, scale, niter,
           opath.c_str());
 
   if (badparam)
@@ -173,7 +172,7 @@ OPTIONS:                                                  Default\n\
 
 */
 bool getOptions(int argc, const char **argv, unsigned &fps, unsigned &input, unsigned &scale, bool &display,
-                bool &verbose, long &niter, char *device, vpV4l2Grabber::vpV4l2PixelFormatType &pixelformat,
+                bool &verbose, long &niter, std::string &device, vpV4l2Grabber::vpV4l2PixelFormatType &pixelformat,
                 vpImage_type &image_type, bool &save, std::string &opath)
 {
   const char *optarg_;
@@ -207,7 +206,7 @@ bool getOptions(int argc, const char **argv, unsigned &fps, unsigned &input, uns
       image_type = (vpImage_type)atoi(optarg_);
       break;
     case 'v':
-      sprintf(device, "%s", optarg_);
+      device = std::string(optarg_);
       break;
     case 'x':
       verbose = true;
@@ -254,9 +253,8 @@ int main(int argc, const char **argv)
     long opt_iter = 100;
     bool opt_verbose = false;
     bool opt_display = true;
-    char opt_device[20];
+    std::string opt_device = "/dev/video0";
     bool opt_save = false;
-    sprintf(opt_device, "/dev/video0");
     // Default output path for image saving
     std::string opt_opath = "/tmp/I%04d.ppm";
 
@@ -265,7 +263,7 @@ int main(int argc, const char **argv)
     // Read the command line options
     if (getOptions(argc, argv, opt_fps, opt_input, opt_scale, opt_display, opt_verbose, opt_iter, opt_device,
                    opt_pixelformat, opt_image_type, opt_save, opt_opath) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Declare an image, this is a gray level image (unsigned char) and
@@ -304,9 +302,9 @@ int main(int argc, const char **argv)
 
 // We open a window using either X11 or GTK.
 // Its size is automatically defined by the image (I) size
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     vpDisplayX display;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display;
 #endif
 
@@ -314,7 +312,7 @@ int main(int argc, const char **argv)
       // Display the image
       // The image class has a member that specify a pointer toward
       // the display that has been initialized in the display declaration
-      // therefore is is no longuer necessary to make a reference to the
+      // therefore is is no longer necessary to make a reference to the
       // display variable.
       if (opt_image_type == grey_image) {
         display.init(Ig, 100, 100, "V4L2 grey images framegrabbing");
@@ -352,7 +350,7 @@ int main(int argc, const char **argv)
 
       if (opt_save) {
         char buf[FILENAME_MAX];
-        sprintf(buf, opt_opath.c_str(), cpt);
+        snprintf(buf, FILENAME_MAX, opt_opath.c_str(), cpt);
         std::string filename(buf);
         std::cout << "Write: " << filename << std::endl;
         if (opt_image_type == grey_image) {
