@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -32,10 +32,7 @@
  * Acquire images using 1394 device with cfox (MAC OSX) and display it
  * using GTK or GTK.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example grabV4l2MultiCpp11Thread.cpp
@@ -48,7 +45,7 @@
 
 #include <visp3/core/vpConfig.h>
 
-#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11) && defined(VISP_HAVE_V4L2) && \
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11) && defined(VISP_HAVE_V4L2) &&                                          \
     (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK))
 
 #include <condition_variable>
@@ -90,7 +87,8 @@ OPTIONS:                                               \n\
      Save each stream in a dedicated folder.\n\
     \n\
   -h \n\
-     Print the help.\n\n", name);
+     Print the help.\n\n",
+          name);
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
@@ -139,13 +137,12 @@ class FrameQueue
 {
 
 public:
-  struct cancelled {
-  };
+  struct cancelled
+  { };
 
   FrameQueue()
     : m_cancelled(false), m_cond(), m_queueColor(), m_maxQueueSize(std::numeric_limits<size_t>::max()), m_mutex()
-  {
-  }
+  { }
 
   void cancel()
   {
@@ -208,8 +205,7 @@ class StorageWorker
 public:
   StorageWorker(FrameQueue &queue, const std::string &filename, unsigned int width, unsigned int height)
     : m_queue(queue), m_filename(filename), m_width(width), m_height(height)
-  {
-  }
+  { }
 
   // Thread main loop
   void run()
@@ -230,7 +226,8 @@ public:
           writer.saveFrame(image);
         }
       }
-    } catch (FrameQueue::cancelled &) {
+    }
+    catch (FrameQueue::cancelled &) {
     }
   }
 
@@ -252,15 +249,15 @@ private:
   unsigned int m_totalSize;
 
 public:
-  struct cancelled {
-  };
+  struct cancelled
+  { };
 
-  ShareImage() : m_cancelled(false), m_cond(), m_mutex(), m_pImgData(NULL), m_totalSize(0) {}
+  ShareImage() : m_cancelled(false), m_cond(), m_mutex(), m_pImgData(NULL), m_totalSize(0) { }
 
   virtual ~ShareImage()
   {
     if (m_pImgData != NULL) {
-      delete[] m_pImgData;
+      delete [] m_pImgData;
     }
   }
 
@@ -289,7 +286,8 @@ public:
     // Copy to imageData
     if (totalSize <= m_totalSize) {
       memcpy(imageData, m_pImgData, totalSize * sizeof(unsigned char));
-    } else {
+    }
+    else {
       std::cerr << "totalSize <= m_totalSize !" << std::endl;
     }
   }
@@ -309,7 +307,7 @@ public:
       m_totalSize = totalSize;
 
       if (m_pImgData != NULL) {
-        delete[] m_pImgData;
+        delete [] m_pImgData;
       }
 
       m_pImgData = new unsigned char[m_totalSize];
@@ -341,14 +339,14 @@ void capture(vpV4l2Grabber *const pGrabber, ShareImage &share_image)
   }
 }
 
-void display(unsigned int width, unsigned int height, int win_x, int win_y,
-             unsigned int deviceId, ShareImage &share_image, FrameQueue &queue, bool save)
+void display(unsigned int width, unsigned int height, int win_x, int win_y, unsigned int deviceId,
+             ShareImage &share_image, FrameQueue &queue, bool save)
 {
   vpImage<vpRGBa> local_img(height, width);
 
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
   vpDisplayX display;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
   vpDisplayGTK display;
 #endif
 
@@ -364,7 +362,7 @@ void display(unsigned int width, unsigned int height, int win_x, int win_y,
 
     vpImage<unsigned char> I_red(height, width), I_green(height, width), I_blue(height, width), I_alpha(height, width);
     vpImage<unsigned char> I_red_gaussian(height, width), I_green_gaussian(height, width),
-        I_blue_gaussian(height, width);
+      I_blue_gaussian(height, width);
     vpImage<double> I_red_gaussian_double, I_green_gaussian_double, I_blue_gaussian_double;
 
     bool exit = false, gaussian_blur = false;
@@ -420,7 +418,8 @@ void display(unsigned int width, unsigned int height, int win_x, int win_y,
         }
       }
     }
-  } catch (ShareImage::cancelled &) {
+  }
+  catch (ShareImage::cancelled &) {
     std::cout << "Cancelled!" << std::endl;
   }
 
@@ -429,7 +428,7 @@ void display(unsigned int width, unsigned int height, int win_x, int win_y,
 
 } // Namespace
 
-int main(int argc, char *argv[])
+int main(int argc, char *argv [])
 {
   unsigned int deviceCount = 1;
   unsigned int cameraScale = 1; // 640x480
@@ -437,7 +436,7 @@ int main(int argc, char *argv[])
 
   // Read the command line options
   if (!getOptions(argc, argv, deviceCount, saveVideo)) {
-    return (-1);
+    return EXIT_FAILURE;
   }
 
   std::vector<vpV4l2Grabber *> grabbers;
@@ -452,7 +451,8 @@ int main(int argc, char *argv[])
       pGrabber->setScale(cameraScale);
 
       grabbers.push_back(pGrabber);
-    } catch (const vpException &e) {
+    }
+    catch (const vpException &e) {
       std::cerr << "Exception: " << e.what() << std::endl;
     }
   }
@@ -559,4 +559,3 @@ int main()
 }
 #endif
 #endif
-
