@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Detection of planar surface using Fern classifier.
  *
- * Authors:
- * Romain Tallonneau
- *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \file planarObjectDetector.cpp
 
@@ -50,8 +47,8 @@
 #include <visp3/core/vpConfig.h>
 #include <visp3/core/vpDebug.h>
 
-#if ((defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI)) &&                                   \
-     (VISP_HAVE_OPENCV_VERSION >= 0x020000) && (VISP_HAVE_OPENCV_VERSION < 0x030000))
+#if ((defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI)) && \
+     (VISP_HAVE_OPENCV_VERSION >= 0x020408) && (VISP_HAVE_OPENCV_VERSION < 0x030000))
 
 #include <iomanip>
 #include <iostream>
@@ -74,7 +71,7 @@
 
 void usage(const char *name, const char *badparam);
 bool getOptions(int argc, const char **argv, bool &isLearning, std::string &dataFile, bool &click_allowed,
-                bool &display, bool &displayPoints, std::string &ipath);
+  bool &display, bool &displayPoints, std::string &ipath);
 
 /*!
 
@@ -86,13 +83,19 @@ bool getOptions(int argc, const char **argv, bool &isLearning, std::string &data
 */
 void usage(const char *name, const char *badparam)
 {
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+  std::string ext("png");
+#else
+  std::string ext("pgm");
+#endif
   fprintf(stdout, "\n\
 Test of detection of planar surface using a Fern classifier. The object needs \
   first to be learned (-l option). This learning process will create a file used\
   to detect the object.\n\
 \n\
 SYNOPSIS\n\
-  %s [-l] [-h] [-b] [-c] [-d] [-p] [-i] [-s]\n", name);
+  %s [-l] [-h] [-b] [-c] [-d] [-p] [-i] [-s]\n",
+    name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               \n\
@@ -101,7 +104,7 @@ OPTIONS:                                               \n\
 \n\
   -i <input image path>                                \n\
      Set image input path.\n\
-     From this path read \"line/image.%%04d.pgm\"\n\
+     From this path read \"line/image.%%04d.%s\"\n\
      images. \n\
      Setting the VISP_INPUT_IMAGE_PATH environment\n\
      variable produces the same behaviour than using\n\
@@ -111,8 +114,8 @@ OPTIONS:                                               \n\
      database filename to use (default is ./dataPlanar).\n\
 \n\
   -c\n\
-     Disable the mouse click. Useful to automaze the \n\
-     execution of this program without humain intervention.\n\
+     Disable the mouse click. Useful to automate the \n\
+     execution of this program without human intervention.\n\
 \n\
   -d \n\
      Turn off the display.\n\
@@ -124,7 +127,7 @@ OPTIONS:                                               \n\
      display points of interest.\n\
 \n\
   -h\n\
-     Print this help.\n");
+     Print this help.\n", ext.c_str());
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
@@ -147,7 +150,7 @@ OPTIONS:                                               \n\
 
 */
 bool getOptions(int argc, const char **argv, bool &isLearning, std::string &dataFile, bool &click_allowed,
-                bool &display, bool &displayPoints, std::string &ipath)
+  bool &display, bool &displayPoints, std::string &ipath)
 {
   const char *optarg_;
   int c;
@@ -209,6 +212,12 @@ int main(int argc, const char **argv)
     std::string dirname;
     std::string filename;
 
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+    std::string ext("png");
+#else
+    std::string ext("pgm");
+#endif
+
     // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH
     // environment variable value
     env_ipath = vpIoTools::getViSPImagesDataPath();
@@ -220,8 +229,8 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, isLearning, dataFile, opt_click_allowed, opt_display, displayPoints, opt_ipath) ==
-        false) {
-      exit(-1);
+      false) {
+      return EXIT_FAILURE;
     }
 
     // Get the option values
@@ -235,8 +244,8 @@ int main(int argc, const char **argv)
       if (ipath != env_ipath) {
         std::cout << std::endl << "WARNING: " << std::endl;
         std::cout << "  Since -i <visp image path=" << ipath << "> "
-                  << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
-                  << "  we skip the environment variable." << std::endl;
+          << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
+          << "  we skip the environment variable." << std::endl;
       }
     }
 
@@ -245,10 +254,10 @@ int main(int argc, const char **argv)
       usage(argv[0], NULL);
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH " << std::endl
-                << "  environment variable to specify the location of the " << std::endl
-                << "  image path where test images are located." << std::endl
-                << std::endl;
-      exit(-1);
+        << "  environment variable to specify the location of the " << std::endl
+        << "  image path where test images are located." << std::endl
+        << std::endl;
+      return EXIT_FAILURE;
     }
 
     // Declare two images, these are gray level images (unsigned char)
@@ -262,44 +271,36 @@ int main(int argc, const char **argv)
     unsigned iter = 0; // Image number
     std::ostringstream s;
     s.setf(std::ios::right, std::ios::adjustfield);
-    s << "image." << std::setw(4) << std::setfill('0') << iter << ".pgm";
+    s << "image." << std::setw(4) << std::setfill('0') << iter << "." << ext;
     filename = vpIoTools::createFilePath(dirname, s.str());
 
-    // Read the PGM image named "filename" on the disk, and put the
-    // bitmap into the image structure I.  I is initialized to the
-    // correct size
-    //
-    // exception readPGM may throw various exception if, for example,
-    // the file does not exist, or if the memory cannot be allocated
+    // Read image named "filename" and put the bitmap in I
     try {
       std::cout << "Load: " << filename << std::endl;
       vpImageIo::read(Iref, filename);
       I = Iref;
-    } catch (...) {
-      // an exception is throwned if an exception from readPGM has been
-      // catched here this will result in the end of the program Note that
-      // another error message has been printed from readPGM to give more
-      // information about the error
+    }
+    catch (...) {
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Cannot read " << filename << std::endl;
       std::cerr << "  Check your -i " << ipath << " option " << std::endl
-                << "  or VISP_INPUT_IMAGE_PATH environment variable." << std::endl;
-      exit(-1);
+        << "  or VISP_INPUT_IMAGE_PATH environment variable." << std::endl;
+      return EXIT_FAILURE;
     }
 
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     vpDisplayX display;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display;
 #endif
 
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     vpDisplayX displayRef;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK displayRef;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI displayRef;
 #endif
 
@@ -315,13 +316,14 @@ int main(int argc, const char **argv)
       }
       if (opt_display && opt_click_allowed) {
         std::cout << "Click on the top left and the bottom right corners to "
-                     "define the reference plane"
-                  << std::endl;
+          "define the reference plane"
+          << std::endl;
         for (int i = 0; i < 2; i++) {
           vpDisplay::getClick(Iref, corners[i]);
           std::cout << corners[i] << std::endl;
         }
-      } else {
+      }
+      else {
         corners[0].set_ij(50, I.getWidth() - 100); // small ROI for the automated test
         corners[1].set_ij(I.getHeight() - 100, I.getWidth() - 2);
       }
@@ -341,8 +343,8 @@ int main(int argc, const char **argv)
       vpRect roi(corners[0], corners[1]);
 
       std::cout << "> train the classifier on the selected plane (may take "
-                   "up to several minutes)."
-                << std::endl;
+        "up to several minutes)."
+        << std::endl;
       if (opt_display) {
         vpDisplay::display(Iref);
         vpDisplay::flush(Iref);
@@ -353,19 +355,21 @@ int main(int argc, const char **argv)
       t0 = vpTime::measureTimeMs();
       planar.recordDetector(objectName, dataFile);
       std::cout << "record detector in " << vpTime::measureTimeMs() - t0 << " ms" << std::endl;
-    } else {
+    }
+    else {
       if (!vpIoTools::checkFilename(dataFile)) {
         vpERROR_TRACE("cannot load the database with the specified name. Has "
-                      "the object been learned with the -l option? ");
-        exit(-1);
+          "the object been learned with the -l option? ");
+        return EXIT_FAILURE;
       }
       try {
         // load a previously recorded file
         planar.load(dataFile, objectName);
-      } catch (...) {
+      }
+      catch (...) {
         vpERROR_TRACE("cannot load the database with the specified name. Has "
-                      "the object been learned with the -l option? ");
-        exit(-1);
+          "the object been learned with the -l option? ");
+        return EXIT_FAILURE;
       }
     }
 
@@ -389,7 +393,7 @@ int main(int argc, const char **argv)
         break;
       }
       s.str("");
-      s << "image." << std::setw(4) << std::setfill('0') << iter << ".pgm";
+      s << "image." << std::setw(4) << std::setfill('0') << iter << "." << ext;
       filename = vpIoTools::createFilePath(dirname, s.str());
       // read the image
       vpImageIo::read(I, filename);
@@ -413,11 +417,13 @@ int main(int argc, const char **argv)
             vpDisplay::displayRectangle(Iref, corners[0], corners[1], vpColor::green);
             planar.display(Iref, I, displayPoints);
             vpDisplay::flush(Iref);
-          } else {
+          }
+          else {
             planar.display(I, displayPoints);
           }
         }
-      } else {
+      }
+      else {
         std::cout << " > reference is not detected in the image" << std::endl;
       }
       if (opt_display) {
@@ -429,7 +435,8 @@ int main(int argc, const char **argv)
     }
 
     return EXIT_SUCCESS;
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return EXIT_FAILURE;
   }
@@ -439,7 +446,8 @@ int main(int argc, const char **argv)
 int main()
 {
 #if (!(defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI)))
-  std::cout << "You do not have X11, or GTK, or GDI (Graphical Device Interface) functionalities to display images..." << std::endl;
+  std::cout << "You do not have X11, or GTK, or GDI (Graphical Device Interface) functionalities to display images..."
+    << std::endl;
   std::cout << "Tip if you are on a unix-like system:" << std::endl;
   std::cout << "- Install X11, configure again ViSP using cmake and build again this example" << std::endl;
   std::cout << "Tip if you are on a windows-like system:" << std::endl;
