@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,23 +31,19 @@
  * Description:
  * Images grabbing example.
  *
- * Authors:
- * Anthony Saunier
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \file manGrab1394-2.cpp
 
   \brief Images grabbing example with the vp1394TwoGrabber class.
 
  */
-/*!
-  \example manGrab1394-2.cpp
+ /*!
+   \example manGrab1394-2.cpp
 
-  \brief Images grabbing example with the vp1394TwoGrabber class.
+   \brief Images grabbing example with the vp1394TwoGrabber class.
 
- */
+  */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -80,11 +76,12 @@ int main()
         g.acquire(I[camera]);
       }
     }
-    delete[] I;
-    return 0;
-  } catch (vpException &e) {
+    delete [] I;
+    return EXIT_SUCCESS;
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
-    return 1;
+    return EXIT_FAILURE;
   }
 
 #endif
