@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -32,14 +32,11 @@
  * Example of visual servoing with moments using discrete points as object
  * container
  *
- * Authors:
- * Filip Novotny
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example servoMomentPoints.cpp
-  Example of moment-based visual servoing with Images
+  Example of moment-based visual servoing with images.
 */
 
 #include <iostream>
@@ -70,8 +67,8 @@
 int main()
 {
   std::cout << "Can't run this example since vpSimulatorAfma6 capability is "
-               "not available."
-            << std::endl;
+    "not available."
+    << std::endl;
   std::cout << "You should install pthread third-party library." << std::endl;
   return EXIT_SUCCESS;
 }
@@ -82,8 +79,8 @@ int main()
 {
   std::cout << "Can't run this example since no display capability is available." << std::endl;
   std::cout << "You should install one of the following third-party library: "
-               "X11, OpenCV, GDI, GTK."
-            << std::endl;
+    "X11, OpenCV, GDI, GTK."
+    << std::endl;
   return EXIT_SUCCESS;
 }
 #else
@@ -94,10 +91,9 @@ class servoMoment
 public:
   servoMoment()
     : m_width(640), m_height(480), m_cMo(), m_cdMo(), m_robot(false), m_Iint(m_height, m_width, 255), m_task(), m_cam(),
-      m_error(0), m_imsim(), m_interaction_type(), m_src(6), m_dst(6), m_moments(NULL), m_momentsDes(NULL),
-      m_featureMoments(NULL), m_featureMomentsDes(NULL), m_displayInt(NULL)
-  {
-  }
+    m_error(0), m_imsim(), m_interaction_type(), m_src(6), m_dst(6), m_moments(NULL), m_momentsDes(NULL),
+    m_featureMoments(NULL), m_featureMomentsDes(NULL), m_displayInt(NULL)
+  { }
   ~servoMoment()
   {
 #ifdef VISP_HAVE_DISPLAY
@@ -117,8 +113,8 @@ public:
     std::vector<vpPoint> src_pts;
     std::vector<vpPoint> dst_pts;
 
-    double x[8] = {1, 3, 4, -1, -3, -2, -1, 1};
-    double y[8] = {0, 1, 4, 4, -2, -2, 1, 0};
+    double x[8] = { 1, 3, 4, -1, -3, -2, -1, 1 };
+    double y[8] = { 0, 1, 4, 4, -2, -2, 1, 0 };
     int nbpoints = 8;
 
     for (int i = 0; i < nbpoints; i++) {
@@ -169,9 +165,9 @@ public:
     // don't need to be specific, vpMomentCommon automatically loads
     // Xg,Yg,An,Ci,Cj,Alpha moments
     m_moments = new vpMomentCommon(vpMomentCommon::getSurface(m_dst), vpMomentCommon::getMu3(m_dst),
-                                   vpMomentCommon::getAlpha(m_dst), vec[2]);
+      vpMomentCommon::getAlpha(m_dst), vec[2]);
     m_momentsDes = new vpMomentCommon(vpMomentCommon::getSurface(m_dst), vpMomentCommon::getMu3(m_dst),
-                                      vpMomentCommon::getAlpha(m_dst), vec[2]);
+      vpMomentCommon::getAlpha(m_dst), vec[2]);
     // same thing with common features
     m_featureMoments = new vpFeatureMomentCommon(*m_moments);
     m_featureMomentsDes = new vpFeatureMomentCommon(*m_momentsDes);
@@ -187,10 +183,10 @@ public:
     //////////////////////////////////add useful features to
     /// task//////////////////////////////
     m_task.addFeature(m_featureMoments->getFeatureGravityNormalized(),
-                      m_featureMomentsDes->getFeatureGravityNormalized());
+      m_featureMomentsDes->getFeatureGravityNormalized());
     m_task.addFeature(m_featureMoments->getFeatureAn(), m_featureMomentsDes->getFeatureAn());
     m_task.addFeature(m_featureMoments->getFeatureCInvariant(), m_featureMomentsDes->getFeatureCInvariant(),
-                      (1 << 3) | (1 << 5));
+      (1 << 3) | (1 << 5));
     m_task.addFeature(m_featureMoments->getFeatureAlpha(), m_featureMomentsDes->getFeatureAlpha());
 
     m_task.setLambda(1.);
@@ -201,8 +197,8 @@ public:
   {
     // double x[8] = { 0.05,0.15, 0.2,-0.05 ,-0.15,-0.1,-0.05,0.05};
     // double y[8] = { 0,0.05, 0.2, 0.2, -0.1,-0.1, 0.05,0};
-    double x[8] = {1, 3, 4, -1, -3, -2, -1, 1};
-    double y[8] = {0, 1, 4, 4, -2, -2, 1, 0};
+    double x[8] = { 1, 3, 4, -1, -3, -2, -1, 1 };
+    double y[8] = { 0, 1, 4, 4, -2, -2, 1, 0 };
     int nbpoints = 8;
     std::vector<vpPoint> cur_pts;
 
@@ -223,15 +219,15 @@ public:
 
 #ifdef VISP_HAVE_DISPLAY
     // init the right display
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     m_displayInt = new vpDisplayX;
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
     m_displayInt = new vpDisplayOpenCV;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     m_displayInt = new vpDisplayGDI;
-#elif defined VISP_HAVE_D3D9
+#elif defined(VISP_HAVE_D3D9)
     m_displayInt = new vpDisplayD3D;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     m_displayInt = new vpDisplayGTK;
 #endif
     m_displayInt->init(m_Iint, 50, 50, "Visual servoing with moments");
@@ -384,12 +380,12 @@ public:
      * -------------------------------------
      */
     const unsigned int NbGraphs = 3;                            // No. of graphs
-    const unsigned int NbCurves_in_graph[NbGraphs] = {6, 6, 6}; // Curves in each graph
+    const unsigned int NbCurves_in_graph[NbGraphs] = { 6, 6, 6 }; // Curves in each graph
 
     ViSP_plot.init(NbGraphs, 800, 800, 100 + static_cast<int>(m_width), 50, "Visual Servoing results...");
 
     vpColor Colors[6] = {// Colour for s1, s2, s3,  in 1st plot
-                         vpColor::red, vpColor::green, vpColor::blue, vpColor::orange, vpColor::cyan, vpColor::purple};
+                         vpColor::red, vpColor::green, vpColor::blue, vpColor::orange, vpColor::cyan, vpColor::purple };
 
     for (unsigned int p = 0; p < NbGraphs; p++) {
       ViSP_plot.initGraph(p, NbCurves_in_graph[p]);
@@ -465,7 +461,8 @@ int main()
     servo.init(cMo, cdMo);
     servo.execute(1500);
     return EXIT_SUCCESS;
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return EXIT_FAILURE;
   }
