@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -32,10 +32,7 @@
  * Implementation of a simple augmented reality application using the vpAROgre
  * class.
  *
- * Authors:
- * Bertrand Delabarre
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example AROgre.cpp
@@ -91,6 +88,12 @@
 */
 void usage(const char *name, const char *badparam, std::string ipath, std::string ppath)
 {
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+  std::string ext("png");
+#else
+  std::string ext("pgm");
+#endif
+
   fprintf(stdout, "\n\
 Test augmented reality using the vpAROgre class.\n\
 \n\
@@ -103,8 +106,8 @@ OPTIONS:                                               Default\n\
   -i <input image path>                                %s\n\
      Set image input path.\n\
      From this path read images \n\
-     \"mire-2/image.%%04d.pgm\". These \n\
-     images come from ViSP-images-x.y.z.tar.gz available \n\
+     \"mire-2/image.%%04d.%s\". These \n\
+     images come from visp-images-x.y.z.tar.gz available \n\
      on the ViSP website.\n\
      Setting the VISP_INPUT_IMAGE_PATH environment\n\
      variable produces the same behaviour than using\n\
@@ -114,18 +117,16 @@ OPTIONS:                                               Default\n\
      Specify a personal sequence containing images \n\
      to process.\n\
      By image sequence, we mean one file per image.\n\
-     The following image file formats PNM (PGM P5, PPM P6)\n\
-     are supported. The format is selected by analysing \n\
-     the filename extension.\n\
-     Example : \"/Temp/ViSP-images/cube/image.%%04d.pgm\"\n\
+     Example : \"/Temp/visp-images/cube/image.%%04d.%s\"\n\
      %%04d is for the image numbering.\n\
 \n\
   -c\n\
-     Disable the mouse click. Useful to automaze the \n\
-     execution of this program without humain intervention.\n\
+     Disable the mouse click. Useful to automate the \n\
+     execution of this program without human intervention.\n\
 \n\
   -h\n\
-     Print the help.\n", ipath.c_str(), ppath.c_str());
+     Print the help.\n",
+          ipath.c_str(), ext.c_str(), ppath.c_str(), ext.c_str());
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
@@ -305,7 +306,8 @@ protected:
     // Play the right animation
     if (event) {
       mAnimationState = robot->getAnimationState("Walk");
-    } else
+    }
+    else
       mAnimationState = robot->getAnimationState("Idle");
 
     // Start over when finished
@@ -332,26 +334,27 @@ void computeInitialPose(vpCameraParameters *mcam, vpImage<unsigned char> &I, vpP
   // ----------------------------------------------------
   bool opt_display = true;
 
-//#if defined(VISP_HAVE_X11) && ! defined(APPLE)
+  //#if defined(VISP_HAVE_X11) && ! defined(APPLE)
 #if defined(VISP_HAVE_X11) && !(defined(__APPLE__) && defined(__MACH__))
   // produce an error on OSX: ‘typedef int Cursor’
   // /usr/X11R6/include/X11/X.h:108: error: ‘Cursor’ has a previous
   // declaration as ‘typedef XID Cursor’. That's why it should not be
   // used on APPLE platforms
   vpDisplayX display;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
   vpDisplayGTK display;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
   vpDisplayGDI display;
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
   vpDisplayOpenCV display;
-#elif defined VISP_HAVE_D3D9
+#elif defined(VISP_HAVE_D3D9)
   vpDisplayD3D display;
 #endif
   for (unsigned int i = 0; i < 4; i++) {
     if (opt_display) {
       md[i].setGraphics(true);
-    } else {
+    }
+    else {
       md[i].setGraphics(false);
     }
   }
@@ -363,33 +366,34 @@ void computeInitialPose(vpCameraParameters *mcam, vpImage<unsigned char> &I, vpP
       // display the image
       // The image class has a member that specify a pointer toward
       // the display that has been initialized in the display declaration
-      // therefore is is no longuer necessary to make a reference to the
+      // therefore is is no longer necessary to make a reference to the
       // display variable.
       vpDisplay::display(I);
       // Flush the display
       vpDisplay::flush(I);
 
-    } catch (...) {
+    }
+    catch (...) {
       vpERROR_TRACE("Error while displaying the image");
       return;
     }
   }
 
   std::cout << "*************************************************************"
-               "***********************"
-            << std::endl;
+    "***********************"
+    << std::endl;
   std::cout << "*************************** Preliminary Pose Calculation "
-               "***************************"
-            << std::endl;
+    "***************************"
+    << std::endl;
   std::cout << "******************************  Click on the 4 dots  "
-               "*******************************"
-            << std::endl;
+    "*******************************"
+    << std::endl;
   std::cout << "********Dot1 : (-x,-y,0), Dot2 : (x,-y,0), Dot3 : (x,y,0), "
-               "Dot4 : (-x,y,0)**********"
-            << std::endl;
+    "Dot4 : (-x,y,0)**********"
+    << std::endl;
   std::cout << "*************************************************************"
-               "***********************"
-            << std::endl;
+    "***********************"
+    << std::endl;
 
   try {
     vpImagePoint ip[4];
@@ -407,7 +411,7 @@ void computeInitialPose(vpCameraParameters *mcam, vpImage<unsigned char> &I, vpP
       // by using setGraphics, we request to see the edges of the dot
       // in red on the screen.
       // It uses the overlay image plane.
-      // The default of this setting is that it is time consumming
+      // The default of this setting is that it is time consuming
 
       md[i].setGraphics(true);
       md[i].setGrayLevelPrecision(0.7);
@@ -423,11 +427,12 @@ void computeInitialPose(vpCameraParameters *mcam, vpImage<unsigned char> &I, vpP
           md[i].initTracking(I);
         else
           md[i].initTracking(I, ip[i]);
-      } catch (...) {
+      }
+      catch (...) {
       }
 
       mcog[i] = md[i].getCog();
-      // an expcetion is thrown by the track method if
+      // an exception is thrown by the track method if
       //  - dot is lost
       //  - the number of pixel is too small
       //  - too many pixels are detected (this is usual when a "big"
@@ -440,7 +445,8 @@ void computeInitialPose(vpCameraParameters *mcam, vpImage<unsigned char> &I, vpP
         vpDisplay::flush(I);
       }
     }
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     vpERROR_TRACE("Error while tracking dots");
     vpCTRACE << e;
     return;
@@ -504,16 +510,12 @@ void computeInitialPose(vpCameraParameters *mcam, vpImage<unsigned char> &I, vpP
   }
 
   // compute the initial pose using Dementhon method followed by a non linear
-  // minimisation method
+  // minimization method
 
-  // Pose by Lagrange it provides an initialization of the pose
-  mPose->computePose(vpPose::LAGRANGE, *cMo);
-  // the pose is now refined using the virtual visual servoing approach
-  // Warning: cMo needs to be initialized otherwise it may  diverge
-  mPose->computePose(vpPose::VIRTUAL_VS, *cMo);
+  // Compute initial pose
+  mPose->computePose(vpPose::DEMENTHON_LAGRANGE_VIRTUAL_VS, *cMo);
 
-  // Display breifly just to have a glimpse a the ViSP pose
-  //	while(cpt<500){
+  // Display briefly just to have a glimpse a the ViSP pose
   if (opt_display) {
     // Display the computed pose
     mPose->display(I, *cMo, *mcam, 0.05, vpColor::red);
@@ -526,6 +528,11 @@ void computeInitialPose(vpCameraParameters *mcam, vpImage<unsigned char> &I, vpP
 
 int main(int argc, const char **argv)
 {
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+  std::string ext("png");
+#else
+  std::string ext("pgm");
+#endif
   try {
     std::string env_ipath;
     std::string opt_ipath;
@@ -545,7 +552,7 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, opt_ipath, opt_ppath, opt_click_allowed) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Get the option values
@@ -558,8 +565,8 @@ int main(int argc, const char **argv)
       if (ipath != env_ipath) {
         std::cout << std::endl << "WARNING: " << std::endl;
         std::cout << "  Since -i <visp image path=" << ipath << "> "
-                  << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
-                  << "  we skip the environment variable." << std::endl;
+          << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
+          << "  we skip the environment variable." << std::endl;
       }
     }
 
@@ -568,13 +575,13 @@ int main(int argc, const char **argv)
       usage(argv[0], NULL, ipath, opt_ppath);
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH " << std::endl
-                << "  environment variable to specify the location of the " << std::endl
-                << "  image path where test images are located." << std::endl
-                << "  Use -p <personal image path> option if you want to " << std::endl
-                << "  use personal images." << std::endl
-                << std::endl;
+        << "  environment variable to specify the location of the " << std::endl
+        << "  image path where test images are located." << std::endl
+        << "  Use -p <personal image path> option if you want to " << std::endl
+        << "  use personal images." << std::endl
+        << std::endl;
 
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     std::ostringstream s;
@@ -586,9 +593,11 @@ int main(int argc, const char **argv)
       // Build the name of the image file
 
       s.setf(std::ios::right, std::ios::adjustfield);
-      s << "image.%04d.pgm";
+      s << "image.%04d.";
+      s << ext;
       filename = vpIoTools::createFilePath(dirname, s.str());
-    } else {
+    }
+    else {
       filename = opt_ppath;
     }
 
@@ -616,12 +625,6 @@ int main(int argc, const char **argv)
     // Keep u0 and v0 as center of the screen
     vpCameraParameters mcam;
 
-    // Read the PGM image named "filename" on the disk, and put the
-    // bitmap into the image structure I.  I is initialized to the
-    // correct size
-    //
-    // exception readPGM may throw various exception if, for example,
-    // the file does not exist, or if the memory cannot be allocated
     try {
       vpCTRACE << "Load: " << filename << std::endl;
       grabber.open(Idisplay);
@@ -635,16 +638,13 @@ int main(int argc, const char **argv)
       // Associate the grabber to the RGBa image
       grabber.open(IC);
       mcam.init(mcamTmp);
-    } catch (...) {
-      // an exception is thrown if an exception from readPGM has been caught
-      // here this will result in the end of the program
-      // Note that another error message has been printed from readPGM
-      // to give more information about the error
+    }
+    catch (...) {
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Cannot read " << filename << std::endl;
       std::cerr << "  Check your -i " << ipath << " option " << std::endl
-                << "  or VISP_INPUT_IMAGE_PATH environment variable." << std::endl;
-      exit(-1);
+        << "  or VISP_INPUT_IMAGE_PATH environment variable." << std::endl;
+      return EXIT_FAILURE;
     }
 
     // Create a vpRAOgre object with color background
@@ -684,7 +684,7 @@ int main(int argc, const char **argv)
       // the pose structure has been updated
 
       // the pose is now updated using the virtual visual servoing approach
-      // Dementhon or lagrange is no longuer necessary, pose at the
+      // Dementhon or lagrange is no longer necessary, pose at the
       // previous iteration is sufficient
       mPose.computePose(vpPose::VIRTUAL_VS, cMo);
 
@@ -700,13 +700,16 @@ int main(int argc, const char **argv)
     grabber.close();
 
     return EXIT_SUCCESS;
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
     return EXIT_FAILURE;
-  } catch (Ogre::Exception &e) {
+  }
+  catch (Ogre::Exception &e) {
     std::cout << "Catch an Ogre exception: " << e.getDescription() << std::endl;
     return EXIT_FAILURE;
-  } catch (...) {
+  }
+  catch (...) {
     std::cout << "Catch an exception " << std::endl;
     return EXIT_FAILURE;
   }
@@ -715,7 +718,8 @@ int main(int argc, const char **argv)
 int main()
 {
 #if (!(defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI)))
-  std::cout << "You do not have X11, or GTK, or GDI (Graphical Device Interface) functionalities to display images..." << std::endl;
+  std::cout << "You do not have X11, or GTK, or GDI (Graphical Device Interface) functionalities to display images..."
+    << std::endl;
   std::cout << "Tip if you are on a unix-like system:" << std::endl;
   std::cout << "- Install X11, configure again ViSP using cmake and build again this example" << std::endl;
   std::cout << "Tip if you are on a windows-like system:" << std::endl;
