@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * Simulation of a 3D visual servoing.
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \example servoSimu3D_cdMc_CamVelocityWithoutVpServo.cpp
 
@@ -106,7 +102,8 @@ Simulation of a 3D visual servoing:\n\
 - without display.\n\
 \n\
 SYNOPSIS\n\
-  %s [-h]\n", name);
+  %s [-h]\n",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
@@ -160,7 +157,7 @@ int main(int argc, const char **argv)
   try {
     // Read the command line options
     if (getOptions(argc, argv) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
     // Log file creation in /tmp/$USERNAME/log.dat
     // This file contains by line:
@@ -183,10 +180,11 @@ int main(int argc, const char **argv)
       try {
         // Create the dirname
         vpIoTools::makeDirectory(logdirname);
-      } catch (...) {
+      }
+      catch (...) {
         std::cerr << std::endl << "ERROR:" << std::endl;
         std::cerr << "  Cannot create " << logdirname << std::endl;
-        exit(-1);
+        return EXIT_FAILURE;
       }
     }
     std::string logfilename;
@@ -284,7 +282,8 @@ int main(int argc, const char **argv)
     // Close the log file
     flog.close();
     return EXIT_SUCCESS;
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
     return EXIT_FAILURE;
   }
