@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Simulation of a 2D visual servoing on a cylinder.
  *
- * Authors:
- * Nicolas Melchior
- *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \example servoSimuCylinder2DCamVelocityDisplaySecondaryTask.cpp
 
@@ -96,14 +93,15 @@ Simulation of a 2D visual servoing on a cylinder:\n\
 - display the camera view.\n\
           \n\
 SYNOPSIS\n\
-  %s [-c] [-d] [-o] [-h]\n", name);
+  %s [-c] [-d] [-o] [-h]\n",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
                   \n\
   -c\n\
-     Disable the mouse click. Useful to automaze the \n\
-     execution of this program without humain intervention.\n\
+     Disable the mouse click. Useful to automate the \n\
+     execution of this program without human intervention.\n\
                   \n\
   -d \n\
      Turn off the display.\n\
@@ -177,7 +175,7 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, opt_click_allowed, opt_display, opt_new_proj_operator) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     vpImage<unsigned char> Iint(512, 512, 0);
@@ -185,19 +183,19 @@ int main(int argc, const char **argv)
 
 // We open a window if a display is available
 #ifdef VISP_HAVE_DISPLAY
-#  if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     vpDisplayX displayInt;
     vpDisplayX displayExt;
-#  elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK displayInt;
     vpDisplayGTK displayExt;
-#  elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI displayInt;
     vpDisplayGDI displayExt;
-#  elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV displayInt;
     vpDisplayOpenCV displayExt;
-#  elif defined VISP_HAVE_D3D9
+#elif defined(VISP_HAVE_D3D9)
     vpDisplayD3D displayInt;
     vpDisplayD3D displayExt;
 #endif
@@ -213,7 +211,7 @@ int main(int argc, const char **argv)
       // Display the image
       // The image class has a member that specify a pointer toward
       // the display that has been initialized in the display declaration
-      // therefore is is no longuer necessary to make a reference to the
+      // therefore is is no longer necessary to make a reference to the
       // display variable.
       vpDisplay::display(Iint);
       vpDisplay::display(Iext);
@@ -423,14 +421,14 @@ int main(int argc, const char **argv)
 
         if (opt_display && opt_click_allowed) {
           std::stringstream ss;
-          ss << std::string("New projection operator: ") + (opt_new_proj_operator ? std::string("yes (use option -o to use old one)") : std::string("no"));
+          ss << std::string("New projection operator: ") +
+                    (opt_new_proj_operator ? std::string("yes (use option -o to use old one)") : std::string("no"));
           vpDisplay::displayText(Iint, 20, 20, "Secondary task enabled: yes", vpColor::white);
           vpDisplay::displayText(Iint, 40, 20, ss.str(), vpColor::white);
         }
 
-        iter_sec ++;
-      }
-      else {
+        iter_sec++;
+      } else {
         if (opt_display && opt_click_allowed) {
           vpDisplay::displayText(Iint, 20, 20, "Secondary task: no", vpColor::white);
         }
