@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * Simulation of a 2 1/2 D visual servoing using theta U visual features.
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example servoSimuPoint2DhalfCamVelocity2.cpp
@@ -83,7 +79,8 @@ Simulation of a 2 1/2 D visual servoing (x,y,log Z, theta U):\n\
 - without display.\n\
           \n\
 SYNOPSIS\n\
-  %s [-h]\n", name);
+  %s [-h]\n",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
@@ -138,7 +135,7 @@ int main(int argc, const char **argv)
   try {
     // Read the command line options
     if (getOptions(argc, argv) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     std::cout << std::endl;
@@ -318,7 +315,7 @@ int main(int argc, const char **argv)
       cdMc = cdMo * cMo.inverse();
       tu.buildFrom(cdMc);
 
-      // there is no feature for logZ, we explicitely build
+      // there is no feature for logZ, we explicitly build
       // the related interaction matrix") ;
       logZ.set_s(log(point.get_Z() / pointd.get_Z()));
       vpMatrix LlogZ(1, 6);
