@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * Simulation of a 2D visual servoing on a sphere.
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example servoSimuSphere2DCamVelocityDisplaySecondaryTask.cpp
@@ -90,14 +86,15 @@ Simulation of a 2D visual servoing on a sphere:\n\
 - a secondary task is the added.\n\
           \n\
 SYNOPSIS\n\
-  %s [-c] [-d] [-o] [-h]\n", name);
+  %s [-c] [-d] [-o] [-h]\n",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
    \n\
   -c\n\
-     Disable the mouse click. Useful to automaze the \n\
-     execution of this program without humain intervention.\n\
+     Disable the mouse click. Useful to automate the \n\
+     execution of this program without human intervention.\n\
                                   \n\
   -d \n\
      Turn off the display.\n\
@@ -172,7 +169,7 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, opt_click_allowed, opt_display, opt_new_proj_operator) == false) {
-      return(EXIT_FAILURE);
+      return (EXIT_FAILURE);
     }
 
     vpImage<unsigned char> I(512, 512, 0);
@@ -180,22 +177,22 @@ int main(int argc, const char **argv)
 
     // We open a window if a display is available
 #ifdef VISP_HAVE_DISPLAY
-#  if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     vpDisplayX displayI;
     vpDisplayX displayExt;
-#  elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK displayI;
     vpDisplayGTK displayExt;
-#  elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI displayI;
     vpDisplayGDI displayExt;
-#  elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV displayI;
     vpDisplayOpenCV displayExt;
-#  elif defined VISP_HAVE_D3D9
+#elif defined(VISP_HAVE_D3D9)
     vpDisplayD3D displayI;
     vpDisplayD3D displayExt;
-#  endif
+#endif
 #endif
 
     if (opt_display) {
@@ -207,7 +204,7 @@ int main(int argc, const char **argv)
       // Display the image
       // The image class has a member that specify a pointer toward
       // the display that has been initialized in the display declaration
-      // therefore is is no longuer necessary to make a reference to the
+      // therefore is is no longer necessary to make a reference to the
       // display variable.
       vpDisplay::display(I);
       vpDisplay::display(Iext);
@@ -220,7 +217,7 @@ int main(int argc, const char **argv)
 #endif
 
     double px = 600, py = 600;
-    double u0 = I.getWidth()/2., v0 = I.getHeight() / 2.;
+    double u0 = I.getWidth() / 2., v0 = I.getHeight() / 2.;
 
     vpCameraParameters cam(px, py, u0, v0);
 
@@ -322,13 +319,14 @@ int main(int argc, const char **argv)
       vpColVector v = task.computeControlLaw();
 
       // Wait primary task convergence before considering secondary task
-      if (task.getError().sumSquare() < 1e-6)  {
+      if (task.getError().sumSquare() < 1e-6) {
         start_secondary_task = true;
       }
 
       if (start_secondary_task) {
         // Only 3 dof are required to achieve primary task: vz, wx, wy
-        // It remains 3 free dof (vx, vy, wz) that could be used in a secondary task for example to move arround the sphere
+        // It remains 3 free dof (vx, vy, wz) that could be used in a secondary task for example to move around the
+        // sphere
         vpColVector de2dt(6);
         de2dt[0] = 0.50;            // vx = 0.50 m/s should also generate a motion on wy = (I-WpW)de2dt[4]
         de2dt[1] = 0.25;            // vy = 0.25 m/s should generate a motion on wx = (I-WpW)de2dt[3]
@@ -343,12 +341,12 @@ int main(int argc, const char **argv)
 
         if (opt_display && opt_click_allowed) {
           std::stringstream ss;
-          ss << std::string("New projection operator: ") + (opt_new_proj_operator ? std::string("yes (use option -o to use old one)") : std::string("no"));
+          ss << std::string("New projection operator: ") +
+                    (opt_new_proj_operator ? std::string("yes (use option -o to use old one)") : std::string("no"));
           vpDisplay::displayText(I, 20, 20, "Secondary task enabled: yes", vpColor::white);
           vpDisplay::displayText(I, 40, 20, ss.str(), vpColor::white);
         }
-      }
-      else {
+      } else {
         if (opt_display && opt_click_allowed) {
           vpDisplay::displayText(I, 20, 20, "Secondary task enabled: no", vpColor::white);
         }
