@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Test for Afma 4 dof robot.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \file moveAfma4.cpp
 
@@ -77,12 +74,13 @@
 void usage(const char *name, const char *badparam)
 {
   fprintf(stdout, "\n\
-Example of a positionning control followed by a velocity control \n\
-of the Afma4 robot.\n						   \
+Example of a positioning control followed by a velocity control \n\
+of the Afma4 robot.\n\
 \n\
 SYNOPSIS\n\
-  %s [-m] [-h]\n						      \
-", name);
+  %s [-m] [-h]\n\
+",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
@@ -151,7 +149,7 @@ int main(int argc, const char **argv)
     // and velocities to the robot.
     // Read the command line options
     if (getOptions(argc, argv, control) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     vpRobotAfma4 robot;
@@ -187,8 +185,8 @@ int main(int argc, const char **argv)
     std::cout << "Velocity control: in articular..." << std::endl;
 
     q = 0 ;
-    q[0] = vpMath::rad(2) ; // rotation arround vertical axis
-    std::cout << "  rotation arround vertical axis: " << q[0] << std::endl;
+    q[0] = vpMath::rad(2) ; // rotation around vertical axis
+    std::cout << "  rotation around vertical axis: " << q[0] << std::endl;
     if (control)
       robot.setVelocity(vpRobot::ARTICULAR_FRAME, q) ;
     sleep(5) ;
@@ -227,7 +225,7 @@ int main(int argc, const char **argv)
     std::cout << "Velocity control: in camera frame..." << std::endl;
     q.resize(6);
     q = 0.0;
-    q[0] = vpMath::rad(2); // rotation arround vertical axis
+    q[0] = vpMath::rad(2); // rotation around vertical axis
     std::cout << "  rx rotation: " << q[0] << std::endl;
     if (control)
       robot.setVelocity(vpRobot::CAMERA_FRAME, q);
@@ -235,7 +233,7 @@ int main(int argc, const char **argv)
 
     q.resize(6);
     q = 0.0;
-    q[1] = vpMath::rad(2); // rotation arround vertical axis
+    q[1] = vpMath::rad(2); // rotation around vertical axis
     std::cout << "  ry rotation: " << q[1] << std::endl;
     if (control)
       robot.setVelocity(vpRobot::CAMERA_FRAME, q);
