@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -33,10 +33,8 @@
  *   eye-in-hand control
  *   velocity computed in the camera frame
  *
- * Authors:
- * Nicolas Melchior
- *
- *****************************************************************************/
+*****************************************************************************/
+
 /*!
   \file servoAfma62DhalfCamVelocity.cpp
 
@@ -110,7 +108,7 @@ int main()
 
 #ifdef VISP_HAVE_X11
     vpDisplayX display(I, 100, 100, "Current image");
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display(I, 100, 100, "Current image");
 #elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display(I, 100, 100, "Current image");
@@ -175,7 +173,8 @@ int main()
     vpMe me;
     me.setRange(10);
     me.setPointsToTrack(100);
-    me.setThreshold(50000);
+    me.setLikelihoodThresholdType(vpMe::NORMALIZED_THRESHOLD);
+    me.setThreshold(15);
     me.setSampleStep(10);
 
     // Initialize the tracking. Define the four lines to track
@@ -193,7 +192,7 @@ int main()
       double x = 0, y = 0;
 
       if (!vpMeLine::intersection(line[i % nbline], line[(i + 1) % nbline], ip)) {
-        exit(-1);
+        return EXIT_FAILURE;
       }
 
       vpPixelMeterConversion::convertPoint(cam, ip, x, y);
@@ -216,8 +215,8 @@ int main()
       pose.addPoint(point[i]); // and added to the pose computation point list
     }
 
-    pose.computePose(vpPose::LAGRANGE, cMo);
-    pose.computePose(vpPose::VIRTUAL_VS, cMo);
+    // Pose by Dementhon or Lagrange provides an initialization of the non linear virtual visual-servoing pose estimation
+    pose.computePose(vpPose::DEMENTHON_LAGRANGE_VIRTUAL_VS, cMo);
 
     vpTRACE("sets the current position of the visual feature ");
 
@@ -290,7 +289,7 @@ int main()
           double x = 0, y = 0;
 
           if (!vpMeLine::intersection(line[i % nbline], line[(i + 1) % nbline], ip)) {
-            exit(-1);
+            return EXIT_FAILURE;
           }
 
           vpPixelMeterConversion::convertPoint(cam, ip, x, y);
@@ -353,7 +352,8 @@ int main()
 
         robot.setVelocity(vpRobot::CAMERA_FRAME, v);
 
-      } catch (...) {
+      }
+      catch (...) {
         v = 0;
         robot.setVelocity(vpRobot::CAMERA_FRAME, v);
         robot.stopMotion();
