@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -32,10 +32,9 @@
  * Example that shows how to do visual servoing with Parrot Bebop 2 drone in ViSP.
  *
  * Authors:
- * Fabien Spindler
  * Gatien Gaumerais
  *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <iostream>
 
@@ -50,6 +49,7 @@
 #include <visp3/core/vpPixelMeterConversion.h>
 #include <visp3/core/vpPoint.h>
 #include <visp3/core/vpTime.h>
+#include <visp3/core/vpXmlParserCamera.h>
 #include <visp3/detection/vpDetectorAprilTag.h>
 #include <visp3/gui/vpDisplayX.h>
 #include <visp3/gui/vpPlot.h>
@@ -60,7 +60,6 @@
 #include <visp3/visual_features/vpFeatureVanishingPoint.h>
 #include <visp3/vs/vpServo.h>
 #include <visp3/vs/vpServoDisplay.h>
-#include <visp3/core/vpXmlParserCamera.h>
 
 #if !defined(VISP_HAVE_ARSDK)
 int main()
@@ -77,7 +76,8 @@ int main()
 #elif (VISP_CXX_STANDARD < VISP_CXX_STANDARD_11)
 int main()
 {
-  std::cout << "\nThis example requires cxx11 standard or higher. Turn it on using cmake -DUSE_CXX_STANDARD=11.\n" << std::endl;
+  std::cout << "\nThis example requires cxx11 standard or higher. Turn it on using cmake -DUSE_CXX_STANDARD=11.\n"
+            << std::endl;
   return EXIT_SUCCESS;
 }
 #else
@@ -119,7 +119,7 @@ int main(int argc, char **argv)
       tagSize = std::atof(argv[2]); // Tag size option is required
       if (tagSize <= 0) {
         std::cout << "Error : invalid tag size." << std::endl << "See " << argv[0] << " --help" << std::endl;
-        return 0;
+        return EXIT_FAILURE;
       }
       for (int i = 3; i < argc; i++) {
         if (std::string(argv[i]) == "--ip" && i + 1 < argc) {
@@ -129,7 +129,7 @@ int main(int argc, char **argv)
           opt_distance_to_tag = std::atof(argv[i + 1]);
           if (opt_distance_to_tag <= 0) {
             std::cout << "Error : invalid distance to tag." << std::endl << "See " << argv[0] << " --help" << std::endl;
-            return 0;
+            return EXIT_FAILURE;
           }
           opt_has_distance_to_tag = true;
           i++;
@@ -145,7 +145,7 @@ int main(int argc, char **argv)
         } else {
           std::cout << "Error : unknown parameter " << argv[i] << std::endl
                     << "See " << argv[0] << " --help" << std::endl;
-          return 0;
+          return EXIT_FAILURE;
         }
       }
     } else if (argc >= 2 && (std::string(argv[1]) == "--help" || std::string(argv[1]) == "-h")) {
@@ -176,11 +176,10 @@ int main(int argc, char **argv)
                 << "  --help, -h\n"
                 << "      Print help message.\n"
                 << std::endl;
-      return 0;
-
+      return EXIT_SUCCESS;
     } else {
       std::cout << "Error : tag size parameter required." << std::endl << "See " << argv[0] << " --help" << std::endl;
-      return 0;
+      return EXIT_FAILURE;
     }
 
     std::cout
@@ -218,13 +217,13 @@ int main(int argc, char **argv)
       vpImage<unsigned char> I;
       drone.getGrayscaleImage(I);
 
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
       vpDisplayX display;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
       vpDisplayGTK display;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
       vpDisplayGDI display;
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
       vpDisplayOpenCV display;
 #endif
       int orig_displayX = 100;
@@ -328,7 +327,7 @@ int main(int argc, char **argv)
       vpMomentGravityCenter mg, mg_d;
       vpMomentCentered mc, mc_d;
       vpMomentAreaNormalized man(0, Z_d), man_d(0, Z_d); // Declare normalized area updated below with m00
-      vpMomentGravityCenterNormalized mgn, mgn_d; // Declare normalized gravity center
+      vpMomentGravityCenterNormalized mgn, mgn_d;        // Declare normalized gravity center
 
       // Desired moments
       m_obj_d.setType(vpMomentObject::DENSE_POLYGON); // Consider the AprilTag as a polygon
@@ -426,13 +425,13 @@ int main(int argc, char **argv)
           m_obj.setType(vpMomentObject::DENSE_POLYGON); // Consider the AprilTag as a polygon
           m_obj.fromVector(vec_P);                      // Initialize the object with the points coordinates
 
-          mg.linkTo(mdb);       // Add gravity center to database
-          mc.linkTo(mdb);       // Add centered moments to database
-          man.linkTo(mdb);      // Add area normalized to database
-          mgn.linkTo(mdb);      // Add gravity center normalized to database
-          mdb.updateAll(m_obj); // All of the moments must be updated, not just an_d
-          mg.compute();         // Compute gravity center moment
-          mc.compute();         // Compute centered moments AFTER gravity center
+          mg.linkTo(mdb);           // Add gravity center to database
+          mc.linkTo(mdb);           // Add centered moments to database
+          man.linkTo(mdb);          // Add area normalized to database
+          mgn.linkTo(mdb);          // Add gravity center normalized to database
+          mdb.updateAll(m_obj);     // All of the moments must be updated, not just an_d
+          mg.compute();             // Compute gravity center moment
+          mc.compute();             // Compute centered moments AFTER gravity center
           man.setDesiredArea(area); // Desired area was init at 0 (unknow at contruction), need to be updated here
           man.compute();            // Compute area normalized moment AFTER centered moment
           mgn.compute();            // Compute gravity center normalized moment AFTER area normalized moment
