@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,9 +31,8 @@
  * Description:
  *  Tests the control law
  * Authors:
- * Fabien Spindler
  *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \file moveBiclops.cpp
 
@@ -79,13 +78,15 @@ void usage(const char *name, const char *badparam, std::string conf)
 Move the biclops robot\n\
 \n\
 SYNOPSIS\n\
-  %s [-c <Biclops configuration file>] [-h]\n						      \
-", name);
+  %s [-c <Biclops configuration file>] [-h]\n\
+",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
   -c <Biclops configuration file>                      %s\n\
-     Sets the biclops robot configuration file.\n\n", conf.c_str());
+     Sets the biclops robot configuration file.\n\n",
+          conf.c_str());
 
   if (badparam) {
     fprintf(stderr, "ERROR: \n");
@@ -143,7 +144,7 @@ int main(int argc, const char **argv)
 
   // Read the command line options
   if (getOptions(argc, argv, opt_conf) == false) {
-    exit(-1);
+    return EXIT_FAILURE;
   }
   try {
     vpRobotBiclops robot(opt_conf.c_str());
@@ -274,8 +275,7 @@ int main(int argc, const char **argv)
     std::cout << "Velocity in the articular frame: "
               << " pan: " << vpMath::deg(qm[0]) << " tilt: " << vpMath::deg(qm[1]) << std::endl;
     return EXIT_SUCCESS;
-  }
-  catch (const vpException &e) {
+  } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e.getMessage() << std::endl;
     return EXIT_FAILURE;
   }
