@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -33,10 +33,7 @@
  *   eye-in-hand control
  *   velocity computed in articular
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file servoBiclopsPoint2DArtVelocity.cpp
@@ -126,7 +123,8 @@ void usage(const char *name, const char *badparam, std::string &conf, std::strin
   point.\n\
 \n\
 SYNOPSIS\n\
-  %s [-c <Biclops configuration file>] [-d <debug file directory>] [-h]\n", name);
+  %s [-c <Biclops configuration file>] [-d <debug file directory>] [-h]\n",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
@@ -136,7 +134,8 @@ OPTIONS:                                               Default\n\
      Sets the debug file directory.\n\
      From this directory, creates the\"%s\"\n\
      subdirectory depending on the username, where\n\
-     it writes biclops.txt file.\n", conf.c_str(), debugdir.c_str(), user.c_str());
+     it writes biclops.txt file.\n",
+          conf.c_str(), debugdir.c_str(), user.c_str());
 
   if (badparam) {
     fprintf(stderr, "ERROR: \n");
@@ -229,7 +228,7 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, opt_conf, opt_debugdir, username) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Get the option value
@@ -249,14 +248,14 @@ int main(int argc, const char **argv)
         std::cerr << std::endl << "ERROR:" << std::endl;
         std::cerr << "  Cannot create " << dirname << std::endl;
         std::cerr << "  Check your -d " << debugdir << " option " << std::endl;
-        exit(-1);
+        return EXIT_FAILURE;
       }
     }
 
     // Create the debug file: debugdir/$user/biclops.txt
-    char filename[FILENAME_MAX];
-    sprintf(filename, "%s/biclops.txt", debugdir.c_str());
-    FILE *fd = fopen(filename, "w");
+    std::string filename;
+    filename = debugdir + "/biclops.txt";
+    FILE *fd = fopen(filename.c_str(), "w");
 
     vpRobotBiclops robot(opt_conf.c_str());
     robot.setDenavitHartenbergModel(vpBiclops::DH2);
@@ -282,14 +281,14 @@ int main(int argc, const char **argv)
       g.acquire(I);
     } catch (...) {
       vpERROR_TRACE(" Error caught");
-      return (-1);
+      return EXIT_FAILURE;
     }
 
 // We open a window using either X11 or GTK or GDI.
 // Its size is automatically defined by the image (I) size
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     vpDisplayX display(I, 100, 100, "Display X...");
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display(I, 100, 100, "Display GTK...");
 #elif defined(_WIN32)
     vpDisplayGDI display(I, 100, 100, "Display GDI...");
@@ -300,7 +299,7 @@ int main(int argc, const char **argv)
       vpDisplay::flush(I);
     } catch (...) {
       vpERROR_TRACE(" Error caught");
-      return (-1);
+      return EXIT_FAILURE;
     }
 
     vpServo task;
@@ -315,7 +314,7 @@ int main(int argc, const char **argv)
       vpERROR_TRACE("after dot.initTracking(I) ");
     } catch (...) {
       vpERROR_TRACE(" Error caught");
-      return (-1);
+      return EXIT_FAILURE;
     }
 
     vpCameraParameters cam;
@@ -378,9 +377,6 @@ int main(int argc, const char **argv)
 
       dot.track(I);
 
-      //    vpDisplay::displayCross(I,(int)dot.I(), (int)dot.J(),
-      //			   10,vpColor::green) ;
-
       vpFeatureBuilder::create(p, cam, dot);
 
       // get the jacobian
@@ -413,8 +409,7 @@ int main(int argc, const char **argv)
     fclose(fd);
 
     return EXIT_SUCCESS;
-  }
-  catch (const vpException &e) {
+  } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e.getMessage() << std::endl;
     return EXIT_FAILURE;
   }
