@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,7 +31,7 @@
  * Description:
  * Data acquisition with RealSense RGB-D sensor and Franka robot.
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example servoFrankaPBVS.cpp
@@ -42,7 +42,7 @@
   controller. Visual features correspond to the 3D pose of the target (an AprilTag)
   in the camera frame.
 
-  The device used to acquire images is a Realsense SR300 device.
+  The device used to acquire images is a Realsense D435 device.
 
   Camera extrinsic (eMc) parameters are set by default to a value that will not match
   Your configuration. Use --eMc command line option to read the values from a file.
@@ -59,20 +59,20 @@
 #include <iostream>
 
 #include <visp3/core/vpCameraParameters.h>
+#include <visp3/detection/vpDetectorAprilTag.h>
 #include <visp3/gui/vpDisplayGDI.h>
 #include <visp3/gui/vpDisplayX.h>
+#include <visp3/gui/vpPlot.h>
 #include <visp3/io/vpImageIo.h>
-#include <visp3/sensor/vpRealSense2.h>
 #include <visp3/robot/vpRobotFranka.h>
-#include <visp3/detection/vpDetectorAprilTag.h>
+#include <visp3/sensor/vpRealSense2.h>
 #include <visp3/visual_features/vpFeatureThetaU.h>
 #include <visp3/visual_features/vpFeatureTranslation.h>
 #include <visp3/vs/vpServo.h>
 #include <visp3/vs/vpServoDisplay.h>
-#include <visp3/gui/vpPlot.h>
 
-#if defined(VISP_HAVE_REALSENSE2) && (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11) && \
-  (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI)) && defined(VISP_HAVE_FRANKA)
+#if defined(VISP_HAVE_REALSENSE2) && (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11) &&                                    \
+    (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI)) && defined(VISP_HAVE_FRANKA)
 
 void display_point_trajectory(const vpImage<unsigned char> &I, const std::vector<vpImagePoint> &vip,
                               std::vector<vpImagePoint> *traj_vip)
@@ -83,8 +83,7 @@ void display_point_trajectory(const vpImage<unsigned char> &I, const std::vector
       if (vpImagePoint::distance(vip[i], traj_vip[i].back()) > 1.) {
         traj_vip[i].push_back(vip[i]);
       }
-    }
-    else {
+    } else {
       traj_vip[i].push_back(vip[i]);
     }
   }
@@ -106,41 +105,36 @@ int main(int argc, char **argv)
   bool opt_plot = false;
   bool opt_adaptive_gain = false;
   bool opt_task_sequencing = false;
-  double convergence_threshold_t = 0.0005, convergence_threshold_tu = vpMath::rad(0.5);
+  double convergence_threshold_t = 0.0005; // Value in [m]
+  double convergence_threshold_tu = 0.5;   // Value in [deg]
 
   for (int i = 1; i < argc; i++) {
     if (std::string(argv[i]) == "--tag_size" && i + 1 < argc) {
       opt_tagSize = std::stod(argv[i + 1]);
-    }
-    else if (std::string(argv[i]) == "--ip" && i + 1 < argc) {
+    } else if (std::string(argv[i]) == "--ip" && i + 1 < argc) {
       opt_robot_ip = std::string(argv[i + 1]);
-    }
-    else if (std::string(argv[i]) == "--eMc" && i + 1 < argc) {
+    } else if (std::string(argv[i]) == "--eMc" && i + 1 < argc) {
       opt_eMc_filename = std::string(argv[i + 1]);
-    }
-    else if (std::string(argv[i]) == "--verbose") {
+    } else if (std::string(argv[i]) == "--verbose") {
       opt_verbose = true;
-    }
-    else if (std::string(argv[i]) == "--plot") {
+    } else if (std::string(argv[i]) == "--plot") {
       opt_plot = true;
-    }
-    else if (std::string(argv[i]) == "--adaptive_gain") {
+    } else if (std::string(argv[i]) == "--adaptive_gain") {
       opt_adaptive_gain = true;
-    }
-    else if (std::string(argv[i]) == "--task_sequencing") {
+    } else if (std::string(argv[i]) == "--task_sequencing") {
       opt_task_sequencing = true;
-    }
-    else if (std::string(argv[i]) == "--quad_decimate" && i + 1 < argc) {
+    } else if (std::string(argv[i]) == "--quad_decimate" && i + 1 < argc) {
       opt_quad_decimate = std::stoi(argv[i + 1]);
-    }
-    else if (std::string(argv[i]) == "--no-convergence-threshold") {
+    } else if (std::string(argv[i]) == "--no-convergence-threshold") {
       convergence_threshold_t = 0.;
       convergence_threshold_tu = 0.;
-    }
-    else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
-      std::cout << argv[0] << " [--ip <default " << opt_robot_ip << ">] [--tag_size <marker size in meter; default " << opt_tagSize << ">] [--eMc <eMc extrinsic file>] "
-                           << "[--quad_decimate <decimation; default " << opt_quad_decimate << ">] [--adaptive_gain] [--plot] [--task_sequencing] [--no-convergence-threshold] [--verbose] [--help] [-h]"
-                           << "\n";
+    } else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
+      std::cout
+          << argv[0] << " [--ip <default " << opt_robot_ip << ">] [--tag_size <marker size in meter; default "
+          << opt_tagSize << ">] [--eMc <eMc extrinsic file>] "
+          << "[--quad_decimate <decimation; default " << opt_quad_decimate
+          << ">] [--adaptive_gain] [--plot] [--task_sequencing] [--no-convergence-threshold] [--verbose] [--help] [-h]"
+          << "\n";
       return EXIT_SUCCESS;
     }
   }
@@ -161,21 +155,26 @@ int main(int argc, char **argv)
     // Get camera extrinsics
     vpPoseVector ePc;
     // Set camera extrinsics default values
-    ePc[0] = 0.0337731; ePc[1] = -0.00535012; ePc[2] = -0.0523339;
-    ePc[3] = -0.247294; ePc[4] = -0.306729; ePc[5] = 1.53055;
+    ePc[0] = 0.0337731;
+    ePc[1] = -0.00535012;
+    ePc[2] = -0.0523339;
+    ePc[3] = -0.247294;
+    ePc[4] = -0.306729;
+    ePc[5] = 1.53055;
 
     // If provided, read camera extrinsics from --eMc <file>
     if (!opt_eMc_filename.empty()) {
       ePc.loadYAML(opt_eMc_filename, ePc);
-    }
-    else {
-      std::cout << "Warning, opt_eMc_filename is empty! Use hard coded values." << "\n";
+    } else {
+      std::cout << "Warning, opt_eMc_filename is empty! Use hard coded values."
+                << "\n";
     }
     vpHomogeneousMatrix eMc(ePc);
     std::cout << "eMc:\n" << eMc << "\n";
 
     // Get camera intrinsics
-    vpCameraParameters cam = rs.getCameraParameters(RS2_STREAM_COLOR, vpCameraParameters::perspectiveProjWithDistortion);
+    vpCameraParameters cam =
+        rs.getCameraParameters(RS2_STREAM_COLOR, vpCameraParameters::perspectiveProjWithDistortion);
     std::cout << "cam:\n" << cam << "\n";
 
     vpImage<unsigned char> I(height, width);
@@ -188,7 +187,7 @@ int main(int argc, char **argv)
 
     vpDetectorAprilTag::vpAprilTagFamily tagFamily = vpDetectorAprilTag::TAG_36h11;
     vpDetectorAprilTag::vpPoseEstimationMethod poseEstimationMethod = vpDetectorAprilTag::HOMOGRAPHY_VIRTUAL_VS;
-    //vpDetectorAprilTag::vpPoseEstimationMethod poseEstimationMethod = vpDetectorAprilTag::BEST_RESIDUAL_VIRTUAL_VS;
+    // vpDetectorAprilTag::vpPoseEstimationMethod poseEstimationMethod = vpDetectorAprilTag::BEST_RESIDUAL_VIRTUAL_VS;
     vpDetectorAprilTag detector(tagFamily);
     detector.setAprilTagPoseEstimationMethod(poseEstimationMethod);
     detector.setDisplayTag(display_tag);
@@ -198,8 +197,8 @@ int main(int argc, char **argv)
     vpHomogeneousMatrix cdMc, cMo, oMo;
 
     // Desired pose to reach
-    vpHomogeneousMatrix cdMo( vpTranslationVector(0, 0, opt_tagSize * 3), // 3 times tag with along camera z axis
-                              vpRotationMatrix( {1, 0, 0, 0, -1, 0, 0, 0, -1} ) );
+    vpHomogeneousMatrix cdMo(vpTranslationVector(0, 0, opt_tagSize * 3), // 3 times tag with along camera z axis
+                             vpRotationMatrix({1, 0, 0, 0, -1, 0, 0, 0, -1}));
 
     cdMc = cdMo * cMo.inverse();
     vpFeatureTranslation t(vpFeatureTranslation::cdMc);
@@ -219,8 +218,7 @@ int main(int argc, char **argv)
     if (opt_adaptive_gain) {
       vpAdaptiveGain lambda(1.5, 0.4, 30); // lambda(0)=4, lambda(oo)=0.4 and lambda'(0)=30
       task.setLambda(lambda);
-    }
-    else {
+    } else {
       task.setLambda(0.5);
     }
 
@@ -228,7 +226,8 @@ int main(int argc, char **argv)
     int iter_plot = 0;
 
     if (opt_plot) {
-      plotter = new vpPlot(2, static_cast<int>(250 * 2), 500, static_cast<int>(I.getWidth()) + 80, 10, "Real time curves plotter");
+      plotter = new vpPlot(2, static_cast<int>(250 * 2), 500, static_cast<int>(I.getWidth()) + 80, 10,
+                           "Real time curves plotter");
       plotter->setTitle(0, "Visual features error");
       plotter->setTitle(1, "Camera velocities");
       plotter->initGraph(0, 6);
@@ -280,7 +279,7 @@ int main(int argc, char **argv)
 
         static bool first_time = true;
         if (first_time) {
-          // Introduce security wrt tag positionning in order to avoid PI rotation
+          // Introduce security wrt tag positioning in order to avoid PI rotation
           std::vector<vpHomogeneousMatrix> v_oMo(2), v_cdMc(2);
           v_oMo[1].buildFrom(0, 0, 0, 0, 0, M_PI);
           for (size_t i = 0; i < 2; i++) {
@@ -288,10 +287,9 @@ int main(int argc, char **argv)
           }
           if (std::fabs(v_cdMc[0].getThetaUVector().getTheta()) < std::fabs(v_cdMc[1].getThetaUVector().getTheta())) {
             oMo = v_oMo[0];
-          }
-          else {
+          } else {
             std::cout << "Desired frame modified to avoid PI rotation of the camera" << std::endl;
-            oMo = v_oMo[1];   // Introduce PI rotation
+            oMo = v_oMo[1]; // Introduce PI rotation
           }
         }
 
@@ -301,28 +299,27 @@ int main(int argc, char **argv)
         tu.buildFrom(cdMc);
 
         if (opt_task_sequencing) {
-          if (! servo_started) {
+          if (!servo_started) {
             if (send_velocities) {
               servo_started = true;
             }
             t_init_servo = vpTime::measureTimeMs();
           }
-          v_c = task.computeControlLaw((vpTime::measureTimeMs() - t_init_servo)/1000.);
-        }
-        else {
+          v_c = task.computeControlLaw((vpTime::measureTimeMs() - t_init_servo) / 1000.);
+        } else {
           v_c = task.computeControlLaw();
         }
 
         // Display desired and current pose features
         vpDisplay::displayFrame(I, cdMo * oMo, cam, opt_tagSize / 1.5, vpColor::yellow, 2);
-        vpDisplay::displayFrame(I, cMo,  cam, opt_tagSize / 2,   vpColor::none,   3);
+        vpDisplay::displayFrame(I, cMo, cam, opt_tagSize / 2, vpColor::none, 3);
         // Get tag corners
         std::vector<vpImagePoint> vip = detector.getPolygon(0);
         // Get the tag cog corresponding to the projection of the tag frame in the image
         vip.push_back(detector.getCog(0));
         // Display the trajectory of the points
         if (first_time) {
-           traj_vip = new std::vector<vpImagePoint> [vip.size()];
+          traj_vip = new std::vector<vpImagePoint>[vip.size()];
         }
         display_point_trajectory(I, vip, traj_vip);
 
@@ -353,7 +350,8 @@ int main(int argc, char **argv)
 
         if (error_tr < convergence_threshold_t && error_tu < convergence_threshold_tu) {
           has_converged = true;
-          std::cout << "Servo task has converged" << std::endl;;
+          std::cout << "Servo task has converged" << std::endl;
+          ;
           vpDisplay::displayText(I, 100, 20, "Servo task has converged", vpColor::red);
         }
 
@@ -419,27 +417,25 @@ int main(int argc, char **argv)
     }
 
     if (traj_vip) {
-      delete [] traj_vip;
+      delete[] traj_vip;
     }
-  }
-  catch(const vpException &e) {
+  } catch (const vpException &e) {
     std::cout << "ViSP exception: " << e.what() << std::endl;
     std::cout << "Stop the robot " << std::endl;
     robot.setRobotState(vpRobot::STATE_STOP);
     return EXIT_FAILURE;
-  }
-  catch(const franka::NetworkException &e) {
+  } catch (const franka::NetworkException &e) {
     std::cout << "Franka network exception: " << e.what() << std::endl;
     std::cout << "Check if you are connected to the Franka robot"
-              << " or if you specified the right IP using --ip command line option set by default to 192.168.1.1. " << std::endl;
+              << " or if you specified the right IP using --ip command line option set by default to 192.168.1.1. "
+              << std::endl;
     return EXIT_FAILURE;
-  }
-  catch(const std::exception &e) {
+  } catch (const std::exception &e) {
     std::cout << "Franka exception: " << e.what() << std::endl;
     return EXIT_FAILURE;
   }
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 #else
 int main()
@@ -453,6 +449,6 @@ int main()
 #if !defined(VISP_HAVE_FRANKA)
   std::cout << "Install libfranka." << std::endl;
 #endif
-  return 0;
+  return EXIT_SUCCESS;
 }
 #endif
