@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,31 +31,28 @@
  * Description:
  * IBVS on Pioneer P3DX mobile platform
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 #include <iostream>
 
 #include <visp3/core/vpConfig.h>
 
-#include <visp3/robot/vpRobotPioneer.h> // Include first to avoid build issues with Status, None, isfinite
 #include <visp3/blob/vpDot2.h>
 #include <visp3/core/vpCameraParameters.h>
 #include <visp3/core/vpHomogeneousMatrix.h>
 #include <visp3/core/vpImage.h>
 #include <visp3/core/vpVelocityTwistMatrix.h>
 #include <visp3/gui/vpDisplayGDI.h>
+#include <visp3/gui/vpDisplayX.h> // Should be included after vpRobotPioneer.h
 #include <visp3/gui/vpPlot.h>
 #include <visp3/robot/vpPioneerPan.h>
 #include <visp3/robot/vpRobotBiclops.h>
+#include <visp3/robot/vpRobotPioneer.h> // Include first to avoid build issues with Status, None, isfinite
 #include <visp3/sensor/vp1394CMUGrabber.h>
 #include <visp3/sensor/vp1394TwoGrabber.h>
 #include <visp3/sensor/vpV4l2Grabber.h>
 #include <visp3/visual_features/vpFeatureBuilder.h>
 #include <visp3/visual_features/vpFeatureSegment.h>
 #include <visp3/vs/vpServo.h>
-#include <visp3/gui/vpDisplayX.h> // Should be included after vpRobotPioneer.h
 
 #define USE_REAL_ROBOT
 #define USE_PLOTTER
@@ -68,7 +65,7 @@
   servoing with respect to a segment. The segment consists in two horizontal
   dots. The current visual features that are used are \f${\bf s} = (x_n, l_n,
   \alpha)\f$. The desired one are \f${\bf s^*} = (0, l_n*, 0)\f$, with:
-  - \f$x_n\f$ the normalized abscisse of the point corresponding to segment
+  - \f$x_n\f$ the normalized abscise of the point corresponding to segment
   - \f$l_n\f$ the normalized segment length
   - \f$\alpha\f$ the segment orientation.
 
@@ -153,7 +150,7 @@ int main(int argc, char **argv)
 
     // Wait 3 sec to be sure that the low level Aria thread used to control
     // the robot is started. Without this delay we experienced a delay
-    // (arround 2.2 sec) between the velocity send to the robot and the
+    // (around 2.2 sec) between the velocity send to the robot and the
     // velocity that is really applied to the wheels.
     sleep(3);
 
