@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -33,10 +33,7 @@
  *   eye-in-hand control
  *   velocity computed in articular
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file servoPtu46Point2DArtVelocity.cpp
@@ -140,7 +137,7 @@ int main()
       g.acquire(I);
     } catch (...) {
       vpERROR_TRACE(" Error caught");
-      return (-1);
+      return EXIT_FAILURE;
     }
 
     vpDisplayX display(I, 100, 100, "testDisplayX.cpp ");
@@ -151,7 +148,7 @@ int main()
       vpDisplay::flush(I);
     } catch (...) {
       vpERROR_TRACE(" Error caught");
-      return (-1);
+      return EXIT_FAILURE;
     }
 
     vpServo task;
@@ -169,7 +166,7 @@ int main()
       vpERROR_TRACE("after dot.initTracking(I) ");
     } catch (...) {
       vpERROR_TRACE(" Error caught ");
-      return (-1);
+      return EXIT_FAILURE;
     }
 
     vpCameraParameters cam;
@@ -231,9 +228,6 @@ int main()
 
       dot.track(I);
 
-      //    vpDisplay::displayCross(I,(int)dot.I(), (int)dot.J(),
-      //			   10,vpColor::green) ;
-
       vpFeatureBuilder::create(p, cam, dot);
 
       // get the jacobian
@@ -255,8 +249,7 @@ int main()
 
     vpTRACE("Display task information ");
     task.print();
-  }
-  catch (const vpException &e) {
+  } catch (const vpException &e) {
     std::cout << "Sorry PtU46 not available. Got exception: " << e << std::endl;
     return EXIT_FAILURE
   }
@@ -264,8 +257,5 @@ int main()
 }
 
 #else
-int main()
-{
-  std::cout << "You do not have an PTU46 PT robot connected to your computer..." << std::endl;
-}
+int main() { std::cout << "You do not have an PTU46 PT robot connected to your computer..." << std::endl; }
 #endif
