@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -33,11 +33,7 @@
  *   eye-in-hand control
  *   velocity computed in articular
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example servoViper850Point2DArtVelocity-jointAvoidance-basic.cpp
@@ -121,7 +117,7 @@ int main()
 
 #ifdef VISP_HAVE_X11
     vpDisplayX display(I, 800, 100, "Current image");
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display(I, 800, 100, "Current image");
 #elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display(I, 800, 100, "Current image");
@@ -175,11 +171,10 @@ int main()
     plot.setTitle(1, "Joint velocity");
 
     // For the first graphic, set the curves legend
-    char legend[10];
+    std::string legend;
     for (unsigned int i = 0; i < 6; i++) {
-      sprintf(legend, "q%u", i + 1);
+      legend = "q" + i + 1;
       plot.setLegend(0, i, legend);
-      sprintf(legend, "q%u", i + 1);
       plot.setLegend(1, i, legend);
     }
     plot.setLegend(0, 6, "tQmin");
@@ -342,7 +337,6 @@ int main()
         unsigned int k = 0;
 
         for (unsigned int j = 0; j < 6; j++) // j is the joint
-          // if (pb[j]==1)	{
           if (std::fabs(pb[j] - 1) <= std::numeric_limits<double>::epsilon()) {
             for (unsigned int i = 0; i < dimKernelL; i++)
               E[k][i] = kernelJ1[j][i];
@@ -401,8 +395,7 @@ int main()
     // Display task information
     task.print();
     return EXIT_SUCCESS;
-  }
-  catch (const vpException &e) {
+  } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e.getMessage() << std::endl;
     return EXIT_FAILURE;
   }
