@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -33,11 +33,7 @@
  *   eye-in-hand control
  *   velocity computed in camera frame
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example servoViper850Point2DCamVelocity.cpp
@@ -103,7 +99,7 @@ int main()
     } catch (...) {
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Cannot create " << logdirname << std::endl;
-      exit(-1);
+      return EXIT_FAILURE;
     }
   }
   std::string logfilename;
@@ -133,7 +129,7 @@ int main()
 
 #ifdef VISP_HAVE_X11
     vpDisplayX display(I, (int)(100 + I.getWidth() + 30), 200, "Current image");
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display(I, (int)(100 + I.getWidth() + 30), 200, "Current image");
 #elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display(I, (int)(100 + I.getWidth() + 30), 200, "Current image");
@@ -223,7 +219,7 @@ int main()
         v = 0;
         // Stop robot
         robot.setVelocity(vpRobot::CAMERA_FRAME, v);
-        return 0;
+        return EXIT_FAILURE;
       }
 
       // Save velocities applied to the robot in the log file
@@ -266,8 +262,7 @@ int main()
     task.print();
 
     return EXIT_SUCCESS;
-  }
-  catch (const vpException &e) {
+  } catch (const vpException &e) {
     flog.close(); // Close the log file
     std::cout << "Catch an exception: " << e.getMessage() << std::endl;
     return EXIT_FAILURE;
