@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -29,12 +29,9 @@
  * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  *
  * Description:
- * Example of keybord management.
+ * Example of parallel port management.
  *
- * Author:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example parallelPort.cpp
@@ -73,7 +70,8 @@ Send a data to the parallel port.\n\
 \n\
 SYNOPSIS\n\
   %s [-d <data>] [-h]\n\
-", name);
+",
+name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
@@ -82,7 +80,8 @@ OPTIONS:                                               Default\n\
      Value should be in [0:255].\n\
 \n\
   -h\n\
-     Print the help.\n\n", data);
+     Print the help.\n\n",
+          data);
 
   if (badparam) {
     fprintf(stderr, "ERROR: \n");
@@ -117,7 +116,8 @@ bool getOptions(int argc, const char **argv, unsigned char &data)
         std::cerr << "ERROR: " << std::endl;
         std::cerr << "  Bad value \"-d " << optarg << "\"" << std::endl << std::endl;
         return false;
-      } else {
+      }
+      else {
         data = (unsigned char)value;
       }
       break;
@@ -157,7 +157,7 @@ int main(int argc, const char **argv)
 
   // Read the command line options
   if (getOptions(argc, argv, data) == false) {
-    exit(-1);
+    return EXIT_FAILURE;
   }
   try {
 
@@ -166,7 +166,8 @@ int main(int argc, const char **argv)
     printf("Send data \"%d\" to the parallel port\n", data);
     parport.sendData(data);
 
-  } catch (vpParallelPortException &e) {
+  }
+  catch (vpParallelPortException &e) {
     switch (e.getCode()) {
     case vpParallelPortException::opening:
       printf("Can't open the parallel port\n");
@@ -175,7 +176,8 @@ int main(int argc, const char **argv)
       printf("Can't close the parallel port\n");
       break;
     }
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "An error occurs: " << e.getMessage() << std::endl;
   }
   return EXIT_SUCCESS;
