@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * Example of Hybrid Tracking of MBT and MBT KTL.
  *
- * Authors:
- * Aurelien Yol
- * Souriya Trinh
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example mbtGenericTracking2.cpp
@@ -47,8 +43,8 @@
 #include <iostream>
 #include <visp3/core/vpConfig.h>
 
-#if (defined(VISP_HAVE_MODULE_MBT) && defined(VISP_HAVE_DISPLAY)) \
-  && (defined(VISP_HAVE_LAPACK) || defined(VISP_HAVE_EIGEN3) || defined(VISP_HAVE_OPENCV))
+#if (defined(VISP_HAVE_MODULE_MBT) && defined(VISP_HAVE_DISPLAY)) &&                                                   \
+    (defined(VISP_HAVE_LAPACK) || defined(VISP_HAVE_EIGEN3) || defined(VISP_HAVE_OPENCV))
 
 #include <visp3/core/vpDebug.h>
 #include <visp3/core/vpHomogeneousMatrix.h>
@@ -70,6 +66,11 @@
 
 void usage(const char *name, const char *badparam)
 {
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+  std::string ext("png");
+#else
+  std::string ext("pgm");
+#endif
   fprintf(stdout, "\n\
 Example of tracking based on the 3D model.\n\
 \n\
@@ -77,15 +78,16 @@ SYNOPSIS\n\
   %s [-i <test image path>] [-x <config file>]\n\
   [-m <model name>] [-n <initialisation file base name>] [-e <last frame index>]\n\
   [-t] [-c] [-d] [-h] [-f] [-C] [-o] [-w] [-l] [-v] [-p]\n\
-  [-T <tracker type>]\n", name);
+  [-T <tracker type>]\n",
+    name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               \n\
   -i <input image path>                                \n\
      Set image input path.\n\
      From this path read images \n\
-     \"mbt/cube/image%%04d.ppm\". These \n\
-     images come from ViSP-images-x.y.z.tar.gz available \n\
+     \"mbt/cube/image%%04d.%s\". These \n\
+     images come from visp-images-x.y.z.tar.gz available \n\
      on the ViSP website.\n\
      Setting the VISP_INPUT_IMAGE_PATH environment\n\
      variable produces the same behavior than using\n\
@@ -147,16 +149,16 @@ OPTIONS:                                               \n\
      Set tracker type (<1 (Edge)>, <2 (KLT)>, <3 (EdgeKlt)>).\n\
 \n\
   -h \n\
-     Print the help.\n\n");
+     Print the help.\n\n", ext.c_str());
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
 }
 
 bool getOptions(int argc, const char **argv, std::string &ipath, std::string &configFile, std::string &modelFile,
-                std::string &initFile, long &lastFrame, bool &displayFeatures, bool &click_allowed, bool &display,
-                bool &cao3DModel, bool &trackCylinder, bool &useOgre, bool &showOgreConfigDialog, bool &useScanline,
-                bool &computeCovariance, bool &projectionError, int &trackerType)
+  std::string &initFile, long &lastFrame, bool &displayFeatures, bool &click_allowed, bool &display,
+  bool &cao3DModel, bool &trackCylinder, bool &useOgre, bool &showOgreConfigDialog, bool &useScanline,
+  bool &computeCovariance, bool &projectionError, int &trackerType)
 {
   const char *optarg_;
   int c;
@@ -258,6 +260,12 @@ int main(int argc, const char **argv)
     bool projectionError = false;
     int trackerType = vpMbGenericTracker::EDGE_TRACKER;
 
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+    std::string ext("png");
+#else
+    std::string ext("pgm");
+#endif
+
     // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH
     // environment variable value
     env_ipath = vpIoTools::getViSPImagesDataPath();
@@ -268,8 +276,8 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (!getOptions(argc, argv, opt_ipath, opt_configFile, opt_modelFile, opt_initFile, opt_lastFrame, displayFeatures,
-                    opt_click_allowed, opt_display, cao3DModel, trackCylinder, useOgre, showOgreConfigDialog,
-                    useScanline, computeCovariance, projectionError, trackerType)) {
+      opt_click_allowed, opt_display, cao3DModel, trackCylinder, useOgre, showOgreConfigDialog,
+      useScanline, computeCovariance, projectionError, trackerType)) {
       return EXIT_FAILURE;
     }
 
@@ -278,18 +286,18 @@ int main(int argc, const char **argv)
       usage(argv[0], NULL);
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH " << std::endl
-                << "  environment variable to specify the location of the " << std::endl
-                << "  image path where test images are located." << std::endl
-                << std::endl;
+        << "  environment variable to specify the location of the " << std::endl
+        << "  image path where test images are located." << std::endl
+        << std::endl;
 
       return EXIT_FAILURE;
     }
 
     // Get the option values
     if (!opt_ipath.empty())
-      ipath = vpIoTools::createFilePath(opt_ipath, "mbt/cube/image%04d.pgm");
+      ipath = vpIoTools::createFilePath(opt_ipath, "mbt/cube/image%04d." + ext);
     else
-      ipath = vpIoTools::createFilePath(env_ipath, "mbt/cube/image%04d.pgm");
+      ipath = vpIoTools::createFilePath(env_ipath, "mbt/cube/image%04d." + ext);
 
 #if USE_XML
     std::string configFile;
@@ -303,13 +311,15 @@ int main(int argc, const char **argv)
 
     if (!opt_modelFile.empty()) {
       modelFile = opt_modelFile;
-    } else {
+    }
+    else {
       std::string modelFileCao;
       std::string modelFileWrl;
       if (trackCylinder) {
         modelFileCao = "mbt/cube_and_cylinder.cao";
         modelFileWrl = "mbt/cube_and_cylinder.wrl";
-      } else {
+      }
+      else {
         modelFileCao = "mbt/cube.cao";
         modelFileWrl = "mbt/cube.wrl";
       }
@@ -317,7 +327,8 @@ int main(int argc, const char **argv)
       if (!opt_ipath.empty()) {
         if (cao3DModel) {
           modelFile = vpIoTools::createFilePath(opt_ipath, modelFileCao);
-        } else {
+        }
+        else {
 #ifdef VISP_HAVE_COIN3D
           modelFile = vpIoTools::createFilePath(opt_ipath, modelFileWrl);
 #else
@@ -325,10 +336,12 @@ int main(int argc, const char **argv)
           modelFile = vpIoTools::createFilePath(opt_ipath, modelFileCao);
 #endif
         }
-      } else {
+      }
+      else {
         if (cao3DModel) {
           modelFile = vpIoTools::createFilePath(env_ipath, modelFileCao);
-        } else {
+        }
+        else {
 #ifdef VISP_HAVE_COIN3D
           modelFile = vpIoTools::createFilePath(env_ipath, modelFileWrl);
 #else
@@ -355,7 +368,8 @@ int main(int argc, const char **argv)
       reader.open(I1);
       I2 = I1;
       I3 = I1;
-    } catch (...) {
+    }
+    catch (...) {
       std::cerr << "Cannot open sequence: " << ipath << std::endl;
       return EXIT_FAILURE;
     }
@@ -371,16 +385,16 @@ int main(int argc, const char **argv)
     mapOfImages["Camera2"] = &I2;
     mapOfImages["Camera3"] = &I3;
 
-// initialise a  display
-#if defined VISP_HAVE_X11
+    // initialise a  display
+#if defined(VISP_HAVE_X11)
     vpDisplayX display1, display2, display3;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display1, display2, display3;
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display1, display2, display3;
-#elif defined VISP_HAVE_D3D9
+#elif defined(VISP_HAVE_D3D9)
     vpDisplayD3D display1, display2, display3;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display1, display2, display3;
 #else
     opt_display = false;
@@ -410,7 +424,7 @@ int main(int argc, const char **argv)
     std::map<std::string, vpHomogeneousMatrix> mapOfCameraPoses;
     std::map<std::string, vpCameraParameters> mapOfCameraParams;
 
-// Initialise the tracker: camera parameters, moving edge and KLT settings
+    // Initialise the tracker: camera parameters, moving edge and KLT settings
 #if USE_XML
     // From the xml file
     std::map<std::string, std::string> mapOfConfigFiles;
@@ -430,7 +444,8 @@ int main(int argc, const char **argv)
     me.setMaskSize(5);
     me.setMaskNumber(180);
     me.setRange(7);
-    me.setThreshold(5000);
+    me.setLikelihoodThresholdType(vpMe::NORMALIZED_THRESHOLD);
+    me.setThreshold(10);
     me.setMu1(0.5);
     me.setMu2(0.5);
     me.setSampleStep(4);
@@ -439,7 +454,7 @@ int main(int argc, const char **argv)
     mapOfMe["Camera2"] = me;
     mapOfMe["Camera3"] = me;
 
-#if defined(VISP_HAVE_MODULE_KLT) && (defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100))
+#if defined(VISP_HAVE_MODULE_KLT) && defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_VIDEO)
     vpKltOpencv klt;
     klt.setMaxFeatures(10000);
     klt.setWindowSize(5);
@@ -469,14 +484,14 @@ int main(int argc, const char **argv)
     std::map<std::string, unsigned int> mapOfClippingFlags;
     dynamic_cast<vpMbGenericTracker *>(tracker)->getClipping(mapOfClippingFlags);
     for (std::map<std::string, unsigned int>::iterator it = mapOfClippingFlags.begin(); it != mapOfClippingFlags.end();
-         ++it) {
+      ++it) {
       it->second = (it->second | vpMbtPolygon::FOV_CLIPPING);
     }
 
     dynamic_cast<vpMbGenericTracker *>(tracker)->setClipping(mapOfClippingFlags);
-//   tracker->setClipping(tracker->getClipping() | vpMbtPolygon::LEFT_CLIPPING
-//   | vpMbtPolygon::RIGHT_CLIPPING | vpMbtPolygon::UP_CLIPPING |
-//   vpMbtPolygon::DOWN_CLIPPING); // Equivalent to FOV_CLIPPING
+    //   tracker->setClipping(tracker->getClipping() | vpMbtPolygon::LEFT_CLIPPING
+    //   | vpMbtPolygon::RIGHT_CLIPPING | vpMbtPolygon::UP_CLIPPING |
+    //   vpMbtPolygon::DOWN_CLIPPING); // Equivalent to FOV_CLIPPING
 #endif
 
     // Display the moving edges, and the Klt points
@@ -516,7 +531,7 @@ int main(int argc, const char **argv)
     //   - a ./cube/cube.init file that defines the 3d coordinates (in meter,
     //   in the object basis) of the points used for the initialisation
     //   - a ./cube/cube.ppm file to display where the user have to click
-    //   (optionnal, set by the third parameter)
+    //   (Optional, set by the third parameter)
     if (opt_display && opt_click_allowed) {
       std::map<std::string, std::string> mapOfInitFiles;
       mapOfInitFiles["Camera1"] = initFile;
@@ -526,8 +541,9 @@ int main(int argc, const char **argv)
 
       // display the 3D model at the given pose
       dynamic_cast<vpMbGenericTracker *>(tracker)->display(mapOfImages, mapOfCameraPoses, mapOfCameraParams,
-                                                           vpColor::red);
-    } else {
+        vpColor::red);
+    }
+    else {
       vpHomogeneousMatrix c1Moi(0.02044769891, 0.1101505452, 0.5078963719, 2.063603907, 1.110231561, -0.4392789872);
       std::map<std::string, vpHomogeneousMatrix> mapOfInitPoses;
       mapOfInitPoses["Camera1"] = c1Moi;
@@ -588,7 +604,8 @@ int main(int argc, const char **argv)
         me.setMaskSize(5);
         me.setMaskNumber(180);
         me.setRange(7);
-        me.setThreshold(5000);
+        me.setLikelihoodThresholdType(vpMe::NORMALIZED_THRESHOLD);
+        me.setThreshold(10);
         me.setMu1(0.5);
         me.setMu2(0.5);
         me.setSampleStep(4);
@@ -597,7 +614,7 @@ int main(int argc, const char **argv)
         mapOfMe["Camera2"] = me;
         mapOfMe["Camera3"] = me;
 
-#if defined(VISP_HAVE_MODULE_KLT) && (defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100))
+#if defined(VISP_HAVE_MODULE_KLT) && defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_VIDEO)
         klt.setMaxFeatures(10000);
         klt.setWindowSize(5);
         klt.setQuality(0.01);
@@ -625,14 +642,14 @@ int main(int argc, const char **argv)
 
         dynamic_cast<vpMbGenericTracker *>(tracker)->getClipping(mapOfClippingFlags);
         for (std::map<std::string, unsigned int>::iterator it = mapOfClippingFlags.begin();
-             it != mapOfClippingFlags.end(); ++it) {
+          it != mapOfClippingFlags.end(); ++it) {
           it->second = (it->second | vpMbtPolygon::FOV_CLIPPING);
         }
 
         dynamic_cast<vpMbGenericTracker *>(tracker)->setClipping(mapOfClippingFlags);
-//   tracker->setClipping(tracker->getClipping() | vpMbtPolygon::LEFT_CLIPPING
-//   | vpMbtPolygon::RIGHT_CLIPPING | vpMbtPolygon::UP_CLIPPING |
-//   vpMbtPolygon::DOWN_CLIPPING); // Equivalent to FOV_CLIPPING
+        //   tracker->setClipping(tracker->getClipping() | vpMbtPolygon::LEFT_CLIPPING
+        //   | vpMbtPolygon::RIGHT_CLIPPING | vpMbtPolygon::UP_CLIPPING |
+        //   vpMbtPolygon::DOWN_CLIPPING); // Equivalent to FOV_CLIPPING
 #endif
         tracker->loadModel(modelFile);
         dynamic_cast<vpMbGenericTracker *>(tracker)->setCameraParameters(mapOfCameraParams);
@@ -656,7 +673,7 @@ int main(int argc, const char **argv)
 
       // track the object: stop tracking from frame 40 to 50
       if (reader.getFrameIndex() - reader.getFirstFrameIndex() < 40 ||
-          reader.getFrameIndex() - reader.getFirstFrameIndex() >= 50) {
+        reader.getFrameIndex() - reader.getFirstFrameIndex() >= 50) {
         dynamic_cast<vpMbGenericTracker *>(tracker)->track(mapOfImages);
         dynamic_cast<vpMbGenericTracker *>(tracker)->getPose(mapOfCameraPoses);
         if (opt_display) {
@@ -667,10 +684,11 @@ int main(int argc, const char **argv)
             mapOfSubImages["Camera2"] = &I2;
 
             dynamic_cast<vpMbGenericTracker *>(tracker)->display(mapOfSubImages, mapOfCameraPoses, mapOfCameraParams,
-                                                                 vpColor::red, 3);
-          } else {
+              vpColor::red, 3);
+          }
+          else {
             dynamic_cast<vpMbGenericTracker *>(tracker)->display(mapOfImages, mapOfCameraPoses, mapOfCameraParams,
-                                                                 vpColor::red, 3);
+              vpColor::red, 3);
           }
           // display the frame
           vpDisplay::displayFrame(I1, mapOfCameraPoses["Camera1"], mapOfCameraParams["Camera1"], 0.05);
@@ -715,9 +733,9 @@ int main(int argc, const char **argv)
 
     std::cout << "Reached last frame: " << reader.getFrameIndex() << std::endl;
     std::cout << "\nFinal poses, c1Mo:\n"
-              << mapOfCameraPoses["Camera1"] << "\nc2Mo:\n"
-              << mapOfCameraPoses["Camera2"] << "\nc3Mo:\n"
-              << mapOfCameraPoses["Camera3"] << std::endl;
+      << mapOfCameraPoses["Camera1"] << "\nc2Mo:\n"
+      << mapOfCameraPoses["Camera2"] << "\nc3Mo:\n"
+      << mapOfCameraPoses["Camera3"] << std::endl;
 
     if (opt_click_allowed && !quit) {
       vpDisplay::getClick(I1);
@@ -728,7 +746,8 @@ int main(int argc, const char **argv)
     tracker = NULL;
 
     return EXIT_SUCCESS;
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return EXIT_FAILURE;
   }
@@ -737,8 +756,7 @@ int main(int argc, const char **argv)
 #elif !(defined(VISP_HAVE_MODULE_MBT) && defined(VISP_HAVE_DISPLAY))
 int main()
 {
-  std::cout << "Cannot run this example: visp_mbt, visp_gui modules are required."
-            << std::endl;
+  std::cout << "Cannot run this example: visp_mbt, visp_gui modules are required." << std::endl;
   return EXIT_SUCCESS;
 }
 #else
