@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,7 +31,7 @@
  * Description:
  * Example of tracking with vpGenericTracker on Castel.
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example mbtGenericTrackingDepthOnly.cpp
@@ -43,8 +43,8 @@
 #include <iostream>
 #include <visp3/core/vpConfig.h>
 
-#if (defined(VISP_HAVE_MODULE_MBT) && defined(VISP_HAVE_DISPLAY)) \
-  && (defined(VISP_HAVE_LAPACK) || defined(VISP_HAVE_EIGEN3) || defined(VISP_HAVE_OPENCV))
+#if (defined(VISP_HAVE_MODULE_MBT) && defined(VISP_HAVE_DISPLAY)) &&                                                   \
+    (defined(VISP_HAVE_LAPACK) || defined(VISP_HAVE_EIGEN3) || defined(VISP_HAVE_OPENCV))
 
 #include <visp3/core/vpDebug.h>
 #include <visp3/core/vpHomogeneousMatrix.h>
@@ -77,7 +77,8 @@ void usage(const char *name, const char *badparam)
     [-M <model name depth>] [-n <initialisation file base name>]\n\
     [-f] [-c] [-d] [-h] [-o] [-w] [-l] [-v] [-p]\n\
     [-T <tracker type>] [-e <last frame index>]\n\
-    [-u <disable face>]\n", name);
+    [-u <disable face>]\n",
+          name);
 
   fprintf(stdout, "\n\
   OPTIONS:                                               \n\
@@ -251,16 +252,23 @@ void rs_deproject_pixel_to_point(float point[3], const rs_intrinsics &intrin, co
   point[2] = depth;
 }
 
-bool read_data(unsigned int cpt, const std::string &input_directory, vpImage<unsigned char> &I, vpImage<uint16_t> &I_depth_raw,
-               std::vector<vpColVector> &pointcloud, unsigned int &pointcloud_width, unsigned int &pointcloud_height)
+bool read_data(unsigned int cpt, const std::string &input_directory, vpImage<unsigned char> &I,
+               vpImage<uint16_t> &I_depth_raw, std::vector<vpColVector> &pointcloud, unsigned int &pointcloud_width,
+               unsigned int &pointcloud_height)
 {
-  char buffer[256];
-
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+  std::string ext("png");
+#else
+  std::string ext("pgm");
+#endif
   // Read image
   std::stringstream ss;
-  ss << input_directory << "/image_%04d.pgm";
-  sprintf(buffer, ss.str().c_str(), cpt);
-  std::string filename_image = buffer;
+  ss << input_directory << "/image_";
+  ss << std::setfill('0') << std::setw(4);
+  ss << cpt;
+  ss << ".";
+  ss << ext;
+  std::string filename_image = ss.str();
 
   if (!vpIoTools::checkFilename(filename_image)) {
     std::cerr << "Cannot read: " << filename_image << std::endl;
@@ -270,9 +278,11 @@ bool read_data(unsigned int cpt, const std::string &input_directory, vpImage<uns
 
   // Read raw depth
   ss.str("");
-  ss << input_directory << "/depth_image_%04d.bin";
-  sprintf(buffer, ss.str().c_str(), cpt);
-  std::string filename_depth = buffer;
+  ss << input_directory << "/depth_image_";
+  ss << std::setfill('0') << std::setw(4);
+  ss << cpt;
+  ss << ".bin";
+  std::string filename_depth = ss.str();
 
   std::ifstream file_depth(filename_depth.c_str(), std::ios::in | std::ios::binary);
   if (!file_depth.is_open()) {
@@ -332,7 +342,7 @@ bool read_data(unsigned int cpt, const std::string &input_directory, vpImage<uns
 
 void loadConfiguration(vpMbTracker *const tracker, const std::string &
 #if USE_XML
-                       configFile_depth
+                                                       configFile_depth
 #endif
 )
 {
@@ -389,7 +399,7 @@ std::vector<std::string> getCastleElementNames(const int element)
 
   return element_names;
 }
-}
+} // namespace
 
 int main(int argc, const char **argv)
 {
@@ -500,15 +510,15 @@ int main(int argc, const char **argv)
     vpImageConvert::createDepthHistogram(I_depth_raw, I_depth);
 
 // initialise a  display
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     vpDisplayX display, display2;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display, display2;
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display, display2;
-#elif defined VISP_HAVE_D3D9
+#elif defined(VISP_HAVE_D3D9)
     vpDisplayD3D display, display2;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display, display2;
 #else
     opt_display = false;
@@ -518,7 +528,7 @@ int main(int argc, const char **argv)
       display.setDownScalingFactor(vpDisplay::SCALE_AUTO);
       display.init(I_depth, 100, 100, "Depth");
       display2.setDownScalingFactor(vpDisplay::SCALE_AUTO);
-      display2.init(I, I_depth.getWidth()+100, 100, "Image");
+      display2.init(I, I_depth.getWidth() + 100, 100, "Image");
 #endif
       vpDisplay::display(I_depth);
       vpDisplay::display(I);
@@ -707,7 +717,7 @@ int main(int argc, const char **argv)
           vpDisplay::displayText(I_depth, 80, 20, ss.str(), vpColor::red);
 
           // generic projection error computed on image from the RGB camera
-          double projection_error = tracker->computeCurrentProjectionError(I, depth_M_color.inverse()*cMo, cam_color);
+          double projection_error = tracker->computeCurrentProjectionError(I, depth_M_color.inverse() * cMo, cam_color);
           ss.str("");
           ss << "Projection error: " << projection_error;
           vpDisplay::displayText(I, 20, 20, ss.str(), vpColor::red);
@@ -771,8 +781,7 @@ int main(int argc, const char **argv)
 #elif !(defined(VISP_HAVE_MODULE_MBT) && defined(VISP_HAVE_DISPLAY))
 int main()
 {
-  std::cout << "Cannot run this example: visp_mbt, visp_gui modules are required."
-            << std::endl;
+  std::cout << "Cannot run this example: visp_mbt, visp_gui modules are required." << std::endl;
   return EXIT_SUCCESS;
 }
 #else
