@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,9 +34,8 @@
  * Authors:
  * Amaury Dame
  * Aurelien Yol
- * Fabien Spindler
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example templateTracker.cpp
@@ -120,20 +119,27 @@ typedef enum {
 void usage(const char *name, const char *badparam, const WarpType &warp_type, TrackerType &tracker_type,
            const long &last_frame, const double &residual_threhold)
 {
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+  std::string ext("png");
+#else
+  std::string ext("pgm");
+#endif
+
   fprintf(stdout, "\n\
 Example of template tracking.\n\
 \n\
 SYNOPSIS\n\
   %s [-i <test image path>] [-c] [-d] [-p] \n\
      [-w <warp type>] [-t <tracker type>] \n\
-     [-l <last frame number>] [-r] [-L] [-h]\n", name);
+     [-l <last frame number>] [-r] [-L] [-h]\n",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                                            Default\n\
   -i <input image path>                                \n\
      Set image input path.\n\
      From this path read images \n\
-     \"cube/image%%04d.pgm\". These \n\
+     \"mire-2/image%%04d.%s\". These \n\
      images come from ViSP-images-x.y.z.tar.gz available \n\
      on the ViSP website.\n\
      Setting the VISP_INPUT_IMAGE_PATH environment\n\
@@ -147,9 +153,10 @@ OPTIONS:                                                            Default\n\
      Turn off the display.\n\
           \n\
   -c\n\
-     Disable the mouse click. Useful to automaze the \n\
-     execution of this program without humain intervention.\n\
-          \n", last_frame);
+     Disable the mouse click. Useful to automate the \n\
+     execution of this program without human intervention.\n\
+          \n",
+          ext.c_str(), last_frame);
 
 #ifdef VISP_HAVE_MODULE_TT_MI
   fprintf(stdout, "\n\
@@ -161,7 +168,8 @@ OPTIONS:                                                            Default\n\
      %d : Homography in SL3\n\
      %d : SRT (scale, rotation, translation)\n\
      %d : Translation\n\
-     %d : RT (rotation, translation)\n\n", (int)warp_type, (int)WARP_AFFINE, (int)WARP_HOMOGRAPHY, (int)WARP_HOMOGRAPHY_SL3, (int)WARP_SRT,
+     %d : RT (rotation, translation)\n\n",
+          (int)warp_type, (int)WARP_AFFINE, (int)WARP_HOMOGRAPHY, (int)WARP_HOMOGRAPHY_SL3, (int)WARP_SRT,
           (int)WARP_TRANSLATION, (int)WARP_RT);
 #else
   fprintf(stdout, "\n\
@@ -172,7 +180,8 @@ OPTIONS:                                                            Default\n\
      %d : Homography\n\
      %d : Homography in SL3\n\
      %d : SRT (scale, rotation, translation)\n\
-     %d : Translation\n\n", (int)warp_type, (int)WARP_AFFINE, (int)WARP_HOMOGRAPHY, (int)WARP_HOMOGRAPHY_SL3, (int)WARP_SRT,
+     %d : Translation\n\n",
+          (int)warp_type, (int)WARP_AFFINE, (int)WARP_HOMOGRAPHY, (int)WARP_HOMOGRAPHY_SL3, (int)WARP_SRT,
           (int)WARP_TRANSLATION);
 #endif
 
@@ -190,7 +199,8 @@ OPTIONS:                                                            Default\n\
      %d : MI ESM\n\
      %d : MI forward additional\n\
      %d : MI forward compositional\n\
-     %d : MI inverse compositional\n", (int)tracker_type, (int)TRACKER_SSD_ESM, (int)TRACKER_SSD_FORWARD_ADDITIONAL,
+     %d : MI inverse compositional\n",
+          (int)tracker_type, (int)TRACKER_SSD_ESM, (int)TRACKER_SSD_FORWARD_ADDITIONAL,
           (int)TRACKER_SSD_FORWARD_COMPOSITIONAL, (int)TRACKER_SSD_INVERSE_COMPOSITIONAL,
           (int)TRACKER_ZNCC_FORWARD_ADDITIONEL, (int)TRACKER_ZNCC_INVERSE_COMPOSITIONAL, (int)TRACKER_MI_ESM,
           (int)TRACKER_MI_FORWARD_ADDITIONAL, (int)TRACKER_MI_FORWARD_COMPOSITIONAL,
@@ -205,7 +215,8 @@ OPTIONS:                                                            Default\n\
      %d : SSD forward compositional\n\
      %d : SSD inverse compositional\n\
      %d : ZNCC forward additional\n\
-     %d : ZNCC inverse compositional\n", (int)tracker_type, (int)TRACKER_SSD_ESM, (int)TRACKER_SSD_FORWARD_ADDITIONAL,
+     %d : ZNCC inverse compositional\n",
+          (int)tracker_type, (int)TRACKER_SSD_ESM, (int)TRACKER_SSD_FORWARD_ADDITIONAL,
           (int)TRACKER_SSD_FORWARD_COMPOSITIONAL, (int)TRACKER_SSD_INVERSE_COMPOSITIONAL,
           (int)TRACKER_ZNCC_FORWARD_ADDITIONEL, (int)TRACKER_ZNCC_INVERSE_COMPOSITIONAL);
 
@@ -226,15 +237,16 @@ OPTIONS:                                                            Default\n\
      Create log file.\n\
                                   \n\
   -h \n\
-     Print the help.\n\n", residual_threhold);
+     Print the help.\n\n",
+          residual_threhold);
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
 }
 
 bool getOptions(int argc, const char **argv, std::string &ipath, bool &click_allowed, bool &display, bool &pyramidal,
-                WarpType &warp_type, TrackerType &tracker_type, long &last_frame, bool &reinit, double &threshold_residual,
-                bool &log)
+                WarpType &warp_type, TrackerType &tracker_type, long &last_frame, bool &reinit,
+                double &threshold_residual, bool &log)
 {
   const char *optarg_;
   int c;
@@ -332,6 +344,12 @@ int main(int argc, const char **argv)
     std::string opath = "C:\\temp";
 #endif
 
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+    std::string ext("png");
+#else
+    std::string ext("pgm");
+#endif
+
     // Get the user login name
     std::string username;
     vpIoTools::getUserName(username);
@@ -351,7 +369,7 @@ int main(int argc, const char **argv)
     // Read the command line options
     if (!getOptions(argc, argv, opt_ipath, opt_click_allowed, opt_display, opt_pyramidal, opt_warp_type,
                     opt_tracker_type, opt_last_frame, opt_reinit, opt_threshold_residual, opt_log)) {
-      return (-1);
+      return EXIT_FAILURE;
     }
 
     // Test if an input path is set
@@ -363,17 +381,17 @@ int main(int argc, const char **argv)
                 << "  image path where test images are located." << std::endl
                 << std::endl;
 
-      return (-1);
+      return EXIT_FAILURE;
     }
 
     // Get the option values
     if (!opt_ipath.empty())
-      ipath = vpIoTools::createFilePath(opt_ipath, "mire-2/image.%04d.pgm");
+      ipath = vpIoTools::createFilePath(opt_ipath, "mire-2/image.%04d." + ext);
     else
-      ipath = vpIoTools::createFilePath(env_ipath, "mire-2/image.%04d.pgm");
+      ipath = vpIoTools::createFilePath(env_ipath, "mire-2/image.%04d." + ext);
 
     if (opt_log) {
-      ofs.open( logfilename.c_str() );
+      ofs.open(logfilename.c_str());
     }
 
     vpImage<unsigned char> I;
@@ -386,22 +404,22 @@ int main(int argc, const char **argv)
       reader.open(I);
     } catch (...) {
       std::cout << "Cannot open sequence: " << ipath << std::endl;
-      return -1;
+      return EXIT_FAILURE;
     }
     reader.acquire(I);
 
     vpDisplay *display = NULL;
     if (opt_display) {
 // initialise a  display
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
       display = new vpDisplayX;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
       display = new vpDisplayGDI;
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
       display = new vpDisplayOpenCV;
-#elif defined VISP_HAVE_D3D9
+#elif defined(VISP_HAVE_D3D9)
       display = new vpDisplayD3D;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
       display = new vpDisplayGTK;
 #else
       opt_display = false;
@@ -436,7 +454,7 @@ int main(int argc, const char **argv)
       break;
 #endif
     default:
-      return 0;
+      return EXIT_FAILURE;
     }
 
     vpTemplateTracker *tracker = NULL;
@@ -474,7 +492,7 @@ int main(int argc, const char **argv)
       break;
 #endif
     default:
-      return 0;
+      return EXIT_FAILURE;
     }
 
     tracker->setSampling(2, 2);
@@ -569,11 +587,11 @@ int main(int argc, const char **argv)
 
       vpDisplay::flush(I);
 
-      niter ++;
+      niter++;
     }
     double t_end = vpTime::measureTimeMs();
     std::cout << "Total time: " << t_end - t_init << " ms" << std::endl;
-    std::cout << "Total mean: " << (t_end - t_init)/niter << " ms" << std::endl;
+    std::cout << "Total mean: " << (t_end - t_init) / niter << " ms" << std::endl;
 
     if (opt_log) {
       std::cout << "Log are saved in: " << logfilename << std::endl;
