@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * Example of dot tracking.
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \file trackKltOpencv.cpp
 
@@ -50,10 +46,9 @@
 #include <stdio.h>
 #include <vector>
 
-#if defined(VISP_HAVE_MODULE_KLT) &&                                                                                   \
-    (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV))
+#if defined(VISP_HAVE_MODULE_KLT) && (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV))
 
-#if defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_VIDEO)
 
 #include <visp3/core/vpImage.h>
 #include <visp3/core/vpIoTools.h>
@@ -66,11 +61,11 @@
 #include <visp3/klt/vpKltOpencv.h>
 
 // List of allowed command line options
-#define GETOPTARGS "cdf:i:n:p:s:h"
+#define GETOPTARGS "cdf:i:l:p:s:h"
 
 void usage(const char *name, const char *badparam, std::string ipath, std::string ppath, unsigned first,
-           unsigned nimages, unsigned step);
-bool getOptions(int argc, const char **argv, std::string &ipath, std::string &ppath, unsigned &first, unsigned &nimages,
+           unsigned last, unsigned step);
+bool getOptions(int argc, const char **argv, std::string &ipath, std::string &ppath, unsigned &first, unsigned &last,
                 unsigned &step, bool &click_allowed, bool &display);
 /*!
   \example trackKltOpencv.cpp
@@ -88,66 +83,71 @@ Print the program options.
   \param ipath : Input image path.
   \param ppath : Personal image path.
   \param first : First image.
-  \param nimages : Number of images to manipulate.
+  \param last : Last image.
   \param step : Step between two images.
 
 
 */
 void usage(const char *name, const char *badparam, std::string ipath, std::string ppath, unsigned first,
-           unsigned nimages, unsigned step)
+           unsigned last, unsigned step)
 {
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+  std::string ext("png");
+#else
+  std::string ext("pgm");
+#endif
   fprintf(stdout, "\n\
 Example of KLT tracking using OpenCV library.\n\
 \n\
 SYNOPSIS\n\
   %s [-i <test image path>] [-p <personal image path>]\n\
-     [-f <first image>] [-n <number of images>] [-s <step>]\n\
-     [-c] [-d] [-h]\n", name);
+     [-f <first image>] [-l <last image>] [-s <step>]\n\
+     [-c] [-d] [-h]\n",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
   -i <input image path>                                %s\n\
      Set image input path.\n\
      From this path read images \n\
-     \"mire-2/image.%%04d.pgm\". These \n\
-     images come from ViSP-images-x.y.z.tar.gz available \n\
+     \"mire-2/image.%%04d.%s\". These \n\
+     images come from visp-images-x.y.z.tar.gz available \n\
      on the ViSP website.\n\
      Setting the VISP_INPUT_IMAGE_PATH environment\n\
      variable produces the same behaviour than using\n\
      this option.\n\
  \n\
- -p <personal image path>                             %s\n\
+ -p <personal image path>                              %s\n\
      Specify a personal sequence containing images \n\
      to process.\n\
      By image sequence, we mean one file per image.\n\
-     The following image file formats PNM (PGM P5, PPM P6)\n\
-     are supported. The format is selected by analysing \n\
-     the filename extension.\n\
-     Example : \"/Temp/ViSP-images/cube/image.%%04d.pgm\"\n\
+     Example : \"/Temp/visp-images/mire-2/image.%%04d.%s\"\n\
      %%04d is for the image numbering.\n\
  \n\
   -f <first image>                                     %u\n\
      First image number of the sequence.\n\
  \n\
-  -n <number of images>                                %u\n\
-     Number of images to load from the sequence.\n\
+  -l <last image>                                      %u\n\
+     Last image number of the sequence.\n\
  \n\
   -s <step>                                            %u\n\
      Step between two images.\n\
 \n\
   -c\n\
-     Disable the mouse click. Useful to automaze the \n\
-     execution of this program without humain intervention.\n\
+     Disable the mouse click. Useful to automate the \n\
+     execution of this program without human intervention.\n\
 \n\
   -d \n\
      Turn off the display.\n\
 \n\
   -h\n\
-     Print the help.\n", ipath.c_str(), ppath.c_str(), first, nimages, step);
+     Print the help.\n",
+          ipath.c_str(), ext.c_str(), ppath.c_str(), ext.c_str(), first, last, step);
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
 }
+
 /*!
 
   Set the program options.
@@ -158,14 +158,14 @@ OPTIONS:                                               Default\n\
   \param click_allowed : Mouse click activation.
   \param ppath : Personal image path.
   \param first : First image.
-  \param nimages : Number of images to display.
+  \param last : Last image.
   \param step : Step between two images.
   \param display : Display activation.
 
   \return false if the program has to be stopped, true otherwise.
 
 */
-bool getOptions(int argc, const char **argv, std::string &ipath, std::string &ppath, unsigned &first, unsigned &nimages,
+bool getOptions(int argc, const char **argv, std::string &ipath, std::string &ppath, unsigned &first, unsigned &last,
                 unsigned &step, bool &click_allowed, bool &display)
 {
   const char *optarg_;
@@ -188,19 +188,19 @@ bool getOptions(int argc, const char **argv, std::string &ipath, std::string &pp
     case 'f':
       first = (unsigned)atoi(optarg_);
       break;
-    case 'n':
-      nimages = (unsigned)atoi(optarg_);
+    case 'l':
+      last = (unsigned)atoi(optarg_);
       break;
     case 's':
       step = (unsigned)atoi(optarg_);
       break;
     case 'h':
-      usage(argv[0], NULL, ipath, ppath, first, nimages, step);
+      usage(argv[0], NULL, ipath, ppath, first, last, step);
       return false;
       break;
 
     default:
-      usage(argv[0], optarg_, ipath, ppath, first, nimages, step);
+      usage(argv[0], optarg_, ipath, ppath, first, last, step);
       return false;
       break;
     }
@@ -208,7 +208,7 @@ bool getOptions(int argc, const char **argv, std::string &ipath, std::string &pp
 
   if ((c == 1) || (c == -1)) {
     // standalone param or error
-    usage(argv[0], NULL, ipath, ppath, first, nimages, step);
+    usage(argv[0], NULL, ipath, ppath, first, last, step);
     std::cerr << "ERROR: " << std::endl;
     std::cerr << "  Bad argument " << optarg_ << std::endl << std::endl;
     return false;
@@ -227,11 +227,17 @@ int main(int argc, const char **argv)
     std::string dirname;
     std::string filename;
     unsigned opt_first = 1;
-    unsigned opt_nimages = 500;
+    unsigned opt_last = 500;
     unsigned opt_step = 1;
     bool opt_click_allowed = true;
     bool opt_display = true;
 
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+    std::string ext("png");
+#else
+    std::string ext("pgm");
+#endif
+
     // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH
     // environment variable value
     env_ipath = vpIoTools::getViSPImagesDataPath();
@@ -241,9 +247,9 @@ int main(int argc, const char **argv)
       ipath = env_ipath;
 
     // Read the command line options
-    if (getOptions(argc, argv, opt_ipath, opt_ppath, opt_first, opt_nimages, opt_step, opt_click_allowed,
+    if (getOptions(argc, argv, opt_ipath, opt_ppath, opt_first, opt_last, opt_step, opt_click_allowed,
                    opt_display) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Get the option values
@@ -263,7 +269,7 @@ int main(int argc, const char **argv)
 
     // Test if an input path is set
     if (opt_ipath.empty() && env_ipath.empty() && opt_ppath.empty()) {
-      usage(argv[0], NULL, ipath, opt_ppath, opt_first, opt_nimages, opt_step);
+      usage(argv[0], NULL, ipath, opt_ppath, opt_first, opt_last, opt_step);
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH " << std::endl
                 << "  environment variable to specify the location of the " << std::endl
@@ -272,18 +278,14 @@ int main(int argc, const char **argv)
                 << "  use personal images." << std::endl
                 << std::endl;
 
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Declare an image, this is a gray level image (unsigned char)
     // it size is not defined yet, it will be defined when the image will
     // read on the disk
     vpImage<unsigned char> vpI; // This is a ViSP image used for display only
-#if (VISP_HAVE_OPENCV_VERSION < 0x020408)
-    IplImage *cvI = NULL; // This is an OpenCV IPL image used by the tracker
-#else
     cv::Mat cvI;
-#endif
 
     unsigned iter = opt_first;
     std::ostringstream s;
@@ -292,16 +294,12 @@ int main(int argc, const char **argv)
     if (opt_ppath.empty()) {
 
       // Warning :
-      // the image sequence is not provided with the ViSP package
-      // therefore the program will return you an error :
-      //  !!    vpImageIoPnm.cpp: readPGM(#210) :couldn't read file
-      //        ViSP-images/mire-2/image.0001.pgm
-      //  !!    vpDotExample.cpp: main(#95) :Error while reading the image
-      //  terminate called after throwing an instance of 'vpImageException'
+      // The image sequence is not provided with the ViSP package
+      // therefore the program will return an error :
+      //  !!    couldn't read file visp-images/mire-2/image.0001.png
       //
-      //  The sequence is available on the visp www site
-      //  https://visp.inria.fr/download/
-      //  in the download section. It is named "ViSP-images.tar.gz"
+      // ViSP dataset is available on the visp www site
+      // https://visp.inria.fr/download/.
 
       // Set the path location of the image sequence
       dirname = vpIoTools::createFilePath(ipath, "mire-2");
@@ -309,18 +307,18 @@ int main(int argc, const char **argv)
       // Build the name of the image file
 
       s.setf(std::ios::right, std::ios::adjustfield);
-      s << "image." << std::setw(4) << std::setfill('0') << iter << ".pgm";
+      s << "image." << std::setw(4) << std::setfill('0') << iter << "." << ext;
       filename = vpIoTools::createFilePath(dirname, s.str());
-    } else {
-      sprintf(cfilename, opt_ppath.c_str(), iter);
+    }
+    else {
+      snprintf(cfilename, FILENAME_MAX, opt_ppath.c_str(), iter);
       filename = cfilename;
     }
 
-    // Read the PGM image named "filename" on the disk, and put the
-    // bitmap into the image structure I.  I is initialized to the
-    // correct size
+    // Read the image named "filename", and put the bitmap into the image structure I.
+    // I is initialized to the correct size
     //
-    // exception readPGM may throw various exception if, for example,
+    // vpImageIo::read() may throw various exception if, for example,
     // the file does not exist, or if the memory cannot be allocated
     try {
       std::cout << "Load: " << filename << std::endl;
@@ -329,25 +327,27 @@ int main(int argc, const char **argv)
       vpImageIo::read(vpI, filename);
       vpImageConvert::convert(vpI, cvI);
     } catch (...) {
-      // an exception is throwned if an exception from readPGM has been
-      // catched here this will result in the end of the program Note that
-      // another error message has been printed from readPGM to give more
-      // information about the error
+      // If an exception is thrown by vpImageIo::read() it will result in the end of the program.
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Cannot read " << filename << std::endl;
-      std::cerr << "  Check your -i " << ipath << " option " << std::endl
-                << "  or VISP_INPUT_IMAGE_PATH environment variable." << std::endl;
-      exit(-1);
+      if (opt_ppath.empty()) {
+        std::cerr << "  Check your -i " << ipath << " option " << std::endl
+                  << "  or VISP_INPUT_IMAGE_PATH environment variable." << std::endl;
+      }
+      else {
+        std::cerr << "  Check your -p " << opt_ppath << " option " << std::endl;
+      }
+      return EXIT_FAILURE;
     }
 
 // We open a window using either X11, GTK or GDI.
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     vpDisplayX display;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display;
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display;
 #endif
 
@@ -357,7 +357,7 @@ int main(int argc, const char **argv)
       // Display the image
       // The image class has a member that specify a pointer toward
       // the display that has been initialized in the display declaration
-      // therefore is is no longuer necessary to make a reference to the
+      // therefore is is no longer necessary to make a reference to the
       // display variable.
       vpDisplay::display(vpI);
       vpDisplay::flush(vpI);
@@ -392,14 +392,14 @@ int main(int argc, const char **argv)
     }
 
     // tracking is now initialized. We can start the tracker.
-    while (iter < opt_first + opt_nimages * opt_step) {
+    while (iter < opt_last) {
       // set the new image name
       if (opt_ppath.empty()) {
         s.str("");
-        s << "image." << std::setw(4) << std::setfill('0') << iter << ".pgm";
+        s << "image." << std::setw(4) << std::setfill('0') << iter << "." << ext;
         filename = vpIoTools::createFilePath(dirname, s.str());
       } else {
-        sprintf(cfilename, opt_ppath.c_str(), iter);
+        snprintf(cfilename, FILENAME_MAX, opt_ppath.c_str(), iter);
         filename = cfilename;
       }
       // read the image
@@ -409,7 +409,7 @@ int main(int argc, const char **argv)
       // track the dot and returns its coordinates in the image
       // results are given in float since many many are usually considered
       //
-      // an expcetion is thrown by the track method if
+      // an exception is thrown by the track method if
       //  - dot is lost
 
       if (opt_display) {
