@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,8 @@
  * Description:
  * Tracking of a line.
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
+
 /*!
   \file trackMeLine.cpp
 
@@ -77,10 +74,7 @@
 #include <visp3/io/vpParseArgv.h>
 
 // List of allowed command line options
-#define GETOPTARGS "cdi:h"
-
-void usage(const char *name, const char *badparam, std::string ipath);
-bool getOptions(int argc, const char **argv, std::string &ipath, bool &click_allowed, bool &display);
+#define GETOPTARGS "cdf:hi:l:p:s:"
 
 /*!
 
@@ -89,39 +83,69 @@ bool getOptions(int argc, const char **argv, std::string &ipath, bool &click_all
   \param name : Program name.
   \param badparam : Bad parameter name.
   \param ipath : Input image path.
+  \param ppath : Personal image path.
+  \param first : First image.
+  \param last : Last image.
+  \param step : Step between two images.
 
 */
-void usage(const char *name, const char *badparam, std::string ipath)
+void usage(const char *name, const char *badparam, std::string ipath, std::string ppath, unsigned first,
+  unsigned last, unsigned step)
 {
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+  std::string ext("png");
+#else
+  std::string ext("pgm");
+#endif
   fprintf(stdout, "\n\
 Tracking of a line.\n\
 \n\
 SYNOPSIS\n\
-  %s [-i <input image path>] [-c] [-d] [-h]\n", name);
+  %s [-i <input image path>] [-p <personal image path>]\n\
+     [-f <first image>] [-l <last image>] [-s <step>]\n\
+     [-c] [-d] [-h]\n", name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
   -i <input image path>                                %s\n\
      Set image input path.\n\
-     From this path read \"line/image.%%04d.pgm\"\n\
+     From this path read \"line/image.%%04d.%s\"\n\
      images. \n\
      Setting the VISP_INPUT_IMAGE_PATH environment\n\
      variable produces the same behaviour than using\n\
      this option.\n\
+\n\
+  -p <personal image path>                             %s\n\
+     Specify a personal sequence containing images \n\
+     to process.\n\
+     By image sequence, we mean one file per image.\n\
+     Example : \"C:/Temp/visp-images/line/image.%%04d.%s\"\n\
+     %%04d is for the image numbering.\n\
+\n\
+  -f <first image>                                     %u\n\
+     First image number of the sequence.\n\
+\n\
+  -l <last image>                                      %u\n\
+     Last image number of the sequence.\n\
+\n\
+  -s <step>                                            %u\n\
+     Step between two images.\n\
 \n\
   -c\n\
-     Disable the mouse click. Useful to automaze the \n\
-     execution of this program without humain intervention.\n\
+     Disable the mouse click. Useful to automate the \n\
+     execution of this program without human intervention.\n\
 \n\
   -d \n\
      Turn off the display.\n\
 \n\
   -h\n\
-     Print the help.\n", ipath.c_str());
+     Print the help.\n",
+    ipath.c_str(), ext.c_str(), ppath.c_str(), ext.c_str(), first, last, step);
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
 }
+
 /*!
 
   Set the program options.
@@ -130,12 +154,17 @@ OPTIONS:                                               Default\n\
   \param argv : Array of command line parameters.
   \param ipath : Input image path.
   \param click_allowed : Mouse click activation.
+  \param ppath : Personal image path.
+  \param first : First image.
+  \param last : Last image.
+  \param step : Step between two images.
   \param display : Display activation.
 
   \return false if the program has to be stopped, true otherwise.
 
 */
-bool getOptions(int argc, const char **argv, std::string &ipath, bool &click_allowed, bool &display)
+bool getOptions(int argc, const char **argv, std::string &ipath, std::string &ppath, unsigned &first, unsigned &last,
+  unsigned &step, bool &click_allowed, bool &display)
 {
   const char *optarg_;
   int c;
@@ -151,13 +180,25 @@ bool getOptions(int argc, const char **argv, std::string &ipath, bool &click_all
     case 'i':
       ipath = optarg_;
       break;
+    case 'p':
+      ppath = optarg_;
+      break;
+    case 'f':
+      first = (unsigned)atoi(optarg_);
+      break;
+    case 'l':
+      last = (unsigned)atoi(optarg_);
+      break;
+    case 's':
+      step = (unsigned)atoi(optarg_);
+      break;
     case 'h':
-      usage(argv[0], NULL, ipath);
+      usage(argv[0], NULL, ipath, ppath, first, last, step);
       return false;
       break;
 
     default:
-      usage(argv[0], optarg_, ipath);
+      usage(argv[0], optarg_, ipath, ppath, first, last, step);
       return false;
       break;
     }
@@ -165,7 +206,7 @@ bool getOptions(int argc, const char **argv, std::string &ipath, bool &click_all
 
   if ((c == 1) || (c == -1)) {
     // standalone param or error
-    usage(argv[0], NULL, ipath);
+    usage(argv[0], NULL, ipath, ppath, first, last, step);
     std::cerr << "ERROR: " << std::endl;
     std::cerr << "  Bad argument " << optarg_ << std::endl << std::endl;
     return false;
@@ -181,11 +222,21 @@ int main(int argc, const char **argv)
     std::string env_ipath;
     std::string opt_ipath;
     std::string ipath;
+    std::string opt_ppath;
     std::string dirname;
     std::string filename;
+    unsigned int opt_first = 1;
+    unsigned int opt_last = 30;
+    unsigned int opt_step = 1;
     bool opt_click_allowed = true;
     bool opt_display = true;
 
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+    std::string ext("png");
+#else
+    std::string ext("pgm");
+#endif
+
     // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH
     // environment variable value
     env_ipath = vpIoTools::getViSPImagesDataPath();
@@ -195,8 +246,9 @@ int main(int argc, const char **argv)
       ipath = env_ipath;
 
     // Read the command line options
-    if (getOptions(argc, argv, opt_ipath, opt_click_allowed, opt_display) == false) {
-      exit(-1);
+    if (getOptions(argc, argv, opt_ipath, opt_ppath, opt_first, opt_last, opt_step, opt_click_allowed,
+      opt_display) == false) {
+      return EXIT_FAILURE;
     }
 
     // Get the option values
@@ -205,24 +257,27 @@ int main(int argc, const char **argv)
 
     // Compare ipath and env_ipath. If they differ, we take into account
     // the input path comming from the command line option
-    if (!opt_ipath.empty() && !env_ipath.empty()) {
+    if (!opt_ipath.empty() && !env_ipath.empty() && opt_ppath.empty()) {
       if (ipath != env_ipath) {
         std::cout << std::endl << "WARNING: " << std::endl;
         std::cout << "  Since -i <visp image path=" << ipath << "> "
-                  << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
-                  << "  we skip the environment variable." << std::endl;
+          << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
+          << "  we skip the environment variable." << std::endl;
       }
     }
 
     // Test if an input path is set
-    if (opt_ipath.empty() && env_ipath.empty()) {
-      usage(argv[0], NULL, ipath);
+    if (opt_ipath.empty() && env_ipath.empty() && opt_ppath.empty()) {
+      usage(argv[0], NULL, ipath, opt_ppath, opt_first, opt_last, opt_step);
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH " << std::endl
-                << "  environment variable to specify the location of the " << std::endl
-                << "  image path where test images are located." << std::endl
-                << std::endl;
-      exit(-1);
+        << "  environment variable to specify the location of the " << std::endl
+        << "  image path where test images are located." << std::endl
+        << "  Use -p <personal image path> option if you want to " << std::endl
+        << "  use personal images." << std::endl
+        << std::endl;
+
+      return EXIT_FAILURE;
     }
 
     // Declare an image, this is a gray level image (unsigned char)
@@ -230,46 +285,65 @@ int main(int argc, const char **argv)
     // read on the disk
     vpImage<unsigned char> I;
 
-    // Set the path location of the image sequence
-    dirname = vpIoTools::createFilePath(ipath, "line");
-
-    // Build the name of the image file
-    unsigned int iter = 1; // Image number
+    unsigned iter = opt_first;
     std::ostringstream s;
-    s.setf(std::ios::right, std::ios::adjustfield);
-    s << "image." << std::setw(4) << std::setfill('0') << iter << ".pgm";
-    filename = vpIoTools::createFilePath(dirname, s.str());
+    char cfilename[FILENAME_MAX];
 
-    // Read the PGM image named "filename" on the disk, and put the
-    // bitmap into the image structure I.  I is initialized to the
-    // correct size
+    if (opt_ppath.empty()) {
+
+      // Warning :
+      // The image sequence is not provided with the ViSP package
+      // therefore the program will return an error :
+      //  !!    couldn't read file visp-images/mire-2/image.0001.png
+      //
+      // ViSP dataset is available on the visp www site
+      // https://visp.inria.fr/download/.
+
+      // Set the path location of the image sequence
+      dirname = vpIoTools::createFilePath(ipath, "line");
+
+      // Build the name of the image file
+      s.setf(std::ios::right, std::ios::adjustfield);
+      s << "image." << std::setw(4) << std::setfill('0') << iter << "." << ext;
+      filename = vpIoTools::createFilePath(dirname, s.str());
+    }
+    else {
+      snprintf(cfilename, FILENAME_MAX, opt_ppath.c_str(), iter);
+      filename = cfilename;
+    }
+
+    // Read the image named "filename", and put the bitmap into the image structure I.
+    // I is initialized to the correct size
     //
-    // exception readPGM may throw various exception if, for example,
+    // vpImageIo::read() may throw various exception if, for example,
     // the file does not exist, or if the memory cannot be allocated
     try {
       vpCTRACE << "Load: " << filename << std::endl;
 
       vpImageIo::read(I, filename);
-    } catch (...) {
-      // an exception is throwned if an exception from readPGM has been
-      // catched here this will result in the end of the program Note that
-      // another error message has been printed from readPGM to give more
-      // information about the error
+    }
+    catch (...) {
+      // If an exception is thrown by vpImageIo::read() it will result in the end of the program.
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Cannot read " << filename << std::endl;
-      std::cerr << "  Check your -i " << ipath << " option " << std::endl
-                << "  or VISP_INPUT_IMAGE_PATH environment variable." << std::endl;
-      exit(-1);
+      if (opt_ppath.empty()) {
+        std::cerr << "  Check your -i " << ipath << " option " << std::endl
+          << "  or VISP_INPUT_IMAGE_PATH environment variable." << std::endl;
+      }
+      else {
+        std::cerr << "  Check your -p " << opt_ppath << " option " << std::endl;
+      }
+      return EXIT_FAILURE;
     }
 
-// We open a window using either X11, GTK or GDI.
-#if defined VISP_HAVE_X11
+    // We open a window using either X11, GTK or GDI.
+#if defined(VISP_HAVE_X11)
     vpDisplayX display;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display;
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display;
 #endif
 
@@ -279,7 +353,7 @@ int main(int argc, const char **argv)
       // Display the image
       // The image class has a member that specify a pointer toward
       // the display that has been initialized in the display declaration
-      // therefore is is no longuer necessary to make a reference to the
+      // therefore is is no longer necessary to make a reference to the
       // display variable.
       vpDisplay::display(I);
       vpDisplay::flush(I);
@@ -290,7 +364,8 @@ int main(int argc, const char **argv)
     vpMe me;
     me.setRange(15);
     me.setPointsToTrack(160);
-    me.setThreshold(15000);
+    me.setLikelihoodThresholdType(vpMe::NORMALIZED_THRESHOLD);
+    me.setThreshold(20);
 
     L1.setMe(&me);
     L1.setDisplay(vpMeSite::RANGE_RESULT);
@@ -320,11 +395,11 @@ int main(int argc, const char **argv)
 
     vpCameraParameters cam;
     vpImage<vpRGBa> Ic;
-    for (iter = 1; iter < 30; iter++) {
+    while (iter < opt_last) {
       std::cout << "----------------------------------------------------------" << std::endl;
       // set the new image name
       s.str("");
-      s << "image." << std::setw(4) << std::setfill('0') << iter << ".pgm";
+      s << "image." << std::setw(4) << std::setfill('0') << iter << "." << ext;
       filename = vpIoTools::createFilePath(dirname, s.str());
       // read the image
       vpImageIo::read(I, filename);
@@ -348,13 +423,16 @@ int main(int argc, const char **argv)
           vpDisplay::getClick(I);
         }
       }
+
+      iter += opt_step;
     }
     if (opt_display && opt_click_allowed) {
       std::cout << "A click to exit..." << std::endl;
       vpDisplay::getClick(I);
     }
     return EXIT_SUCCESS;
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return EXIT_FAILURE;
   }
@@ -371,8 +449,8 @@ int main(int argc, const char **argv)
 int main()
 {
   std::cout << "visp_me module or X11, GTK, GDI or OpenCV display "
-               "functionalities are required..."
-            << std::endl;
+    "functionalities are required..."
+    << std::endl;
   return EXIT_SUCCESS;
 }
 
