@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,20 +31,17 @@
  * Description:
  * Reading an image sequence.
  *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file imageSequenceReader.cpp
   \brief   reading an image sequence using vpVideoReader class.
  */
 
-/*!
-  \example imageSequenceReader.cpp
-  Reading an image sequence using vpVideoReader class.
- */
+ /*!
+   \example imageSequenceReader.cpp
+   Reading an image sequence using vpVideoReader class.
+  */
 
 #include <visp3/core/vpDebug.h>
 #include <visp3/core/vpImage.h>
@@ -59,7 +56,7 @@
 
 #if defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV) || defined(VISP_HAVE_GTK)
 
-// List of allowed command line options
+  // List of allowed command line options
 #define GETOPTARGS "cdi:p:f:h"
 
 void usage(const char *name, const char *badparam, std::string ipath, std::string ppath);
@@ -78,19 +75,25 @@ Print the program options.
  */
 void usage(const char *name, const char *badparam, std::string ipath, std::string ppath)
 {
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+  std::string ext("png");
+#else
+  std::string ext("pgm");
+#endif
   fprintf(stdout, "\n\
 Read an image sequence on the disk.\n\
 \n\
 SYNOPSIS\n\
   %s [-i <input images path>] [-p <personal image sequence path>]\n\
-     [-c][-d][-h]\n						      \
-", name);
+     [-c][-d][-h]\n\
+",
+name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
   -i <input images path>                                %s\n\
      Set ViSP-images input path.\n\
-     From this path read \"cube/image.%%04d.pgm\"\n\
+     From this path read \"cube/image.%%04d.%s\"\n\
      images.\n\
      Setting the VISP_INPUT_IMAGE_PATH environment\n\
      variable produces the same behaviour than using\n\
@@ -99,21 +102,22 @@ OPTIONS:                                               Default\n\
   -p <personal image sequence path>                             %s\n\
      Specify a personal folder containing an image sequence \n\
      to process.\n\
-     Example : \"/Temp/ViSP-images/cube/image.%%04d.pgm\"\n\
+     Example : \"/Temp/visp-images/cube/image.%%04d.%s\"\n\
      %%04d is for the image numbering.\n\
 \n\
   -f <index of the first frame>                             \n\
      Specify the first image index.\n\
 \n\
   -c\n\
-     Disable the mouse click. Useful to automaze the \n\
-     execution of this program without humain intervention.\n\
+     Disable the mouse click. Useful to automate the \n\
+     execution of this program without human intervention.\n\
 \n\
   -d \n\
      Turn off the display.\n\
 \n\
   -h\n\
-     Print the help.\n\n", ipath.c_str(), ppath.c_str());
+     Print the help.\n\n",
+          ipath.c_str(), ext.c_str(), ppath.c_str(), ext.c_str());
 
   if (badparam) {
     fprintf(stderr, "ERROR: \n");
@@ -192,6 +196,12 @@ int main(int argc, const char **argv)
     bool opt_click_allowed = true;
     bool opt_display = true;
 
+#if VISP_HAVE_DATASET_VERSION >= 0x030600
+    std::string ext("png");
+#else
+    std::string ext("pgm");
+#endif
+
     std::cout << "-------------------------------------------------------" << std::endl;
     std::cout << "  videoImageSequenceReader.cpp" << std::endl << std::endl;
 
@@ -209,7 +219,7 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, opt_ipath, opt_ppath, opt_first, opt_click_allowed, opt_display) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Get the option values
@@ -222,8 +232,8 @@ int main(int argc, const char **argv)
       if (ipath != env_ipath) {
         std::cout << std::endl << "WARNING: " << std::endl;
         std::cout << "  Since -i <visp image path=" << ipath << "> "
-                  << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
-                  << "  we skip the environment variable." << std::endl;
+          << "  is different from VISP_IMAGE_PATH=" << env_ipath << std::endl
+          << "  we skip the environment variable." << std::endl;
       }
     }
 
@@ -232,10 +242,10 @@ int main(int argc, const char **argv)
       usage(argv[0], NULL, ipath, opt_ppath);
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Use -i <visp image path> option or set VISP_INPUT_IMAGE_PATH " << std::endl
-                << "  environment variable to specify the location of the " << std::endl
-                << "  video path where test images are located." << std::endl
-                << std::endl;
-      exit(-1);
+        << "  environment variable to specify the location of the " << std::endl
+        << "  video path where test images are located." << std::endl
+        << std::endl;
+      return EXIT_FAILURE;
     }
 
     /////////////////////////////////////////////////////////////////////
@@ -248,8 +258,9 @@ int main(int argc, const char **argv)
     vpVideoReader reader;
 
     if (opt_ppath.empty()) {
-      filename = vpIoTools::createFilePath(ipath, "mire-2/image.%04d.pgm");
-    } else {
+      filename = vpIoTools::createFilePath(ipath, "mire-2/image.%04d." + ext);
+    }
+    else {
       filename.assign(opt_ppath);
     }
 
@@ -263,14 +274,14 @@ int main(int argc, const char **argv)
       return EXIT_FAILURE;
     }
 
-// We open a window using either X11, GTK, GDI or OpenCV.
-#if defined VISP_HAVE_X11
+    // We open a window using either X11, GTK, GDI or OpenCV.
+#if defined(VISP_HAVE_X11)
     vpDisplayX display;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display;
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display;
 #endif
 
@@ -305,7 +316,7 @@ int main(int argc, const char **argv)
 
     reader.getFrame(I, reader.getLastFrameIndex());
     std::cout << "Current image number (should be " << reader.getLastFrameIndex() << "): " << reader.getFrameIndex()
-              << std::endl;
+      << std::endl;
 
     if (opt_display) {
       vpDisplay::display(I);
@@ -334,7 +345,8 @@ int main(int argc, const char **argv)
     }
 
     return EXIT_SUCCESS;
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return EXIT_FAILURE;
   }
