@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Reading a video file.
  *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file videoReader.cpp
@@ -84,8 +81,9 @@ Read a video file on the disk.\n\
 \n\
 SYNOPSIS\n\
   %s [-i <input video path>] \n\
-     [-h]\n						      \
-", name);
+     [-h]\n\
+",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
@@ -100,17 +98,18 @@ OPTIONS:                                               Default\n\
   -p <personal video path>                             %s\n\
      Specify a personal folder containing a video \n\
      to process.\n\
-     Example : \"/Temp/ViSP-images/video/video.mpeg\"\n\
+     Example : \"/Temp/visp-images/video/video.mpeg\"\n\
 \n\
   -c\n\
-     Disable the mouse click. Useful to automaze the \n\
-     execution of this program without humain intervention.\n\
+     Disable the mouse click. Useful to automate the \n\
+     execution of this program without human intervention.\n\
 \n\
   -d \n\
      Turn off the display.\n\
 \n\
   -h\n\
-     Print the help.\n\n", ipath.c_str(), ppath.c_str());
+     Print the help.\n\n",
+          ipath.c_str(), ppath.c_str());
 
   if (badparam) {
     fprintf(stderr, "ERROR: \n");
@@ -200,7 +199,7 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, opt_ipath, opt_ppath, opt_click_allowed, opt_display) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Get the option values
@@ -226,7 +225,7 @@ int main(int argc, const char **argv)
                 << "  environment variable to specify the location of the " << std::endl
                 << "  video path where test images are located." << std::endl
                 << std::endl;
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     /////////////////////////////////////////////////////////////////////
@@ -250,13 +249,13 @@ int main(int argc, const char **argv)
     reader.open(I);
 
 // We open a window using either X11, GTK, GDI or OpenCV.
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     vpDisplayX display;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display;
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display;
 #endif
 
