@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Bertrand Delabarre
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpAROgre.cpp
@@ -80,7 +80,7 @@ vpAROgre::vpAROgre(const vpCameraParameters &cam, unsigned int width, unsigned i
     keepOn(true), // When created no reason to stop displaying
     mImageRGBA(), mImage(), mPixelBuffer(), mBackground(NULL), mBackgroundHeight(0), mBackgroundWidth(0),
     mWindowHeight(height), mWindowWidth(width), windowHidden(false), mNearClipping(0.001), mFarClipping(200), mcam(cam),
-    mshowConfigDialog(true), mOptionnalResourceLocation()
+    mshowConfigDialog(true), mOptionalResourceLocation()
 {
 }
 
@@ -248,8 +248,7 @@ void vpAROgre::init(bool
 
   if (Ogre::Root::getSingletonPtr() == NULL) {
     mRoot = new Ogre::Root(pluginFile, "ogre.cfg", "Ogre.log");
-  }
-  else {
+  } else {
     mRoot = Ogre::Root::getSingletonPtr();
   }
 
@@ -302,9 +301,9 @@ void vpAROgre::init(bool
     }
   }
   std::cout << "##################### add resources" << std::endl;
-  // Add optionnal resources (given by the user).
-  for (std::list<std::string>::const_iterator iter = mOptionnalResourceLocation.begin();
-       iter != mOptionnalResourceLocation.end(); ++iter) {
+  // Add Optional resources (given by the user).
+  for (std::list<std::string>::const_iterator iter = mOptionalResourceLocation.begin();
+       iter != mOptionalResourceLocation.end(); ++iter) {
     Ogre::ResourceGroupManager::getSingleton().addResourceLocation(
         *iter, "FileSystem", Ogre::ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME);
   }
@@ -383,11 +382,11 @@ void vpAROgre::init(bool
   //-----------------------------------------------------
   // 4 Create the SceneManager
   //
-  //		ST_GENERIC = octree
-  //		ST_EXTERIOR_CLOSE = simple terrain
-  //		ST_EXTERIOR_FAR = nature terrain (depreciated)
-  //		ST_EXTERIOR_REAL_FAR = paging landscape
-  //		ST_INTERIOR = Quake3 BSP
+  //    ST_GENERIC = octree
+  //    ST_EXTERIOR_CLOSE = simple terrain
+  //    ST_EXTERIOR_FAR = nature terrain (depreciated)
+  //    ST_EXTERIOR_REAL_FAR = paging landscape
+  //    ST_INTERIOR = Quake3 BSP
   //-----------------------------------------------------
 
   mSceneMgr = mRoot->createSceneManager(Ogre::ST_GENERIC);
@@ -469,7 +468,8 @@ vpAROgre::~vpAROgre(void)
   }
 
   // Delete root
-  if (Ogre::Root::getSingletonPtr() && !Ogre::Root::getSingletonPtr()->getSceneManagerIterator().hasMoreElements() && mRoot) {
+  if (Ogre::Root::getSingletonPtr() && !Ogre::Root::getSingletonPtr()->getSceneManagerIterator().hasMoreElements() &&
+      mRoot) {
     delete mRoot;
   }
   mRoot = 0;
@@ -485,8 +485,7 @@ bool vpAROgre::stopTest(const Ogre::FrameEvent &evt)
   // Always keep this part
   if (keepOn) {
     return updateScene(evt);
-  }
-  else {
+  } else {
     return keepOn;
   }
 }
@@ -1078,6 +1077,6 @@ void vpAROgre::getRenderingOutput(vpImage<vpRGBa> &I, const vpHomogeneousMatrix
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_ar.a(vpAROgre.cpp.o) has no symbols
+// Work around to avoid warning: libvisp_ar.a(vpAROgre.cpp.o) has no symbols
 void dummy_vpAROgre(){};
 #endif
