@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,8 +29,7 @@
  *
  * Description:
  * CPU features (hardware capabilities).
- *
- *****************************************************************************/
+ */
 
 #ifndef _vpCPUFeatures_h_
 #define _vpCPUFeatures_h_
@@ -70,7 +68,11 @@ VISP_EXPORT bool checkSSE41();
 VISP_EXPORT bool checkSSE42();
 VISP_EXPORT bool checkAVX();
 VISP_EXPORT bool checkAVX2();
+VISP_EXPORT bool checkNeon();
+VISP_EXPORT size_t getCPUCacheL1();
+VISP_EXPORT size_t getCPUCacheL2();
+VISP_EXPORT size_t getCPUCacheL3();
 VISP_EXPORT void printCPUInfo();
-}
+} // namespace vpCPUFeatures
 
 #endif
