@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,12 +29,7 @@
  *
  * Description:
  * Color definition.
- *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+ */
 
 #ifndef vpColor_hh
 #define vpColor_hh
@@ -49,7 +43,7 @@
 
   \ingroup group_core_gui
 
-  \brief Class to define RGB colors available for display functionnalities.
+  \brief Class to define RGB colors available for display functionalities.
 
   - You may use predefined colors:
     - vpColor::black, vpColor::white,
@@ -124,7 +118,7 @@ int main()
   d = new vpDisplayGDI;
 #elif defined(VISP_HAVE_D3D9)
   d = new vpDisplayD3D;
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
   d = new vpDisplayOpenCV;
 #endif
 
@@ -238,7 +232,7 @@ public:
     that this color is not a predefined one.
 
   */
-  inline vpColor() : vpRGBa(), id(id_unknown){}
+  inline vpColor() : vpRGBa(), id(id_unknown) {}
   /*!
     Construct a color from its RGB values.
 
@@ -251,7 +245,9 @@ public:
   */
   inline vpColor(unsigned char r, unsigned char g, unsigned char b,
                  vpColor::vpColorIdentifier cid = vpColor::id_unknown)
-    : vpRGBa(r, g, b), id(cid){}
+    : vpRGBa(r, g, b), id(cid)
+  {
+  }
   /*!
     Construct a color from its RGB values and alpha channel.
 
@@ -265,18 +261,19 @@ public:
   */
   inline vpColor(unsigned char r, unsigned char g, unsigned char b, unsigned char alpha,
                  vpColor::vpColorIdentifier cid = vpColor::id_unknown)
-    : vpRGBa(r, g, b, alpha), id(cid){}
+    : vpRGBa(r, g, b, alpha), id(cid)
+  {
+  }
   /*!
     Construct a color with an alpha channel.
 
     \param color : RGB color.
     \param alpha : Alpha channel for transparency.
   */
-  inline vpColor(const vpColor &color, unsigned char alpha)
-    : vpRGBa(color.R, color.G, color.B, alpha), id(color.id) {}
+  inline vpColor(const vpColor &color, unsigned char alpha) : vpRGBa(color.R, color.G, color.B, alpha), id(color.id) {}
 
   /*! Default destructor. */
-  inline virtual ~vpColor(){}
+  inline virtual ~vpColor() {}
 
   friend VISP_EXPORT bool operator==(const vpColor &c1, const vpColor &c2);
   friend VISP_EXPORT bool operator!=(const vpColor &c1, const vpColor &c2);
@@ -292,7 +289,7 @@ public:
     that this color is not a predefined one.
 
   */
-  inline void setColor(unsigned char r, unsigned char g, unsigned char b, unsigned char a=vpRGBa::alpha_default)
+  inline void setColor(unsigned char r, unsigned char g, unsigned char b, unsigned char a = vpRGBa::alpha_default)
   {
     this->R = r;
     this->G = g;
