@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,12 +29,7 @@
  *
  * Description:
  * Directory management.
- *
- * Authors:
- * Fabien Spindler
- * Souriya Trinh
- *
- *****************************************************************************/
+ */
 
 #ifndef _vpConvert_h_
 #define _vpConvert_h_
@@ -47,10 +41,8 @@
 
 #include <visp3/core/vpConfig.h>
 
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
-#include <opencv2/core/core.hpp>
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_FEATURES2D)
 #include <opencv2/features2d/features2d.hpp>
-#endif
 
 #include <visp3/core/vpImagePoint.h>
 #include <visp3/core/vpPoint.h>
@@ -62,9 +54,7 @@
  */
 class VISP_EXPORT vpConvert
 {
-
 public:
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
   static void convertFromOpenCV(const cv::KeyPoint &from, vpImagePoint &to);
   static void convertFromOpenCV(const cv::Point2f &from, vpImagePoint &to);
   static void convertFromOpenCV(const cv::Point2d &from, vpImagePoint &to);
@@ -87,10 +77,8 @@ public:
 
   static void convertToOpenCV(const std::vector<vpImagePoint> &from, std::vector<cv::Point2f> &to);
   static void convertToOpenCV(const std::vector<vpImagePoint> &from, std::vector<cv::Point2d> &to);
-  static void convertToOpenCV(const std::vector<vpPoint> &from, std::vector<cv::Point3f> &to,
-                              bool cameraFrame = false);
-  static void convertToOpenCV(const std::vector<vpPoint> &from, std::vector<cv::Point3d> &to,
-                              bool cameraFrame = false);
+  static void convertToOpenCV(const std::vector<vpPoint> &from, std::vector<cv::Point3f> &to, bool cameraFrame = false);
+  static void convertToOpenCV(const std::vector<vpPoint> &from, std::vector<cv::Point3d> &to, bool cameraFrame = false);
 
 private:
   static vpImagePoint keyPointToVpImagePoint(const cv::KeyPoint &keypoint);
@@ -109,7 +97,7 @@ private:
   static cv::Point3f vpObjectPointToPoint3f(const vpPoint &point);
   static cv::Point3d vpObjectPointToPoint3d(const vpPoint &point);
 
-#endif
 };
 
 #endif
+#endif
