@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +30,7 @@
  * Description:
  * Twist transformation matrix that allows to transform forces from one
  * frame to an other.
- *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+ */
 
 #ifndef vpForceTwistMatrix_h
 #define vpForceTwistMatrix_h
@@ -185,7 +180,7 @@ public:
   /*!
     Destructor.
   */
-  virtual ~vpForceTwistMatrix(){};
+  virtual ~vpForceTwistMatrix(){}
 
   vpForceTwistMatrix buildFrom(const vpTranslationVector &t, const vpRotationMatrix &R);
   vpForceTwistMatrix buildFrom(const vpTranslationVector &t, const vpThetaUVector &thetau);
@@ -218,7 +213,7 @@ public:
     (void)ncols;
     (void)flagNullify;
     throw(vpException(vpException::fatalError, "Cannot resize a velocity twist matrix"));
-  };
+  }
 
 #if defined(VISP_BUILD_DEPRECATED_FUNCTIONS)
   /*!
@@ -229,7 +224,7 @@ public:
      \deprecated Provided only for compat with previous releases.
      This function does nothing.
    */
-  vp_deprecated void init(){};
+  vp_deprecated void init(){}
   /*!
      \deprecated You should rather use eye().
    */
