@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * Generation of random number with uniform and normal probability density.
- *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+ */
 
 #ifndef vpGaussRand_hh
 #define vpGaussRand_hh
@@ -50,7 +45,7 @@
   The algorithms and notations used are described in \cite Gentle:2004.
 
   The code below shows how to use the random generator to get values that have
-  their mean equal to 10 with a standart deviation equal to 0.5.
+  their mean equal to 10 with a standard deviation equal to 0.5.
 
   \code
 #include <iostream>
@@ -67,7 +62,7 @@ int main()
   \endcode
 
   The previous example produces the following printings:
-\code
+  \verbatim
 noise 0: 10.645
 noise 1: 9.67129
 noise 2: 10.1208
@@ -78,14 +73,14 @@ noise 6: 9.81414
 noise 7: 9.96076
 noise 8: 11.0795
 noise 9: 9.79229
-\endcode
+  \endverbatim
 
   Note that the previous example produces always the same "random" results. To
 produce real random values, you need to initialize the random generator with
 different values using seed(). For example, this could be done using the
 current time. The code becomes:
 
-\code
+  \verbatim
 #include <iostream>
 #include <visp3/core/vpGaussRand.h>
 #include <visp3/core/vpTime.h>
@@ -101,10 +96,10 @@ int main()
   }
   return 0;
 }
-\endcode
+  \endverbatim
 
   Now if you run the previous example you will always get different values:
-  \code
+  \verbatim
 noise 0: 10.5982
 noise 1: 9.19111
 noise 2: 9.82498
@@ -115,7 +110,7 @@ noise 6: 9.75621
 noise 7: 10.3259
 noise 8: 10.4238
 noise 9: 10.2391
-  \endcode
+  \endverbatim
  */
 class VISP_EXPORT vpGaussRand
 {
