@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,8 +29,7 @@
  *
  * Description:
  * Matrix manipulation.
- *
- *****************************************************************************/
+ */
 
 #ifndef vpMatrix_H
 #define vpMatrix_H
@@ -157,7 +155,8 @@ public:
     Method used to compute the determinant of a square matrix.
     \sa det()
   */
-  typedef enum {
+  typedef enum
+  {
     LU_DECOMPOSITION /*!< LU decomposition method. */
   } vpDetMethod;
 
@@ -166,7 +165,7 @@ public:
     Basic constructor of a matrix of double. Number of columns and rows are
     zero.
   */
-  vpMatrix() : vpArray2D<double>(0, 0) {}
+  vpMatrix() : vpArray2D<double>(0, 0) { }
 
   /*!
     Constructor that initialize a matrix of double with 0.
@@ -174,7 +173,7 @@ public:
     \param r : Matrix number of rows.
     \param c : Matrix number of columns.
   */
-  vpMatrix(unsigned int r, unsigned int c) : vpArray2D<double>(r, c) {}
+  vpMatrix(unsigned int r, unsigned int c) : vpArray2D<double>(r, c) { }
 
   /*!
     Constructor that initialize a matrix of double with \e val.
@@ -183,7 +182,7 @@ public:
     \param c : Matrix number of columns.
     \param val : Each element of the matrix is set to \e val.
   */
-  vpMatrix(unsigned int r, unsigned int c, double val) : vpArray2D<double>(r, c, val) {}
+  vpMatrix(unsigned int r, unsigned int c, double val) : vpArray2D<double>(r, c, val) { }
   vpMatrix(const vpMatrix &M, unsigned int r, unsigned int c, unsigned int nrows, unsigned int ncols);
 
   /*!
@@ -198,9 +197,9 @@ vpRotationMatrix R;
 vpMatrix M(R);
 \endcode
    */
-  vpMatrix(const vpArray2D<double> &A) : vpArray2D<double>(A) {}
+  vpMatrix(const vpArray2D<double> &A) : vpArray2D<double>(A) { }
 
-  vpMatrix(const vpMatrix &A) : vpArray2D<double>(A) {}
+  vpMatrix(const vpMatrix &A) : vpArray2D<double>(A) { }
 
 #if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
   vpMatrix(vpMatrix &&A);
@@ -210,7 +209,7 @@ vpMatrix M(R);
 #endif
 
   //! Destructor (Memory de-allocation)
-  virtual ~vpMatrix() {}
+  virtual ~vpMatrix() { }
 
   /*!
     Removes all elements from the matrix (which are destroyed),
@@ -243,9 +242,7 @@ vpMatrix M(R);
    *
    * \sa setLapackMatrixMinSize()
    */
-  static unsigned int getLapackMatrixMinSize() {
-    return m_lapack_min_size;
-  }
+  static unsigned int getLapackMatrixMinSize() { return m_lapack_min_size; }
 
   /*!
    * Modify default size used to determine if Blas/Lapack basic linear algebra operations are enabled.
@@ -259,9 +256,7 @@ vpMatrix M(R);
    *
    * \sa getLapackMatrixMinSize()
    */
-  static void setLapackMatrixMinSize(unsigned int min_size) {
-    m_lapack_min_size = min_size;
-  }
+  static void setLapackMatrixMinSize(unsigned int min_size) { m_lapack_min_size = min_size; }
   //@}
 
   //-------------------------------------------------
@@ -284,15 +279,15 @@ vpMatrix M(R);
   /** @name Assignment operators */
   //@{
   vpMatrix &operator<<(double *);
-  vpMatrix& operator<<(double val);
-  vpMatrix& operator,(double val);
+  vpMatrix &operator<<(double val);
+  vpMatrix &operator,(double val);
   vpMatrix &operator=(const vpArray2D<double> &A);
 #if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
   vpMatrix &operator=(const vpMatrix &A);
   vpMatrix &operator=(vpMatrix &&A);
 
-  vpMatrix& operator=(const std::initializer_list<double> &list);
-  vpMatrix& operator=(const std::initializer_list<std::initializer_list<double> > &lists);
+  vpMatrix &operator=(const std::initializer_list<double> &list);
+  vpMatrix &operator=(const std::initializer_list<std::initializer_list<double> > &lists);
 #endif
   vpMatrix &operator=(double x);
   //@}
@@ -351,13 +346,13 @@ vpMatrix M(R);
   // return the determinant of the matrix.
   double det(vpDetMethod method = LU_DECOMPOSITION) const;
   double detByLU() const;
-#ifdef VISP_HAVE_EIGEN3
+#if defined(VISP_HAVE_EIGEN3)
   double detByLUEigen3() const;
 #endif
 #if defined(VISP_HAVE_LAPACK)
   double detByLULapack() const;
 #endif
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV)
   double detByLUOpenCV() const;
 #endif
 
@@ -454,7 +449,7 @@ vpMatrix M(R);
 #if defined(VISP_HAVE_LAPACK)
   vpMatrix inverseByLULapack() const;
 #endif
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV)
   vpMatrix inverseByLUOpenCV() const;
 #endif
 
@@ -465,7 +460,7 @@ vpMatrix M(R);
 #if defined(VISP_HAVE_LAPACK)
   vpMatrix inverseByCholeskyLapack() const;
 #endif
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV)
   vpMatrix inverseByCholeskyOpenCV() const;
 #endif
 
@@ -482,7 +477,8 @@ vpMatrix M(R);
   unsigned int pseudoInverse(vpMatrix &Ap, double svThreshold = 1e-6) const;
   unsigned int pseudoInverse(vpMatrix &Ap, vpColVector &sv, double svThreshold = 1e-6) const;
   unsigned int pseudoInverse(vpMatrix &Ap, vpColVector &sv, double svThreshold, vpMatrix &imA, vpMatrix &imAt) const;
-  unsigned int pseudoInverse(vpMatrix &Ap, vpColVector &sv, double svThreshold, vpMatrix &imA, vpMatrix &imAt, vpMatrix &kerAt) const;
+  unsigned int pseudoInverse(vpMatrix &Ap, vpColVector &sv, double svThreshold, vpMatrix &imA, vpMatrix &imAt,
+                             vpMatrix &kerAt) const;
   vpMatrix pseudoInverse(int rank_in) const;
   int pseudoInverse(vpMatrix &Ap, int rank_in) const;
   int pseudoInverse(vpMatrix &Ap, vpColVector &sv, int rank_in) const;
@@ -493,31 +489,37 @@ vpMatrix M(R);
   vpMatrix pseudoInverseLapack(double svThreshold = 1e-6) const;
   unsigned int pseudoInverseLapack(vpMatrix &Ap, double svThreshold = 1e-6) const;
   unsigned int pseudoInverseLapack(vpMatrix &Ap, vpColVector &sv, double svThreshold = 1e-6) const;
-  unsigned int pseudoInverseLapack(vpMatrix &Ap, vpColVector &sv, double svThreshold, vpMatrix &imA, vpMatrix &imAt, vpMatrix &kerAt) const;
+  unsigned int pseudoInverseLapack(vpMatrix &Ap, vpColVector &sv, double svThreshold, vpMatrix &imA, vpMatrix &imAt,
+                                   vpMatrix &kerAt) const;
   vpMatrix pseudoInverseLapack(int rank_in) const;
   int pseudoInverseLapack(vpMatrix &Ap, int rank_in) const;
   int pseudoInverseLapack(vpMatrix &Ap, vpColVector &sv, int rank_in) const;
-  int pseudoInverseLapack(vpMatrix &Ap, vpColVector &sv, int rank_in, vpMatrix &imA, vpMatrix &imAt, vpMatrix &kerAt) const;
+  int pseudoInverseLapack(vpMatrix &Ap, vpColVector &sv, int rank_in, vpMatrix &imA, vpMatrix &imAt,
+                          vpMatrix &kerAt) const;
 #endif
 #if defined(VISP_HAVE_EIGEN3)
   vpMatrix pseudoInverseEigen3(double svThreshold = 1e-6) const;
   unsigned int pseudoInverseEigen3(vpMatrix &Ap, double svThreshold = 1e-6) const;
   unsigned int pseudoInverseEigen3(vpMatrix &Ap, vpColVector &sv, double svThreshold = 1e-6) const;
-  unsigned int pseudoInverseEigen3(vpMatrix &Ap, vpColVector &sv, double svThreshold, vpMatrix &imA, vpMatrix &imAt, vpMatrix &kerAt) const;
+  unsigned int pseudoInverseEigen3(vpMatrix &Ap, vpColVector &sv, double svThreshold, vpMatrix &imA, vpMatrix &imAt,
+                                   vpMatrix &kerAt) const;
   vpMatrix pseudoInverseEigen3(int rank_in) const;
   int pseudoInverseEigen3(vpMatrix &Ap, int rank_in) const;
   int pseudoInverseEigen3(vpMatrix &Ap, vpColVector &sv, int rank_in) const;
-  int pseudoInverseEigen3(vpMatrix &Ap, vpColVector &sv, int rank_in, vpMatrix &imA, vpMatrix &imAt, vpMatrix &kerAt) const;
+  int pseudoInverseEigen3(vpMatrix &Ap, vpColVector &sv, int rank_in, vpMatrix &imA, vpMatrix &imAt,
+                          vpMatrix &kerAt) const;
 #endif
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV)
   vpMatrix pseudoInverseOpenCV(double svThreshold = 1e-6) const;
   unsigned int pseudoInverseOpenCV(vpMatrix &Ap, double svThreshold = 1e-6) const;
   unsigned int pseudoInverseOpenCV(vpMatrix &Ap, vpColVector &sv, double svThreshold = 1e-6) const;
-  unsigned int pseudoInverseOpenCV(vpMatrix &Ap, vpColVector &sv, double svThreshold, vpMatrix &imA, vpMatrix &imAt, vpMatrix &kerAt) const;
+  unsigned int pseudoInverseOpenCV(vpMatrix &Ap, vpColVector &sv, double svThreshold, vpMatrix &imA, vpMatrix &imAt,
+                                   vpMatrix &kerAt) const;
   vpMatrix pseudoInverseOpenCV(int rank_in) const;
   int pseudoInverseOpenCV(vpMatrix &Ap, int rank_in) const;
   int pseudoInverseOpenCV(vpMatrix &Ap, vpColVector &sv, int rank_in) const;
-  int pseudoInverseOpenCV(vpMatrix &Ap, vpColVector &sv, int rank_in, vpMatrix &imA, vpMatrix &imAt, vpMatrix &kerAt) const;
+  int pseudoInverseOpenCV(vpMatrix &Ap, vpColVector &sv, int rank_in, vpMatrix &imA, vpMatrix &imAt,
+                          vpMatrix &kerAt) const;
 #endif
   //@}
 
@@ -545,7 +547,7 @@ vpMatrix M(R);
 #if defined(VISP_HAVE_LAPACK)
   void svdLapack(vpColVector &w, vpMatrix &V);
 #endif
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101) // Require opencv >= 2.1.1
+#if defined(VISP_HAVE_OPENCV) // Require opencv >= 2.1.1
   void svdOpenCV(vpColVector &w, vpMatrix &V);
 #endif
   //@}
@@ -557,7 +559,8 @@ vpMatrix M(R);
   /** @name QR decomposition  */
   //@{
   unsigned int qr(vpMatrix &Q, vpMatrix &R, bool full = false, bool squareR = false, double tol = 1e-6) const;
-  unsigned int qrPivot(vpMatrix &Q, vpMatrix &R, vpMatrix &P, bool full = false, bool squareR = false, double tol = 1e-6) const;
+  unsigned int qrPivot(vpMatrix &Q, vpMatrix &R, vpMatrix &P, bool full = false, bool squareR = false,
+                       double tol = 1e-6) const;
   void solveByQR(const vpColVector &b, vpColVector &x) const;
   vpColVector solveByQR(const vpColVector &b) const;
   //@}
@@ -568,7 +571,7 @@ vpMatrix M(R);
   /** @name Eigen values  */
 
   //@{
-  // compute the eigen values using Lapack
+  // Compute the eigen values using Lapack.
   vpColVector eigenValues() const;
   void eigenValues(vpColVector &evalue, vpMatrix &evector) const;
   //@}
@@ -578,7 +581,6 @@ vpMatrix M(R);
   //-------------------------------------------------
   /** @name Norms  */
   //@{
-  double euclideanNorm() const;
   double frobeniusNorm() const;
   double inducedL2Norm() const;
   double infinityNorm() const;
@@ -673,13 +675,6 @@ vpMatrix M(R);
   static vpMatrix kron(const vpMatrix &m1, const vpMatrix &m2);
   //@}
 
-  //-------------------------------------------------
-  // 2D Convolution Static Public Member Functions
-  //-------------------------------------------------
-  /** @name 2D Convolution with Static Public Member Functions  */
-  static vpMatrix conv2(const vpMatrix &M, const vpMatrix &kernel, const std::string &mode="full");
-  static void conv2(const vpMatrix &M, const vpMatrix &kernel, vpMatrix &res, const std::string &mode="full");
-
   //---------------------------------
   // Covariance computation Static Public Member Functions
   //---------------------------------
@@ -702,13 +697,68 @@ vpMatrix M(R);
   /*!
     Load a matrix from a file. This function overloads vpArray2D::load().
 
-    \param filename : absolute file name.
-    \param M : matrix to be loaded.
-    \param binary :If true the matrix is loaded from a binary file, else from
-    a text file. \param header : Header of the file is loaded in this
-    parameter
+    \param filename : Absolute file name.
+    \param M : Matrix to be loaded.
+    \param binary : If true the matrix data are considered as binary, otherwise as human readable (text) data. Using
+    binary data allows to keep data precision.
+    \param header : Header of the file is loaded in this parameter.
 
-    \return Returns true if no problem appends.
+    \return Returns true if success, false otherwise.
+
+    The following example shows how to use this function:
+    \code
+    #include <visp3/core/vpMatrix.h>
+
+    int main()
+    {
+      std::string filename("matrix.bin");
+      bool binary_data = true;
+      {
+        vpMatrix M(2, 3);
+        M[0][0] = -1; M[0][1] =  -2; M[0][2] = -3;
+        M[1][0] =  4; M[1][1] = 5.5; M[1][2] =  6.0f;
+
+        std::string header("My header");
+
+        if (vpMatrix::saveMatrix(filename, M, binary_data, header.c_str())) {
+          std::cout << "Matrix saved in " << filename << std::endl;
+          M.print(std::cout, 10, header);
+        } else {
+          std::cout << "Cannot save matrix in " << filename << std::endl;
+        }
+      }
+      {
+        vpMatrix N;
+        char header[FILENAME_MAX];
+        if (vpMatrix::loadMatrix(filename, N, binary_data, header)) {
+          std::cout << "Matrix loaded from " << filename << std::endl;
+          N.print(std::cout, 10, header);
+        } else {
+          std::cout << "Cannot load matrix from " << filename << std::endl;
+        }
+      }
+    }
+    \endcode
+
+    The output of this example is the following:
+    \verbatim
+    Matrix saved in matrix.bin
+    My header[2,3]=
+      -1.0 -2.0 -3.0
+       4.0  5.5  6.0
+    Matrix loaded from matrix.bin
+    My header[2,3]=
+      -1.0 -2.0 -3.0
+       4.0  5.5  6.0
+    \endverbatim
+
+    And the content of `matrix.bin` file where data are saved as binary data is the following:
+    \verbatim
+    % cat matrix.bin
+    My header??@@@%
+    \endverbatim
+
+    \sa saveMatrix(), saveMatrixYAML(), loadMatrixYAML()
   */
   static inline bool loadMatrix(const std::string &filename, vpArray2D<double> &M, bool binary = false,
                                 char *header = NULL)
@@ -720,11 +770,70 @@ vpMatrix M(R);
     Load a matrix from a YAML-formatted file. This function overloads
     vpArray2D::loadYAML().
 
-    \param filename : absolute file name.
-    \param M : matrix to be loaded from the file.
+    \param filename : Absolute YAML file name.
+    \param M : Matrix to be loaded from the file.
     \param header : Header of the file is loaded in this parameter.
 
-    \return Returns true if no problem appends.
+    \return Returns true when success, false otherwise.
+
+    The following example shows how to use this function:
+    \code
+    #include <visp3/core/vpMatrix.h>
+
+    int main()
+    {
+      std::string filename("matrix.yaml");
+      {
+        vpMatrix M(2, 3);
+        M[0][0] = -1; M[0][1] =  -2; M[0][2] = -3;
+        M[1][0] =  4; M[1][1] = 5.5; M[1][2] =  6.0f;
+
+        std::string header("My header");
+
+        if (vpMatrix::saveMatrixYAML(filename, M, header.c_str())) {
+          std::cout << "Matrix saved in " << filename << std::endl;
+          M.print(std::cout, 10, header);
+        } else {
+          std::cout << "Cannot save matrix in " << filename << std::endl;
+        }
+      }
+      {
+        vpMatrix N;
+        char header[FILENAME_MAX];
+        if (vpMatrix::loadMatrixYAML(filename, N, header)) {
+          std::cout << "Matrix loaded from " << filename << std::endl;
+          N.print(std::cout, 10, header);
+        } else {
+          std::cout << "Cannot load matrix from " << filename << std::endl;
+        }
+      }
+    }
+    \endcode
+
+    The output of this example is the following:
+    \verbatim
+    Matrix saved in matrix.yaml
+    My header[2,3]=
+      -1.0 -2.0 -3.0
+       4.0  5.5  6.0
+    Matrix loaded from matrix.yaml
+    My header[2,3]=
+      -1.0 -2.0 -3.0
+       4.0  5.5  6.0
+    \endverbatim
+
+    And the content of `matrix.yaml` file is the following:
+    \verbatim
+    % cat matrix.yaml
+    My header
+    rows: 2
+    cols: 3
+    data:
+      - [-1, -2, -3]
+      - [4, 5.5, 6]
+    \endverbatim
+
+    \sa saveMatrixYAML(), saveMatrix(), loadMatrix()
   */
   static inline bool loadMatrixYAML(const std::string &filename, vpArray2D<double> &M, char *header = NULL)
   {
@@ -732,18 +841,72 @@ vpMatrix M(R);
   }
 
   /*!
-    Save a matrix to a file. This function overloads vpArray2D::load().
+    Save a matrix to a file. This function overloads vpArray2D::save().
 
-    \param filename : absolute file name.
-    \param M : matrix to be saved.
-    \param binary : If true the matrix is save in a binary file, else a text
-    file. \param header : optional line that will be saved at the beginning of
-    the file.
+    \param filename : Absolute file name.
+    \param M : Matrix to be saved.
+    \param binary : If true the matrix is save as a binary file, otherwise as a text file.
+    \param header : Optional line that will be saved at the beginning of the file as a header.
 
     \return Returns true if no problem appends.
 
-    Warning : If you save the matrix as in a text file the precision is less
-    than if you save it in a binary file.
+    \warning If you save the matrix as a text file the precision is less
+    than if you save it as a binary file.
+
+    The following example shows how to use this function:
+    \code
+    #include <visp3/core/vpMatrix.h>
+
+    int main()
+    {
+      std::string filename("matrix.bin");
+      bool binary_data = true;
+      {
+        vpMatrix M(2, 3);
+        M[0][0] = -1; M[0][1] =  -2; M[0][2] = -3;
+        M[1][0] =  4; M[1][1] = 5.5; M[1][2] =  6.0f;
+
+        std::string header("My header");
+
+        if (vpMatrix::saveMatrix(filename, M, binary_data, header.c_str())) {
+          std::cout << "Matrix saved in " << filename << std::endl;
+          M.print(std::cout, 10, header);
+        } else {
+          std::cout << "Cannot save matrix in " << filename << std::endl;
+        }
+      }
+      {
+        vpMatrix N;
+        char header[FILENAME_MAX];
+        if (vpMatrix::loadMatrix(filename, N, binary_data, header)) {
+          std::cout << "Matrix loaded from " << filename << std::endl;
+          N.print(std::cout, 10, header);
+        } else {
+          std::cout << "Cannot load matrix from " << filename << std::endl;
+        }
+      }
+    }
+    \endcode
+
+    The output of this example is the following:
+    \verbatim
+    Matrix saved in matrix.bin
+    My header[2,3]=
+      -1.0 -2.0 -3.0
+       4.0  5.5  6.0
+    Matrix loaded from matrix.bin
+    My header[2,3]=
+      -1.0 -2.0 -3.0
+       4.0  5.5  6.0
+    \endverbatim
+
+    And the content of `matrix.bin` file where data are saved as binary data is the following:
+    \verbatim
+    % cat matrix.bin
+    My header??@@@%
+    \endverbatim
+
+    \sa loadMatrix(), saveMatrixYAML(), loadMatrixYAML()
   */
   static inline bool saveMatrix(const std::string &filename, const vpArray2D<double> &M, bool binary = false,
                                 const char *header = "")
@@ -755,13 +918,71 @@ vpMatrix M(R);
     Save a matrix in a YAML-formatted file. This function overloads
     vpArray2D::saveYAML().
 
-    \param filename : absolute file name.
-    \param M : matrix to be saved in the file.
-    \param header : optional lines that will be saved at the beginning of the
-    file. Should be YAML-formatted and will adapt to the indentation if any.
+    \param filename : Absolute file name.
+    \param M : Matrix to be saved in the file.
+    \param header : Optional lines that will be saved at the beginning of the
+    file as a header.
 
     \return Returns true if success.
 
+    The following example shows how to use this function:
+    \code
+    #include <visp3/core/vpMatrix.h>
+
+    int main()
+    {
+      std::string filename("matrix.yaml");
+      {
+        vpMatrix M(2, 3);
+        M[0][0] = -1; M[0][1] =  -2; M[0][2] = -3;
+        M[1][0] =  4; M[1][1] = 5.5; M[1][2] =  6.0f;
+
+        std::string header("My header");
+
+        if (vpMatrix::saveMatrixYAML(filename, M, header.c_str())) {
+          std::cout << "Matrix saved in " << filename << std::endl;
+          M.print(std::cout, 10, header);
+        } else {
+          std::cout << "Cannot save matrix in " << filename << std::endl;
+        }
+      }
+      {
+        vpMatrix N;
+        char header[FILENAME_MAX];
+        if (vpMatrix::loadMatrixYAML(filename, N, header)) {
+          std::cout << "Matrix loaded from " << filename << std::endl;
+          N.print(std::cout, 10, header);
+        } else {
+          std::cout << "Cannot load matrix from " << filename << std::endl;
+        }
+      }
+    }
+    \endcode
+
+    The output of this example is the following:
+    \verbatim
+    Matrix saved in matrix.yaml
+    My header[2,3]=
+      -1.0 -2.0 -3.0
+       4.0  5.5  6.0
+    Matrix loaded from matrix.yaml
+    My header[2,3]=
+      -1.0 -2.0 -3.0
+       4.0  5.5  6.0
+    \endverbatim
+
+    And the content of `matrix.yaml` file is the following:
+    \verbatim
+    % cat matrix.yaml
+    My header
+    rows: 2
+    cols: 3
+    data:
+      - [-1, -2, -3]
+      - [4, 5.5, 6]
+    \endverbatim
+
+    \sa saveMatrix(), loadMatrix(), loadMatrixYAML()
   */
   static inline bool saveMatrixYAML(const std::string &filename, const vpArray2D<double> &M, const char *header = "")
   {
@@ -770,6 +991,8 @@ vpMatrix M(R);
   //@}
 
 #if defined(VISP_BUILD_DEPRECATED_FUNCTIONS)
+  vp_deprecated double euclideanNorm() const;
+
   /*!
     @name Deprecated functions
   */
@@ -778,7 +1001,7 @@ vpMatrix M(R);
      \deprecated Only provided for compatibilty with ViSP previous releases.
      This function does nothing.
    */
-  vp_deprecated void init() {}
+  vp_deprecated void init() { }
 
   /*!
      \deprecated You should rather use stack(const vpMatrix &A)
@@ -828,90 +1051,90 @@ vpMatrix M(R);
   /*!
      \deprecated You should rather use detByLULapack() or detByLU().
    */
-  vp_deprecated double detByLUGsl() const {
+  vp_deprecated double detByLUGsl() const
+  {
 #if defined(VISP_HAVE_LAPACK)
     return detByLULapack();
 #else
-    throw(vpException(vpException::fatalError,
-                      "Undefined detByLULapack(). Install Lapack 3rd party"));
+    throw(vpException(vpException::fatalError, "Undefined detByLULapack(). Install Lapack 3rd party"));
 #endif
   }
 
   /*!
      \deprecated You should rather use inverseByLULapack() or inverseByLU().
    */
-  vp_deprecated vpMatrix inverseByLUGsl() const {
+  vp_deprecated vpMatrix inverseByLUGsl() const
+  {
 #if defined(VISP_HAVE_LAPACK)
     return inverseByLULapack();
 #else
-    throw(vpException(vpException::fatalError,
-                      "Undefined inverseByLULapack(). Install Lapack 3rd party"));
+    throw(vpException(vpException::fatalError, "Undefined inverseByLULapack(). Install Lapack 3rd party"));
 #endif
   }
 
   /*!
      \deprecated You should rather use inverseByCholeskyLapack() or inverseByCholesky().
    */
-  vpMatrix inverseByCholeskyGsl() const {
+  vpMatrix inverseByCholeskyGsl() const
+  {
 #if defined(VISP_HAVE_LAPACK)
     return inverseByCholeskyLapack();
 #else
-    throw(vpException(vpException::fatalError,
-                      "Undefined inverseByCholeskyLapack(). Install Lapack 3rd party"));
+    throw(vpException(vpException::fatalError, "Undefined inverseByCholeskyLapack(). Install Lapack 3rd party"));
 #endif
   }
 
   /*!
      \deprecated You should rather use inverseByQRLapack() or inverseByQR().
    */
-  vpMatrix inverseByQRGsl() const {
+  vpMatrix inverseByQRGsl() const
+  {
 #if defined(VISP_HAVE_LAPACK)
     return inverseByQRLapack();
 #else
-    throw(vpException(vpException::fatalError,
-                      "Undefined inverseByQRLapack(). Install Lapack 3rd party"));
+    throw(vpException(vpException::fatalError, "Undefined inverseByQRLapack(). Install Lapack 3rd party"));
 #endif
   }
 
   /*!
      \deprecated You should rather use pseudoInverseLapack() or pseudoInverse().
    */
-  vpMatrix pseudoInverseGsl(double svThreshold = 1e-6) const {
+  vpMatrix pseudoInverseGsl(double svThreshold = 1e-6) const
+  {
 #if defined(VISP_HAVE_LAPACK)
     return pseudoInverseLapack(svThreshold);
 #else
     (void)svThreshold;
-    throw(vpException(vpException::fatalError,
-                      "Undefined pseudoInverseLapack(). Install Lapack 3rd party"));
+    throw(vpException(vpException::fatalError, "Undefined pseudoInverseLapack(). Install Lapack 3rd party"));
 #endif
   }
 
   /*!
      \deprecated You should rather use pseudoInverseLapack() or pseudoInverse().
    */
-  unsigned int pseudoInverseGsl(vpMatrix &Ap, double svThreshold = 1e-6) const {
+  unsigned int pseudoInverseGsl(vpMatrix &Ap, double svThreshold = 1e-6) const
+  {
 #if defined(VISP_HAVE_LAPACK)
     return pseudoInverseLapack(Ap, svThreshold);
 #else
     (void)Ap;
     (void)svThreshold;
-    throw(vpException(vpException::fatalError,
-                      "Undefined pseudoInverseLapack(). Install Lapack 3rd party"));
+    throw(vpException(vpException::fatalError, "Undefined pseudoInverseLapack(). Install Lapack 3rd party"));
 #endif
   }
 
   /*!
      \deprecated You should rather use pseudoInverseLapack() or pseudoInverse().
    */
-  unsigned int pseudoInverseGsl(vpMatrix &Ap, vpColVector &sv, double svThreshold = 1e-6) const {
+  unsigned int pseudoInverseGsl(vpMatrix &Ap, vpColVector &sv, double svThreshold = 1e-6) const
+  {
 #if defined(VISP_HAVE_LAPACK)
     return pseudoInverseLapack(Ap, sv, svThreshold);
 #else
     (void)Ap;
     (void)sv;
     (void)svThreshold;
-    throw(vpException(vpException::fatalError,
-                      "Undefined pseudoInverseLapack(). Install Lapack 3rd party"));
+    throw(vpException(vpException::fatalError, "Undefined pseudoInverseLapack(). Install Lapack 3rd party"));
 #endif
   }
 
@@ -919,7 +1142,8 @@ vpMatrix M(R);
      \deprecated You should rather use pseudoInverseLapack() or pseudoInverse().
    */
   unsigned int pseudoInverseGsl(vpMatrix &Ap, vpColVector &sv, double svThreshold, vpMatrix &imA, vpMatrix &imAt,
-                                vpMatrix &kerAt) const {
+                                vpMatrix &kerAt) const
+  {
 #if defined(VISP_HAVE_LAPACK)
     return pseudoInverseLapack(Ap, sv, svThreshold, imA, imAt, kerAt);
 #else
@@ -929,22 +1153,21 @@ vpMatrix M(R);
     (void)imA;
     (void)imAt;
     (void)kerAt;
-    throw(vpException(vpException::fatalError,
-                      "Undefined pseudoInverseLapack(). Install Lapack 3rd party"));
+    throw(vpException(vpException::fatalError, "Undefined pseudoInverseLapack(). Install Lapack 3rd party"));
 #endif
   }
 
   /*!
      \deprecated You should rather use svdLapack() or svd().
    */
-  void svdGsl(vpColVector &w, vpMatrix &V) {
+  void svdGsl(vpColVector &w, vpMatrix &V)
+  {
 #if defined(VISP_HAVE_LAPACK)
     svdLapack(w, V);
 #else
     (void)w;
     (void)V;
-    throw(vpException(vpException::fatalError,
-                      "Undefined svdLapack(). Install Lapack 3rd party"));
+    throw(vpException(vpException::fatalError, "Undefined svdLapack(). Install Lapack 3rd party"));
 #endif
   }
 
@@ -958,12 +1181,12 @@ private:
 
 #if defined(VISP_HAVE_LAPACK)
   static void blas_dgemm(char trans_a, char trans_b, unsigned int M_, unsigned int N_, unsigned int K_, double alpha,
-                         double *a_data, unsigned int lda_, double *b_data, unsigned int ldb_, double beta, double *c_data,
-                         unsigned int ldc_);
+                         double *a_data, unsigned int lda_, double *b_data, unsigned int ldb_, double beta,
+                         double *c_data, unsigned int ldc_);
   static void blas_dgemv(char trans, unsigned int M_, unsigned int N_, double alpha, double *a_data, unsigned int lda_,
                          double *x_data, int incx_, double beta, double *y_data, int incy_);
-  static void blas_dsyev(char jobz, char uplo, unsigned int n_, double *a_data, unsigned int lda_,
-                         double *w_data, double *work_data, int lwork_, int &info_);
+  static void blas_dsyev(char jobz, char uplo, unsigned int n_, double *a_data, unsigned int lda_, double *w_data,
+                         double *work_data, int lwork_, int &info_);
 #endif
 
   static void computeCovarianceMatrixVVS(const vpHomogeneousMatrix &cMo, const vpColVector &deltaS, const vpMatrix &Ls,
