@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * 2D normalized surface moment descriptor (usually described as An)
- *
- * Authors:
- * Filip Novotny
- *
- *****************************************************************************/
+ */
 /*!
   \file vpMomentAreaNormalized.h
   \brief 2D normalized surface moment descriptor (usually described as An).
@@ -81,12 +76,12 @@ continous cases.
 
   This example shows a computation in the discrete case.
   \code
+#include <visp3/core/vpMomentAreaNormalized.h>
+#include <visp3/core/vpMomentCentered.h>
+#include <visp3/core/vpMomentDatabase.h>
+#include <visp3/core/vpMomentGravityCenter.h>
 #include <visp3/core/vpMomentObject.h>
 #include <visp3/core/vpPoint.h>
-#include <visp3/core/vpMomentGravityCenter.h>
-#include <visp3/core/vpMomentDatabase.h>
-#include <visp3/core/vpMomentCentered.h>
-#include <visp3/core/vpMomentAreaNormalized.h>
 
 int main()
 {
@@ -143,7 +138,7 @@ private:
 
 public:
   vpMomentAreaNormalized(double a_star, double Z_star);
-  virtual ~vpMomentAreaNormalized(){};
+  virtual ~vpMomentAreaNormalized() { };
   void compute();
   /*!
     Retrieves the desired surface \e a* as specified in the constructor.
@@ -153,11 +148,7 @@ public:
     Retrieves the desired depth \e Z* as specified in the constructor.
   */
   double getDesiredDepth() const { return desiredDepth; }
-  /*!
-    \deprecated Use rather getDesiredArea()
-    Retrieves the desired surface \e a* as specified in the constructor.
-  */
-  vp_deprecated double getDesiredSurface() const { return desiredSurface; }
+
   /*!
     Set the desired depth \e Z* to a new value than the one specified in the constructor.
     This value has to be set before calling compute().
@@ -169,6 +160,20 @@ public:
   */
   void setDesiredArea(double a_star) { desiredSurface = a_star; }
 
+
+#if defined(VISP_BUILD_DEPRECATED_FUNCTIONS)
+  /*!
+    @name Deprecated functions
+  */
+  //@{
+  /*!
+    \deprecated Use rather getDesiredArea()
+    Retrieves the desired surface \e a* as specified in the constructor.
+  */
+  vp_deprecated double getDesiredSurface() const { return desiredSurface; }
+  //@}
+#endif
+
   /*!
     Moment name.
   */
