@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -29,16 +28,12 @@
  * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  *
  * Description:
- * Descriptor for various invariants used to drive space roations around X and
- *Y axis.
- *
- * Authors:
- * Filip Novotny
- *
- *****************************************************************************/
+ * Descriptor for various invariants used to drive space rotations around X and
+ * Y axis.
+ */
 /*!
   \file vpMomentCInvariant.h
-  \brief Descriptor for various invariants used to drive space roations around
+  \brief Descriptor for various invariants used to drive space rotations around
   X and Y axis.
 */
 #ifndef _vpMomentCInvariant_h_
@@ -78,11 +73,11 @@ get shortcuts.
 
   The example below shows how to retrieve the \f$C_2\f$ invariant:
   \code
-#include <visp3/core/vpMomentObject.h>
-#include <visp3/core/vpPoint.h>
+#include <iostream>
 #include <visp3/core/vpMomentCInvariant.h>
 #include <visp3/core/vpMomentCommon.h>
-#include <iostream>
+#include <visp3/core/vpMomentObject.h>
+#include <visp3/core/vpPoint.h>
 
 int main()
 {
@@ -145,7 +140,7 @@ private:
 
 public:
   explicit vpMomentCInvariant(bool flg_sxsynormalization = false);
-  virtual ~vpMomentCInvariant(){};
+  virtual ~vpMomentCInvariant() { };
 
   /*!
     Shorcut for getting the value of \f$C_1\f$.
