@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * TCP Network
- *
- * Authors:
- * Aurelien Yol
- *
- *****************************************************************************/
+ */
 
 #ifndef vpNetwork_H
 #define vpNetwork_H
@@ -50,24 +45,24 @@
 #include <sys/select.h>
 #endif
 
-// inet_ntop() not supported on win XP
+ // inet_ntop() not supported on win XP
 #ifdef VISP_HAVE_FUNC_INET_NTOP
 
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-#  include <arpa/inet.h>
-#  include <netdb.h>
-#  include <netinet/in.h>
-#  include <sys/socket.h>
-#  include <unistd.h>
+#include <arpa/inet.h>
+#include <netdb.h>
+#include <netinet/in.h>
+#include <sys/socket.h>
+#include <unistd.h>
 #else
-#  include <io.h>
+#include <io.h>
 //#  include<winsock.h>
-#  include <winsock2.h>
+#include <winsock2.h>
 //#  pragma comment(lib, "ws2_32.lib") // Done by CMake in main CMakeLists.txt
 #endif
 
 #if defined(__APPLE__) && defined(__MACH__) // Apple OSX and iOS (Darwin)
-#  include <TargetConditionals.h>             // To detect OSX or IOS using TARGET_OS_IPHONE or TARGET_OS_IOS macro
+#include <TargetConditionals.h>             // To detect OSX or IOS using TARGET_OS_IPHONE or TARGET_OS_IOS macro
 #endif
 
 /*!
@@ -81,7 +76,7 @@
   on one computer to another program on another computer.
 
   \warning This class shouldn't be used directly. You better use vpClient and
-  vpServer to simulate your network. Some exemples are provided in these
+  vpServer to simulate your network. Some examples are provided in these
   classes.
 
   \sa vpServer
@@ -91,7 +86,8 @@ class VISP_EXPORT vpNetwork
 {
 protected:
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-  struct vpReceptor {
+  struct vpReceptor
+  {
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
     int socketFileDescriptorReceptor;
     socklen_t receptorAddressSize;
@@ -102,10 +98,11 @@ protected:
     struct sockaddr_in receptorAddress;
     std::string receptorIP;
 
-    vpReceptor() : socketFileDescriptorReceptor(0), receptorAddressSize(), receptorAddress(), receptorIP() {}
+    vpReceptor() : socketFileDescriptorReceptor(0), receptorAddressSize(), receptorAddress(), receptorIP() { }
   };
 
-  struct vpEmitter {
+  struct vpEmitter
+  {
     struct sockaddr_in emitterAddress;
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
     int socketFileDescriptorEmitter;
@@ -153,13 +150,13 @@ protected:
   bool verboseMode;
 
 private:
-  std::vector<int> _handleRequests();
-  int _handleFirstRequest();
+  std::vector<int> privHandleRequests();
+  int privHandleFirstRequest();
 
-  void _receiveRequest();
-  void _receiveRequestFrom(const unsigned int &receptorEmitting);
-  int _receiveRequestOnce();
-  int _receiveRequestOnceFrom(const unsigned int &receptorEmitting);
+  void privReceiveRequest();
+  void privReceiveRequestFrom(const unsigned int &receptorEmitting);
+  int privReceiveRequestOnce();
+  int privReceiveRequestOnceFrom(const unsigned int &receptorEmitting);
 
 public:
   vpNetwork();
@@ -289,7 +286,7 @@ template <typename T> int vpNetwork::receive(T *object, const unsigned int &size
   }
 
   tv.tv_sec = tv_sec;
-#if TARGET_OS_IPHONE
+#ifdef TARGET_OS_IPHONE
   tv.tv_usec = (int)tv_usec;
 #else
   tv.tv_usec = tv_usec;
@@ -314,17 +311,19 @@ template <typename T> int vpNetwork::receive(T *object, const unsigned int &size
     if (verboseMode)
       vpERROR_TRACE("Select error");
     return -1;
-  } else if (value == 0) {
+  }
+  else if (value == 0) {
     // Timeout
     return 0;
-  } else {
+  }
+  else {
     for (unsigned int i = 0; i < receptor_list.size(); i++) {
       if (FD_ISSET((unsigned int)receptor_list[i].socketFileDescriptorReceptor, &readFileDescriptor)) {
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
         numbytes = recv(receptor_list[i].socketFileDescriptorReceptor, (char *)(void *)object, sizeOfObject, 0);
 #else
         numbytes = recv((unsigned int)receptor_list[i].socketFileDescriptorReceptor, (char *)(void *)object,
-                        (int)sizeOfObject, 0);
+          (int)sizeOfObject, 0);
 #endif
         if (numbytes <= 0) {
           std::cout << "Disconnected : " << inet_ntoa(receptor_list[i].receptorAddress.sin_addr) << std::endl;
@@ -371,7 +370,7 @@ int vpNetwork::receiveFrom(T *object, const unsigned int &receptorEmitting, cons
   }
 
   tv.tv_sec = tv_sec;
-#if TARGET_OS_IPHONE
+#ifdef TARGET_OS_IPHONE
   tv.tv_usec = (int)tv_usec;
 #else
   tv.tv_usec = tv_usec;
@@ -389,21 +388,23 @@ int vpNetwork::receiveFrom(T *object, const unsigned int &receptorEmitting, cons
     if (verboseMode)
       vpERROR_TRACE("Select error");
     return -1;
-  } else if (value == 0) {
+  }
+  else if (value == 0) {
     // timeout
     return 0;
-  } else {
+  }
+  else {
     if (FD_ISSET((unsigned int)receptor_list[receptorEmitting].socketFileDescriptorReceptor, &readFileDescriptor)) {
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
       numbytes =
-          recv(receptor_list[receptorEmitting].socketFileDescriptorReceptor, (char *)(void *)object, sizeOfObject, 0);
+        recv(receptor_list[receptorEmitting].socketFileDescriptorReceptor, (char *)(void *)object, sizeOfObject, 0);
 #else
       numbytes = recv((unsigned int)receptor_list[receptorEmitting].socketFileDescriptorReceptor,
-                      (char *)(void *)object, (int)sizeOfObject, 0);
+        (char *)(void *)object, (int)sizeOfObject, 0);
 #endif
       if (numbytes <= 0) {
         std::cout << "Disconnected : " << inet_ntoa(receptor_list[receptorEmitting].receptorAddress.sin_addr)
-                  << std::endl;
+          << std::endl;
         receptor_list.erase(receptor_list.begin() + (int)receptorEmitting);
         return numbytes;
       }
@@ -443,17 +444,17 @@ template <typename T> int vpNetwork::send(T *object, const unsigned int &sizeOfO
   }
 
   int flags = 0;
-//#if ! defined(APPLE) && ! defined(SOLARIS) && ! defined(_WIN32)
+  //#if ! defined(APPLE) && ! defined(SOLARIS) && ! defined(_WIN32)
 #if defined(__linux__)
   flags = MSG_NOSIGNAL; // Only for Linux
 #endif
 
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
   return sendto(receptor_list[0].socketFileDescriptorReceptor, (const char *)(void *)object, sizeOfObject, flags,
-                (sockaddr *)&receptor_list[0].receptorAddress, receptor_list[0].receptorAddressSize);
+    (sockaddr *)&receptor_list[0].receptorAddress, receptor_list[0].receptorAddressSize);
 #else
   return sendto(receptor_list[0].socketFileDescriptorReceptor, (const char *)(void *)object, (int)sizeOfObject, flags,
-                (sockaddr *)&receptor_list[0].receptorAddress, receptor_list[0].receptorAddressSize);
+    (sockaddr *)&receptor_list[0].receptorAddress, receptor_list[0].receptorAddressSize);
 #endif
 }
 
@@ -487,17 +488,17 @@ template <typename T> int vpNetwork::sendTo(T *object, const unsigned int &dest,
   }
 
   int flags = 0;
-//#if ! defined(APPLE) && ! defined(SOLARIS) && ! defined(_WIN32)
+  //#if ! defined(APPLE) && ! defined(SOLARIS) && ! defined(_WIN32)
 #if defined(__linux__)
   flags = MSG_NOSIGNAL; // Only for Linux
 #endif
 
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
   return sendto(receptor_list[dest].socketFileDescriptorReceptor, (const char *)(void *)object, sizeOfObject, flags,
-                (sockaddr *)&receptor_list[dest].receptorAddress, receptor_list[dest].receptorAddressSize);
+    (sockaddr *)&receptor_list[dest].receptorAddress, receptor_list[dest].receptorAddressSize);
 #else
   return sendto(receptor_list[dest].socketFileDescriptorReceptor, (const char *)(void *)object, (int)sizeOfObject,
-                flags, (sockaddr *)&receptor_list[dest].receptorAddress, receptor_list[dest].receptorAddressSize);
+    flags, (sockaddr *)&receptor_list[dest].receptorAddress, receptor_list[dest].receptorAddressSize);
 #endif
 }
 
