@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * Quaternion definition.
- *
- * Authors:
- * Filip Novotny
- *
- *****************************************************************************/
+ */
 
 #ifndef _vpQuaternionVector_h_
 #define _vpQuaternionVector_h_
@@ -123,7 +118,7 @@ public:
   explicit vpQuaternionVector(const std::vector<double> &q);
 
   //! Destructor.
-  virtual ~vpQuaternionVector(){};
+  virtual ~vpQuaternionVector(){}
 
   vpQuaternionVector buildFrom(const double qx, const double qy, const double qz, const double qw);
   vpQuaternionVector buildFrom(const vpRotationMatrix &R);
@@ -132,17 +127,22 @@ public:
   vpQuaternionVector buildFrom(const std::vector<double> &q);
   void set(double x, double y, double z, double w);
 
-  double x() const;
-  double y() const;
-  double z() const;
-  double w() const;
+  const double& x() const;
+  const double& y() const;
+  const double& z() const;
+  const double& w() const;
+
+  double& x();
+  double& y();
+  double& z();
+  double& w();
 
   vpQuaternionVector operator+(const vpQuaternionVector &q) const;
   vpQuaternionVector operator-(const vpQuaternionVector &q) const;
   vpQuaternionVector operator-() const;
   vpQuaternionVector operator*(double l) const;
   vpQuaternionVector operator*(const vpQuaternionVector &rq) const;
-  vpQuaternionVector operator/( double l) const;
+  vpQuaternionVector operator/(double l) const;
   vpQuaternionVector &operator=(const vpColVector &q);
 #if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
   vpQuaternionVector &operator=(const vpQuaternionVector &q) = default;
@@ -153,6 +153,12 @@ public:
   vpQuaternionVector inverse() const;
   double magnitude() const;
   void normalize();
+
+  static double dot(const vpQuaternionVector& q0, const vpQuaternionVector& q1);
+
+  static vpQuaternionVector lerp(const vpQuaternionVector& q0, const vpQuaternionVector& q1, double t);
+  static vpQuaternionVector nlerp(const vpQuaternionVector& q0, const vpQuaternionVector& q1, double t);
+  static vpQuaternionVector slerp(const vpQuaternionVector& q0, const vpQuaternionVector& q1, double t);
 };
 
 #endif
