@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,12 +29,7 @@
  *
  * Description:
  * RGBA pixel.
- *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+ */
 
 #ifndef vpRGBa_h
 #define vpRGBa_h
@@ -43,7 +37,7 @@
 /*!
   \file vpRGBa.h
   \brief Define the object vpRGBa that is used to build color
-  images (it define a RGB 32 bits structure, fourth byte is not used)
+  images (it defines a RGB 32 bits structure, fourth byte is not used)
 */
 
 #include <visp3/core/vpColVector.h>
@@ -72,7 +66,6 @@ public:
     Basic constructor.
 
     Build a black value.
-
   */
   inline vpRGBa() : R(0), G(0), B(0), A(vpRGBa::alpha_default) {}
 
@@ -85,7 +78,6 @@ public:
     \param g : Green value.
     \param b : Blue value.
     \param a : Additional value.
-
   */
   inline vpRGBa(unsigned char r, unsigned char g, unsigned char b, unsigned char a = vpRGBa::alpha_default)
     : R(r), G(g), B(b), A(a)
@@ -98,7 +90,6 @@ public:
     Initialize all the R, G, B, A components to \e v.
 
     \param v : Value to set.
-
   */
   inline vpRGBa(unsigned char v) : R(v), G(v), B(v), A(v) {}
 
@@ -114,13 +105,12 @@ public:
     G=v[1]
     B=v[2]
     A=v[3]
-
   */
   inline vpRGBa(const vpColVector &v) : R(0), G(0), B(0), A(vpRGBa::alpha_default) { *this = v; }
 
   // We cannot add here the following destructor without changing the
   // hypothesis that the size of this class is 4. With the destructor it
-  // becomes 16 that does break a lot of things arround image conversions
+  // becomes 16 that does break a lot of things around image conversions
   // virtual ~vpRGBa() {}; // Not to implement
 
   vpRGBa &operator=(const unsigned char &v);
@@ -129,8 +119,8 @@ public:
   vpRGBa &operator=(const vpRGBa &&v);
 #endif
   vpRGBa &operator=(const vpColVector &v);
-  bool operator==(const vpRGBa &v);
-  bool operator!=(const vpRGBa &v);
+  bool operator==(const vpRGBa &v) const;
+  bool operator!=(const vpRGBa &v) const;
 
   vpColVector operator-(const vpRGBa &v) const;
   vpRGBa operator+(const vpRGBa &v) const;
