@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,12 +29,7 @@
  *
  * Description:
  * Translation vector.
- *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+ */
 
 #ifndef vpTRANSLATIONVECTOR_H
 #define vpTRANSLATIONVECTOR_H
@@ -123,7 +117,7 @@ public:
       Default constructor.
       The translation vector is initialized to zero.
     */
-  vpTranslationVector() : vpArray2D<double>(3, 1), m_index(0) {};
+  vpTranslationVector() : vpArray2D<double>(3, 1), m_index(0) { };
   vpTranslationVector(double tx, double ty, double tz);
   vpTranslationVector(const vpTranslationVector &tv);
   explicit vpTranslationVector(const vpHomogeneousMatrix &M);
@@ -135,7 +129,6 @@ public:
   vpTranslationVector buildFrom(const vpPoseVector &p);
   vpTranslationVector buildFrom(const vpColVector &v);
 
-  vp_deprecated double euclideanNorm() const;
   double frobeniusNorm() const;
 
   // operators
@@ -169,7 +162,6 @@ public:
   vpTranslationVector &operator<<(double val);
   vpTranslationVector &operator,(double val);
 
-
   /*!
     This function is not applicable to a translation vector that is always a
     3-by-1 column vector.
@@ -198,6 +190,15 @@ public:
   static vpMatrix skew(const vpTranslationVector &tv);
   static void skew(const vpTranslationVector &tv, vpMatrix &M);
 
+#if defined(VISP_BUILD_DEPRECATED_FUNCTIONS)
+  /*!
+      @name Deprecated functions
+  */
+  //@{
+  vp_deprecated double euclideanNorm() const;
+  //}
+#endif
+
 protected:
   unsigned int m_index; // index used for operator<< and operator, to fill a vector
 };
