@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,8 +29,7 @@
  *
  * Description:
  * UDP Server
- *
- *****************************************************************************/
+ */
 
 #ifndef _vpUDPServer_h_
 #define _vpUDPServer_h_
@@ -42,11 +40,11 @@
 #ifdef VISP_HAVE_FUNC_INET_NTOP
 
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-#  include <netinet/in.h>
-#  include <sys/socket.h>
-#  include <sys/types.h>
+#include <netinet/in.h>
+#include <sys/socket.h>
+#include <sys/types.h>
 #else
-#  include <winsock2.h>
+#include <winsock2.h>
 #endif
 
 #include <visp3/core/vpException.h>
@@ -144,12 +142,12 @@ receive):
 #include <vector>
 #include <visp3/core/vpUDPServer.h>
 
-struct DataType {
+struct vpDataType_t {
   double double_val;
   int int_val;
 
-  DataType() : double_val(0.0), int_val(0) {}
-  DataType(double dbl, int i) : double_val(dbl), int_val(i) {}
+  vpDataType_t() : double_val(0.0), int_val(0) {}
+  vpDataType_t(double dbl, int i) : double_val(dbl), int_val(i) {}
 };
 
 int main() {
@@ -160,7 +158,7 @@ int main() {
     std::string msg = "", hostInfo = "";
     int res = server.receive(msg, hostInfo);
     if (res) {
-      DataType data_type;
+      vpDataType_t data_type;
       memcpy(&data_type.double_val, msg.c_str(),
 sizeof(data_type.double_val)); memcpy(&data_type.int_val,
 msg.c_str()+sizeof(data_type.double_val), sizeof(data_type.int_val));
