@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,15 +29,10 @@
  *
  * Description:
  * Velocity twist transformation matrix.
- *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+ */
 
-#ifndef vpVelocityRwistMatrix_h
-#define vpVelocityRwistMatrix_h
+#ifndef vpVelocityTwistMatrix_h
+#define vpVelocityTwistMatrix_h
 
 #include <visp3/core/vpArray2D.h>
 #include <visp3/core/vpColVector.h>
