@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -32,10 +32,9 @@
  * Camera intrinsic parameters.
  *
  * Authors:
- * Eric Marchand
  * Anthony Saunier
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpCameraParameters.cpp
@@ -71,9 +70,9 @@ const vpCameraParameters::vpCameraParametersProjType vpCameraParameters::DEFAULT
 */
 vpCameraParameters::vpCameraParameters()
   : px(DEFAULT_PX_PARAMETER), py(DEFAULT_PY_PARAMETER), u0(DEFAULT_U0_PARAMETER), v0(DEFAULT_V0_PARAMETER),
-    kud(DEFAULT_KUD_PARAMETER), kdu(DEFAULT_KDU_PARAMETER), m_dist_coefs(), width(0), height(0),
-    isFov(false), m_hFovAngle(0), m_vFovAngle(0), fovNormals(), inv_px(1. / DEFAULT_PX_PARAMETER),
-    inv_py(1. / DEFAULT_PY_PARAMETER), projModel(DEFAULT_PROJ_TYPE)
+    kud(DEFAULT_KUD_PARAMETER), kdu(DEFAULT_KDU_PARAMETER), m_dist_coefs(), width(0), height(0), isFov(false),
+    m_hFovAngle(0), m_vFovAngle(0), fovNormals(), inv_px(1. / DEFAULT_PX_PARAMETER), inv_py(1. / DEFAULT_PY_PARAMETER),
+    projModel(DEFAULT_PROJ_TYPE)
 {
   init();
 }
@@ -83,9 +82,9 @@ vpCameraParameters::vpCameraParameters()
  */
 vpCameraParameters::vpCameraParameters(const vpCameraParameters &c)
   : px(DEFAULT_PX_PARAMETER), py(DEFAULT_PY_PARAMETER), u0(DEFAULT_U0_PARAMETER), v0(DEFAULT_V0_PARAMETER),
-    kud(DEFAULT_KUD_PARAMETER), kdu(DEFAULT_KDU_PARAMETER), m_dist_coefs(), width(0), height(0),
-    isFov(false), m_hFovAngle(0), m_vFovAngle(0), fovNormals(), inv_px(1. / DEFAULT_PX_PARAMETER),
-    inv_py(1. / DEFAULT_PY_PARAMETER), projModel(DEFAULT_PROJ_TYPE)
+    kud(DEFAULT_KUD_PARAMETER), kdu(DEFAULT_KDU_PARAMETER), m_dist_coefs(), width(0), height(0), isFov(false),
+    m_hFovAngle(0), m_vFovAngle(0), fovNormals(), inv_px(1. / DEFAULT_PX_PARAMETER), inv_py(1. / DEFAULT_PY_PARAMETER),
+    projModel(DEFAULT_PROJ_TYPE)
 {
   init(c);
 }
@@ -99,9 +98,9 @@ vpCameraParameters::vpCameraParameters(const vpCameraParameters &c)
  */
 vpCameraParameters::vpCameraParameters(double cam_px, double cam_py, double cam_u0, double cam_v0)
   : px(DEFAULT_PX_PARAMETER), py(DEFAULT_PY_PARAMETER), u0(DEFAULT_U0_PARAMETER), v0(DEFAULT_V0_PARAMETER),
-    kud(DEFAULT_KUD_PARAMETER), kdu(DEFAULT_KDU_PARAMETER), m_dist_coefs(), width(0), height(0),
-    isFov(false), m_hFovAngle(0), m_vFovAngle(0), fovNormals(), inv_px(1. / DEFAULT_PX_PARAMETER),
-    inv_py(1. / DEFAULT_PY_PARAMETER), projModel(DEFAULT_PROJ_TYPE)
+    kud(DEFAULT_KUD_PARAMETER), kdu(DEFAULT_KDU_PARAMETER), m_dist_coefs(), width(0), height(0), isFov(false),
+    m_hFovAngle(0), m_vFovAngle(0), fovNormals(), inv_px(1. / DEFAULT_PX_PARAMETER), inv_py(1. / DEFAULT_PY_PARAMETER),
+    projModel(DEFAULT_PROJ_TYPE)
 {
   initPersProjWithoutDistortion(cam_px, cam_py, cam_u0, cam_v0);
 }
@@ -115,12 +114,12 @@ vpCameraParameters::vpCameraParameters(double cam_px, double cam_py, double cam_
   \param cam_kdu : distorted to undistorted radial distortion
 
  */
-vpCameraParameters::vpCameraParameters(double cam_px, double cam_py, double cam_u0,
-                                       double cam_v0, double cam_kud, double cam_kdu)
+vpCameraParameters::vpCameraParameters(double cam_px, double cam_py, double cam_u0, double cam_v0, double cam_kud,
+                                       double cam_kdu)
   : px(DEFAULT_PX_PARAMETER), py(DEFAULT_PY_PARAMETER), u0(DEFAULT_U0_PARAMETER), v0(DEFAULT_V0_PARAMETER),
-    kud(DEFAULT_KUD_PARAMETER), kdu(DEFAULT_KDU_PARAMETER), m_dist_coefs(), width(0), height(0),
-    isFov(false), m_hFovAngle(0), m_vFovAngle(0), fovNormals(), inv_px(1. / DEFAULT_PX_PARAMETER),
-    inv_py(1. / DEFAULT_PY_PARAMETER), projModel(DEFAULT_PROJ_TYPE)
+    kud(DEFAULT_KUD_PARAMETER), kdu(DEFAULT_KDU_PARAMETER), m_dist_coefs(), width(0), height(0), isFov(false),
+    m_hFovAngle(0), m_vFovAngle(0), fovNormals(), inv_px(1. / DEFAULT_PX_PARAMETER), inv_py(1. / DEFAULT_PY_PARAMETER),
+    projModel(DEFAULT_PROJ_TYPE)
 {
   initPersProjWithDistortion(cam_px, cam_py, cam_u0, cam_v0, cam_kud, cam_kdu);
 }
@@ -130,15 +129,15 @@ vpCameraParameters::vpCameraParameters(double cam_px, double cam_py, double cam_
 
   \param cam_px,cam_py : pixel size
   \param cam_u0,cam_v0 : principal points
-  \param coefficients  : distorsion model coefficients
+  \param coefficients  : distortion model coefficients
 
  */
-vpCameraParameters::vpCameraParameters(double cam_px, double cam_py, double cam_u0,
-                                       double cam_v0, const std::vector<double> &coefficients)
+vpCameraParameters::vpCameraParameters(double cam_px, double cam_py, double cam_u0, double cam_v0,
+                                       const std::vector<double> &coefficients)
   : px(DEFAULT_PX_PARAMETER), py(DEFAULT_PY_PARAMETER), u0(DEFAULT_U0_PARAMETER), v0(DEFAULT_V0_PARAMETER),
-    kud(DEFAULT_KUD_PARAMETER), kdu(DEFAULT_KDU_PARAMETER), m_dist_coefs(), width(0), height(0),
-    isFov(false), m_hFovAngle(0), m_vFovAngle(0), fovNormals(), inv_px(1. / DEFAULT_PX_PARAMETER),
-    inv_py(1. / DEFAULT_PY_PARAMETER), projModel(DEFAULT_PROJ_TYPE)
+    kud(DEFAULT_KUD_PARAMETER), kdu(DEFAULT_KDU_PARAMETER), m_dist_coefs(), width(0), height(0), isFov(false),
+    m_hFovAngle(0), m_vFovAngle(0), fovNormals(), inv_px(1. / DEFAULT_PX_PARAMETER), inv_py(1. / DEFAULT_PY_PARAMETER),
+    projModel(DEFAULT_PROJ_TYPE)
 {
   initProjWithKannalaBrandtDistortion(cam_px, cam_py, cam_u0, cam_v0, coefficients);
 }
@@ -188,15 +187,14 @@ int main()
    It produces the following output:
    \code
 Camera parameters for perspective projection without distortion:
-  px = 600	 py = 600
-  u0 = 320	 v0 = 240
+  px = 600   py = 600
+  u0 = 320   v0 = 240
 
 Field of view (horizontal: 56.145 and vertical: 43.6028 degrees)
    \endcode
 
  */
-void vpCameraParameters::initPersProjWithoutDistortion(double cam_px, double cam_py, double cam_u0,
-                                                       double cam_v0)
+void vpCameraParameters::initPersProjWithoutDistortion(double cam_px, double cam_py, double cam_u0, double cam_v0)
 {
   this->projModel = vpCameraParameters::perspectiveProjWithoutDistortion;
 
@@ -207,11 +205,13 @@ void vpCameraParameters::initPersProjWithoutDistortion(double cam_px, double cam
   this->kud = 0;
   this->kdu = 0;
 
+  this->m_dist_coefs.clear();
+
   if (fabs(px) < 1e-6) {
     throw(vpException(vpException::divideByZeroError, "Camera parameter px = 0"));
   }
   if (fabs(py) < 1e-6) {
-    throw(vpException(vpException::divideByZeroError, "Camera parameter px = 0"));
+    throw(vpException(vpException::divideByZeroError, "Camera parameter py = 0"));
   }
   this->inv_px = 1. / px;
   this->inv_py = 1. / py;
@@ -251,16 +251,16 @@ int main()
    It produces the following output:
    \code
 Camera parameters for perspective projection with distortion:
-  px = 600	 py = 600
-  u0 = 320	 v0 = 240
+  px = 600   py = 600
+  u0 = 320   v0 = 240
   kud = -0.19
   kdu = 0.2
 
 Field of view (horizontal: 56.14497387 and vertical: 43.60281897 degrees)
 \endcode
 */
-void vpCameraParameters::initPersProjWithDistortion(double cam_px, double cam_py, double cam_u0,
-                                                    double cam_v0, double cam_kud, double cam_kdu)
+void vpCameraParameters::initPersProjWithDistortion(double cam_px, double cam_py, double cam_u0, double cam_v0,
+                                                    double cam_kud, double cam_kdu)
 {
   this->projModel = vpCameraParameters::perspectiveProjWithDistortion;
 
@@ -270,6 +270,7 @@ void vpCameraParameters::initPersProjWithDistortion(double cam_px, double cam_py
   this->v0 = cam_v0;
   this->kud = cam_kud;
   this->kdu = cam_kdu;
+  this->m_dist_coefs.clear();
 
   if (fabs(px) < 1e-6) {
     throw(vpException(vpException::divideByZeroError, "Camera parameter px = 0"));
@@ -285,7 +286,7 @@ void vpCameraParameters::initPersProjWithDistortion(double cam_px, double cam_py
   Initialization with specific parameters using Kannala-Brandt distortion model
   \param cam_px,cam_py : The ratio between the focal length and the size of a pixel.
   \param cam_u0,cam_v0 : Principal points coordinates in pixels.
-  \param coefficients  : Distorsion coefficients.
+  \param coefficients  : Distortion coefficients.
 */
 void vpCameraParameters::initProjWithKannalaBrandtDistortion(double cam_px, double cam_py, double cam_u0, double cam_v0,
                                                              const std::vector<double> &coefficients)
@@ -297,6 +298,9 @@ void vpCameraParameters::initProjWithKannalaBrandtDistortion(double cam_px, doub
   this->u0 = cam_u0;
   this->v0 = cam_v0;
 
+  this->kud = 0.0;
+  this->kdu = 0.0;
+
   if (fabs(px) < 1e-6) {
     throw(vpException(vpException::divideByZeroError, "Camera parameter px = 0"));
   }
@@ -347,7 +351,7 @@ void vpCameraParameters::initFromCalibrationMatrix(const vpMatrix &_K)
 }
 
 /*!
-   Initialize the camera model without distorsion from the image dimension and
+   Initialize the camera model without distortion from the image dimension and
 the camera field of view. \param w : Image width. \param h : Image height.
    \param hfov : Camera horizontal field of view angle expressed in radians.
    \param vfov : Camera vertical field of view angle expressed in radians.
@@ -373,8 +377,8 @@ int main()
    It produces the following output:
    \code
 Camera parameters for perspective projection without distortion:
-  px = 601.832	 py = 609.275
-  u0 = 320	 v0 = 240
+  px = 601.832   py = 609.275
+  u0 = 320   v0 = 240
 
 Field of view (horizontal: 56 and vertical: 43 degrees)
    \endcode
@@ -424,7 +428,8 @@ vpCameraParameters &vpCameraParameters::operator=(const vpCameraParameters &cam)
 /*!
   True if the two objects are absolutely identical.
  */
-bool vpCameraParameters::operator==(const vpCameraParameters &c) const {
+bool vpCameraParameters::operator==(const vpCameraParameters &c) const
+{
   if (projModel != c.projModel)
     return false;
 
@@ -438,14 +443,16 @@ bool vpCameraParameters::operator==(const vpCameraParameters &c) const {
       !vpMath::equal(inv_py, c.inv_py, std::numeric_limits<double>::epsilon()))
     return false;
 
-  for(unsigned int i = 0; i < m_dist_coefs.size(); i++)
-    if(!vpMath::equal(m_dist_coefs[i], c.m_dist_coefs[i], std::numeric_limits<double>::epsilon()))
+  if(m_dist_coefs.size() != c.m_dist_coefs.size())
+    return false;
+
+  for (unsigned int i = 0; i < m_dist_coefs.size(); i++)
+    if (!vpMath::equal(m_dist_coefs[i], c.m_dist_coefs[i], std::numeric_limits<double>::epsilon()))
       return false;
 
-  if (isFov != c.isFov ||
-      !vpMath::equal(m_hFovAngle, c.m_hFovAngle, std::numeric_limits<double>::epsilon()) ||
-      !vpMath::equal(m_vFovAngle, c.m_vFovAngle, std::numeric_limits<double>::epsilon()) ||
-      width != c.width || height != c.height)
+  if (isFov != c.isFov || !vpMath::equal(m_hFovAngle, c.m_hFovAngle, std::numeric_limits<double>::epsilon()) ||
+      !vpMath::equal(m_vFovAngle, c.m_vFovAngle, std::numeric_limits<double>::epsilon()) || width != c.width ||
+      height != c.height)
     return false;
 
   if (fovNormals.size() != c.fovNormals.size())
@@ -464,9 +471,7 @@ bool vpCameraParameters::operator==(const vpCameraParameters &c) const {
 /*!
   False if the two objects are absolutely identical.
  */
-bool vpCameraParameters::operator!=(const vpCameraParameters &c) const {
-  return !(*this == c);
-}
+bool vpCameraParameters::operator!=(const vpCameraParameters &c) const { return !(*this == c); }
 
 /*!
   Compute angles and normals of the FOV.
@@ -616,30 +621,26 @@ VISP_EXPORT std::ostream &operator<<(std::ostream &os, const vpCameraParameters
     os << "  px = " << cam.get_px() << "\t py = " << cam.get_py() << std::endl;
     os << "  u0 = " << cam.get_u0() << "\t v0 = " << cam.get_v0() << std::endl;
     break;
-  case vpCameraParameters::perspectiveProjWithDistortion:
-    {
-      std::ios_base::fmtflags original_flags = os.flags();
-      os.precision(10);
-      os << "Camera parameters for perspective projection with distortion:" << std::endl;
-      os << "  px = " << cam.get_px() << "\t py = " << cam.get_py() << std::endl;
-      os << "  u0 = " << cam.get_u0() << "\t v0 = " << cam.get_v0() << std::endl;
-      os << "  kud = " << cam.get_kud() << std::endl;
-      os << "  kdu = " << cam.get_kdu() << std::endl;
-      os.flags(original_flags); // restore os to standard state
-    }
-    break;
-  case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-    {
-      os << "Camera parameters for projection with Kannala-Brandt distortion:" << std::endl;
-      os << "  px = " << cam.get_px() << "\t py = " << cam.get_py() << std::endl;
-      os << "  u0 = " << cam.get_u0() << "\t v0 = " << cam.get_v0() << std::endl;
-      os << "  Coefficients: ";
-      std::vector<double> tmp_coefs = cam.getKannalaBrandtDistortionCoefficients();
-      for(unsigned int i = 0; i < tmp_coefs.size(); i++)
-        os << " " << tmp_coefs[i];
-      os << std::endl;
-    }
-    break;
+  case vpCameraParameters::perspectiveProjWithDistortion: {
+    std::ios_base::fmtflags original_flags = os.flags();
+    os.precision(10);
+    os << "Camera parameters for perspective projection with distortion:" << std::endl;
+    os << "  px = " << cam.get_px() << "\t py = " << cam.get_py() << std::endl;
+    os << "  u0 = " << cam.get_u0() << "\t v0 = " << cam.get_v0() << std::endl;
+    os << "  kud = " << cam.get_kud() << std::endl;
+    os << "  kdu = " << cam.get_kdu() << std::endl;
+    os.flags(original_flags); // restore os to standard state
+  } break;
+  case vpCameraParameters::ProjWithKannalaBrandtDistortion: {
+    os << "Camera parameters for projection with Kannala-Brandt distortion:" << std::endl;
+    os << "  px = " << cam.get_px() << "\t py = " << cam.get_py() << std::endl;
+    os << "  u0 = " << cam.get_u0() << "\t v0 = " << cam.get_v0() << std::endl;
+    os << "  Coefficients: ";
+    std::vector<double> tmp_coefs = cam.getKannalaBrandtDistortionCoefficients();
+    for (unsigned int i = 0; i < tmp_coefs.size(); i++)
+      os << " " << tmp_coefs[i];
+    os << std::endl;
+  } break;
   }
   return os;
 }
