@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,7 +31,7 @@
  * Description:
  * XML parser to load and save camera intrinsic parameters.
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpXmlParserCamera.cpp
@@ -46,10 +46,10 @@
 #include <visp3/core/vpDebug.h>
 /* --------------------------------------------------------------------------
  */
-/* --- LABEL XML ------------------------------------------------------------
- */
-/* --------------------------------------------------------------------------
- */
+ /* --- LABEL XML ------------------------------------------------------------
+  */
+  /* --------------------------------------------------------------------------
+   */
 
 #define LABEL_XML_ROOT "root"
 #define LABEL_XML_CAMERA "camera"
@@ -86,7 +86,8 @@ class vpXmlParserCamera::Impl
 private:
   /* --- XML Code------------------------------------------------------------
    */
-  enum vpXmlCodeType {
+  enum vpXmlCodeType
+  {
     CODE_XML_BAD = -1,
     CODE_XML_OTHER,
     CODE_XML_CAMERA,
@@ -114,14 +115,14 @@ private:
   };
 
 public:
-  Impl() : camera(), camera_name(), image_width(0), image_height(0), subsampling_width(0),
-           subsampling_height(0), full_width(0), full_height(0)
-  {
-  }
+  Impl()
+    : camera(), camera_name(), image_width(0), image_height(0), subsampling_width(0), subsampling_height(0),
+    full_width(0), full_height(0)
+  { }
 
   int parse(vpCameraParameters &cam, const std::string &filename, const std::string &cam_name,
-            const vpCameraParameters::vpCameraParametersProjType &projModel,
-            unsigned int im_width, unsigned int im_height)
+            const vpCameraParameters::vpCameraParametersProjType &projModel, unsigned int im_width,
+            unsigned int im_height, bool verbose)
   {
     pugi::xml_document doc;
     if (!doc.load_file(filename.c_str())) {
@@ -133,7 +134,7 @@ public:
       return SEQUENCE_ERROR;
     }
 
-    int ret = read(node, cam_name, projModel, im_width, im_height);
+    int ret = read(node, cam_name, projModel, im_width, im_height, verbose);
 
     cam = camera;
 
@@ -142,27 +143,26 @@ public:
 
   /*!
     Read camera parameters from a XML file.
-    \param node_ : XML tree, pointing on a marker equipement.
-    \param cam_name : name of the camera : useful if the xml file has multiple
-    camera parameters. Set as "" if the camera name is not ambiguous.
+    \param node_ : XML tree, pointing on a marker equipment.
+    \param cam_name : Name of the camera. Useful if the xml file has multiple
+    camera parameters. Set to an empty string "" if the camera name is not ambiguous.
     \param projModel : Projection model type.
     \param im_width : width of image  on which camera calibration was performed.
-      Set as 0 if not ambiguous.
+    Set to 0 if not ambiguous.
     \param im_height : height of the image  on which camera calibration
-      was performed. Set as 0 if not ambiguous.
+    was performed. Set as 0 if not ambiguous.
     \param subsampl_width : subsampling of the image width sent by the camera.
-      Set as 0 if not ambiguous.
+    Set to 0 if not ambiguous.
     \param subsampl_height : subsampling of the image height sent by the camera.
-      Set as 0 if not ambiguous.
+    Set to 0 if not ambiguous.
+    \param verbose true to enable verbose mode, false otherwise.
     \return vpXmlParserCamera::SEQUENCE_OK if success and vpXmlParserCamera::SEQUENCE_ERROR otherwise.
    */
   int read(const pugi::xml_node &node_, const std::string &cam_name,
-           const vpCameraParameters::vpCameraParametersProjType &projModel,
-           unsigned int im_width, unsigned int im_height,
-           unsigned int subsampl_width=0, unsigned int subsampl_height=0)
+           const vpCameraParameters::vpCameraParametersProjType &projModel, unsigned int im_width,
+           unsigned int im_height, bool verbose, unsigned int subsampl_width = 0, unsigned int subsampl_height = 0)
   {
     vpXmlCodeType prop;
-
     vpXmlCodeSequenceType back = SEQUENCE_OK;
     unsigned int nbCamera = 0;
 
@@ -175,21 +175,22 @@ public:
         back = SEQUENCE_ERROR;
       }
       if (prop == CODE_XML_CAMERA) {
-        if (SEQUENCE_OK ==
-            read_camera(node, cam_name, projModel, im_width, im_height, subsampl_width, subsampl_height))
+        if (SEQUENCE_OK == read_camera(node, cam_name, projModel, im_width, im_height, subsampl_width, subsampl_height, verbose))
           nbCamera++;
-      } else
+      }
+      else
         back = SEQUENCE_ERROR;
     }
 
     if (nbCamera == 0) {
       back = SEQUENCE_ERROR;
       vpCERROR << "No camera parameters is available" << std::endl << "with your specifications" << std::endl;
-    } else if (nbCamera > 1) {
+    }
+    else if (nbCamera > 1) {
       back = SEQUENCE_ERROR;
       vpCERROR << nbCamera << " sets of camera parameters are available" << std::endl
-               << "with your specifications : " << std::endl
-               << "precise your choice..." << std::endl;
+        << "with your specifications : " << std::endl
+        << "precise your choice..." << std::endl;
     }
 
     return back;
@@ -197,24 +198,24 @@ public:
 
   /*!
     Read camera fields from a XML file.
-    \param node_ : XML tree, pointing on a marker equipement.
-    \param cam_name : name of the camera : useful if the xml file has multiple
-    camera parameters. Set as "" if the camera name is not ambiguous.
+    \param node_ : XML tree, pointing on a marker equipment.
+    \param cam_name : Name of the camera. Useful if the xml file has multiple
+    camera parameters. Set to an empty string "" if the camera name is not ambiguous.
     \param projModel : Projection model type.
     \param im_width : width of image  on which camera calibration was performed.
-      Set as 0 if not ambiguous.
+    Set to 0 if not ambiguous.
     \param im_height : height of the image  on which camera calibration
-      was performed. Set as 0 if not ambiguous.
+    was performed. Set as 0 if not ambiguous.
     \param subsampl_width : scale of the image width sent by the camera.
-      Set as 0 if not ambiguous.
+    Set to 0 if not ambiguous.
     \param subsampl_height : scale of the image height sent by the camera.
-      Set as 0 if not ambiguous.
-    \return error code.
+    Set to 0 if not ambiguous.
+    \param verbose true to enable verbose mode, false otherwise.
+    \return Error code: SEQUENCE_OK when the required camera is found, SEQUENCE_ERROR otherwise.
    */
   int read_camera(const pugi::xml_node &node_, const std::string &cam_name,
-                  const vpCameraParameters::vpCameraParametersProjType &projModel,
-                  unsigned int im_width, unsigned int im_height,
-                  unsigned int subsampl_width, unsigned int subsampl_height)
+                  const vpCameraParameters::vpCameraParametersProjType &projModel, unsigned int im_width,
+                  unsigned int im_height, unsigned int subsampl_width, unsigned int subsampl_height, bool verbose)
   {
     vpXmlCodeType prop;
     /* read value in the XML file. */
@@ -225,7 +226,7 @@ public:
     unsigned int subsampling_height_tmp = 0;
     vpCameraParameters cam_tmp;
     vpCameraParameters cam_tmp_model;
-    bool projModelFound = false;
+    bool same_proj_model = false;
     vpXmlCodeSequenceType back = SEQUENCE_OK;
 
     for (pugi::xml_node node = node_.first_child(); node; node = node.next_sibling()) {
@@ -240,7 +241,9 @@ public:
       switch (prop) {
       case CODE_XML_CAMERA_NAME: {
         camera_name_tmp = node.text().as_string();
-        std::cout << "Found camera with name: \"" << camera_name_tmp << "\"" << std::endl;
+        if (verbose) {
+          std::cout << "Found camera with name: \"" << camera_name_tmp << "\"" << std::endl;
+        }
         break;
       }
       case CODE_XML_WIDTH:
@@ -261,7 +264,7 @@ public:
         back = read_camera_model(node, cam_tmp_model);
         if (cam_tmp_model.get_projModel() == projModel) {
           cam_tmp = cam_tmp_model;
-          projModelFound = true;
+          same_proj_model = true; // Same projection model
         }
         break;
 
@@ -287,6 +290,7 @@ public:
       case CODE_XML_K5:
       default:
         back = SEQUENCE_ERROR;
+
         break;
       }
     }
@@ -303,12 +307,14 @@ public:
       test_subsampling_height = (abs((int)subsampl_height - (int)subsampling_height_tmp) <
                                  (allowedPixelDiffOnImageSize * (int)(subsampling_height_tmp / subsampling_height)));
     }
-    if (!((projModelFound == true) && (cam_name == camera_name_tmp) &&
-          (abs((int)im_width - (int)image_width_tmp) < allowedPixelDiffOnImageSize || im_width == 0) &&
-          (abs((int)im_height - (int)image_height_tmp) < allowedPixelDiffOnImageSize || im_height == 0) &&
-          (test_subsampling_width) && (test_subsampling_height))) {
-      back = SEQUENCE_ERROR;
-    } else {
+    // if same name && same projection model && same image size camera already exists, we return SEQUENCE_OK
+    // otherwise it is a new camera that need to be updated and we return SEQUENCE_OK
+    bool same_name = (!cam_name.empty() && (cam_name == camera_name_tmp));
+    bool same_img_size = (abs((int)im_width - (int)image_width_tmp) < allowedPixelDiffOnImageSize || im_width == 0) &&
+      (abs((int)im_height - (int)image_height_tmp) < allowedPixelDiffOnImageSize || im_height == 0) &&
+      (test_subsampling_width) && (test_subsampling_height);
+    if (same_name && same_img_size && same_proj_model) {
+      back = SEQUENCE_OK; // Camera exists
       camera = cam_tmp;
       camera_name = camera_name_tmp;
       image_width = image_width_tmp;
@@ -318,17 +324,45 @@ public:
       full_width = subsampling_width_tmp * image_width_tmp;
       full_height = subsampling_height_tmp * image_height_tmp;
     }
+    else {
+
+      back = SEQUENCE_ERROR; // Camera doesn't exist yet in the file
+    }
+#if 0
+    if (!((projModelFound == true) &&
+          (abs((int)im_width - (int)image_width_tmp) < allowedPixelDiffOnImageSize || im_width == 0) &&
+          (abs((int)im_height - (int)image_height_tmp) < allowedPixelDiffOnImageSize || im_height == 0) &&
+          (test_subsampling_width) && (test_subsampling_height))) {
+      // Same images size, we need to check if the camera have the same name
+      if (!cam_name.empty() && (cam_name != camera_name_tmp)) {
+        back = SEQUENCE_ERROR; // Camera doesn't exist yet in the file
+      }
+      else {
+        back = SEQUENCE_OK; // Camera already found
+      }
+    }
+    else {
+      camera = cam_tmp;
+      camera_name = camera_name_tmp;
+      image_width = image_width_tmp;
+      image_height = image_height_tmp;
+      subsampling_width = subsampling_width_tmp;
+      subsampling_height = subsampling_height_tmp;
+      full_width = subsampling_width_tmp * image_width_tmp;
+      full_height = subsampling_height_tmp * image_height_tmp;
+      back = SEQUENCE_ERROR; // Camera doesn't exist yet in the file
+    }
+#endif
     return back;
   }
 
   /*!
     Read camera model fields from a XML file.
-    \param node_ : XML tree, pointing on a marker equipement.
-    \param cam_tmp : camera parameters to fill with read data (output).
-    \return error code.
+    \param node_ : XML tree, pointing on a marker equipment.
+    \param cam_tmp : Camera parameters to fill with read data (output).
+    \return Error code.
    */
-  vpXmlCodeSequenceType read_camera_model(const pugi::xml_node &node_,
-                                          vpCameraParameters &cam_tmp)
+  vpXmlCodeSequenceType read_camera_model(const pugi::xml_node &node_, vpCameraParameters &cam_tmp)
   {
     // counter of the number of read parameters
     int nb = 0;
@@ -448,7 +482,8 @@ public:
         return SEQUENCE_ERROR;
       }
       cam_tmp.initPersProjWithoutDistortion(px, py, u0, v0);
-    } else if (!strcmp(model_type.c_str(), LABEL_XML_MODEL_WITH_DISTORTION)) {
+    }
+    else if (!strcmp(model_type.c_str(), LABEL_XML_MODEL_WITH_DISTORTION)) {
       if (nb != 7 || validation != 0x7F) {
         vpCERROR << "ERROR in 'model' field:\n";
         vpCERROR << "it must contain 7 parameters\n";
@@ -456,7 +491,8 @@ public:
         return SEQUENCE_ERROR;
       }
       cam_tmp.initPersProjWithDistortion(px, py, u0, v0, kud, kdu);
-    } else if (!strcmp(model_type.c_str(), LABEL_XML_MODEL_WITH_KANNALA_BRANDT_DISTORTION)) {
+    }
+    else if (!strcmp(model_type.c_str(), LABEL_XML_MODEL_WITH_KANNALA_BRANDT_DISTORTION)) {
       if (nb != 10 || validation != 0x3FF) { // at least one coefficient is missing. We should know which one
         vpCERROR << "ERROR in 'model' field:\n";
         vpCERROR << "it must contain 10 parameters\n";
@@ -470,10 +506,9 @@ public:
         int check = validation / 32;
         int j = 0;
 
-        for(int i = 0; i < 5; i++)
-        {
+        for (int i = 0; i < 5; i++) {
           int bit = check % 2; // if bit == 1 => the corresponding distortion coefficient is present.
-          if(!bit)
+          if (!bit)
             fixed_distortion_coeffs.push_back(0.);
           else
             fixed_distortion_coeffs.push_back(distortion_coeffs[j++]);
@@ -484,7 +519,8 @@ public:
         return SEQUENCE_ERROR;
       }
       cam_tmp.initProjWithKannalaBrandtDistortion(px, py, u0, v0, distortion_coeffs);
-    } else {
+    }
+    else {
       vpERROR_TRACE("projection model type doesn't match with any known model !");
 
       return SEQUENCE_ERROR;
@@ -493,8 +529,7 @@ public:
   }
 
   int save(const vpCameraParameters &cam, const std::string &filename, const std::string &cam_name,
-           unsigned int im_width, unsigned int im_height,
-           const std::string &additionalInfo)
+           unsigned int im_width, unsigned int im_height, const std::string &additionalInfo, bool verbose)
   {
     pugi::xml_document doc;
     pugi::xml_node node;
@@ -518,7 +553,7 @@ public:
 
     camera = cam;
 
-    int nbCamera = count(node, cam_name, cam.get_projModel(), im_width, im_height);
+    int nbCamera = count(node, cam_name, cam.get_projModel(), verbose, im_width, im_height);
     if (nbCamera) {
       return SEQUENCE_ERROR;
     }
@@ -526,7 +561,8 @@ public:
     pugi::xml_node nodeCamera = find_camera(node, cam_name, im_width, im_height);
     if (!nodeCamera) {
       write(node, cam_name, im_width, im_height);
-    } else {
+    }
+    else {
       write_camera(nodeCamera);
     }
 
@@ -564,7 +600,7 @@ public:
   /*!
     Read camera parameters from a XML file and count the number of available
     sets of camera parameters corresponding with inputs.
-    \param node_ : XML tree, pointing on a marker equipement.
+    \param node_ : XML tree, pointing on a marker equipment.
     \param cam_name : name of the camera : useful if the xml file has multiple
     camera parameters. Set as "" if the camera name is not ambiguous.
     \param projModel : Projection model type.
@@ -576,12 +612,12 @@ public:
       Set as 0 if not ambiguous.
     \param subsampl_height : subsampling of the image height sent by the camera.
       Set as 0 if not ambiguous.
+    \param verbose true to enable verbose mode, false otherwise.
     \return number of available camera parameters corresponding with inputs.
    */
   int count(const pugi::xml_node &node_, const std::string &cam_name,
-            const vpCameraParameters::vpCameraParametersProjType &projModel,
-            unsigned int im_width, unsigned int im_height,
-            unsigned int subsampl_width=0, unsigned int subsampl_height=0)
+            const vpCameraParameters::vpCameraParametersProjType &projModel, unsigned int im_width,
+            unsigned int im_height, bool verbose, unsigned int subsampl_width = 0, unsigned int subsampl_height = 0)
   {
     vpXmlCodeType prop;
     int nbCamera = 0;
@@ -595,8 +631,7 @@ public:
       }
 
       if (prop == CODE_XML_CAMERA) {
-        if (SEQUENCE_OK ==
-            read_camera(node, cam_name, projModel, im_width, im_height, subsampl_width, subsampl_height))
+        if (SEQUENCE_OK == read_camera(node, cam_name, projModel, im_width, im_height, subsampl_width, subsampl_height, verbose))
           nbCamera++;
       }
     }
@@ -607,7 +642,7 @@ public:
   /*!
     Read camera headers from a XML file and return the last available
     node pointeur in the xml tree corresponding with inputs.
-    \param node_ : XML tree, pointing on a marker equipement.
+    \param node_ : XML tree, pointing on a marker equipment.
     \param cam_name : name of the camera : useful if the xml file has multiple
     camera parameters. Set as "" if the camera name is not ambiguous.
     \param im_width : width of image  on which camera calibration was performed.
@@ -620,9 +655,8 @@ public:
       Set as 0 if not ambiguous.
     \return number of available camera parameters corresponding with inputs.
    */
-  pugi::xml_node find_camera(const pugi::xml_node &node_, const std::string &cam_name,
-                             unsigned int im_width, unsigned int im_height,
-                             unsigned int subsampl_width=0, unsigned int subsampl_height=0)
+  pugi::xml_node find_camera(const pugi::xml_node &node_, const std::string &cam_name, unsigned int im_width,
+                             unsigned int im_height, unsigned int subsampl_width = 0, unsigned int subsampl_height = 0)
   {
     vpXmlCodeType prop;
 
@@ -644,7 +678,7 @@ public:
 
   /*!
     Read camera header fields from a XML file.
-    \param node_ : XML tree, pointing on a marker equipement.
+    \param node_ : XML tree, pointing on a marker equipment.
     \param cam_name : name of the camera : useful if the xml file has multiple
     camera parameters. Set as "" if the camera name is not ambiguous.
     \param im_width : width of image  on which camera calibration was performed.
@@ -657,9 +691,8 @@ public:
       Set as 0 if not ambiguous.
     \return error code.
    */
-  int read_camera_header(const pugi::xml_node &node_, const std::string &cam_name,
-                         unsigned int im_width, unsigned int im_height,
-                         unsigned int subsampl_width=0, unsigned int subsampl_height=0)
+  int read_camera_header(const pugi::xml_node &node_, const std::string &cam_name, unsigned int im_width,
+                         unsigned int im_height, unsigned int subsampl_width = 0, unsigned int subsampl_height = 0)
   {
     vpXmlCodeType prop;
     /* read value in the XML file. */
@@ -733,7 +766,7 @@ public:
 
   /*!
     Write camera parameters in an XML Tree.
-    \param node : XML tree, pointing on a marker equipement.
+    \param node : XML tree, pointing on a marker equipment.
     \param cam_name : name of the camera : useful if the xml file has multiple
     camera parameters. Set as "" if the camera name is not ambiguous.
     \param im_width : width of image  on which camera calibration was performed.
@@ -746,9 +779,8 @@ public:
       Set as 0 if not ambiguous.
     \return error code.
    */
-  int write(pugi::xml_node &node, const std::string &cam_name, unsigned int im_width,
-            unsigned int im_height, unsigned int subsampl_width=0,
-            unsigned int subsampl_height=0)
+  int write(pugi::xml_node &node, const std::string &cam_name, unsigned int im_width, unsigned int im_height,
+            unsigned int subsampl_width = 0, unsigned int subsampl_height = 0)
   {
     int back = SEQUENCE_OK;
 
@@ -822,6 +854,7 @@ public:
     pugi::xml_node node_tmp;
 
     int back = SEQUENCE_OK;
+
     switch (camera.get_projModel()) {
     case vpCameraParameters::perspectiveProjWithoutDistortion:
       //<model>
@@ -896,7 +929,7 @@ public:
         node_tmp.append_child(pugi::node_pcdata).text() = camera.get_kdu();
       }
       break;
-    
+
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
       //<model>
       node_model = node_camera.append_child(LABEL_XML_MODEL);
@@ -928,21 +961,26 @@ public:
         //<k1>, <k2>, <k3>, <k4>, <k5>
         std::vector<double> distortion_coefs = camera.getKannalaBrandtDistortionCoefficients();
 
-        if(distortion_coefs.size() != 5)
+        if (distortion_coefs.size() != 5)
           std::cout << "Make sure to have 5 distortion coefficients for Kannala-Brandt distortions." << std::endl;
 
         node_tmp = node_model.append_child(pugi::node_comment);
         node_tmp.set_value("Distortion coefficients");
         node_tmp = node_model.append_child(LABEL_XML_K1);
-        distortion_coefs.size() == 0 ? node_tmp.append_child(pugi::node_pcdata).text() = 0 : node_tmp.append_child(pugi::node_pcdata).text() = distortion_coefs[0];
+        distortion_coefs.size() == 0 ? node_tmp.append_child(pugi::node_pcdata).text() = 0
+          : node_tmp.append_child(pugi::node_pcdata).text() = distortion_coefs[0];
         node_tmp = node_model.append_child(LABEL_XML_K2);
-        distortion_coefs.size() <= 1 ? node_tmp.append_child(pugi::node_pcdata).text() = 0 : node_tmp.append_child(pugi::node_pcdata).text() = distortion_coefs[1];
+        distortion_coefs.size() <= 1 ? node_tmp.append_child(pugi::node_pcdata).text() = 0
+          : node_tmp.append_child(pugi::node_pcdata).text() = distortion_coefs[1];
         node_tmp = node_model.append_child(LABEL_XML_K3);
-        distortion_coefs.size() <= 2 ? node_tmp.append_child(pugi::node_pcdata).text() = 0 : node_tmp.append_child(pugi::node_pcdata).text() = distortion_coefs[2];
+        distortion_coefs.size() <= 2 ? node_tmp.append_child(pugi::node_pcdata).text() = 0
+          : node_tmp.append_child(pugi::node_pcdata).text() = distortion_coefs[2];
         node_tmp = node_model.append_child(LABEL_XML_K4);
-        distortion_coefs.size() <= 3 ? node_tmp.append_child(pugi::node_pcdata).text() = 0 : node_tmp.append_child(pugi::node_pcdata).text() = distortion_coefs[3];
+        distortion_coefs.size() <= 3 ? node_tmp.append_child(pugi::node_pcdata).text() = 0
+          : node_tmp.append_child(pugi::node_pcdata).text() = distortion_coefs[3];
         node_tmp = node_model.append_child(LABEL_XML_K5);
-        distortion_coefs.size() <= 4 ? node_tmp.append_child(pugi::node_pcdata).text() = 0 : node_tmp.append_child(pugi::node_pcdata).text() = distortion_coefs[4];
+        distortion_coefs.size() <= 4 ? node_tmp.append_child(pugi::node_pcdata).text() = 0
+          : node_tmp.append_child(pugi::node_pcdata).text() = distortion_coefs[4];
       }
       break;
     }
@@ -977,7 +1015,6 @@ public:
     return pugi::xml_node();
   }
 
-
   /*!
     Translate a string (label) to a xml code.
     \param str : string to translate.
@@ -991,49 +1028,71 @@ public:
 
     if (!strcmp(str, LABEL_XML_CAMERA)) {
       val_int = CODE_XML_CAMERA;
-    } else if (!strcmp(str, LABEL_XML_CAMERA_NAME)) {
+    }
+    else if (!strcmp(str, LABEL_XML_CAMERA_NAME)) {
       val_int = CODE_XML_CAMERA_NAME;
-    } else if (!strcmp(str, LABEL_XML_MODEL)) {
+    }
+    else if (!strcmp(str, LABEL_XML_MODEL)) {
       val_int = CODE_XML_MODEL;
-    } else if (!strcmp(str, LABEL_XML_MODEL_TYPE)) {
+    }
+    else if (!strcmp(str, LABEL_XML_MODEL_TYPE)) {
       val_int = CODE_XML_MODEL_TYPE;
-    } else if (!strcmp(str, LABEL_XML_WIDTH)) {
+    }
+    else if (!strcmp(str, LABEL_XML_WIDTH)) {
       val_int = CODE_XML_WIDTH;
-    } else if (!strcmp(str, LABEL_XML_HEIGHT)) {
+    }
+    else if (!strcmp(str, LABEL_XML_HEIGHT)) {
       val_int = CODE_XML_HEIGHT;
-    } else if (!strcmp(str, LABEL_XML_SUBSAMPLING_WIDTH)) {
+    }
+    else if (!strcmp(str, LABEL_XML_SUBSAMPLING_WIDTH)) {
       val_int = CODE_XML_SUBSAMPLING_WIDTH;
-    } else if (!strcmp(str, LABEL_XML_SUBSAMPLING_HEIGHT)) {
+    }
+    else if (!strcmp(str, LABEL_XML_SUBSAMPLING_HEIGHT)) {
       val_int = CODE_XML_SUBSAMPLING_HEIGHT;
-    } else if (!strcmp(str, LABEL_XML_FULL_WIDTH)) {
+    }
+    else if (!strcmp(str, LABEL_XML_FULL_WIDTH)) {
       val_int = CODE_XML_FULL_WIDTH;
-    } else if (!strcmp(str, LABEL_XML_FULL_HEIGHT)) {
+    }
+    else if (!strcmp(str, LABEL_XML_FULL_HEIGHT)) {
       val_int = CODE_XML_FULL_HEIGHT;
-    } else if (!strcmp(str, LABEL_XML_U0)) {
+    }
+    else if (!strcmp(str, LABEL_XML_U0)) {
       val_int = CODE_XML_U0;
-    } else if (!strcmp(str, LABEL_XML_V0)) {
+    }
+    else if (!strcmp(str, LABEL_XML_V0)) {
       val_int = CODE_XML_V0;
-    } else if (!strcmp(str, LABEL_XML_PX)) {
+    }
+    else if (!strcmp(str, LABEL_XML_PX)) {
       val_int = CODE_XML_PX;
-    } else if (!strcmp(str, LABEL_XML_PY)) {
+    }
+    else if (!strcmp(str, LABEL_XML_PY)) {
       val_int = CODE_XML_PY;
-    } else if (!strcmp(str, LABEL_XML_KUD)) {
+    }
+    else if (!strcmp(str, LABEL_XML_KUD)) {
       val_int = CODE_XML_KUD;
-    } else if (!strcmp(str, LABEL_XML_KDU)) {
+    }
+    else if (!strcmp(str, LABEL_XML_KDU)) {
       val_int = CODE_XML_KDU;
-    } else if (!strcmp(str, LABEL_XML_K1)) {
+    }
+    else if (!strcmp(str, LABEL_XML_K1)) {
       val_int = CODE_XML_K1;
-    } else if (!strcmp(str, LABEL_XML_K2)) {
+    }
+    else if (!strcmp(str, LABEL_XML_K2)) {
       val_int = CODE_XML_K2;
-    } else if (!strcmp(str, LABEL_XML_K3)) {
+    }
+    else if (!strcmp(str, LABEL_XML_K3)) {
       val_int = CODE_XML_K3;
-    } else if (!strcmp(str, LABEL_XML_K4)) {
+    }
+    else if (!strcmp(str, LABEL_XML_K4)) {
       val_int = CODE_XML_K4;
-    } else if (!strcmp(str, LABEL_XML_K5)) {
+    }
+    else if (!strcmp(str, LABEL_XML_K5)) {
       val_int = CODE_XML_K5;
-    } else if (!strcmp(str, LABEL_XML_ADDITIONAL_INFO)) {
+    }
+    else if (!strcmp(str, LABEL_XML_ADDITIONAL_INFO)) {
       val_int = CODE_XML_ADDITIONAL_INFO;
-    } else {
+    }
+    else {
       val_int = CODE_XML_OTHER;
     }
     res = val_int;
@@ -1070,48 +1129,45 @@ private:
 };
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
-vpXmlParserCamera::vpXmlParserCamera() : m_impl(new Impl())
-{
-}
+vpXmlParserCamera::vpXmlParserCamera() : m_impl(new Impl()) { }
 
-vpXmlParserCamera::~vpXmlParserCamera()
-{
-  delete m_impl;
-}
+vpXmlParserCamera::~vpXmlParserCamera() { delete m_impl; }
 
 /*!
   Parse an xml file to load camera parameters.
-  \param cam : camera parameters to fill.
-  \param filename : name of the xml file to parse
-  \param cam_name : name of the camera : useful if the xml file has multiple
-  camera parameters. Set as "" if the camera name is not ambiguous.
-  \param projModel : camera projection model needed.
-  \param im_width : image width on which camera calibration was performed.
-  Set as 0 if not ambiguous.
-  \param im_height : image height on which camera calibration was performed.
-  Set as 0 if not ambiguous.
+  \param cam : Camera parameters to fill.
+  \param filename : Name of the xml file to parse.
+  \param cam_name : Name of the camera. Useful if the xml file has multiple
+  camera parameters. Set to an empty string "" if the camera name is not ambiguous.
+  \param projModel : Camera projection model needed.
+  \param im_width : Image width on which camera calibration was performed.
+  Set to 0 if not ambiguous.
+  \param im_height : Image height on which camera calibration was performed.
+  Set to 0 if not ambiguous.
+  \param verbose true to enable verbose mode, false otherwise.
 
   \return vpXmlParserCamera::SEQUENCE_OK if success and vpXmlParserCamera::SEQUENCE_ERROR otherwise.
 */
 int vpXmlParserCamera::parse(vpCameraParameters &cam, const std::string &filename, const std::string &cam_name,
-                             const vpCameraParameters::vpCameraParametersProjType &projModel,
-                             unsigned int im_width, unsigned int im_height)
+                             const vpCameraParameters::vpCameraParametersProjType &projModel, unsigned int im_width,
+                             unsigned int im_height, bool verbose)
 {
-  return m_impl->parse(cam, filename, cam_name, projModel, im_width, im_height);
+  return m_impl->parse(cam, filename, cam_name, projModel, im_width, im_height, verbose);
 }
 
 /*!
   Save camera parameters in an xml file.
-  \param cam : camera parameters to save.
-  \param filename : name of the xml file to fill.
-  \param cam_name : name of the camera : useful if the xml file has multiple
-    camera parameters. Set as "" if the camera name is not ambiguous.
-  \param im_width : width of image  on which camera calibration was performed.
-    Set as 0 if not ambiguous.
-  \param im_height : height of the image  on which camera calibration was
-performed. Set as 0 if not ambiguous. \param additionalInfo : Additional
-information added in the saved xml file. The content of this string should be
-in xml format.
+  \param cam : Camera parameters to save.
+  \param filename : Name of the xml file to fill.
+  \param cam_name : Name of the camera: useful if the xml file has multiple
+  camera parameters. Set to "" if the camera name is not ambiguous.
+  \param im_width : Width of image on which camera calibration was performed.
+  Set to 0 if not ambiguous.
+  \param im_height : Height of the image on which camera calibration was
+  performed. Set to 0 if not ambiguous.
+  \param additionalInfo : Additional information added in the saved xml file.
+  The content of this string should be in xml format.
+  \param verbose true to enable verbose mode, false otherwise.
 
   \return error code.
 
@@ -1144,63 +1200,29 @@ int main()
   \endcode
 */
 int vpXmlParserCamera::save(const vpCameraParameters &cam, const std::string &filename, const std::string &cam_name,
-                            unsigned int im_width, unsigned int im_height,
-                            const std::string &additionalInfo)
+                            unsigned int im_width, unsigned int im_height, const std::string &additionalInfo, bool verbose)
 {
-  return m_impl->save(cam, filename, cam_name, im_width, im_height, additionalInfo);
+  return m_impl->save(cam, filename, cam_name, im_width, im_height, additionalInfo, verbose);
 }
 
-std::string vpXmlParserCamera::getCameraName() const
-{
-  return m_impl->getCameraName();
-}
+std::string vpXmlParserCamera::getCameraName() const { return m_impl->getCameraName(); }
 
-vpCameraParameters vpXmlParserCamera::getCameraParameters() const
-{
-  return m_impl->getCameraParameters();
-}
+vpCameraParameters vpXmlParserCamera::getCameraParameters() const { return m_impl->getCameraParameters(); }
 
-unsigned int vpXmlParserCamera::getHeight() const
-{
-  return m_impl->getHeight();
-}
+unsigned int vpXmlParserCamera::getHeight() const { return m_impl->getHeight(); }
 
-unsigned int vpXmlParserCamera::getSubsampling_width() const
-{
-  return m_impl->getSubsampling_width();
-}
+unsigned int vpXmlParserCamera::getSubsampling_width() const { return m_impl->getSubsampling_width(); }
 
-unsigned int vpXmlParserCamera::getSubsampling_height() const
-{
-  return m_impl->getSubsampling_height();
-}
+unsigned int vpXmlParserCamera::getSubsampling_height() const { return m_impl->getSubsampling_height(); }
 
-unsigned int vpXmlParserCamera::getWidth() const
-{
-  return m_impl->getWidth();
-}
+unsigned int vpXmlParserCamera::getWidth() const { return m_impl->getWidth(); }
 
-void vpXmlParserCamera::setCameraName(const std::string &name)
-{
-  m_impl->setCameraName(name);
-}
+void vpXmlParserCamera::setCameraName(const std::string &name) { m_impl->setCameraName(name); }
 
-void vpXmlParserCamera::setHeight(unsigned int height)
-{
-  m_impl->setHeight(height);
-}
+void vpXmlParserCamera::setHeight(unsigned int height) { m_impl->setHeight(height); }
 
-void vpXmlParserCamera::setSubsampling_width(unsigned int subsampling)
-{
-  m_impl->setSubsampling_width(subsampling);
-}
+void vpXmlParserCamera::setSubsampling_width(unsigned int subsampling) { m_impl->setSubsampling_width(subsampling); }
 
-void vpXmlParserCamera::setSubsampling_height(unsigned int subsampling)
-{
-  m_impl->setSubsampling_height(subsampling);
-}
+void vpXmlParserCamera::setSubsampling_height(unsigned int subsampling) { m_impl->setSubsampling_height(subsampling); }
 
-void vpXmlParserCamera::setWidth(unsigned int width)
-{
-  m_impl->setWidth(width);
-}
+void vpXmlParserCamera::setWidth(unsigned int width) { m_impl->setWidth(width); }
