@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,9 @@
  * Description:
  * Display implementation.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
+
+#include <visp3/core/vpMath.h>
 #include <visp3/core/vpMeterPixelConversion.h>
 #include <visp3/core/vpPoint.h>
 
@@ -193,8 +192,9 @@ void vp_display_display_dot_line(const vpImage<Type> &I, int i1, int j1, int i2,
 
 template <class Type>
 void vp_display_display_ellipse(const vpImage<Type> &I, const vpImagePoint &center, const double &coef1,
-                                const double &coef2, const double &coef3, const double &smallalpha, const double &highalpha,
-                                bool use_normalized_centered_moments, const vpColor &color, unsigned int thickness, bool display_center, bool display_arc)
+                                const double &coef2, const double &coef3, const double &smallalpha,
+                                const double &highalpha, bool use_normalized_centered_moments, const vpColor &color,
+                                unsigned int thickness, bool display_center, bool display_arc)
 {
   if (I.display != NULL) {
     double a = 0., b = 0., e = 0.;
@@ -206,18 +206,17 @@ void vp_display_display_ellipse(const vpImage<Type> &I, const vpImagePoint &cent
       double n11_p = coef2;
       double n02_p = coef3;
       double num = n20_p - n02_p;
-      double d = num * num + 4.0 * n11_p * n11_p;   // always >= 0
+      double d = num * num + 4.0 * n11_p * n11_p; // always >= 0
 
       if (d <= std::numeric_limits<double>::epsilon()) { // circle
-        e = 0.0;  // case n20 = n02 and n11 = 0 : circle, e undefined
-        a = b = 2.0*sqrt(n20_p);
-      }
-      else { // real ellipse
-        e = atan2(2.0*n11_p, num)/2.0;  // e in [-Pi/2 ; Pi/2]
-        d = sqrt(d); // d in sqrt always >= 0
+        e = 0.0;                                         // case n20 = n02 and n11 = 0 : circle, e undefined
+        a = b = 2.0 * sqrt(n20_p);
+      } else {                             // real ellipse
+        e = atan2(2.0 * n11_p, num) / 2.0; // e in [-Pi/2 ; Pi/2]
+        d = sqrt(d);                       // d in sqrt always >= 0
         num = n20_p + n02_p;
-        a = sqrt(2.0*(num + d)); // term in sqrt always > 0
-        b = sqrt(2.0*(num - d)); // term in sqrt always > 0
+        a = sqrt(2.0 * (num + d)); // term in sqrt always > 0
+        b = sqrt(2.0 * (num - d)); // term in sqrt always > 0
       }
     } else {
       a = coef1;
@@ -233,13 +232,13 @@ void vp_display_display_ellipse(const vpImage<Type> &I, const vpImagePoint &cent
     double angle = highalpha - smallalpha;
 
     // Disable arc drawing when the ellipse is complete
-    if (std::fabs(angle - 2* M_PI) <= std::numeric_limits<double>::epsilon()) {
+    if (std::fabs(angle - 2 * M_PI) <= std::numeric_limits<double>::epsilon()) {
       display_arc = false;
     }
 
     double t = (a - b) / (a + b);
-    t *= t;  // t^2
-    double circumference = (angle/2.0) * (a + b) * (1.0 + 3.0 * t / (10.0 + sqrt(4.0 - 3.0 * t)));
+    t *= t; // t^2
+    double circumference = (angle / 2.0) * (a + b) * (1.0 + 3.0 * t / (10.0 + sqrt(4.0 - 3.0 * t)));
     unsigned int nbpoints = (unsigned int)(floor(circumference / 20));
     if (nbpoints < 10) {
       nbpoints = 10;
@@ -292,47 +291,118 @@ void vp_display_display_ellipse(const vpImage<Type> &I, const vpImagePoint &cent
 
 template <class Type>
 void vp_display_display_frame(const vpImage<Type> &I, const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam,
-                              double size, const vpColor &color, unsigned int thickness, const vpImagePoint &offset)
+                              double size, const vpColor &color, unsigned int thickness, const vpImagePoint &offset,
+                              const std::string& frameName, const vpColor& textColor, const vpImagePoint& textOffset)
 {
-  // used by display
+  // Projecting the origin of the object frame in the camera plane
   vpPoint o(0.0, 0.0, 0.0);
-  vpPoint x(size, 0.0, 0.0);
-  vpPoint y(0.0, size, 0.0);
-  vpPoint z(0.0, 0.0, size);
-
   o.track(cMo);
-  x.track(cMo);
-  y.track(cMo);
-  z.track(cMo);
 
-  vpImagePoint ipo, ip1;
+  vpColor xAxisColor(vpColor::none), yAxisColor(vpColor::none), zAxisColor(vpColor::none);
+  vpImagePoint ipo, ipx, ipy, ipz;
   vpRect bbox(0, 0, I.getWidth(), I.getHeight());
 
-  if (color == vpColor::none) {
-    vpMeterPixelConversion::convertPoint(cam, o.p[0], o.p[1], ipo);
-    if (bbox.isInside(ipo)) {
-      vpMeterPixelConversion::convertPoint(cam, x.p[0], x.p[1], ip1);
-      vpDisplay::displayArrow(I, ipo + offset, ip1 + offset, vpColor::red, 4 * thickness, 2 * thickness, thickness);
+  // Selecting the color of the axes
+  if (color == vpColor::none)
+  {
+    xAxisColor = vpColor::red;
+    yAxisColor = vpColor::green;
+    zAxisColor = vpColor::blue;
+  }
+  else
+  {
+    xAxisColor = color;
+    yAxisColor = color;
+    zAxisColor = color;
+  }
 
-      vpMeterPixelConversion::convertPoint(cam, y.p[0], y.p[1], ip1);
-      vpDisplay::displayArrow(I, ipo + offset, ip1 + offset, vpColor::green, 4 * thickness, 2 * thickness, thickness);
+  vpMeterPixelConversion::convertPoint(cam, o.p[0], o.p[1], ipo);
+  if (bbox.isInside(ipo)) {
+    double u_size = cam.get_px() * size / cMo[2][3]; // u_size = size/Z * cam.px
+    double v_size = cam.get_py() * size / cMo[2][3]; // v_size = size/Z * cam.py
 
-      vpMeterPixelConversion::convertPoint(cam, z.p[0], z.p[1], ip1);
-      vpDisplay::displayArrow(I, ipo + offset, ip1 + offset, vpColor::blue, 4 * thickness, 2 * thickness, thickness);
+    // Computing the perspective projection of the X-axis and drawing it
+    vpImagePoint ipx(ipo);
+    ipx.set_u( ipx.get_u() + u_size * cMo[0][0]);
+    ipx.set_v( ipx.get_v() + v_size * cMo[1][0]);
+    vpDisplay::displayArrow(I, ipo + offset, ipx + offset, xAxisColor, 4 * thickness, 2 * thickness, thickness);
 
+    // Computing the perspective projection of the Y-axis and drawing it
+    vpImagePoint ipy(ipo);
+    ipy.set_u( ipy.get_u() + u_size * cMo[0][1]);
+    ipy.set_v( ipy.get_v() + v_size * cMo[1][1]);
+    vpDisplay::displayArrow(I, ipo + offset, ipy + offset, yAxisColor, 4 * thickness, 2 * thickness, thickness);
+
+    // Computing the perspective projection of the Y-axis and drawing it
+    vpImagePoint ipz(ipo);
+    ipz.set_u( ipz.get_u() + u_size * cMo[0][2]);
+    ipz.set_v( ipz.get_v() + v_size * cMo[1][2]);
+    vpDisplay::displayArrow(I, ipo + offset, ipz + offset, zAxisColor, 4 * thickness, 2 * thickness, thickness);
+  }
+
+  // If frameName != empty, computing the image coordinates (u v) of the text
+  // such as we avoid as much as we can to cross an axis
+  if(!frameName.empty())
+  {
+    // The actual offset that will be applied to the text with regard to the frame origin
+    // The horizontal / vertical offset direction will go in the direction opposed to the
+    // most horizontal and most vertical axis
+    vpImagePoint actualTextOffset;
+
+    // Looking for the axis of the object frame that has the hugest X and Y value
+    // in the camera frame, in terms of absolute value
+    double abs_u_val = std::abs(cMo[0][0]); // Taking the X-axis of the object frame as first initial guess
+    int u_direction = vpMath::sign(cMo[0][0]); // Taking the direction of the X-axis of the object frame in the camera frame
+    double abs_v_val = std::abs(cMo[1][0]); // Taking the X-axis of the object frame as first initial guess
+    int v_direction = vpMath::sign(cMo[1][0]); // Taking the direction of the X-axis of the object frame in the camera frame
+
+    for(int i = 1; i <= 2; i++)
+    {
+      double abs_u_candidate = std::abs(cMo[0][i]);
+      int u_direction_candidate = vpMath::sign(cMo[0][i]);
+      if(abs_u_candidate - abs_u_val > std::numeric_limits<double>::epsilon())
+      {
+        // The norm of the candidate axis is greater => we take its direction
+        abs_u_val = abs_u_candidate;
+        u_direction = u_direction_candidate;
+      }
+      else if(std::abs(abs_u_candidate - abs_u_val) < std::numeric_limits<double>::epsilon())
+      {
+        if(std::abs(u_direction - u_direction_candidate) > 0)
+        {
+          // The norm are equal => we always take the positive direction
+          u_direction = +1;
+        }
+      }
+
+      double abs_v_candidate = std::abs(cMo[1][i]);
+      int v_direction_candidate = vpMath::sign(cMo[1][i]);
+      if(abs_v_candidate - abs_v_val > std::numeric_limits<double>::epsilon())
+      {
+        // The norm of the candidate axis is greater => we take its direction
+        abs_v_val = abs_v_candidate;
+        v_direction = v_direction_candidate;
+      }
+      else if(std::abs(abs_v_candidate - abs_v_val) < std::numeric_limits<double>::epsilon())
+      {
+        if(std::abs(v_direction - v_direction_candidate) > 0)
+        {
+          // The norm are equal => we always take the positive direction
+          v_direction = +1;
+        }
+      }
     }
-  } else {
-    vpMeterPixelConversion::convertPoint(cam, o.p[0], o.p[1], ipo);
-    if (bbox.isInside(ipo)) {
-      vpMeterPixelConversion::convertPoint(cam, x.p[0], x.p[1], ip1);
-      vpDisplay::displayArrow(I, ipo + offset, ip1 + offset, color, 4 * thickness, 2 * thickness, thickness);
 
-      vpMeterPixelConversion::convertPoint(cam, y.p[0], y.p[1], ip1);
-      vpDisplay::displayArrow(I, ipo + offset, ip1 + offset, color, 4 * thickness, 2 * thickness, thickness);
-
-      vpMeterPixelConversion::convertPoint(cam, z.p[0], z.p[1], ip1);
-      vpDisplay::displayArrow(I, ipo + offset, ip1 + offset, color, 4 * thickness, 2 * thickness, thickness);
+    // The offset of the text is set in the opposite direction of the object frame axes
+    // having the greatest projection in the camera frame in order to limit
+    // the risk of crossing a frame axis in the image
+    actualTextOffset.set_u(-1. * u_direction * textOffset.get_u());
+    actualTextOffset.set_v(-1. * v_direction * textOffset.get_v());
 
+    // Check if the text position is located inside the image
+    if (bbox.isInside(ipo + actualTextOffset))
+    {
+      vpDisplay::displayText(I, ipo + actualTextOffset, frameName, textColor);
     }
   }
 }
@@ -382,17 +452,16 @@ void vp_display_display_point(const vpImage<Type> &I, int i, int j, const vpColo
 
 template <class Type>
 void vp_display_display_polygon(const vpImage<Type> &I, const std::vector<vpImagePoint> &vip, const vpColor &color,
-                                unsigned int thickness, bool closed=true)
+                                unsigned int thickness, bool closed = true)
 {
   if (I.display != NULL) {
     if (closed) {
       for (unsigned int i = 0; i < vip.size(); i++) {
         (I.display)->displayLine(vip[i], vip[(i + 1) % vip.size()], color, thickness);
       }
-    }
-    else {
+    } else {
       for (unsigned int i = 1; i < vip.size(); i++) {
-        (I.display)->displayLine(vip[i-1], vip[i], color, thickness);
+        (I.display)->displayLine(vip[i - 1], vip[i], color, thickness);
       }
     }
   }
@@ -580,7 +649,7 @@ template <class Type> bool vp_display_get_keyboard_event(const vpImage<Type> &I,
   if (I.display != NULL) {
     std::string str;
     bool ret = (I.display)->getKeyboardEvent(str, blocking);
-    sprintf(key, "%s", str.c_str());
+    snprintf(key, str.size(), "%s", str.c_str());
     return ret;
   }
   return false;
@@ -655,6 +724,6 @@ template <class Type> unsigned int vp_display_get_down_scaling_factor(const vpIm
   if (I.display != NULL) {
     return (I.display)->getDownScalingFactor();
   } else {
-    throw(vpException(vpException::fatalError, "Cannot get the down scaling factor: Display is not initialized"));
+    return 1;
   }
 }
