@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Display implementation.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpDisplay.h>
 
@@ -136,6 +133,23 @@ void vpDisplay::displayCharString(const vpImage<vpRGBa> &I, int i, int j, const
   vp_display_display_char_string(I, i, j, string, color);
 }
 
+/*!
+  Display a circle.
+  \param I : The image associated to the display.
+  \param circle: Circle to display.
+  \param color : Circle color.
+  \param fill : When set to true fill the circle. When vpDisplayOpenCV is used,
+  and color alpha channel is set, filling feature can handle transparency. See vpColor
+  header class documentation.
+  \param thickness : Thickness of the circle. This parameter is only useful
+  when \e fill is set to false.
+*/
+void vpDisplay::displayCircle(const vpImage<vpRGBa> &I, const vpImageCircle &circle,
+                              const vpColor &color, bool fill, unsigned int thickness)
+{
+  vp_display_display_circle(I, circle.getCenter(), static_cast<unsigned int>(circle.getRadius()), color, fill, thickness);
+}
+
 /*!
   Display a circle.
   \param I : The image associated to the display.
@@ -288,7 +302,7 @@ void vpDisplay::displayDotLine(const vpImage<vpRGBa> &I, const std::list<vpImage
   - second order centered moments of the ellipse normalized by its area
     (i.e., such that \f$n_{ij} = \mu_{ij}/a\f$ where \f$\mu_{ij}\f$ are the
     centered moments and a the area) expressed in pixels.
-  - the major and minor axis lenght in pixels and the excentricity of the
+  - the major and minor axis length in pixels and the eccentricity of the
   ellipse in radians: \f$a, b, e\f$.
   \param use_normalized_centered_moments : When false,
   the parameters coef1, coef2, coef3 are the parameters \f$a, b, e\f$. When
@@ -332,7 +346,7 @@ void vpDisplay::displayEllipse(const vpImage<vpRGBa> &I, const vpImagePoint &cen
   - second order centered moments of the ellipse normalized by its area
     (i.e., such that \f$n_{ij} = \mu_{ij}/a\f$ where \f$\mu_{ij}\f$ are the
     centered moments and a the area) expressed in pixels.
-  - the major and minor axis lenght in pixels and the excentricity of the
+  - the major and minor axis length in pixels and the eccentricity of the
   ellipse in radians: \f$a, b, e\f$.
   \param smallalpha : Smallest \f$ alpha \f$ angle in rad (0 for a complete ellipse).
   \param highalpha : Highest \f$ alpha \f$ angle in rad (2 \f$ \Pi \f$ for a complete ellipse).
@@ -363,9 +377,9 @@ void vpDisplay::displayEllipse(const vpImage<vpRGBa> &I, const vpImagePoint &cen
   \endcode
 */
 void vpDisplay::displayEllipse(const vpImage<vpRGBa> &I, const vpImagePoint &center, const double &coef1,
-                               const double &coef2, const double &coef3, const double &smallalpha, const double &highalpha,
-                               bool use_normalized_centered_moments, const vpColor &color, unsigned int thickness,
-                               bool display_center, bool display_arc)
+                               const double &coef2, const double &coef3, const double &smallalpha,
+                               const double &highalpha, bool use_normalized_centered_moments, const vpColor &color,
+                               unsigned int thickness, bool display_center, bool display_arc)
 {
   vp_display_display_ellipse(I, center, coef1, coef2, coef3, smallalpha, highalpha, use_normalized_centered_moments,
                              color, thickness, display_center, display_arc);
@@ -383,13 +397,16 @@ void vpDisplay::displayEllipse(const vpImage<vpRGBa> &I, const vpImagePoint &cen
   \param size : Size of the object frame.
   \param color : Color used to display the frame in the image.
   \param thickness : the thickness of the line.
-  \param offset : Offset in pixels applied to the frame origin location in the
-  image.
+  \param offset : Offset in pixels applied to the frame origin location in the image.
+  \param frameName : Text to display along side the origin of the frame.
+  \param textColor : Color of the text associated to `frameName`.
+  \param textOffset : Offset used to shift the text from the origin of the frame.
 */
 void vpDisplay::displayFrame(const vpImage<vpRGBa> &I, const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam,
-                             double size, const vpColor &color, unsigned int thickness, const vpImagePoint &offset)
+                             double size, const vpColor &color, unsigned int thickness, const vpImagePoint &offset,
+                             const std::string &frameName, const vpColor &textColor, const vpImagePoint &textOffset)
 {
-  vp_display_display_frame(I, cMo, cam, size, color, thickness, offset);
+  vp_display_display_frame(I, cMo, cam, size, color, thickness, offset, frameName, textColor, textOffset);
 }
 
 /*!
@@ -404,7 +421,8 @@ void vpDisplay::displayFrame(const vpImage<vpRGBa> &I, const vpHomogeneousMatrix
 void vpDisplay::displayLine(const vpImage<vpRGBa> &I, const vpImagePoint &ip1, const vpImagePoint &ip2,
                             const vpColor &color, unsigned int thickness, bool segment)
 {
-  displayLine(I, static_cast<int>(ip1.get_i()), static_cast<int>(ip1.get_j()), static_cast<int>(ip2.get_i()), static_cast<int>(ip2.get_j()), color, thickness, segment);
+  displayLine(I, static_cast<int>(ip1.get_i()), static_cast<int>(ip1.get_j()), static_cast<int>(ip2.get_i()),
+              static_cast<int>(ip2.get_j()), color, thickness, segment);
 }
 
 /*!
@@ -429,11 +447,11 @@ void vpDisplay::displayLine(const vpImage<vpRGBa> &I, int i1, int j1, int i2, in
     double delta_i = static_cast<double>(i2) - static_cast<double>(i1);
     // Test if horizontal line
     if (std::fabs(delta_i) <= std::numeric_limits<double>::epsilon()) {
-      vp_display_display_line(I, i1, 0, i1, (I.getWidth()-1), color, thickness);
+      vp_display_display_line(I, i1, 0, i1, (I.getWidth() - 1), color, thickness);
     }
     // Test if vertical line
     else if (std::fabs(delta_j) <= std::numeric_limits<double>::epsilon()) {
-      vp_display_display_line(I, 0, j1, (I.getHeight()-1), j1, color, thickness);
+      vp_display_display_line(I, 0, j1, (I.getHeight() - 1), j1, color, thickness);
     }
     else {
       double a = delta_i / delta_j;
@@ -441,12 +459,12 @@ void vpDisplay::displayLine(const vpImage<vpRGBa> &I, int i1, int j1, int i2, in
       std::vector<vpImagePoint> vip; // Image points that intersect image borders
       // Test intersection with vertical line j=0
       vpImagePoint ip_left(b, 0);
-      if (ip_left.get_i() >= 0. && ip_left.get_i() <= (I.getHeight()-1.)) {
+      if (ip_left.get_i() >= 0. && ip_left.get_i() <= (I.getHeight() - 1.)) {
         vip.push_back(ip_left);
       }
       // Test intersection with vertical line j=width-1
-      vpImagePoint ip_right(a*(I.getWidth()-1)+b, I.getWidth()-1.);
-      if (ip_right.get_i() >= 0. && ip_right.get_i() <= (I.getHeight()-1.)) {
+      vpImagePoint ip_right(a * (I.getWidth() - 1) + b, I.getWidth() - 1.);
+      if (ip_right.get_i() >= 0. && ip_right.get_i() <= (I.getHeight() - 1.)) {
         vip.push_back(ip_right);
       }
       if (vip.size() == 2) {
@@ -454,8 +472,8 @@ void vpDisplay::displayLine(const vpImage<vpRGBa> &I, int i1, int j1, int i2, in
         return;
       }
       // Test intersection with horizontal line i=0
-      vpImagePoint ip_top(0, -b/a);
-      if (ip_top.get_j() >= 0. && ip_top.get_j() <= (I.getWidth()-1.)) {
+      vpImagePoint ip_top(0, -b / a);
+      if (ip_top.get_j() >= 0. && ip_top.get_j() <= (I.getWidth() - 1.)) {
         vip.push_back(ip_top);
       }
       if (vip.size() == 2) {
@@ -463,8 +481,8 @@ void vpDisplay::displayLine(const vpImage<vpRGBa> &I, int i1, int j1, int i2, in
         return;
       }
       // Test intersection with horizontal line i=height-1
-      vpImagePoint ip_bottom(I.getHeight()-1., (I.getHeight()-1. - b)/a);
-      if (ip_bottom.get_j() >= 0. && ip_bottom.get_j() <= (I.getWidth()-1.)) {
+      vpImagePoint ip_bottom(I.getHeight() - 1., (I.getHeight() - 1. - b) / a);
+      if (ip_bottom.get_j() >= 0. && ip_bottom.get_j() <= (I.getWidth() - 1.)) {
         vip.push_back(ip_bottom);
       }
       if (vip.size() == 2) {
@@ -747,7 +765,7 @@ int main() {
   unsigned int radius = 100;
   vpDisplay::displayCircle(I, center, radius, vpColor::red);
 
-  vpDisplay::flush(I); // Mendatory to display the requested features.
+  vpDisplay::flush(I); // Mandatory to display the requested features.
 }
   \endcode
 
@@ -760,7 +778,7 @@ void vpDisplay::flush(const vpImage<vpRGBa> &I) { vp_display_flush(I); }
   It's necessary to use this function to see the results of any drawing.
 
   \warning This function is particular and must be called
-  to show the overlay. Because it's time spending, use it parcimoniously.
+  to show the overlay. Because it's time spending, use it parsimoniously.
 
   \sa flush()
 */
@@ -963,7 +981,7 @@ int main()
   d = new vpDisplayGDI;
 #elif defined(VISP_HAVE_D3D9)
   d = new vpDisplayD3D;
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
   d = new vpDisplayOpenCV;
 #else
   std::cout << "Sorry, no video device is available" << std::endl;
@@ -1052,7 +1070,7 @@ int main()
   d = new vpDisplayGDI;
 #elif defined(VISP_HAVE_D3D9)
   d = new vpDisplayD3D;
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
   d = new vpDisplayOpenCV;
 #else
   std::cout << "Sorry, no video device is available" << std::endl;
@@ -1143,7 +1161,7 @@ int main()
   d = new vpDisplayGDI;
 #elif defined(VISP_HAVE_D3D9)
   d = new vpDisplayD3D;
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
   d = new vpDisplayOpenCV;
 #else
   std::cout << "Sorry, no video device is available" << std::endl;
@@ -1276,10 +1294,8 @@ void vpDisplay::setWindowPosition(const vpImage<vpRGBa> &I, int winx, int winy)
 /*!
   Return the value of the down scale factor applied to the image in order to
   reduce the size of the window used to display the image.
+  When display is not initialized, returns 1.
 
   \param I : Image associated to the display window.
-
-  \exception vpDisplayException::notInitializedError : If the video
-  device is not initialized.
 */
 unsigned int vpDisplay::getDownScalingFactor(const vpImage<vpRGBa> &I) { return vp_display_get_down_scaling_factor(I); }
