@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Matrix SVD decomposition.
  *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpColVector.h>
 #include <visp3/core/vpConfig.h>
@@ -52,29 +49,29 @@
 #include <Eigen/SVD>
 #endif
 
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101) // Require opencv >= 2.1.1
+#if defined(VISP_HAVE_OPENCV) // Require opencv >= 2.1.1
 #include <opencv2/core/core.hpp>
 #endif
 
 #ifdef VISP_HAVE_LAPACK
-#  ifdef VISP_HAVE_GSL
-#    include <gsl/gsl_linalg.h>
-#  endif
-#  ifdef VISP_HAVE_MKL
+#ifdef VISP_HAVE_GSL
+#include <gsl/gsl_linalg.h>
+#endif
+#ifdef VISP_HAVE_MKL
 #include <mkl.h>
 typedef MKL_INT integer;
-#  else
-#    if defined(VISP_HAVE_LAPACK_BUILT_IN)
+#else
+#if defined(VISP_HAVE_LAPACK_BUILT_IN)
 typedef long int integer;
-#    else
+#else
 typedef int integer;
-#    endif
+#endif
 extern "C" int dgesdd_(char *jobz, integer *m, integer *n, double *a, integer *lda, double *s, double *u, integer *ldu,
                        double *vt, integer *ldvt, double *work, integer *lwork, integer *iwork, integer *info);
 
 #include <stdio.h>
 #include <string.h>
-#  endif
+#endif
 #endif
 /*---------------------------------------------------------------------
 
@@ -82,7 +79,7 @@ SVD related functions
 
 ---------------------------------------------------------------------*/
 
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101) // Require opencv >= 2.1.1
+#if defined(VISP_HAVE_OPENCV) // Require opencv >= 2.1.1
 
 /*!
 
@@ -246,12 +243,11 @@ void vpMatrix::svdLapack(vpColVector &w, vpMatrix &V)
     unsigned int nc = getCols();
     unsigned int nr = getRows();
 
-    if(rowNum < colNum) {
+    if (rowNum < colNum) {
       U = this->transpose();
       nc = getRows();
       nr = getCols();
-    }
-    else {
+    } else {
       nc = getCols();
       nr = getRows();
     }
@@ -265,10 +261,9 @@ void vpMatrix::svdLapack(vpColVector &w, vpMatrix &V)
     A.size1 = nr;
     A.size2 = nc;
     A.tda = A.size2;
-    if(rowNum < colNum) {
+    if (rowNum < colNum) {
       A.data = U.data;
-    }
-    else {
+    } else {
       A.data = this->data;
     }
     A.owner = 0;
@@ -291,7 +286,7 @@ void vpMatrix::svdLapack(vpColVector &w, vpMatrix &V)
 
     gsl_linalg_SV_decomp(&A, &V_, &S, work);
 
-    if(rowNum < colNum) {
+    if (rowNum < colNum) {
       (*this) = V.transpose();
       V = U;
     }
