@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * This class implements the B-Spline
  *
- * Authors:
- * Nicolas Melchior
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpBSpline.h>
 #include <visp3/core/vpDebug.h>
@@ -47,9 +44,8 @@
 */
 vpBSpline::vpBSpline()
   : controlPoints(), knots(), p(3), // By default : p=3 for clubic spline
-    crossingPoints()
-{
-}
+  crossingPoints()
+{ }
 
 /*!
   Copy constructor.
@@ -57,13 +53,12 @@ vpBSpline::vpBSpline()
 */
 vpBSpline::vpBSpline(const vpBSpline &bspline)
   : controlPoints(bspline.controlPoints), knots(bspline.knots), p(bspline.p), // By default : p=3 for clubic spline
-    crossingPoints(bspline.crossingPoints)
-{
-}
+  crossingPoints(bspline.crossingPoints)
+{ }
 /*!
   Basic destructor.
 */
-vpBSpline::~vpBSpline() {}
+vpBSpline::~vpBSpline() { }
 
 /*!
   Find the knot interval in which the parameter \f$ l_u \f$ lies. Indeed \f$
@@ -71,9 +66,9 @@ vpBSpline::~vpBSpline() {}
 
    Example : The knot vector is the following \f$ U = \{0,  0 , 1 , 2 ,3 , 3\}
   \f$ with \f$ p \f$ is equal to 1.
-    - For \f$ l_u \f$ equal to 0.5 the method will retun 1.
-    - For \f$ l_u \f$ equal to 2.5 the method will retun 3.
-    - For \f$ l_u \f$ equal to 3 the method will retun 3.
+    - For \f$ l_u \f$ equal to 0.5 the method will return 1.
+    - For \f$ l_u \f$ equal to 2.5 the method will return 3.
+    - For \f$ l_u \f$ equal to 3 the method will return 3.
 
   \param l_u : The knot whose knot interval is seeked.
   \param l_p : Degree of the B-Spline basis functions.
@@ -100,8 +95,7 @@ unsigned int vpBSpline::findSpan(double l_u, unsigned int l_p, std::vector<doubl
   double high = m - l_p;
   double middle = (low + high) / 2.0;
 
-  while (l_u < l_knots[(unsigned int)middle] ||
-         l_u >= l_knots[(unsigned int)middle + 1]) {
+  while (l_u < l_knots[(unsigned int)middle] || l_u >= l_knots[(unsigned int)middle + 1]) {
     if (l_u < l_knots[(unsigned int)vpMath::round(middle)])
       high = middle;
     else
@@ -118,9 +112,9 @@ unsigned int vpBSpline::findSpan(double l_u, unsigned int l_p, std::vector<doubl
 
    Example : The knot vector is the following \f$ U = \{0,  0 , 1 , 2 ,3 , 3\}
   \f$ with \f$ p \f$ is equal to 1.
-    - For \f$ u \f$ equal to 0.5 the method will retun 1.
-    - For \f$ u \f$ equal to 2.5 the method will retun 3.
-    - For \f$ u \f$ equal to 3 the method will retun 3.
+    - For \f$ u \f$ equal to 0.5 the method will return 1.
+    - For \f$ u \f$ equal to 2.5 the method will return 3.
+    - For \f$ u \f$ equal to 3 the method will return 3.
 
   \param u : The knot whose knot interval is seeked.
 
@@ -137,7 +131,7 @@ unsigned int vpBSpline::findSpan(double u) { return findSpan(u, p, knots); }
   \f$, ... , \f$ N_{l_i-k,k}(l_u) \f$, ..., \f$ N_{l_i,k}(l_u) \f$, ... , \f$
   N_{l_i-p,p}(l_u) \f$, ... , \f$ N_{l_i,p}(l_u) \f$
 
-  \param l_u : A real number which is between the extrimities of the knot
+  \param l_u : A real number which is between the extremities of the knot
   vector \param l_i : the number of the knot interval in which \f$ l_u \f$
   lies \param l_p : Degree of the B-Spline basis functions. \param l_knots :
   The knot vector
@@ -191,7 +185,7 @@ vpBasisFunction *vpBSpline::computeBasisFuns(double l_u, unsigned int l_i, unsig
 
   where i the number of the knot interval in which \f$ u \f$ lies.
 
-  \param u : A real number which is between the extrimities of the knot vector
+  \param u : A real number which is between the extremities of the knot vector
 
   \return An array containing the nonvanishing basis functions at \f$ u \f$.
   The size of the array is \f$ p +1 \f$.
@@ -219,7 +213,7 @@ vpBasisFunction *vpBSpline::computeBasisFuns(double u)
   where \f$ i \f$ is the knot interval number in which \f$ u \f$ lies and \f$
   p \f$ is the degree of the B-Spline basis function.
 
-  \param l_u : A real number which is between the extrimities of the knot
+  \param l_u : A real number which is between the extremities of the knot
   vector \param l_i : the number of the knot interval in which \f$ l_u \f$
   lies \param l_p : Degree of the B-Spline basis functions. \param l_der : The
   last derivative to be computed. \param l_knots : The knot vector
@@ -352,7 +346,7 @@ vpBasisFunction **vpBSpline::computeDersBasisFuns(double l_u, unsigned int l_i,
   where \f$ i \f$ is the knot interval number in which \f$ u \f$ lies and \f$
   p \f$ is the degree of the B-Spline basis function.
 
-  \param u : A real number which is between the extrimities of the knot vector
+  \param u : A real number which is between the extremities of the knot vector
   \param der : The last derivative to be computed.
 
   \return the basis functions and their derivatives as an array of size der+1
@@ -371,7 +365,7 @@ vpBasisFunction **vpBSpline::computeDersBasisFuns(double u, unsigned int der)
   Compute the coordinates of a point \f$ C(u) = \sum_{i=0}^n (N_{i,p}(u)P_i)
   \f$ corresponding to the knot \f$ u \f$.
 
-  \param l_u : A real number which is between the extrimities of the knot
+  \param l_u : A real number which is between the extremities of the knot
   vector \param l_i : the number of the knot interval in which \f$ l_u \f$
   lies \param l_p : Degree of the B-Spline basis functions. \param l_knots :
   The knot vector \param l_controlPoints : the list of control points.
@@ -403,7 +397,7 @@ vpImagePoint vpBSpline::computeCurvePoint(double l_u, unsigned int l_i, unsigned
   Compute the coordinates of a point \f$ C(u) = \sum_{i=0}^n (N_{i,p}(u)P_i)
   \f$ corresponding to the knot \f$ u \f$.
 
-  \param u : A real number which is between the extrimities of the knot vector
+  \param u : A real number which is between the extremities of the knot vector
 
   return the coordinates of a point corresponding to the knot \f$ u \f$.
 */
@@ -438,7 +432,7 @@ vpImagePoint vpBSpline::computeCurvePoint(double u)
   where \f$ i \f$ is the knot interval number in which \f$ u \f$ lies and \f$
   p \f$ is the degree of the B-Spline basis function.
 
-  \param l_u : A real number which is between the extrimities of the knot
+  \param l_u : A real number which is between the extremities of the knot
   vector \param l_i : the number of the knot interval in which \f$ l_u \f$
   lies \param l_p : Degree of the B-Spline basis functions. \param l_der : The
   last derivative to be computed. \param l_knots : The knot vector \param
@@ -459,7 +453,8 @@ vpImagePoint *vpBSpline::computeCurveDers(double l_u, unsigned int l_i, unsigned
   if (l_p < l_der) {
     vpTRACE("l_der must be under or equal to l_p");
     du = l_p;
-  } else
+  }
+  else
     du = l_der;
 
   for (unsigned int k = 0; k <= du; k++) {
@@ -487,7 +482,7 @@ vpImagePoint *vpBSpline::computeCurveDers(double l_u, unsigned int l_i, unsigned
   where \f$ i \f$ is the knot interval number in which \f$ u \f$ lies and \f$
   p \f$ is the degree of the B-Spline basis function.
 
-  \param u : A real number which is between the extrimities of the knot vector
+  \param u : A real number which is between the extremities of the knot vector
   \param der : The last derivative to be computed.
 
   \return an array of size der+1 containing the coordinates \f$ C^{(k)}(u) \f$
@@ -504,7 +499,8 @@ vpImagePoint *vpBSpline::computeCurveDers(double u, unsigned int der)
   if (p < der) {
     vpTRACE("der must be under or equal to p");
     du = p;
-  } else
+  }
+  else
     du = der;
 
   for (unsigned int k = 0; k <= du; k++) {
