@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Homogeneous matrix.
  *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpHomogeneousMatrix.cpp
@@ -69,7 +66,10 @@ vpHomogeneousMatrix::vpHomogeneousMatrix() : vpArray2D<double>(4, 4), m_index(0)
   Copy constructor that initialize an homogeneous matrix from another
   homogeneous matrix.
 */
-vpHomogeneousMatrix::vpHomogeneousMatrix(const vpHomogeneousMatrix &M) : vpArray2D<double>(4, 4), m_index(0) { *this = M; }
+vpHomogeneousMatrix::vpHomogeneousMatrix(const vpHomogeneousMatrix &M) : vpArray2D<double>(4, 4), m_index(0)
+{
+  *this = M;
+}
 
 /*!
   Construct an homogeneous matrix from a translation vector and \f$\theta {\bf
@@ -187,7 +187,8 @@ N:
 0  0  0  1
   \endcode
  */
-vpHomogeneousMatrix::vpHomogeneousMatrix(const std::initializer_list<double> &list) : vpArray2D<double>(4, 4), m_index(0)
+vpHomogeneousMatrix::vpHomogeneousMatrix(const std::initializer_list<double> &list)
+  : vpArray2D<double>(4, 4), m_index(0)
 {
   if (list.size() == 12) {
     std::copy(list.begin(), list.end(), data);
@@ -200,37 +201,45 @@ vpHomogeneousMatrix::vpHomogeneousMatrix(const std::initializer_list<double> &li
     std::copy(list.begin(), list.end(), data);
     for (size_t i = 12; i < 15; i++) {
       if (std::fabs(data[i]) > std::numeric_limits<double>::epsilon()) {
-        throw(vpException(vpException::fatalError, "Cannot initialize homogeneous matrix. "
-                          "List element %d (%f) should be 0.", i, data[i]));
+        throw(vpException(vpException::fatalError,
+                          "Cannot initialize homogeneous matrix. "
+                          "List element %d (%f) should be 0.",
+                          i, data[i]));
       }
     }
     if (std::fabs(data[15] - 1.) > std::numeric_limits<double>::epsilon()) {
-      throw(vpException(vpException::fatalError, "Cannot initialize homogeneous matrix. "
-                        "List element 15 (%f) should be 1.", data[15]));
+      throw(vpException(vpException::fatalError,
+                        "Cannot initialize homogeneous matrix. "
+                        "List element 15 (%f) should be 1.",
+                        data[15]));
     }
   }
   else {
-    throw(vpException(vpException::fatalError, "Cannot initialize homogeneous matrix from a list (%d elements) that has not 12 or 16 elements", list.size()));
+    throw(vpException(vpException::fatalError,
+                      "Cannot initialize homogeneous matrix from a list (%d elements) that has not 12 or 16 elements",
+                      list.size()));
   }
 
   if (!isAnHomogeneousMatrix()) {
     if (isAnHomogeneousMatrix(1e-3)) {
       // re-orthogonalize rotation matrix since the input is close to a valid rotation matrix
-      vpMatrix U {
-        {data[0], data[1], data[2]},
-        {data[4], data[5], data[6]},
-        {data[8], data[9], data[10]}
-      };
-      vpColVector w;
-      vpMatrix V;
-      U.svd(w, V);
-      vpMatrix R = U * V.t();
+      vpRotationMatrix R(*this);
+      R.orthogonalize();
 
-      data[0] = R[0][0]; data[1] = R[0][1]; data[2] = R[0][2];
-      data[4] = R[1][0]; data[5] = R[1][1]; data[6] = R[1][2];
-      data[8] = R[2][0]; data[9] = R[2][1]; data[10] = R[2][2];
-    } else {
-      throw(vpException(vpException::fatalError, "Rotation matrix initialization fails since it's elements doesn't represent a rotation matrix"));
+      data[0] = R[0][0];
+      data[1] = R[0][1];
+      data[2] = R[0][2];
+      data[4] = R[1][0];
+      data[5] = R[1][1];
+      data[6] = R[1][2];
+      data[8] = R[2][0];
+      data[9] = R[2][1];
+      data[10] = R[2][2];
+    }
+    else {
+      throw(vpException(
+        vpException::fatalError,
+        "Homogeneous matrix initialization fails since its elements are not valid (rotation part or last row)"));
     }
   }
 }
@@ -618,6 +627,25 @@ vpTranslationVector vpHomogeneousMatrix::operator*(const vpTranslationVector &t)
   return t_out;
 }
 
+/*!
+  Operator that allows to multiply a rotation matrix by a rotation matrix.
+
+  \param[in] R : Rotation matrix.
+
+  \return The product between the homogeneous matrix and the rotation matrix `R`.
+
+  The following snippet shows how to use this method:
+  \code
+  vpHomogeneousMatrix c1_M_c2;
+  vpRotationMatrix c2_R_c3;
+  vpHomogeneousMatrix c1_M_c3 = c1_M_c2 * c2_R_c3;
+  \endcode
+*/
+vpHomogeneousMatrix vpHomogeneousMatrix::operator*(const vpRotationMatrix &R) const
+{
+  return (vpHomogeneousMatrix((*this).getTranslationVector(), (*this).getRotationMatrix() * R));
+}
+
 /*!
   Set homogeneous matrix first element.
 
@@ -660,7 +688,7 @@ N:
 
   \sa operator,()
  */
-vpHomogeneousMatrix& vpHomogeneousMatrix::operator<<(double val)
+vpHomogeneousMatrix &vpHomogeneousMatrix::operator<<(double val)
 {
   m_index = 0;
   data[m_index] = val;
@@ -709,11 +737,14 @@ N:
 
   \sa operator<<()
  */
-vpHomogeneousMatrix& vpHomogeneousMatrix::operator,(double val)
+vpHomogeneousMatrix &vpHomogeneousMatrix::operator,(double val)
 {
-  m_index ++;
+  m_index++;
   if (m_index >= size()) {
-    throw(vpException(vpException::dimensionError, "Cannot set homogenous matrix out of bounds. It has only %d elements while you try to initialize with %d elements", size(), m_index+1));
+    throw(vpException(vpException::dimensionError,
+                      "Cannot set homogenous matrix out of bounds. It has only %d elements while you try to initialize "
+                      "with %d elements",
+                      size(), m_index + 1));
   }
   data[m_index] = val;
   return *this;
@@ -722,15 +753,33 @@ vpHomogeneousMatrix& vpHomogeneousMatrix::operator,(double val)
 /*********************************************************************/
 
 /*!
-  Test if the 3x3 rotational part of the homogeneous matrix is really
-  a rotation matrix.
+  Test if the 3x3 rotational part of the homogeneous matrix is a valid
+  rotation matrix and the last row is equal to [0, 0, 0, 1].
+
+  \return true if the matrix is a homogeneous matrix, false otherwise.
 */
 bool vpHomogeneousMatrix::isAnHomogeneousMatrix(double threshold) const
 {
   vpRotationMatrix R;
   extract(R);
 
-  return R.isARotationMatrix(threshold);
+  const double epsilon = std::numeric_limits<double>::epsilon();
+  return R.isARotationMatrix(threshold) && vpMath::nul((*this)[3][0], epsilon) && vpMath::nul((*this)[3][1], epsilon) &&
+    vpMath::nul((*this)[3][2], epsilon) && vpMath::equal((*this)[3][3], 1.0, epsilon);
+}
+
+/*!
+ * Check if the homogeneous transformation matrix doesn't have a value NaN.
+ * \return true when no NaN found, false otherwise.
+ */
+bool vpHomogeneousMatrix::isValid() const
+{
+  for (unsigned int i = 0; i < size(); i++) {
+    if (vpMath::isNaN(data[i])) {
+      return false;
+    }
+  }
+  return true;
 }
 
 /*!
@@ -903,7 +952,8 @@ void vpHomogeneousMatrix::save(std::ofstream &f) const
 {
   if (!f.fail()) {
     f << *this;
-  } else {
+  }
+  else {
     throw(vpException(vpException::ioError, "Cannot save homogeneous matrix: ostream not open"));
   }
 }
@@ -934,11 +984,31 @@ void vpHomogeneousMatrix::load(std::ifstream &f)
         f >> (*this)[i][j];
       }
     }
-  } else {
+  }
+  else {
     throw(vpException(vpException::ioError, "Cannot load homogeneous matrix: ifstream not open"));
   }
 }
 
+/*!
+  Perform orthogonalization of the rotation part of the homogeneous transformation.
+ */
+void vpHomogeneousMatrix::orthogonalizeRotation()
+{
+  vpRotationMatrix R(*this);
+  R.orthogonalize();
+
+  data[0] = R[0][0];
+  data[1] = R[0][1];
+  data[2] = R[0][2];
+  data[4] = R[1][0];
+  data[5] = R[1][1];
+  data[6] = R[1][2];
+  data[8] = R[2][0];
+  data[9] = R[2][1];
+  data[10] = R[2][2];
+}
+
 //! Print the matrix as a pose vector \f$({\bf t}^T \theta {\bf u}^T)\f$
 void vpHomogeneousMatrix::print() const
 {
@@ -1038,12 +1108,66 @@ vpColVector vpHomogeneousMatrix::getCol(unsigned int j) const
   return c;
 }
 
+/*!
+ * Compute the transformation between two point clouds.
+ * \param[in] p : First point cloud.
+ * \param[in] q : Second point cloud.
+ * \return The homogeneous transformation \f${^p}{\bf M}_q\f$.
+ */
+vpHomogeneousMatrix vpHomogeneousMatrix::compute3d3dTransformation(const std::vector<vpPoint> &p, const std::vector<vpPoint> &q)
+{
+  const double N = static_cast<double>(p.size());
+
+  vpColVector p_bar(3, 0.0);
+  vpColVector q_bar(3, 0.0);
+  for (size_t i = 0; i < p.size(); i++) {
+    for (unsigned int j = 0; j < 3; j++) {
+      p_bar[j] += p.at(i).oP[j];
+      q_bar[j] += q.at(i).oP[j];
+    }
+  }
+
+  for (unsigned int j = 0; j < 3; j++) {
+    p_bar[j] /= N;
+    q_bar[j] /= N;
+  }
+
+  vpMatrix pc(static_cast<unsigned int>(p.size()), 3);
+  vpMatrix qc(static_cast<unsigned int>(q.size()), 3);
+
+  for (unsigned int i = 0; i < static_cast<unsigned int>(p.size()); i++) {
+    for (unsigned int j = 0; j < 3; j++) {
+      pc[i][j] = p.at(i).oP[j] - p_bar[j];
+      qc[i][j] = q.at(i).oP[j] - q_bar[j];
+    }
+  }
+
+  const vpMatrix pct_qc = pc.t() * qc;
+  vpMatrix U = pct_qc, V;
+  vpColVector W;
+  U.svd(W, V);
+
+  vpMatrix Vt = V.t();
+  vpMatrix R = U * Vt;
+  if (R.det() < 0) {
+    Vt[2][0] *= -1;
+    Vt[2][1] *= -1;
+    Vt[2][2] *= -1;
+
+    R = U * Vt;
+  }
+
+  const vpColVector t = p_bar - R * q_bar;
+
+  return vpHomogeneousMatrix(vpTranslationVector(t), vpRotationMatrix(R));
+}
+
 /*!
   Compute the Euclidean mean of the homogeneous matrices.
   The Euclidean mean of the rotation matrices is computed following Moakher's method (SIAM 2002).
 
   \param[in] vec_M : Set of homogeneous matrices.
-  \return The Euclidian mean of the homogeneous matrices.
+  \return The Euclidean mean of the homogeneous matrices.
 
   \sa vpTranslationVector::mean(), vpRotationMatrix::mean()
  */
@@ -1054,8 +1178,8 @@ vpHomogeneousMatrix vpHomogeneousMatrix::mean(const std::vector<vpHomogeneousMat
   vpRotationMatrix R;
   for (size_t i = 0; i < vec_M.size(); i++) {
     R = vec_M[i].getRotationMatrix();
-    meanR += (vpMatrix) R;
-    meanT += (vpColVector) vec_M[i].getTranslationVector();
+    meanR += (vpMatrix)R;
+    meanT += (vpColVector)vec_M[i].getTranslationVector();
   }
   meanR /= static_cast<double>(vec_M.size());
   meanT /= static_cast<double>(vec_M.size());
@@ -1064,14 +1188,15 @@ vpHomogeneousMatrix vpHomogeneousMatrix::mean(const std::vector<vpHomogeneousMat
   vpMatrix M, U, V;
   vpColVector sv;
   meanR.pseudoInverse(M, sv, 1e-6, U, V);
-  double det = sv[0]*sv[1]*sv[2];
+  double det = sv[0] * sv[1] * sv[2];
   if (det > 0) {
     meanR = U * V.t();
   }
   else {
-    vpMatrix D(3,3);
+    vpMatrix D(3, 3);
     D = 0.0;
-    D[0][0] = D[1][1] = 1.0; D[2][2] = -1;
+    D[0][0] = D[1][1] = 1.0;
+    D[2][2] = -1;
     meanR = U * D * V.t();
   }
 
@@ -1093,3 +1218,35 @@ vpHomogeneousMatrix vpHomogeneousMatrix::mean(const std::vector<vpHomogeneousMat
 void vpHomogeneousMatrix::setIdentity() { eye(); }
 
 #endif //#if defined(VISP_BUILD_DEPRECATED_FUNCTIONS)
+
+#ifdef VISP_HAVE_NLOHMANN_JSON
+const std::string vpHomogeneousMatrix::jsonTypeName = "vpHomogeneousMatrix";
+#include <visp3/core/vpJsonParsing.h>
+void vpHomogeneousMatrix::convert_to_json(nlohmann::json &j) const
+{
+  const vpArray2D<double> *asArray = (vpArray2D<double>*) this;
+  to_json(j, *asArray);
+  j["type"] = vpHomogeneousMatrix::jsonTypeName;
+}
+
+void vpHomogeneousMatrix::parse_json(const nlohmann::json &j)
+{
+  vpArray2D<double> *asArray = (vpArray2D<double>*) this;
+  if (j.is_object() && j.contains("type")) { // Specific conversions
+    const bool converted = convertFromTypeAndBuildFrom<vpHomogeneousMatrix, vpPoseVector>(j, *this);
+    if (!converted) {
+      from_json(j, *asArray);
+    }
+  }
+  else { // Generic 2D array conversion
+    from_json(j, *asArray);
+  }
+
+  if (getCols() != 4 && getRows() != 4) {
+    throw vpException(vpException::badValue, "From JSON, tried to read something that is not a 4x4 matrix");
+  }
+  if (!isAnHomogeneousMatrix()) {
+    throw vpException(vpException::badValue, "From JSON read a non homogeneous matrix into a vpHomogeneousMatrix");
+  }
+}
+#endif
