@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Rotation matrix.
  *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpRotationMatrix.cpp
@@ -118,16 +115,24 @@ R:
   \endcode
   \sa operator<<()
  */
-vpRotationMatrix& vpRotationMatrix::operator=(const std::initializer_list<double> &list)
+vpRotationMatrix &vpRotationMatrix::operator=(const std::initializer_list<double> &list)
 {
   if (dsize != static_cast<unsigned int>(list.size())) {
-    throw(vpException(vpException::dimensionError, "Cannot set a 3-by-3 rotation matrix from a %d-elements list of doubles."));
+    throw(vpException(vpException::dimensionError,
+                      "Cannot set a 3-by-3 rotation matrix from a %d-elements list of doubles."));
   }
 
   std::copy(list.begin(), list.end(), data);
 
-  if (! isARotationMatrix() ) {
-    throw(vpException(vpException::fatalError, "Rotation matrix initialization fails since it's elements doesn't represent a rotation matrix"));
+  if (!isARotationMatrix()) {
+    if (isARotationMatrix(1e-3)) {
+      orthogonalize();
+    }
+    else {
+      throw(vpException(
+        vpException::fatalError,
+        "Rotation matrix initialization fails since its elements do not represent a valid rotation matrix"));
+    }
   }
 
   return *this;
@@ -165,8 +170,8 @@ vpRotationMatrix &vpRotationMatrix::operator=(const vpMatrix &M)
 
   if (isARotationMatrix() == false) {
     throw(vpException(vpException::fatalError, "Cannot set a rotation matrix "
-                                               "from a matrix that is not a "
-                                               "rotation matrix"));
+                      "from a matrix that is not a "
+                      "rotation matrix"));
   }
 
   return *this;
@@ -199,7 +204,7 @@ R:
 
   \sa operator,()
  */
-vpRotationMatrix& vpRotationMatrix::operator<<(double val)
+vpRotationMatrix &vpRotationMatrix::operator<<(double val)
 {
   m_index = 0;
   data[m_index] = val;
@@ -233,11 +238,14 @@ R:
 
   \sa operator<<()
  */
-vpRotationMatrix& vpRotationMatrix::operator,(double val)
+vpRotationMatrix &vpRotationMatrix::operator,(double val)
 {
-  m_index ++;
+  m_index++;
   if (m_index >= size()) {
-    throw(vpException(vpException::dimensionError, "Cannot set rotation matrix out of bounds. It has only %d elements while you try to initialize with %d elements", size(), m_index+1));
+    throw(vpException(vpException::dimensionError,
+                      "Cannot set rotation matrix out of bounds. It has only %d elements while you try to initialize "
+                      "with %d elements",
+                      size(), m_index + 1));
   }
   data[m_index] = val;
   return *this;
@@ -260,19 +268,23 @@ vpRotationMatrix vpRotationMatrix::operator*(const vpRotationMatrix &R) const
   }
   return p;
 }
+
 /*!
   Operator that allows to multiply a rotation matrix by a 3-by-3 matrix.
   Allows for example to multiply a rotation matrix by a skew matrix.
+
+  \param[in] M : 3-by-3 matrix.
+
+  \return The product between the rotation matrix and the 3-by-3 matrix `M`.
+  \exception vpException::dimensionError : If \e M is not  a 3-by-3 dimension matrix.
+
+  The following snippet shows how to use this method:
   \code
   vpRotationMatrix R;
   vpTranslationVector t;
   vpMatrix M = t.skew();
   vpMatrix RM = R * M;
   \endcode
-
-  \exception vpException::dimensionError : If \e M is not
-  a 3-by-3 dimension matrix.
-
 */
 vpMatrix vpRotationMatrix::operator*(const vpMatrix &M) const
 {
@@ -293,6 +305,25 @@ vpMatrix vpRotationMatrix::operator*(const vpMatrix &M) const
   return p;
 }
 
+/*!
+  Operator that allows to multiply a rotation matrix by a homogeneous matrix.
+
+  \param[in] M : Homogeneous matrix.
+
+  \return The product between the rotation matrix and the homogeneous matrix `M`.
+
+  The following snippet shows how to use this method:
+  \code
+  vpRotationMatrix c1_R_c2;
+  vpHomogeneousMatrix c2_M_c3;
+  vpHomogeneousMatrix c1_M_c3 = c1_R_c2 * c2_M_c3;
+  \endcode
+*/
+vpHomogeneousMatrix vpRotationMatrix::operator*(const vpHomogeneousMatrix &M) const
+{
+  return (vpHomogeneousMatrix(*this * M.getTranslationVector(), *this * M.getRotationMatrix()));
+}
+
 /*!
 
   Operator that allows to multiply a rotation matrix by a 3 dimension
@@ -394,6 +425,9 @@ vpRotationMatrix &vpRotationMatrix::operator*=(double x)
 
 /*!
   Test if the rotation matrix is really a rotation matrix.
+
+  \return true if the matrix is a rotation matrix, false otherwise.
+
 */
 bool vpRotationMatrix::isARotationMatrix(double threshold) const
 {
@@ -411,7 +445,8 @@ bool vpRotationMatrix::isARotationMatrix(double threshold) const
         if (fabs(RtR[i][j] - 1) > threshold) {
           isRotation = false;
         }
-      } else {
+      }
+      else {
         if (fabs(RtR[i][j]) > threshold) {
           isRotation = false;
         }
@@ -468,7 +503,10 @@ vpRotationMatrix::vpRotationMatrix(const vpPoseVector &p) : vpArray2D<double>(3,
   Construct a 3-by-3 rotation matrix from \f$ R(z,y,z) \f$ Euler angle
   representation.
  */
-vpRotationMatrix::vpRotationMatrix(const vpRzyzVector &euler) : vpArray2D<double>(3, 3), m_index(0) { buildFrom(euler); }
+vpRotationMatrix::vpRotationMatrix(const vpRzyzVector &euler) : vpArray2D<double>(3, 3), m_index(0)
+{
+  buildFrom(euler);
+}
 
 /*!
   Construct a 3-by-3 rotation matrix from \f$ R(x,y,z) \f$ Euler angle
@@ -525,10 +563,18 @@ R:
 -1  0  0
   \endcode
  */
-vpRotationMatrix::vpRotationMatrix(const std::initializer_list<double> &list) : vpArray2D<double>(3, 3, list), m_index(0)
+vpRotationMatrix::vpRotationMatrix(const std::initializer_list<double> &list)
+  : vpArray2D<double>(3, 3, list), m_index(0)
 {
-  if (! isARotationMatrix() ) {
-    throw(vpException(vpException::fatalError, "Rotation matrix initialization fails since it's elements doesn't represent a rotation matrix"));
+  if (!isARotationMatrix()) {
+    if (isARotationMatrix(1e-3)) {
+      orthogonalize();
+    }
+    else {
+      throw(vpException(
+        vpException::fatalError,
+        "Rotation matrix initialization fails since its elements do not represent a valid rotation matrix"));
+    }
   }
 }
 #endif
@@ -816,8 +862,8 @@ vpThetaUVector vpRotationMatrix::getThetaUVector()
 /*!
   Extract a column vector from a rotation matrix.
   \warning All the indexes start from 0 in this function.
-  \param j : Index of the column to extract. If j=0, the first column is
-extracted. \return The extracted column vector.
+  \param j : Index of the column to extract. If j=0, the first column is extracted.
+  \return The extracted column vector.
 
   The following example shows how to use this function:
   \code
@@ -832,7 +878,7 @@ int main()
   std::cout << "Last column: \n" << r << std::endl;
 }
   \endcode
-It produces the following output:
+  It produces the following output:
   \code
 Last column:
 0
@@ -852,10 +898,11 @@ vpColVector vpRotationMatrix::getCol(unsigned int j) const
 }
 
 /*!
-  Compute the Euclidean mean of the rotation matrices extracted from a vector of homogeneous matrices following Moakher's method (SIAM 2002).
+  Compute the Euclidean mean of the rotation matrices extracted from a vector of homogeneous matrices following
+  Moakher's method (SIAM 2002).
 
   \param[in] vec_M : Set of homogeneous matrices.
-  \return The Euclidian mean of the rotation matrices.
+  \return The Euclidean mean of the rotation matrices.
 
   \sa vpTranslationVector::mean()
  */
@@ -865,7 +912,7 @@ vpRotationMatrix vpRotationMatrix::mean(const std::vector<vpHomogeneousMatrix> &
   vpRotationMatrix R;
   for (size_t i = 0; i < vec_M.size(); i++) {
     R = vec_M[i].getRotationMatrix();
-    meanR += (vpMatrix) R;
+    meanR += (vpMatrix)R;
   }
   meanR /= static_cast<double>(vec_M.size());
 
@@ -873,14 +920,15 @@ vpRotationMatrix vpRotationMatrix::mean(const std::vector<vpHomogeneousMatrix> &
   vpMatrix M, U, V;
   vpColVector sv;
   meanR.pseudoInverse(M, sv, 1e-6, U, V);
-  double det = sv[0]*sv[1]*sv[2];
+  double det = sv[0] * sv[1] * sv[2];
   if (det > 0) {
     meanR = U * V.t();
   }
   else {
-    vpMatrix D(3,3);
+    vpMatrix D(3, 3);
     D = 0.0;
-    D[0][0] = D[1][1] = 1.0; D[2][2] = -1;
+    D[0][0] = D[1][1] = 1.0;
+    D[2][2] = -1;
     meanR = U * D * V.t();
   }
 
@@ -892,7 +940,7 @@ vpRotationMatrix vpRotationMatrix::mean(const std::vector<vpHomogeneousMatrix> &
   Compute the Euclidean mean of the rotation matrices following Moakher's method (SIAM 2002).
 
   \param[in] vec_R : Set of rotation matrices.
-  \return The Euclidian mean of the rotation matrices.
+  \return The Euclidean mean of the rotation matrices.
 
   \sa vpTranslationVector::mean()
  */
@@ -901,7 +949,7 @@ vpRotationMatrix vpRotationMatrix::mean(const std::vector<vpRotationMatrix> &vec
   vpMatrix meanR(3, 3);
   vpRotationMatrix R;
   for (size_t i = 0; i < vec_R.size(); i++) {
-    meanR += (vpMatrix) vec_R[i];
+    meanR += (vpMatrix)vec_R[i];
   }
   meanR /= static_cast<double>(vec_R.size());
 
@@ -909,14 +957,15 @@ vpRotationMatrix vpRotationMatrix::mean(const std::vector<vpRotationMatrix> &vec
   vpMatrix M, U, V;
   vpColVector sv;
   meanR.pseudoInverse(M, sv, 1e-6, U, V);
-  double det = sv[0]*sv[1]*sv[2];
+  double det = sv[0] * sv[1] * sv[2];
   if (det > 0) {
     meanR = U * V.t();
   }
   else {
-    vpMatrix D(3,3);
+    vpMatrix D(3, 3);
     D = 0.0;
-    D[0][0] = D[1][1] = 1.0; D[2][2] = -1;
+    D[0][0] = D[1][1] = 1.0;
+    D[2][2] = -1;
     meanR = U * D * V.t();
   }
 
@@ -924,6 +973,38 @@ vpRotationMatrix vpRotationMatrix::mean(const std::vector<vpRotationMatrix> &vec
   return R;
 }
 
+/*!
+  Perform rotation matrix orthogonalization.
+ */
+void vpRotationMatrix::orthogonalize()
+{
+  vpMatrix U = *this;
+  vpColVector w;
+  vpMatrix V;
+  U.svd(w, V);
+  vpMatrix Vt = V.t();
+  vpMatrix R = U * Vt;
+
+  double det = R.det();
+  if (det < 0) {
+    Vt[2][0] *= -1;
+    Vt[2][1] *= -1;
+    Vt[2][2] *= -1;
+
+    R = U * Vt;
+  }
+
+  data[0] = R[0][0];
+  data[1] = R[0][1];
+  data[2] = R[0][2];
+  data[3] = R[1][0];
+  data[4] = R[1][1];
+  data[5] = R[1][2];
+  data[6] = R[2][0];
+  data[7] = R[2][1];
+  data[8] = R[2][2];
+}
+
 #if defined(VISP_BUILD_DEPRECATED_FUNCTIONS)
 
 /*!
