@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Theta U parameterization for the rotation.
  *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
 \file vpThetaUVector.cpp
@@ -54,10 +51,7 @@ vpThetaUVector::vpThetaUVector() : vpRotationVector(3) {}
 /*! Copy constructor. */
 vpThetaUVector::vpThetaUVector(const vpThetaUVector &tu) : vpRotationVector(tu) {}
 /*! Copy constructor from a 3-dimension vector. */
-vpThetaUVector::vpThetaUVector(const vpColVector &tu) : vpRotationVector(3)
-{
-  buildFrom(tu);
-}
+vpThetaUVector::vpThetaUVector(const vpColVector &tu) : vpRotationVector(3) { buildFrom(tu); }
 /*!
   Initialize a \f$\theta {\bf u}\f$ vector from an homogeneous matrix.
 */
@@ -104,18 +98,12 @@ int main()
 tu: 0  1.570796327  3.141592654
   \endcode
 */
-vpThetaUVector::vpThetaUVector(double tux, double tuy, double tuz) : vpRotationVector(3)
-{
-  buildFrom(tux, tuy, tuz);
-}
+vpThetaUVector::vpThetaUVector(double tux, double tuy, double tuz) : vpRotationVector(3) { buildFrom(tux, tuy, tuz); }
 
 /*!
   Build a \f$\theta {\bf u}\f$ vector from a vector of 3 angles in radian.
 */
-vpThetaUVector::vpThetaUVector(const std::vector<double> &tu)
-{
-  buildFrom(tu);
-}
+vpThetaUVector::vpThetaUVector(const std::vector<double> &tu) { buildFrom(tu); }
 
 /*!
   Converts an homogeneous matrix into a \f$\theta {\bf u}\f$ vector.
@@ -165,38 +153,42 @@ vpThetaUVector vpThetaUVector::buildFrom(const vpRotationMatrix &R)
   } else /* theta near PI */
   {
     double x = 0;
-    if ( (R[0][0]-c) > std::numeric_limits<double>::epsilon() )
-      x = sqrt((R[0][0]-c)/(1-c));
+    if ((R[0][0] - c) > std::numeric_limits<double>::epsilon())
+      x = sqrt((R[0][0] - c) / (1 - c));
 
     double y = 0;
-    if ( (R[1][1]-c) > std::numeric_limits<double>::epsilon() )
-      y = sqrt((R[1][1]-c)/(1-c));
+    if ((R[1][1] - c) > std::numeric_limits<double>::epsilon())
+      y = sqrt((R[1][1] - c) / (1 - c));
 
     double z = 0;
-    if ( (R[2][2]-c) > std::numeric_limits<double>::epsilon() )
-      z = sqrt((R[2][2]-c)/(1-c));
+    if ((R[2][2] - c) > std::numeric_limits<double>::epsilon())
+      z = sqrt((R[2][2] - c) / (1 - c));
 
-    if(x > y && x > z)
-    {
-        if ((R[2][1]-R[1][2]) < 0) x = -x;
-        if(vpMath::sign(x)*vpMath::sign(y) != vpMath::sign(R[0][1]+R[1][0])) y = -y;
-        if(vpMath::sign(x)*vpMath::sign(z) != vpMath::sign(R[0][2]+R[2][0])) z = -z;
+    if (x > y && x > z) {
+      if ((R[2][1] - R[1][2]) < 0)
+        x = -x;
+      if (vpMath::sign(x) * vpMath::sign(y) != vpMath::sign(R[0][1] + R[1][0]))
+        y = -y;
+      if (vpMath::sign(x) * vpMath::sign(z) != vpMath::sign(R[0][2] + R[2][0]))
+        z = -z;
+    } else if (y > z) {
+      if ((R[0][2] - R[2][0]) < 0)
+        y = -y;
+      if (vpMath::sign(y) * vpMath::sign(x) != vpMath::sign(R[1][0] + R[0][1]))
+        x = -x;
+      if (vpMath::sign(y) * vpMath::sign(z) != vpMath::sign(R[1][2] + R[2][1]))
+        z = -z;
+    } else {
+      if ((R[1][0] - R[0][1]) < 0)
+        z = -z;
+      if (vpMath::sign(z) * vpMath::sign(x) != vpMath::sign(R[2][0] + R[0][2]))
+        x = -x;
+      if (vpMath::sign(z) * vpMath::sign(y) != vpMath::sign(R[2][1] + R[1][2]))
+        y = -y;
     }
-    else if(y > z)
-    {
-        if((R[0][2]-R[2][0]) < 0) y = -y;
-        if(vpMath::sign(y)*vpMath::sign(x) != vpMath::sign(R[1][0]+R[0][1])) x = -x;
-        if(vpMath::sign(y)*vpMath::sign(z) != vpMath::sign(R[1][2]+R[2][1])) z = -z;
-    }
-    else
-    {
-        if((R[1][0]-R[0][1]) < 0) z = -z;
-        if(vpMath::sign(z)*vpMath::sign(x) != vpMath::sign(R[2][0]+R[0][2])) x = -x;
-        if(vpMath::sign(z)*vpMath::sign(y) != vpMath::sign(R[2][1]+R[1][2])) y = -y;
-    }
-    data[0] = theta*x;
-    data[1] = theta*y;
-    data[2] = theta*z;
+    data[0] = theta * x;
+    data[1] = theta * y;
+    data[2] = theta * z;
   }
 
   return *this;
@@ -451,6 +443,27 @@ void vpThetaUVector::buildFrom(double tux, double tuy, double tuz)
   data[2] = tuz;
 }
 
+/*!
+  Perform rotation chaining / rotation multiplication using the theta.u rotation representation.
+  See: <a href="https://math.stackexchange.com/a/1978136">this answer</a> for some details about the maths.
+*/
+vpThetaUVector vpThetaUVector::operator*(const vpThetaUVector &tu_b) const
+{
+  double a_2 = getTheta() / 2;
+  vpColVector a_hat = getU();
+  double b_2 = tu_b.getTheta() / 2;
+  vpColVector b_hat = tu_b.getU();
+
+  vpColVector a_hat_sin_2 = a_hat * std::sin(a_2);
+  vpColVector b_hat_sin_2 = b_hat * std::sin(b_2);
+  double c = 2 * std::acos(std::cos(a_2) * std::cos(b_2) - vpColVector::dotProd(a_hat_sin_2, b_hat_sin_2));
+  vpColVector d = std::sin(a_2) * std::cos(b_2) * a_hat + std::cos(a_2) * std::sin(b_2) * b_hat +
+                  std::sin(a_2) * std::sin(b_2) * vpColVector::crossProd(a_hat, b_hat);
+  d = c * d / std::sin(c / 2);
+
+  return vpThetaUVector(d);
+}
+
 #if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
 /*!
   Set vector from a list of 3 double angle values in radians.
@@ -472,7 +485,10 @@ tu: 3.141592654  0  1.570796327
 vpThetaUVector &vpThetaUVector::operator=(const std::initializer_list<double> &list)
 {
   if (list.size() > size()) {
-    throw(vpException(vpException::dimensionError, "Cannot set theta u vector out of bounds. It has only %d values while you try to initialize with %d values", size(), list.size()));
+    throw(vpException(
+        vpException::dimensionError,
+        "Cannot set theta u vector out of bounds. It has only %d values while you try to initialize with %d values",
+        size(), list.size()));
   }
   std::copy(list.begin(), list.end(), data);
   return *this;
