@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * Translation vector.
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <stdio.h>
 #include <string.h>
@@ -68,7 +64,10 @@ vpTranslationVector::vpTranslationVector(double tx, double ty, double tz) : vpAr
   \param M : Homogeneous matrix where translations are in meters.
 
 */
-vpTranslationVector::vpTranslationVector(const vpHomogeneousMatrix &M) : vpArray2D<double>(3, 1), m_index(0) { M.extract(*this); }
+vpTranslationVector::vpTranslationVector(const vpHomogeneousMatrix &M) : vpArray2D<double>(3, 1), m_index(0)
+{
+  M.extract(*this);
+}
 
 /*!
   Construct a translation vector \f$ \bf t \f$ from the translation contained
@@ -94,7 +93,7 @@ vpTranslationVector::vpTranslationVector(const vpPoseVector &p) : vpArray2D<doub
   vpTranslationVector t2(t1);    // t2 is now a copy of t1
   \endcode
 */
-vpTranslationVector::vpTranslationVector(const vpTranslationVector &tv) : vpArray2D<double>(tv), m_index(0) {}
+vpTranslationVector::vpTranslationVector(const vpTranslationVector &tv) : vpArray2D<double>(tv), m_index(0) { }
 
 /*!
   Construct a translation vector \f$ \bf t \f$ from a 3-dimension column
@@ -446,7 +445,8 @@ vpTranslationVector &vpTranslationVector::operator=(const vpColVector &tv)
   if (rowNum != k) {
     try {
       resize(k, 1);
-    } catch (...) {
+    }
+    catch (...) {
       throw;
     }
   }
@@ -474,7 +474,8 @@ vpTranslationVector &vpTranslationVector::operator=(const vpTranslationVector &t
   if (rowNum != k) {
     try {
       resize(k, 1);
-    } catch (...) {
+    }
+    catch (...) {
       throw;
     }
   }
@@ -526,7 +527,10 @@ t: 0  0.1  0.5
 vpTranslationVector &vpTranslationVector::operator=(const std::initializer_list<double> &list)
 {
   if (list.size() > size()) {
-    throw(vpException(vpException::dimensionError, "Cannot set translation vector out of bounds. It has only %d values while you try to initialize with %d values", size(), list.size()));
+    throw(vpException(
+      vpException::dimensionError,
+      "Cannot set translation vector out of bounds. It has only %d values while you try to initialize with %d values",
+      size(), list.size()));
   }
   std::copy(list.begin(), list.end(), data);
   return *this;
@@ -556,7 +560,7 @@ t: 0  0.1  0.5
 
   \sa operator,()
  */
-vpTranslationVector& vpTranslationVector::operator<<(double val)
+vpTranslationVector &vpTranslationVector::operator<<(double val)
 {
   m_index = 0;
   data[m_index] = val;
@@ -586,11 +590,14 @@ t: 0  0.1  0.5
 
   \sa operator<<()
  */
-vpTranslationVector& vpTranslationVector::operator,(double val)
+vpTranslationVector &vpTranslationVector::operator,(double val)
 {
-  m_index ++;
+  m_index++;
   if (m_index >= size()) {
-    throw(vpException(vpException::dimensionError, "Cannot set translation vector out of bounds. It has only %d values while you try to initialize with %d values", size(), m_index+1));
+    throw(vpException(
+      vpException::dimensionError,
+      "Cannot set translation vector out of bounds. It has only %d values while you try to initialize with %d values",
+      size(), m_index + 1));
   }
   data[m_index] = val;
   return *this;
@@ -702,25 +709,26 @@ vpRowVector vpTranslationVector::t() const
   return v;
 }
 
+#if defined(VISP_BUILD_DEPRECATED_FUNCTIONS)
+
 /*!
   \deprecated This function is deprecated. You should rather use frobeniusNorm().
 
-  Compute and return the Euclidean norm also called Fronebius nom of the translation vector
+  Compute and return the Euclidean norm also called Frobenius nom of the translation vector
   \f$ ||t|| = \sqrt{ \sum{t_{i}^2}} \f$.
 
   \return The Euclidean norm if the vector is initialized, 0 otherwise.
 
   \sa frobeniusNorm()
 */
-double vpTranslationVector::euclideanNorm() const
-{
-  return frobeniusNorm();
-}
+double vpTranslationVector::euclideanNorm() const { return frobeniusNorm(); }
+
+#endif
 
 /*!
-  Compute and return the Fronebius norm \f$ ||t|| = \sqrt{ \sum{t_{i}^2}} \f$.
+  Compute and return the Frobenius norm \f$ ||t|| = \sqrt{ \sum{t_{i}^2}} \f$.
 
-  \return The Fronebius norm if the vector is initialized, 0 otherwise.
+  \return The Frobenius norm if the vector is initialized, 0 otherwise.
 */
 double vpTranslationVector::frobeniusNorm() const
 {
@@ -751,7 +759,7 @@ double vpTranslationVector::sumSquare() const
   Compute the Euclidean mean of the translation vector extracted from a vector of homogeneous matrices.
 
   \param[in] vec_M : Set of homogeneous matrices.
-  \return The Euclidian mean of the translation vectors.
+  \return The Euclidean mean of the translation vectors.
 
   \sa vpRotationMatrix::mean()
  */
@@ -759,7 +767,7 @@ vpTranslationVector vpTranslationVector::mean(const std::vector<vpHomogeneousMat
 {
   vpColVector meanT(3);
   for (size_t i = 0; i < vec_M.size(); i++) {
-    meanT += (vpColVector) vec_M[i].getTranslationVector();
+    meanT += (vpColVector)vec_M[i].getTranslationVector();
   }
   meanT /= static_cast<double>(vec_M.size());
 
@@ -771,7 +779,7 @@ vpTranslationVector vpTranslationVector::mean(const std::vector<vpHomogeneousMat
   Compute the Euclidean mean of a vector of translation vector.
 
   \param[in] vec_t : Set of translation vectors.
-  \return The Euclidian mean of the translation vectors.
+  \return The Euclidean mean of the translation vectors.
 
   \sa vpRotationMatrix::mean()
  */
@@ -779,7 +787,7 @@ vpTranslationVector vpTranslationVector::mean(const std::vector<vpTranslationVec
 {
   vpColVector meanT(3);
   for (size_t i = 0; i < vec_t.size(); i++) {
-    meanT += (vpColVector) vec_t[i];
+    meanT += (vpColVector)vec_t[i];
   }
   meanT /= static_cast<double>(vec_t.size());
 
