@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,13 +31,15 @@
  * Description:
  * CPU features (hardware capabilities).
  *
- *****************************************************************************/
+*****************************************************************************/
 
 #include "x86/cpu_x86.h"
+#include <Simd/SimdLib.hpp>
 #include <visp3/core/vpCPUFeatures.h>
 
 namespace vpCPUFeatures
 {
+// TODO: try to refactor to keep only SimdCpuInfo code and remove cpu_x86 code?
 static const FeatureDetector::cpu_x86 cpu_features;
 
 bool checkSSE2() { return cpu_features.HW_SSE2; }
@@ -54,5 +56,13 @@ bool checkAVX() { return cpu_features.HW_AVX; }
 
 bool checkAVX2() { return cpu_features.HW_AVX2; }
 
+size_t getCPUCacheL1() { return SimdCpuInfo(SimdCpuInfoCacheL1); }
+
+size_t getCPUCacheL2() { return SimdCpuInfo(SimdCpuInfoCacheL2); }
+
+size_t getCPUCacheL3() { return SimdCpuInfo(SimdCpuInfoCacheL3); }
+
+bool checkNeon() { return SimdCpuInfo(SimdCpuInfoNeon) != 0; }
+
 void printCPUInfo() { cpu_features.print(); }
 } // namespace vpCPUFeatures
