@@ -1,3 +1,33 @@
+/*
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
+ *
+ * This software is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * See the file LICENSE.txt at the root directory of this source
+ * distribution for additional information about the GNU GPL.
+ *
+ * For using ViSP with software that can not be combined with the GNU
+ * GPL, please contact Inria about acquiring a ViSP Professional
+ * Edition License.
+ *
+ * See https://visp.inria.fr for more information.
+ *
+ * This software was developed at:
+ * Inria Rennes - Bretagne Atlantique
+ * Campus Universitaire de Beaulieu
+ * 35042 Rennes Cedex
+ * France
+ *
+ * If you have questions regarding the use of this file, please contact
+ * Inria at visp@inria.fr
+ *
+ * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
+ * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
 /* cpu_x86.cpp
  *
  * Author           : Alexander J. Yee
@@ -22,7 +52,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////
 #if defined(__x86_64__) || defined(_M_X64) || defined(__i386) || defined(_M_IX86)
-#if defined(_WIN32) && ( !defined(__MINGW32__) || ( !defined(__i386) && !defined(_M_IX86) ) )
+#if defined(_WIN32) && (!defined(__MINGW32__) || (!defined(__i386) && !defined(_M_IX86)))
 #include "cpu_x86_Windows.ipp"
 #elif defined(__GNUC__) || defined(__clang__)
 #include "cpu_x86_Linux.ipp"
@@ -132,7 +162,8 @@ void cpu_x86::detect_host()
   std::string vendor(get_vendor_string());
   if (vendor == "GenuineIntel") {
     Vendor_Intel = true;
-  } else if (vendor == "AuthenticAMD") {
+  }
+  else if (vendor == "AuthenticAMD") {
     Vendor_AMD = true;
   }
 
