@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,20 +31,80 @@
  * Description:
  * Defines a generic 2D polygon.
  *
- * Author:
- * Amaury Dame
- * Nicolas Melchior
- * Romain Tallonneau
- *
- *****************************************************************************/
+*****************************************************************************/
 
+// System
 #include <limits>
 #include <set>
+
+// Core
 #include <visp3/core/vpDisplay.h>
 #include <visp3/core/vpException.h>
 #include <visp3/core/vpMeterPixelConversion.h>
 #include <visp3/core/vpPolygon.h>
 #include <visp3/core/vpUniRand.h>
+
+// Local helper
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC)
+
+#include <opencv2/imgproc/imgproc.hpp>
+
+/*!
+ * Compute convex hull corners.
+ *
+ * \param[in] ips : List of 2D points.
+ */
+template <typename IpContainer> std::vector<vpImagePoint> convexHull(const IpContainer &ips)
+{
+  if (ips.size() == 0) {
+    throw vpException(vpException::badValue,
+                      "Convex Hull can not be computed as the input does not contain any image point.");
+  }
+
+  // Visp -> CV
+  std::vector<cv::Point> cv_pts;
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_14)
+  std::transform(cbegin(ips), cend(ips), std::back_inserter(cv_pts), [](const vpImagePoint &ip) {
+    return cv::Point(static_cast<int>(ip.get_u()), static_cast<int>(ip.get_v()));
+  });
+#elif (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
+  std::transform(begin(ips), end(ips), std::back_inserter(cv_pts), [](const vpImagePoint &ip) {
+    return cv::Point(static_cast<int>(ip.get_u()), static_cast<int>(ip.get_v()));
+  });
+#else
+  for (typename IpContainer::const_iterator it = ips.begin(); it != ips.end(); ++it) {
+    cv_pts.push_back(cv::Point(static_cast<int>(it->get_u()), static_cast<int>(it->get_v())));
+  }
+#endif
+
+  // Get convex hull from OpenCV
+  std::vector<cv::Point> cv_conv_hull_corners;
+  cv::convexHull(cv_pts, cv_conv_hull_corners);
+
+  // CV -> Visp
+  std::vector<vpImagePoint> conv_hull_corners;
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_14)
+  std::transform(cbegin(cv_conv_hull_corners), cend(cv_conv_hull_corners), std::back_inserter(conv_hull_corners),
+                 [](const cv::Point &pt) {
+                   return vpImagePoint{static_cast<double>(pt.y), static_cast<double>(pt.x)};
+                 });
+#elif (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
+  std::transform(begin(cv_conv_hull_corners), end(cv_conv_hull_corners), std::back_inserter(conv_hull_corners),
+                 [](const cv::Point &pt) {
+                   return vpImagePoint{static_cast<double>(pt.y), static_cast<double>(pt.x)};
+                 });
+#else
+  for (std::vector<cv::Point>::const_iterator it = cv_conv_hull_corners.begin(); it != cv_conv_hull_corners.end();
+       ++it) {
+    conv_hull_corners.push_back(vpImagePoint(static_cast<double>(it->y), static_cast<double>(it->x)));
+  }
+#endif
+
+  return conv_hull_corners;
+}
+
+#endif
+
 /*!
    Default constructor that creates an empty polygon.
 */
@@ -127,8 +187,20 @@ vpPolygon &vpPolygon::operator=(const vpPolygon &poly)
   clockwise).
 
   \param corners : The corners of the polyon.
+  \param create_convex_hull: Create a convex hull from the given corners.
 */
-void vpPolygon::buildFrom(const std::vector<vpImagePoint> &corners) { init(corners); }
+void vpPolygon::buildFrom(const std::vector<vpImagePoint> &corners, const bool create_convex_hull)
+{
+  if (create_convex_hull) {
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC)
+    init(convexHull(corners));
+#else
+    vpException(vpException::notImplementedError, "Cannot build a convex hull without OpenCV imgproc module");
+#endif
+  } else {
+    init(corners);
+  }
+}
 
 /*!
   Initialises the polygon thanks to the collection of 2D points (in pixel).
@@ -137,8 +209,20 @@ void vpPolygon::buildFrom(const std::vector<vpImagePoint> &corners) { init(corne
   clockwise).
 
   \param corners : The corners of the polyon.
+  \param create_convex_hull: Create a convex hull from the given corners.
 */
-void vpPolygon::buildFrom(const std::list<vpImagePoint> &corners) { init(corners); }
+void vpPolygon::buildFrom(const std::list<vpImagePoint> &corners, const bool create_convex_hull)
+{
+  if (create_convex_hull) {
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC)
+    init(convexHull(corners));
+#else
+    vpException(vpException::notImplementedError, "Cannot build a convex hull without OpenCV imgproc module");
+#endif
+  } else {
+    init(corners);
+  }
+}
 
 /*!
   Initialises the triangle thanks to the collection of 2D points (in meter).
@@ -151,14 +235,16 @@ void vpPolygon::buildFrom(const std::list<vpImagePoint> &corners) { init(corners
   \param corners : The corners of the polyon.
   \param cam : The camera parameters used to convert the coordinates from
   meter to pixel.
+  \param create_convex_hull: Create a convex hull from the given corners.
 */
-void vpPolygon::buildFrom(const std::vector<vpPoint> &corners, const vpCameraParameters &cam)
+void vpPolygon::buildFrom(const std::vector<vpPoint> &corners, const vpCameraParameters &cam,
+                          const bool create_convex_hull)
 {
   std::vector<vpImagePoint> ipCorners(corners.size());
   for (unsigned int i = 0; i < corners.size(); ++i) {
     vpMeterPixelConversion::convertPoint(cam, corners[i].get_x(), corners[i].get_y(), ipCorners[i]);
   }
-  buildFrom(ipCorners);
+  buildFrom(ipCorners, create_convex_hull);
 }
 
 /*!
@@ -220,7 +306,7 @@ void vpPolygon::initClick(const vpImage<vpRGBa> &I, unsigned int size, const vpC
 }
 
 /*!
-  Intialises the polygon using the collection of image points. This method
+  Initialises the polygon using the collection of image points. This method
   computes some internal variables such as center, area, ...
 
   \warning the corners must be ordered (either clockwise or counter
@@ -240,7 +326,7 @@ void vpPolygon::init(const std::vector<vpImagePoint> &corners)
 }
 
 /*!
-  Intialises the polygon using the collection of image points. This method
+  Initialises the polygon using the collection of image points. This method
   computes some internal variables such as center, area, ...
 
   \warning the corners must be ordered (either clockwise or counter
@@ -315,12 +401,12 @@ bool vpPolygon::isInside(const vpImagePoint &ip, const PointInPolygonMethod &met
   bool test = false;
   switch (method) {
   case PnPolySegmentIntersection: {
-    vpImagePoint infPoint(100000, 100000); // take a point at 'inifinity'
+    vpImagePoint infPoint(100000, 100000); // take a point at 'infinity'
     vpUniRand generator;
     infPoint.set_i(infPoint.get_i() + 1000 * generator());
     infPoint.set_j(infPoint.get_j() + 1000 * generator()); // we add random since it appears that
                                                            // sometimes infPoint may cause a
-                                                           // degenerated case (so realucnch and
+                                                           // degenerated case (so relaunch and
                                                            // hope that result will be
                                                            // different).
 
