@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Gray level histogram manipulation.
  *
- * Author:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpHistogram.cpp
@@ -55,7 +52,8 @@
 
 namespace
 {
-struct Histogram_Param_t {
+struct vpHistogram_Param_t
+{
   unsigned int m_start_index;
   unsigned int m_end_index;
 
@@ -63,14 +61,13 @@ struct Histogram_Param_t {
   unsigned int *m_histogram;
   const vpImage<unsigned char> *m_I;
 
-  Histogram_Param_t() : m_start_index(0), m_end_index(0), m_lut(), m_histogram(NULL), m_I(NULL) {}
+  vpHistogram_Param_t() : m_start_index(0), m_end_index(0), m_lut(), m_histogram(NULL), m_I(NULL) { }
 
-  Histogram_Param_t(unsigned int start_index, unsigned int end_index, const vpImage<unsigned char> *const I)
+  vpHistogram_Param_t(unsigned int start_index, unsigned int end_index, const vpImage<unsigned char> *const I)
     : m_start_index(start_index), m_end_index(end_index), m_lut(), m_histogram(NULL), m_I(I)
-  {
-  }
+  { }
 
-  ~Histogram_Param_t()
+  ~vpHistogram_Param_t()
   {
     if (m_histogram != NULL) {
       delete[] m_histogram;
@@ -80,7 +77,7 @@ struct Histogram_Param_t {
 
 vpThread::Return computeHistogramThread(vpThread::Args args)
 {
-  Histogram_Param_t *histogram_param = static_cast<Histogram_Param_t *>(args);
+  vpHistogram_Param_t *histogram_param = static_cast<vpHistogram_Param_t *>(args);
   unsigned int start_index = histogram_param->m_start_index;
   unsigned int end_index = histogram_param->m_end_index;
 
@@ -90,12 +87,6 @@ vpThread::Return computeHistogramThread(vpThread::Args args)
   unsigned char *ptrEnd = (unsigned char *)(I->bitmap) + end_index;
   unsigned char *ptrCurrent = ptrStart;
 
-  //    while(ptrCurrent != ptrEnd) {
-  //      histogram_param->m_histogram[ histogram_param->m_lut[ *ptrCurrent ]
-  //      ] ++;
-  //      ++ptrCurrent;
-  //    }
-
   if (end_index - start_index >= 8) {
     // Unroll loop version
     for (; ptrCurrent <= ptrEnd - 8;) {
@@ -131,7 +122,7 @@ vpThread::Return computeHistogramThread(vpThread::Args args)
 
   return 0;
 }
-}
+} // namespace
 #endif
 
 bool compare_vpHistogramPeak(vpHistogramPeak first, vpHistogramPeak second);
@@ -280,12 +271,13 @@ void vpHistogram::calculate(const vpImage<unsigned char> &I, unsigned int nbins,
       histogram[lut[*ptrCurrent]]++;
       ++ptrCurrent;
     }
-  } else {
+  }
+  else {
 #if defined(VISP_HAVE_PTHREAD) || (defined(_WIN32) && !defined(WINRT_8_0))
     // Multi-threads
 
     std::vector<vpThread *> threadpool;
-    std::vector<Histogram_Param_t *> histogramParams;
+    std::vector<vpHistogram_Param_t *> histogramParams;
 
     unsigned int image_size = I.getSize();
     unsigned int step = image_size / nbThreads;
@@ -299,7 +291,7 @@ void vpHistogram::calculate(const vpImage<unsigned char> &I, unsigned int nbins,
         end_index = start_index + last_step;
       }
 
-      Histogram_Param_t *histogram_param = new Histogram_Param_t(start_index, end_index, &I);
+      vpHistogram_Param_t *histogram_param = new vpHistogram_Param_t(start_index, end_index, &I);
       histogram_param->m_histogram = new unsigned int[size];
       memset(histogram_param->m_histogram, 0, size * sizeof(unsigned int));
       memcpy(histogram_param->m_lut, lut, 256 * sizeof(unsigned int));
@@ -388,18 +380,16 @@ void vpHistogram::display(const vpImage<unsigned char> &I, const vpColor &color,
 
 /*!
 
-  Smoothes the histogram and returns it.
+  Smoothes the histogram.
 
   A simple average scheme is used where each value \f$h(i)\f$ in the
   histogram is replaced by the average of itself and the neighbours.
 
   \f[h(i) = \sum_{j=i-\frac{fsize}{2}}^{i+\frac{fsize}{2}} h(j) \f]
 
-  \param fsize : Filter size. Corresponds to the number of values
+  \param[in] fsize : Filter size. Corresponds to the number of values
   around each point used to compute the mean value.
 
-  \return Smoothed histogram.
-
   \exception vpImageException::notInitializedError : Histogram array
   not initialsed. Means that the histogram was not calculated before.
 
@@ -612,11 +602,6 @@ bool vpHistogram::getPeaks(unsigned char dist, vpHistogramPeak &peakl, vpHistogr
   if (prev_slope > 0)
     peak[nbpeaks++] = (unsigned char)(size - 1);
 
-  //   vpTRACE("nb peaks: %d", nbpeaks);
-  //   for (unsigned i=0; i < nbpeaks; i ++)
-  //     vpTRACE("peak %d: pos %d value: %d", i, peak[i], histogram[ peak[i]
-  //     ]);
-
   // Get the global maximum
   index_highest_peak = 0;
   for (unsigned int i = 0; i < nbpeaks; i++) {
@@ -625,10 +610,6 @@ bool vpHistogram::getPeaks(unsigned char dist, vpHistogramPeak &peakl, vpHistogr
     }
   }
 
-  //   vpTRACE("highest peak index: %d pos: %d value: %d",
-  // 	  index_highest_peak, peak[index_highest_peak],
-  // 	  histogram[ peak[index_highest_peak] ]);
-
   maxprof = 0;
   index_second_peak = index_highest_peak;
 
@@ -661,15 +642,13 @@ bool vpHistogram::getPeaks(unsigned char dist, vpHistogramPeak &peakl, vpHistogr
       }
     }
   }
-  //   vpTRACE("second peak index: %d pos: %d value: %d",
-  // 	  index_second_peak, peak[index_second_peak],
-  // 	  histogram[ peak[index_second_peak] ]);
 
   // Determine position of the first and second highest peaks
   if (peak[index_highest_peak] < peak[index_second_peak]) {
     peakr.set(peak[index_second_peak], histogram[peak[index_second_peak]]);
     peakl.set(peak[index_highest_peak], histogram[peak[index_highest_peak]]);
-  } else {
+  }
+  else {
     peakl.set(peak[index_second_peak], histogram[peak[index_second_peak]]);
     peakr.set(peak[index_highest_peak], histogram[peak[index_highest_peak]]);
   }
@@ -708,7 +687,8 @@ bool vpHistogram::getPeaks(unsigned char dist, vpHistogramPeak &peakl, vpHistogr
     delete[] peak;
 
     return false;
-  } else {
+  }
+  else {
     mini = sumindmini / nbmini; // mean
     valey.set((unsigned char)mini, histogram[mini]);
 
@@ -806,7 +786,8 @@ bool vpHistogram::getValey(const vpHistogramPeak &peak1, const vpHistogramPeak &
   if (peak1.getLevel() > peak2.getLevel()) {
     peakl = peak2;
     peakr = peak1;
-  } else {
+  }
+  else {
     peakl = peak1;
     peakr = peak2;
   }
@@ -837,7 +818,8 @@ bool vpHistogram::getValey(const vpHistogramPeak &peak1, const vpHistogramPeak &
     valey.set(0, 0);
 
     return false;
-  } else {
+  }
+  else {
     unsigned int minipos = sumindmini / nbmini; // position of the minimum
 
     valey.set((unsigned char)minipos, histogram[minipos]);
@@ -890,16 +872,6 @@ unsigned vpHistogram::getValey(unsigned char dist, const vpHistogramPeak &peak,
       /* nbpeaks = */ getPeaks(peaks);
     }
 
-    //     if (1) {
-    //       //      vpTRACE("nb peaks: %d", nbpeaks);
-    //       peaks.front();
-    //       for (unsigned i=0; i < nbpeaks; i ++) {
-    // 	vpHistogramPeak p = peaks.value();
-    // // 	vpTRACE("peak index %d: pos %d value: %d",
-    // // 		i, p.getLevel(), p.getValue());
-    // 	peaks.next();
-    //       }
-    //     }
     // Go to the requested peak in the list
     std::list<vpHistogramPeak>::const_iterator it;
     unsigned index = 0;
@@ -916,8 +888,9 @@ unsigned vpHistogram::getValey(unsigned char dist, const vpHistogramPeak &peak,
       // No chance to get a peak on the left
       // should not occur !
       peakl.set(0, 0);
-    } else {
-      // search for the nearest peak on the left that matches the distance
+    }
+    else {
+   // search for the nearest peak on the left that matches the distance
       std::list<vpHistogramPeak>::const_iterator lit; // left iterator
       for (lit = peaks.begin(); lit != it; ++lit) {
         if (abs((*lit).getLevel() - peak.getLevel()) > dist) {
@@ -950,7 +923,8 @@ unsigned vpHistogram::getValey(unsigned char dist, const vpHistogramPeak &peak,
     if (nbmini == 0) {
       valeyl.set(0, 0);
       ret &= 0x01;
-    } else {
+    }
+    else {
       unsigned int minipos = sumindmini / nbmini; // position of the minimum
       valeyl.set((unsigned char)minipos, histogram[minipos]);
       ret &= 0x11;
@@ -964,13 +938,11 @@ unsigned vpHistogram::getValey(unsigned char dist, const vpHistogramPeak &peak,
     }
     // Go to the requested peak in the list
     std::list<vpHistogramPeak>::const_iterator it;
-    unsigned index = 0;
     for (it = peaks.begin(); it != peaks.end(); ++it) {
       if (peak == *it) {
         // we are on the peak.
         break;
       }
-      index++;
     }
 
     bool found = false;
@@ -1007,7 +979,8 @@ unsigned vpHistogram::getValey(unsigned char dist, const vpHistogramPeak &peak,
     if (nbmini == 0) {
       valeyr.set((unsigned char)(size - 1), 0);
       ret &= 0x10;
-    } else {
+    }
+    else {
       unsigned int minipos = sumindmini / nbmini; // position of the minimum
       valeyr.set((unsigned char)minipos, histogram[minipos]);
       ret &= 0x11;
