@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Aurelien Yol
  *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpNetwork.h>
 
@@ -43,11 +43,11 @@
 
 vpNetwork::vpNetwork()
   : emitter(), receptor_list(), readFileDescriptor(), socketMax(0), request_list(), max_size_message(999999),
-    separator("[*@*]"), beginning("[*start*]"), end("[*end*]"), param_sep("[*|*]"), currentMessageReceived(), tv(),
-    tv_sec(0), tv_usec(10), verboseMode(false)
+  separator("[*@*]"), beginning("[*start*]"), end("[*end*]"), param_sep("[*|*]"), currentMessageReceived(), tv(),
+  tv_sec(0), tv_usec(10), verboseMode(false)
 {
   tv.tv_sec = tv_sec;
-#if TARGET_OS_IPHONE
+#ifdef TARGET_OS_IPHONE
   tv.tv_usec = (int)tv_usec;
 #else
   tv.tv_usec = tv_usec;
@@ -92,8 +92,8 @@ void vpNetwork::addDecodingRequest(vpRequest *req)
 
   if (alreadyHas)
     std::cout << "Server already has one request with the similar ID. "
-                 "Request hasn't been added."
-              << std::endl;
+    "Request hasn't been added."
+    << std::endl;
   else
     request_list.push_back(req);
 }
@@ -265,7 +265,7 @@ int vpNetwork::sendAndEncodeRequestTo(vpRequest &req, const unsigned int &dest)
 }
 
 /*!
-  Receive requests untils there is requests to receive.
+  Receive requests until there is requests to receive.
 
   \warning Requests will be received but not decoded.
 
@@ -280,12 +280,12 @@ int vpNetwork::sendAndEncodeRequestTo(vpRequest &req, const unsigned int &dest)
 */
 std::vector<int> vpNetwork::receiveRequest()
 {
-  _receiveRequest();
-  return _handleRequests();
+  privReceiveRequest();
+  return privHandleRequests();
 }
 
 /*!
-  Receives requests, from a specific emitter, untils there is request to
+  Receives requests, from a specific emitter, until there is request to
   receive.
 
   \warning Requests will be received but not decoded.
@@ -303,8 +303,8 @@ std::vector<int> vpNetwork::receiveRequest()
 */
 std::vector<int> vpNetwork::receiveRequestFrom(const unsigned int &receptorEmitting)
 {
-  _receiveRequestFrom(receptorEmitting);
-  return _handleRequests();
+  privReceiveRequestFrom(receptorEmitting);
+  return privHandleRequests();
 }
 
 /*!
@@ -327,8 +327,8 @@ std::vector<int> vpNetwork::receiveRequestFrom(const unsigned int &receptorEmitt
 */
 int vpNetwork::receiveRequestOnce()
 {
-  _receiveRequestOnce();
-  return _handleFirstRequest();
+  privReceiveRequestOnce();
+  return privHandleFirstRequest();
 }
 
 /*!
@@ -354,12 +354,12 @@ int vpNetwork::receiveRequestOnce()
 */
 int vpNetwork::receiveRequestOnceFrom(const unsigned int &receptorEmitting)
 {
-  _receiveRequestOnceFrom(receptorEmitting);
-  return _handleFirstRequest();
+  privReceiveRequestOnceFrom(receptorEmitting);
+  return privHandleFirstRequest();
 }
 
 /*!
-  Receives and decode requests untils there is requests to receive.
+  Receives and decode requests until there is requests to receive.
 
   \warning Requests will be received but not decoded.
 
@@ -383,7 +383,7 @@ std::vector<int> vpNetwork::receiveAndDecodeRequest()
 }
 
 /*!
-  Receives and decode requests, from a specific emitter, untils there is
+  Receives and decode requests, from a specific emitter, until there is
   request to receive.
 
   \warning Requests will be received but not decoded.
@@ -483,14 +483,14 @@ int vpNetwork::receiveAndDecodeRequestOnceFrom(const unsigned int &receptorEmitt
   \return : The list of index corresponding to the requests that have been
   handled.
 */
-std::vector<int> vpNetwork::_handleRequests()
+std::vector<int> vpNetwork::privHandleRequests()
 {
   std::vector<int> resIndex;
-  int index = _handleFirstRequest();
+  int index = privHandleFirstRequest();
 
   while (index != -1) {
     resIndex.push_back(index);
-    index = _handleFirstRequest();
+    index = privHandleFirstRequest();
   }
 
   return resIndex;
@@ -506,7 +506,7 @@ std::vector<int> vpNetwork::_handleRequests()
 
   \return : The index of the request that has been handled.
 */
-int vpNetwork::_handleFirstRequest()
+int vpNetwork::privHandleFirstRequest()
 {
   size_t indStart = currentMessageReceived.find(beginning);
   size_t indSep = currentMessageReceived.find(separator);
@@ -587,7 +587,7 @@ int vpNetwork::_handleFirstRequest()
 }
 
 /*!
-  Receive requests untils there is requests to receive.
+  Receive requests until there is requests to receive.
 
   \warning Requests will be received but not decoded.
 
@@ -600,14 +600,14 @@ int vpNetwork::_handleFirstRequest()
   \sa vpNetwork::receiveAndDecodeRequestOnce()
   \sa vpNetwork::receiveAndDecodeRequestOnceFrom()
 */
-void vpNetwork::_receiveRequest()
+void vpNetwork::privReceiveRequest()
 {
-  while (_receiveRequestOnce() > 0) {
+  while (privReceiveRequestOnce() > 0) {
   };
 }
 
 /*!
-  Receives requests, from a specific emitter, untils there is request to
+  Receives requests, from a specific emitter, until there is request to
   receive.
 
   \warning Requests will be received but not decoded.
@@ -623,9 +623,9 @@ void vpNetwork::_receiveRequest()
 
   \param receptorEmitting : Index of the receptor emitting the message
 */
-void vpNetwork::_receiveRequestFrom(const unsigned int &receptorEmitting)
+void vpNetwork::privReceiveRequestFrom(const unsigned int &receptorEmitting)
 {
-  while (_receiveRequestOnceFrom(receptorEmitting) > 0) {
+  while (privReceiveRequestOnceFrom(receptorEmitting) > 0) {
   };
 }
 
@@ -647,7 +647,7 @@ void vpNetwork::_receiveRequestFrom(const unsigned int &receptorEmitting)
 
   \return The number of bytes received, -1 if an error occured.
 */
-int vpNetwork::_receiveRequestOnce()
+int vpNetwork::privReceiveRequestOnce()
 {
   if (receptor_list.size() == 0) {
     if (verboseMode)
@@ -656,7 +656,7 @@ int vpNetwork::_receiveRequestOnce()
   }
 
   tv.tv_sec = tv_sec;
-#if TARGET_OS_IPHONE
+#ifdef TARGET_OS_IPHONE
   tv.tv_usec = (int)tv_usec;
 #else
   tv.tv_usec = tv_usec;
@@ -680,10 +680,12 @@ int vpNetwork::_receiveRequestOnce()
     if (verboseMode)
       vpERROR_TRACE("Select error");
     return -1;
-  } else if (value == 0) {
-    // Timeout
+  }
+  else if (value == 0) {
+ // Timeout
     return 0;
-  } else {
+  }
+  else {
     for (unsigned int i = 0; i < receptor_list.size(); i++) {
       if (FD_ISSET((unsigned int)receptor_list[i].socketFileDescriptorReceptor, &readFileDescriptor)) {
         char *buf = new char[max_size_message];
@@ -698,7 +700,8 @@ int vpNetwork::_receiveRequestOnce()
           receptor_list.erase(receptor_list.begin() + (int)i);
           delete[] buf;
           return numbytes;
-        } else {
+        }
+        else {
           std::string returnVal(buf, (unsigned int)numbytes);
           currentMessageReceived.append(returnVal);
         }
@@ -732,7 +735,7 @@ int vpNetwork::_receiveRequestOnce()
 
   \return The number of bytes received, -1 if an error occured.
 */
-int vpNetwork::_receiveRequestOnceFrom(const unsigned int &receptorEmitting)
+int vpNetwork::privReceiveRequestOnceFrom(const unsigned int &receptorEmitting)
 {
   int size = (int)receptor_list.size();
   int sizeMinusOne = (int)receptor_list.size() - 1;
@@ -743,7 +746,7 @@ int vpNetwork::_receiveRequestOnceFrom(const unsigned int &receptorEmitting)
   }
 
   tv.tv_sec = tv_sec;
-#if TARGET_OS_IPHONE
+#ifdef TARGET_OS_IPHONE
   tv.tv_usec = (int)tv_usec;
 #else
   tv.tv_usec = tv_usec;
@@ -760,10 +763,12 @@ int vpNetwork::_receiveRequestOnceFrom(const unsigned int &receptorEmitting)
     if (verboseMode)
       vpERROR_TRACE("Select error");
     return -1;
-  } else if (value == 0) {
-    // Timeout
+  }
+  else if (value == 0) {
+ // Timeout
     return 0;
-  } else {
+  }
+  else {
     if (FD_ISSET((unsigned int)receptor_list[receptorEmitting].socketFileDescriptorReceptor, &readFileDescriptor)) {
       char *buf = new char[max_size_message];
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
@@ -774,11 +779,12 @@ int vpNetwork::_receiveRequestOnceFrom(const unsigned int &receptorEmitting)
 #endif
       if (numbytes <= 0) {
         std::cout << "Disconnected : " << inet_ntoa(receptor_list[receptorEmitting].receptorAddress.sin_addr)
-                  << std::endl;
+          << std::endl;
         receptor_list.erase(receptor_list.begin() + (int)receptorEmitting);
         delete[] buf;
         return numbytes;
-      } else {
+      }
+      else {
         std::string returnVal(buf, (unsigned int)numbytes);
         currentMessageReceived.append(returnVal);
       }
@@ -790,6 +796,6 @@ int vpNetwork::_receiveRequestOnceFrom(const unsigned int &receptorEmitting)
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_core.a(vpNetwork.cpp.o) has no symbols
-void dummy_vpNetwork(){};
+// Work around to avoid warning: libvisp_core.a(vpNetwork.cpp.o) has no symbols
+void dummy_vpNetwork() { };
 #endif
