@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,13 +31,12 @@
  * Description:
  * TCP Server
  *
- * Authors:
- * Aurelien Yol
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpServer.h>
 
+#include <sstream>
+
 // inet_ntop() not supported on win XP
 #ifdef VISP_HAVE_FUNC_INET_NTOP
 
@@ -158,13 +157,13 @@ bool vpServer::start()
 
   if (bindResult < 0) {
     std::cout << "Error id : " << bindResult << std::endl;
-    std::string errorMessage("vpServer::vpServer(), cannot bind to port");
-    char posrtNumberString[32];
-    sprintf(posrtNumberString, "%d", port);
-    errorMessage += " ";
-    errorMessage += posrtNumberString;
-    errorMessage += " The port may be already used.";
-    vpERROR_TRACE(errorMessage.c_str());
+    std::stringstream errorMessage;
+    errorMessage << "vpServer::vpServer(), cannot bind to port";
+    errorMessage << " ";
+    errorMessage << port;
+    errorMessage << " The port may be already used.";
+
+    vpERROR_TRACE(errorMessage.str().c_str());
     return false;
   }
 
@@ -208,7 +207,7 @@ bool vpServer::checkForConnections()
     }
 
   tv.tv_sec = tv_sec;
-#if TARGET_OS_IPHONE
+#ifdef TARGET_OS_IPHONE
   tv.tv_usec = (int)tv_usec;
 #else
   tv.tv_usec = tv_usec;
@@ -289,6 +288,6 @@ bool vpServer::checkForConnections()
 void vpServer::print() { vpNetwork::print("Client"); }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_core.a(vpServer.cpp.o) has no symbols
+// Work around to avoid warning: libvisp_core.a(vpServer.cpp.o) has no symbols
 void dummy_vpServer(){};
 #endif
