@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,7 +31,7 @@
  * Description:
  * UDP Server
  *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <cstring>
 #include <sstream>
@@ -42,25 +42,25 @@
 #ifdef VISP_HAVE_FUNC_INET_NTOP
 
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-#  include <arpa/inet.h>
-#  include <errno.h>
-#  include <netdb.h>
-#  include <unistd.h>
-#  define DWORD int
-#  define WSAGetLastError() strerror(errno)
+#include <arpa/inet.h>
+#include <errno.h>
+#include <netdb.h>
+#include <unistd.h>
+#define DWORD int
+#define WSAGetLastError() strerror(errno)
 #else
-#  if defined(__MINGW32__)
-#    ifdef _WIN32_WINNT
+#if defined(__MINGW32__)
+#ifdef _WIN32_WINNT
 // Undef  _WIN32_WINNT to avoid a warning (_WIN32_WINNT redefinition) with mingw
-#      undef _WIN32_WINNT
-#      define _WIN32_WINNT _WIN32_WINNT_VISTA // 0x0600
+#undef _WIN32_WINNT
+#define _WIN32_WINNT _WIN32_WINNT_VISTA // 0x0600
 // Without re-defining _WIN32_WINNT = _WIN32_WINNT_VISTA there is a build issue with mingw:
 // vpUDPServer.cpp:254:23: error: 'inet_ntop' was not declared in this scope
 // const char *ptr = inet_ntop(AF_INET, (void *)&m_clientAddress.sin_addr, result, sizeof(result));
 // vpUDPServer.cpp:254:23: note: suggested alternative: 'inet_ntoa'
-#    endif
-#  endif
-#  include <Ws2tcpip.h>
+#endif
+#endif
+#include <Ws2tcpip.h>
 #endif
 
 #include <visp3/core/vpUDPServer.h>
@@ -230,8 +230,8 @@ int vpUDPServer::receive(std::string &msg, std::string &hostInfo, int timeoutMs)
   if (retval > 0) {
 /* recvfrom: receive a UDP datagram from a client */
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-    int length = static_cast<int>(recvfrom(m_socketFileDescriptor, m_buf, sizeof(m_buf), 0, (struct sockaddr *)&m_clientAddress,
-                                           (socklen_t *)&m_clientLength));
+    int length = static_cast<int>(recvfrom(m_socketFileDescriptor, m_buf, sizeof(m_buf), 0,
+                                           (struct sockaddr *)&m_clientAddress, (socklen_t *)&m_clientLength));
 #else
     int length =
         recvfrom(m_socketFileDescriptor, m_buf, sizeof(m_buf), 0, (struct sockaddr *)&m_clientAddress, &m_clientLength);
@@ -323,8 +323,8 @@ int vpUDPServer::send(const std::string &msg, const std::string &hostname, int p
 
 /* send the message to the client */
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX
-  return static_cast<int>(sendto(m_socketFileDescriptor, msg.c_str(), msg.size(), 0, (struct sockaddr *)&m_clientAddress,
-                                 m_clientLength));
+  return static_cast<int>(
+      sendto(m_socketFileDescriptor, msg.c_str(), msg.size(), 0, (struct sockaddr *)&m_clientAddress, m_clientLength));
 #else
   return sendto(m_socketFileDescriptor, msg.c_str(), (int)msg.size(), 0, (struct sockaddr *)&m_clientAddress,
                 m_clientLength);
@@ -332,6 +332,6 @@ int vpUDPServer::send(const std::string &msg, const std::string &hostname, int p
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_core.a(vpUDPServer.cpp.o) has no symbols
+// Work around to avoid warning: libvisp_core.a(vpUDPServer.cpp.o) has no symbols
 void dummy_vpUDPServer(){};
 #endif
