@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,19 +31,16 @@
  * Description:
  * Time management and measurement.
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <ctime>
 
 #include <visp3/core/vpDebug.h>
 #include <visp3/core/vpTime.h>
 
-//https://devblogs.microsoft.com/cppblog/c14-stl-features-fixes-and-breaking-changes-in-visual-studio-14-ctp1/
-#if VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11 && (defined(_MSC_VER) && _MSC_VER >= 1900 /* VS2015 */ || !defined(_MSC_VER))
+// https://devblogs.microsoft.com/cppblog/c14-stl-features-fixes-and-breaking-changes-in-visual-studio-14-ctp1/
+#if VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11 &&                                                                       \
+    (defined(_MSC_VER) && _MSC_VER >= 1900 /* VS2015 */ || !defined(_MSC_VER))
 #define USE_CXX11_CHRONO 1
 #else
 #define USE_CXX11_CHRONO 0
@@ -102,7 +99,8 @@ double measureTimeMicros()
   QueryPerformanceFrequency(&frequency);
   if (frequency.QuadPart == 0) {
     return (timeGetTime());
-  } else {
+  }
+  else {
     QueryPerformanceCounter(&time);
     return (double)(1000000.0 * time.QuadPart / frequency.QuadPart);
   }
@@ -135,7 +133,8 @@ double measureTimeMs()
   QueryPerformanceFrequency(&frequency);
   if (frequency.QuadPart == 0) {
     return (timeGetTime());
-  } else {
+  }
+  else {
     QueryPerformanceCounter(&time);
     return (double)(1000.0 * time.QuadPart / frequency.QuadPart);
   }
@@ -283,57 +282,57 @@ void sleepMs(double t)
 }
 
 /*!
-   Return a string containing date and time.
+  Return a string containing date and time.
 
-   \param[in] format : The string format supported by strftime() function that represents the time.
-   The default format is the following \c "%Y/%m/%d %H:%M:%S".
-   This string contains any combination of special format specifiers given in the next table:
-   | specifier | Replaced by                                          | Example                  |
-   |-----------|------------------------------------------------------|--------------------------|
-   | %%a	     | Abbreviated weekday name *                           | Thu                      |
-   | %%A	     | Full weekday name *                                  | Thursday                 |
-   | %%b	     | Abbreviated month name *                             | Aug                      |
-   | %%B	     | Full month name *                                    | August                   |
-   | %%c	     | Date and time representation *                       | Thu Aug 23 14:55:02 2001 |
-   | %%C	     | Year divided by 100 and truncated to integer (00-99) | 20                       |
-   | %%d	     | Day of the month, zero-padded (01-31)                | 23                       |
-   | %%D	     | Short MM/DD/YY date, equivalent to %m/%d/%y          | 08/23/01                 |
-   | %%e	     | Day of the month, space-padded ( 1-31)               | 23                       |
-   | %%F	     | Short YYYY-MM-DD date, equivalent to %Y-%m-%d        | 2001-08-23               |
-   | %%g	     | Week-based year, last two digits (00-99)             | 01                       |
-   | %%G	     | Week-based year                                      | 2001                     |
-   | %%h	     | Abbreviated month name * (same as %b)                | Aug                      |
-   | %%H	     | Hour in 24h format (00-23)                           | 14                       |
-   | %%I	     | Hour in 12h format (01-12)                           | 02                       |
-   | %%j	     | Day of the year (001-366)                            | 235                      |
-   | %%m	     | Month as a decimal number (01-12)                    | 08                       |
-   | %%M	     | Minute (00-59)                                       | 55                       |
-   | %%n       | New-line character ('\\n')	                          |                          |
-   | %%p       | AM or PM designation	                                | PM                       |
-   | %%r       | 12-hour clock time *	                                | 02:55:02 pm              |
-   | %%R       | 24-hour HH:MM time, equivalent to %H:%M              | 14:55                    |
-   | %%S       | Second (00-61)                                       | 02                       |
-   | %%t       | Horizontal-tab character ('\\t')                     |                          |
-   | %%T       | ISO 8601 time format (HH:MM:SS), equivalent to %H:%M:%S | 14:55:02              |
-   | %%u       | ISO 8601 weekday as number with Monday as 1 (1-7)    | 4                        |
-   | %%U       | Week number with the first Sunday as the first day of week one (00-53) | 33     |
-   | %%V       | ISO 8601 week number (00-53)                         | 34                       |
-   | %%w       | Weekday as a decimal number with Sunday as 0 (0-6)   | 4                        |
-   | %%W       | Week number with the first Monday as the first day of week one (00-53) | 34     |
-   | %%x       | Date representation *                                | 08/23/01                 |
-   | %%X       | Time representation *                                | 14:55:02                 |
-   | %%y       | Year, last two digits (00-99)                        | 01                       |
-   | %%Y       | Year                                                 | 2001                     |
-   | %%z       | ISO 8601 offset from UTC in timezone (1 minute=1, 1 hour=100) \n If timezone cannot be determined, no characters	| +100 |
-   | %%Z       | Timezone name or abbreviation * \n If timezone cannot be determined, no characters| CDT |
-   | %%        | A % sign                                             |	%                        |
-   * The specifiers marked with an asterisk (*) are locale-dependent.
+  \param[in] format : The string format supported by strftime() function that represents the time.
+  The default format is the following \c "%Y/%m/%d %H:%M:%S".
+  This string contains any combination of special format specifiers given in the next table:
+  | specifier | Replaced by                                          | Example                  |
+  |-----------|------------------------------------------------------|--------------------------|
+  | %%a       | Abbreviated weekday name *                           | Thu                      |
+  | %%A       | Full weekday name *                                  | Thursday                 |
+  | %%b       | Abbreviated month name *                             | Aug                      |
+  | %%B       | Full month name *                                    | August                   |
+  | %%c       | Date and time representation *                       | Thu Aug 23 14:55:02 2001 |
+  | %%C       | Year divided by 100 and truncated to integer (00-99) | 20                       |
+  | %%d       | Day of the month, zero-padded (01-31)                | 23                       |
+  | %%D       | Short MM/DD/YY date, equivalent to %m/%d/%y          | 08/23/01                 |
+  | %%e       | Day of the month, space-padded ( 1-31)               | 23                       |
+  | %%F       | Short YYYY-MM-DD date, equivalent to %Y-%m-%d        | 2001-08-23               |
+  | %%g       | Week-based year, last two digits (00-99)             | 01                       |
+  | %%G       | Week-based year                                      | 2001                     |
+  | %%h       | Abbreviated month name * (same as %b)                | Aug                      |
+  | %%H       | Hour in 24h format (00-23)                           | 14                       |
+  | %%I       | Hour in 12h format (01-12)                           | 02                       |
+  | %%j       | Day of the year (001-366)                            | 235                      |
+  | %%m       | Month as a decimal number (01-12)                    | 08                       |
+  | %%M       | Minute (00-59)                                       | 55                       |
+  | %%n       | New-line character ('\\n')                           |                          |
+  | %%p       | AM or PM designation                                 | PM                       |
+  | %%r       | 12-hour clock time *                                 | 02:55:02 pm              |
+  | %%R       | 24-hour HH:MM time, equivalent to %H:%M              | 14:55                    |
+  | %%S       | Second (00-61)                                       | 02                       |
+  | %%t       | Horizontal-tab character ('\\t')                     |                          |
+  | %%T       | ISO 8601 time format (HH:MM:SS), equivalent to %H:%M:%S | 14:55:02              |
+  | %%u       | ISO 8601 weekday as number with Monday as 1 (1-7)    | 4                        |
+  | %%U       | Week number with the first Sunday as the first day of week one (00-53) | 33     |
+  | %%V       | ISO 8601 week number (00-53)                         | 34                       |
+  | %%w       | Weekday as a decimal number with Sunday as 0 (0-6)   | 4                        |
+  | %%W       | Week number with the first Monday as the first day of week one (00-53) | 34     |
+  | %%x       | Date representation *                                | 08/23/01                 |
+  | %%X       | Time representation *                                | 14:55:02                 |
+  | %%y       | Year, last two digits (00-99)                        | 01                       |
+  | %%Y       | Year                                                 | 2001                     |
+  | %%z       | ISO 8601 offset from UTC in timezone (1 minute=1, 1 hour=100) \n If timezone cannot be determined, no
+characters  | +100 | | %%Z       | Timezone name or abbreviation * \n If timezone cannot be determined, no
+characters| CDT | | %%        | A % sign                                             |  %                        |
+  * The specifiers marked with an asterisk (*) are locale-dependent.
 
-   \return A formated date and time string. When default format is used, the
-returned string contains "YYYY/MM/DD hh:mm:ss".
+  \return A formatted date and time string. When default format is used, the
+  returned string contains "YYYY/MM/DD hh:mm:ss".
 
-   The following example shows how to use this function:
-   \code
+  The following example shows how to use this function:
+  \code
 #include <visp3/core/vpTime.h>
 
 int main()
@@ -374,33 +373,22 @@ std::string getDateTime(const std::string &format)
 };
 #endif
 
-vpChrono::vpChrono() : m_durationMs(), m_lastTimePoint()
-{
-}
+vpChrono::vpChrono() : m_durationMs(), m_lastTimePoint() { }
 
 /*!
   Get chrono duration in microsecond.
 */
-double vpChrono::getDurationMicros()
-{
-  return m_durationMs * 1e3;
-}
+double vpChrono::getDurationMicros() { return m_durationMs * 1e3; }
 
 /*!
   Get chrono duration in millisecond.
 */
-double vpChrono::getDurationMs()
-{
-  return m_durationMs;
-}
+double vpChrono::getDurationMs() { return m_durationMs; }
 
 /*!
   Get chrono duration in second.
 */
-double vpChrono::getDurationSeconds()
-{
-  return m_durationMs * 1e-3;
-}
+double vpChrono::getDurationSeconds() { return m_durationMs * 1e-3; }
 
 /*!
   Start the chrono.
