@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Visual feature circle.
  *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpCircle.h>
 
@@ -159,6 +156,7 @@ void vpCircle::projection() { projection(cP, p); }
   */
 void vpCircle::projection(const vpColVector &cP_, vpColVector &p_) const
 {
+  double det_threshold = 1e-10;
   p_.resize(5, false);
 
   vpColVector K(6);
@@ -189,8 +187,8 @@ void vpCircle::projection(const vpColVector &cP_, vpColVector &p_) const
   }
 
   double det = K[2] * K[2] - K[0] * K[1];
-  if (fabs(det) < 1e-8) {
-    throw(vpException(vpException::divideByZeroError, "division par 0"));
+  if (fabs(det) < det_threshold) {
+    throw(vpException(vpException::divideByZeroError, "Division by 0 in vpCircle::projection."));
   }
 
   double xc = (K[1] * K[3] - K[2] * K[4]) / det;
