@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Filip Novotny
  *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <cmath>
 #include <visp3/core/vpMomentAlpha.h>
@@ -48,7 +48,11 @@
   class harbouring an alpha value computed for a \f$[-\pi/2 ; \pi/2]\f$ portion
   of the circle.
  */
-vpMomentAlpha::vpMomentAlpha() : m_isRef(true), m_symmetric(false), m_mu3Ref(), m_alphaRef(0.), m_symmetricThreshold(1e-6) { values.resize(1); }
+vpMomentAlpha::vpMomentAlpha()
+  : m_isRef(true), m_symmetric(false), m_mu3Ref(), m_alphaRef(0.), m_symmetricThreshold(1e-6)
+{
+  values.resize(1);
+}
 
 /*!
   Common constructor. Initializes alpha moment as a non-reference alpha with a
@@ -57,12 +61,13 @@ vpMomentAlpha::vpMomentAlpha() : m_isRef(true), m_symmetric(false), m_mu3Ref(),
   order: \f$\mu_{30},\mu_{21},\mu_{12},\mu_{03}\f$.
   \param alpha_ref : Value of the reference alpha that has \e mu3_ref 3rd order moments.
   \param threshold : Threshold used to determine object symmetry along its 2 axis. The object is declared symmetric
-  if all the four 3rd order centered moments \e mu3_ref have values lower than this threshold. If the object is symmetric,
-  the alpha angle is commuted in [\f$[-\pi/2 ; \pi/2]\f$]. If the object is non symmetric, the alpha angle is
+  if all the four 3rd order centered moments \e mu3_ref have values lower than this threshold. If the object is
+  symmetric, the alpha angle is commuted in [\f$[-\pi/2 ; \pi/2]\f$]. If the object is non symmetric, the alpha angle is
   commuted in [\f$[-\pi ; \pi]\f$]
 */
 vpMomentAlpha::vpMomentAlpha(const std::vector<double> &mu3_ref, double alpha_ref, double threshold)
-  : vpMoment(), m_isRef(false), m_symmetric(true), m_mu3Ref(mu3_ref), m_alphaRef(alpha_ref), m_symmetricThreshold(threshold)
+  : vpMoment(), m_isRef(false), m_symmetric(true), m_mu3Ref(mu3_ref), m_alphaRef(alpha_ref),
+    m_symmetricThreshold(threshold)
 {
   for (std::vector<double>::const_iterator it = mu3_ref.begin(); it != mu3_ref.end(); ++it) {
     if (std::fabs(*it) > m_symmetricThreshold) {
@@ -89,14 +94,14 @@ void vpMomentAlpha::compute()
   if (!found_moment_centered)
     throw vpException(vpException::notInitialized, "vpMomentCentered not found");
 
-  double alpha = 0.5 * atan2(2.0 * momentCentered.get(1, 1),  (momentCentered.get(2, 0) - momentCentered.get(0, 2)));
+  double alpha = 0.5 * atan2(2.0 * momentCentered.get(1, 1), (momentCentered.get(2, 0) - momentCentered.get(0, 2)));
 
   std::vector<double> rotMu(4);
 
   if (m_isRef) {
     m_alphaRef = alpha;
   } else {
-    if (! m_symmetric) {
+    if (!m_symmetric) {
       double r11 = cos(alpha - m_alphaRef);
       double r12 = sin(alpha - m_alphaRef);
       double r21 = -r12;
@@ -126,8 +131,8 @@ void vpMomentAlpha::compute()
       double sum = 0.;
       bool signChange = false;
       for (unsigned int i = 0; i < 4; i++) {
-        if (std::fabs(rotMu[i]) > m_symmetricThreshold &&
-            std::fabs(m_mu3Ref[i]) > m_symmetricThreshold && rotMu[i] * m_mu3Ref[i] < 0) {
+        if (std::fabs(rotMu[i]) > m_symmetricThreshold && std::fabs(m_mu3Ref[i]) > m_symmetricThreshold &&
+            rotMu[i] * m_mu3Ref[i] < 0) {
           signChange = true;
         }
         sum += std::fabs(rotMu[i] * m_mu3Ref[i]);
@@ -138,12 +143,11 @@ void vpMomentAlpha::compute()
       }
 
       if (signChange) {
-         if (alpha < 0) {
+        if (alpha < 0) {
           alpha += M_PI;
-         }
-        else {
+        } else {
           alpha -= M_PI;
-         }
+        }
       }
     }
   }
