@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Filip Novotny
  *
- *****************************************************************************/
+*****************************************************************************/
 #include <cmath>
 #include <visp3/core/vpMomentAreaNormalized.h>
 #include <visp3/core/vpMomentCentered.h>
@@ -50,11 +50,12 @@ void vpMomentAreaNormalized::compute()
   bool found_moment_centered;
 
   /* getMoments() returns a reference to a vpMomentDatabase. (a protected
-    member inherited from vpMoment)
-    .get() 		is a member function of vpMomentDatabase that returns
-    a specific moment which is linked to it*/
+   * member inherited from vpMoment)
+   *.get() is a member function of vpMomentDatabase that returns
+   * a specific moment which is linked to it
+   * */
   const vpMomentCentered &momentCentered =
-      static_cast<const vpMomentCentered &>(getMoments().get("vpMomentCentered", found_moment_centered));
+    static_cast<const vpMomentCentered &>(getMoments().get("vpMomentCentered", found_moment_centered));
 
   if (!found_moment_centered)
     throw vpException(vpException::notInitialized, "vpMomentCentered not found");
@@ -107,7 +108,7 @@ void vpMomentAreaNormalized::printDependencies(std::ostream &os) const
 
   bool found_moment_centered;
   const vpMomentCentered &momentCentered =
-      static_cast<const vpMomentCentered &>(getMoments().get("vpMomentCentered", found_moment_centered));
+    static_cast<const vpMomentCentered &>(getMoments().get("vpMomentCentered", found_moment_centered));
   if (!found_moment_centered)
     throw vpException(vpException::notInitialized, "vpMomentCentered not found");
 
