@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Filip Novotny
  *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <iostream>
 #include <typeinfo>
@@ -63,7 +63,7 @@ void vpMomentDatabase::add(vpMoment &moment, const char *name)
 */
 const vpMoment &vpMomentDatabase::get(const char *type, bool &found) const
 {
-  std::map<const char *, vpMoment *, vpMomentDatabase::cmp_str>::const_iterator it = moments.find(type);
+  std::map<const char *, vpMoment *, vpMomentDatabase::vpCmpStr_t>::const_iterator it = moments.find(type);
 
   found = (it != moments.end());
   return *(it->second);
@@ -81,7 +81,7 @@ const vpMoment &vpMomentDatabase::get(const char *type, bool &found) const
 */
 void vpMomentDatabase::updateAll(vpMomentObject &object)
 {
-  std::map<const char *, vpMoment *, vpMomentDatabase::cmp_str>::const_iterator itr;
+  std::map<const char *, vpMoment *, vpMomentDatabase::vpCmpStr_t>::const_iterator itr;
   for (itr = moments.begin(); itr != moments.end(); ++itr) {
     (*itr).second->update(object);
   }
@@ -92,7 +92,7 @@ void vpMomentDatabase::updateAll(vpMomentObject &object)
 */
 VISP_EXPORT std::ostream &operator<<(std::ostream &os, const vpMomentDatabase &m)
 {
-  std::map<const char *, vpMoment *, vpMomentDatabase::cmp_str>::const_iterator itr;
+  std::map<const char *, vpMoment *, vpMomentDatabase::vpCmpStr_t>::const_iterator itr;
   os << "{";
 
   for (itr = m.moments.begin(); itr != m.moments.end(); ++itr) {
