@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Test for image conversions.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <iomanip>
 #include <stdlib.h>
@@ -75,8 +72,9 @@ Test image conversions.\n\
 \n\
 SYNOPSIS\n\
   %s [-i <input image path>] [-o <output image path>] [-n <nb benchmark iterations>]\n\
-     [-h]\n						      \
-", name);
+     [-h]\n\
+",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
@@ -99,7 +97,8 @@ OPTIONS:                                               Default\n\
      Set the number of benchmark iterations.\n\
 \n\
   -h\n\
-     Print the help.\n\n", ipath.c_str(), opath.c_str(), user.c_str(), nbiter);
+     Print the help.\n\n",
+          ipath.c_str(), opath.c_str(), user.c_str(), nbiter);
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
@@ -192,7 +191,7 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, opt_ipath, opt_opath, username, nbIterations) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Get the option values
@@ -214,7 +213,7 @@ int main(int argc, const char **argv)
         std::cerr << std::endl << "ERROR:" << std::endl;
         std::cerr << "  Cannot create " << opath << std::endl;
         std::cerr << "  Check your -o " << opt_opath << " option " << std::endl;
-        exit(-1);
+        return EXIT_FAILURE;
       }
     }
 
@@ -237,7 +236,7 @@ int main(int argc, const char **argv)
                 << "  environment variable to specify the location of the " << std::endl
                 << "  image path where test images are located." << std::endl
                 << std::endl;
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     //
@@ -282,145 +281,12 @@ int main(int argc, const char **argv)
               << ") b(" << (int)b << ")" << std::endl;
 
     vpChrono chrono;
-#ifdef VISP_HAVE_OPENCV
-#if VISP_HAVE_OPENCV_VERSION < 0x020408
-    double t0 = vpTime::measureTimeMs();
-    /////////////////////////
-    // Convert a IplImage to a vpImage<vpRGBa>
-    ////////////////////////
-    std::cout << "** Convert an IplImage to a vpImage<vpRGBa>" << std::endl;
-    IplImage *image = NULL; /*!< The image read / acquired */
-    filename = vpIoTools::createFilePath(ipath, "Klimt/Klimt.ppm");
 
-    /* Read the color image */
+    /* ------------------------------------------------------------------------ */
+    /*                  conversion for the new c++ interface                    */
+    /* ------------------------------------------------------------------------ */
 
-    std::cout << "   Reading the color image with opencv: " << filename << std::endl;
-    if ((image = cvLoadImage(filename.c_str(), CV_LOAD_IMAGE_COLOR)) == NULL) {
-      std::cout << "   Cannot read image: " << filename << std::endl;
-      return (-1);
-    }
-    vpImageConvert::convert(image, Ic);
-    filename = vpIoTools::createFilePath(opath, "Klimt_color_cv.ppm");
-    std::cout << "   Resulting image saved in: " << filename << std::endl;
-    vpImageIo::write(Ic, filename);
-
-    std::cout << "   Convert result in " << filename << std::endl;
-
-    filename = vpIoTools::createFilePath(ipath, "Klimt/Klimt.pgm");
-
-    /* Read the pgm image */
-    std::cout << "   Reading the greyscale image with opencv: " << filename << std::endl;
-    if (image != NULL)
-      cvReleaseImage(&image);
-    if ((image = cvLoadImage(filename.c_str(), CV_LOAD_IMAGE_GRAYSCALE)) == NULL) {
-      std::cout << "   Cannot read image: " << filename << std::endl;
-      return (-1);
-    }
-    vpImageConvert::convert(image, Ic);
-    filename = vpIoTools::createFilePath(opath, "Klimt_grey_cv.ppm");
-    std::cout << "   Resulting image saved in: " << filename << std::endl;
-    vpImageIo::write(Ic, filename);
-
-    std::cout << "   Convert result in " << filename << std::endl;
-
-    ///////////////////////////
-    // Convert a IplImage to a vpImage<unsigned char>
-    ////////////////////////////
-    std::cout << "** Convert an IplImage to a vpImage<unsigned char>" << std::endl;
-    filename = vpIoTools::createFilePath(ipath, "Klimt/Klimt.ppm");
-
-    /* Read the color image */
-
-    std::cout << "   Reading the color image with opencv: " << filename << std::endl;
-    if (image != NULL)
-      cvReleaseImage(&image);
-    if ((image = cvLoadImage(filename.c_str(), CV_LOAD_IMAGE_COLOR)) == NULL) {
-      std::cout << "   Cannot read image: " << filename << std::endl;
-      return (-1);
-    }
-    vpImageConvert::convert(image, Ig);
-    filename = vpIoTools::createFilePath(opath, "Klimt_color_cv.pgm");
-    std::cout << "   Resulting image saved in: " << filename << std::endl;
-    vpImageIo::write(Ig, filename);
-
-    std::cout << "   Convert result in " << filename << std::endl;
-
-    filename = vpIoTools::createFilePath(ipath, "Klimt/Klimt.pgm");
-
-    /* Read the pgm image */
-
-    std::cout << "   Reading the greyscale image with opencv: " << filename << std::endl;
-    if (image != NULL)
-      cvReleaseImage(&image);
-    if ((image = cvLoadImage(filename.c_str(), CV_LOAD_IMAGE_GRAYSCALE)) == NULL) {
-      std::cout << "   Cannot read image: " << filename << std::endl;
-      return (-1);
-    }
-    vpImageConvert::convert(image, Ig);
-    filename = vpIoTools::createFilePath(opath, "Klimt_grey_cv.pgm");
-    std::cout << "   Resulting image saved in: " << filename << std::endl;
-    vpImageIo::write(Ig, filename);
-
-    std::cout << "   Convert result in " << filename << std::endl;
-
-    ////////////////////////////////////
-    // Convert a vpImage<vpRGBa> to a IplImage
-    ////////////////////////////////////
-    std::cout << "** Convert a vpImage<vpRGBa> to an IplImage" << std::endl;
-    filename = vpIoTools::createFilePath(ipath, "Klimt/Klimt.ppm");
-
-    /* Read the color image */
-
-    // Load a color image from the disk
-    std::cout << "   Load " << filename << std::endl;
-    vpImageIo::read(Ic, filename);
-    vpImageConvert::convert(Ic, image);
-    filename = vpIoTools::createFilePath(opath, "Klimt_ipl_color_cv.ppm");
-    /* Save the the current image */
-    std::cout << "   Write " << filename << std::endl;
-    if ((cvSaveImage(filename.c_str(), image)) == 0) {
-      std::cout << "   Cannot write image: " << filename << std::endl;
-      if (image != NULL)
-        cvReleaseImage(&image);
-      return (-1);
-    }
-    std::cout << "   Convert result in " << filename << std::endl;
-
-    ////////////////////////////////////////
-    // Convert a vpImage<unsigned char> to an IplImage
-    ////////////////////////////////////////
-    std::cout << "** Convert a vpImage<unsigned char> to an IplImage" << std::endl;
-    filename = vpIoTools::createFilePath(ipath, "Klimt/Klimt.pgm");
-
-    /* Read the grey image */
-
-    // Load a color image from the disk
-    std::cout << "   Load " << filename << std::endl;
-    vpImageIo::read(Ig, filename);
-    vpImageConvert::convert(Ig, image);
-    filename = vpIoTools::createFilePath(opath, "Klimt_ipl_grey_cv.pgm");
-    /* Save the the current image */
-
-    std::cout << "   Write " << filename << std::endl;
-    if ((cvSaveImage(filename.c_str(), image)) == 0) {
-      std::cout << "   Cannot write image: " << std::endl << filename << std::endl;
-      if (image != NULL)
-        cvReleaseImage(&image);
-      return (-1);
-    }
-    std::cout << "   Convert result in " << filename << std::endl;
-
-    if (image != NULL)
-      cvReleaseImage(&image);
-    double t1 = vpTime::measureTimeMs();
-    std::cout << "== Conversion c interface : " << t1 - t0 << " ms" << std::endl;
-#endif
-
-/* ------------------------------------------------------------------------ */
-/*                  conversion for the new c++ interface                    */
-/* ------------------------------------------------------------------------ */
-
-#if VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC)
     chrono.start();
     /////////////////////////
     // Convert a cv::Mat to a vpImage<vpRGBa>
@@ -431,13 +297,13 @@ int main(int argc, const char **argv)
     std::cout << "   Reading the color image with c++ interface of opencv: " << filename << std::endl;
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
     int flags = cv::IMREAD_COLOR;
-#elif VISP_HAVE_OPENCV_VERSION >= 0x020100
+#else
     int flags = CV_LOAD_IMAGE_COLOR;
 #endif
     imageMat = cv::imread(filename, flags); // Force to a three channel BGR color image.
     if (imageMat.data == NULL) {
       std::cout << "   Cannot read image: " << filename << std::endl;
-      return -1;
+      return EXIT_FAILURE;
     }
     vpImageConvert::convert(imageMat, Ic);
     filename = vpIoTools::createFilePath(opath, "Klimt_color_cvMat.ppm");
@@ -447,16 +313,16 @@ int main(int argc, const char **argv)
     filename = vpIoTools::createFilePath(ipath, "Klimt/Klimt.pgm");
     /* Read the pgm image */
 
-    std::cout << "   Reading the greyscale image with opencv: " << filename << std::endl;
+    std::cout << "   Reading the grayscale image with opencv: " << filename << std::endl;
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
     flags = cv::IMREAD_GRAYSCALE;
-#elif VISP_HAVE_OPENCV_VERSION >= 0x020100
+#else
     flags = CV_LOAD_IMAGE_GRAYSCALE;
 #endif
     imageMat = cv::imread(filename, flags); // Forced to grayscale.
     if (imageMat.data == NULL) {
       std::cout << "   Cannot read image: " << filename << std::endl;
-      return (-1);
+      return EXIT_FAILURE;
     }
     vpImageConvert::convert(imageMat, Ic);
     filename = vpIoTools::createFilePath(opath, "Klimt_grey_cvMat.ppm");
@@ -474,13 +340,13 @@ int main(int argc, const char **argv)
     std::cout << "   Reading the color image with opencv: " << filename << std::endl;
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
     flags = cv::IMREAD_COLOR;
-#elif VISP_HAVE_OPENCV_VERSION >= 0x020100
+#else
     flags = CV_LOAD_IMAGE_COLOR;
 #endif
     imageMat = cv::imread(filename, flags); // Force to a three channel BGR color image.
     if (imageMat.data == NULL) {
       std::cout << "   Cannot read image: " << filename << std::endl;
-      return -1;
+      return EXIT_FAILURE;
     }
     vpImageConvert::convert(imageMat, Ig);
     filename = vpIoTools::createFilePath(opath, "Klimt_color_cvMat.pgm");
@@ -494,13 +360,13 @@ int main(int argc, const char **argv)
     std::cout << "   Reading the greyscale image with opencv: " << filename << std::endl;
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
     flags = cv::IMREAD_GRAYSCALE;
-#elif VISP_HAVE_OPENCV_VERSION >= 0x020100
+#else
     flags = CV_LOAD_IMAGE_GRAYSCALE;
 #endif
     imageMat = cv::imread(filename, flags);
     if (imageMat.data == NULL) {
       std::cout << "   Cannot read image: " << filename << std::endl;
-      return (-1);
+      return EXIT_FAILURE;
     }
     vpImageConvert::convert(imageMat, Ig);
     filename = vpIoTools::createFilePath(opath, "Klimt_grey_cvMat.pgm");
@@ -526,7 +392,7 @@ int main(int argc, const char **argv)
     std::cout << "   Resulting image saved in: " << filename << std::endl;
     if (!cv::imwrite(filename, imageMat)) {
       std::cout << "   Cannot write image: " << filename << std::endl;
-      return (-1);
+      return EXIT_FAILURE;
     }
     std::cout << "   Convert result in " << filename << std::endl;
 
@@ -548,12 +414,11 @@ int main(int argc, const char **argv)
     std::cout << "   Resulting image saved in: " << filename << std::endl;
     if (!cv::imwrite(filename, imageMat)) {
       std::cout << "   Cannot write image: " << filename << std::endl;
-      return (-1);
+      return EXIT_FAILURE;
     }
     std::cout << "   Convert result in " << filename << std::endl;
     chrono.stop();
     std::cout << "== Conversion c++ interface : " << chrono.getDurationMs() << " ms" << std::endl;
-#endif
 #endif
 
     ////////////////////////////////////
@@ -661,7 +526,7 @@ int main(int argc, const char **argv)
     // Test construction of a vpImage from an array with copyData==true
     ////////////////////////////////////
     std::cout << "** Construction of a vpImage from an array with copyData==true" << std::endl;
-    std::vector<unsigned char> rgba2(size*4);
+    std::vector<unsigned char> rgba2(size * 4);
     std::fill(rgba2.begin(), rgba2.end(), 127);
     vpImage<vpRGBa> I_copyData(reinterpret_cast<vpRGBa *>(&rgba2.front()), h, w, true);
 
@@ -682,10 +547,10 @@ int main(int argc, const char **argv)
       vpImageIo::read(I_color, filename);
 
       // RGB to Grayscale conversion
-      std::vector<unsigned char> rgb_array(I_color.getSize()*3);
+      std::vector<unsigned char> rgb_array(I_color.getSize() * 3);
       vpImageConvert::RGBaToRGB((unsigned char *)I_color.bitmap, &rgb_array.front(), I_color.getSize());
 
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC)
       // BGR cv::Mat to Grayscale
       std::cout << "\n   BGR cv::Mat to Grayscale" << std::endl;
       filename = vpIoTools::createFilePath(ipath, "Klimt/Klimt.ppm");
@@ -695,8 +560,10 @@ int main(int argc, const char **argv)
       // Test RGB to Grayscale + Flip
       std::cout << "\n   RGB to Grayscale + Flip" << std::endl;
       std::vector<unsigned char> rgb2gray_flip_array_sse(I_color.getSize());
-      vpImageConvert::RGBToGrey(&rgb_array.front(), &rgb2gray_flip_array_sse.front(), I_color.getWidth(), I_color.getHeight(), true);
-      vpImage<unsigned char> I_rgb2gray_flip_sse(&rgb2gray_flip_array_sse.front(), I_color.getHeight(), I_color.getWidth());
+      vpImageConvert::RGBToGrey(&rgb_array.front(), &rgb2gray_flip_array_sse.front(), I_color.getWidth(),
+                                I_color.getHeight(), true);
+      vpImage<unsigned char> I_rgb2gray_flip_sse(&rgb2gray_flip_array_sse.front(), I_color.getHeight(),
+                                                 I_color.getWidth());
 
       filename = vpIoTools::createFilePath(opath, "I_rgb2gray_flip_sse.pgm");
       std::cout << "   Resulting image saved in: " << filename << std::endl;
@@ -705,7 +572,8 @@ int main(int argc, const char **argv)
       // Test BGR to Grayscale + Flip
       std::cout << "\n   Conversion BGR to Grayscale + Flip" << std::endl;
       std::vector<unsigned char> bgr2gray_flip_array_sse(I_color.getSize());
-      vpImage<unsigned char> I_bgr2gray_flip_sse(&bgr2gray_flip_array_sse.front(), I_color.getHeight(), I_color.getWidth());
+      vpImage<unsigned char> I_bgr2gray_flip_sse(&bgr2gray_flip_array_sse.front(), I_color.getHeight(),
+                                                 I_color.getWidth());
       vpImageConvert::convert(colorMat, I_bgr2gray_flip_sse, true);
 
       filename = vpIoTools::createFilePath(opath, "I_bgr2gray_flip_sse.pgm");
@@ -716,11 +584,11 @@ int main(int argc, const char **argv)
       std::cout << "\n   RGB to Grayscale + Flip + Crop" << std::endl;
       cv::Rect rect_roi(11, 17, 347, 449);
       cv::Mat colorMat_crop = colorMat(rect_roi);
-      cv::Mat colorMat_crop_continous = colorMat(rect_roi).clone();
+      cv::Mat colorMat_crop_continuous = colorMat(rect_roi).clone();
       std::cout << "   colorMat_crop: " << colorMat_crop.cols << "x" << colorMat_crop.rows << " is continuous? "
                 << colorMat_crop.isContinuous() << std::endl;
-      std::cout << "   colorMat_crop_continous: " << colorMat_crop_continous.cols << "x" << colorMat_crop_continous.rows
-                << " is continuous? " << colorMat_crop_continous.isContinuous() << std::endl;
+      std::cout << "   colorMat_crop_continuous: " << colorMat_crop_continuous.cols << "x" << colorMat_crop_continuous.rows
+                << " is continuous? " << colorMat_crop_continuous.isContinuous() << std::endl;
 
       vpImage<vpRGBa> I_color_crop((unsigned int)(rect_roi.height - rect_roi.y),
                                    (unsigned int)(rect_roi.width - rect_roi.x));
@@ -749,7 +617,7 @@ int main(int argc, const char **argv)
       // Test BGR to Grayscale + Flip + Crop
       std::cout << "\n   BGR to Grayscale + Flip + Crop" << std::endl;
       vpImage<unsigned char> I_bgr2gray_flip_crop_sse(I_color_crop.getHeight(), I_color_crop.getWidth());
-      vpImageConvert::convert(colorMat_crop_continous, I_bgr2gray_flip_crop_sse, true);
+      vpImageConvert::convert(colorMat_crop_continuous, I_bgr2gray_flip_crop_sse, true);
 
       filename = vpIoTools::createFilePath(opath, "I_bgr2gray_flip_crop_sse.pgm");
       std::cout << "   Resulting image saved in: " << filename << std::endl;
