@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -32,10 +32,9 @@
  * Image difference.
  *
  * Authors:
- * Fabien Spindler
  * Souriya Trinh
  *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <iostream>
 #include <visp3/core/vpImageTools.h>
@@ -45,8 +44,10 @@
 
   \brief Test vpImageTools::imageDifference()
 */
-namespace {
-void regularImageDifference(const vpImage<unsigned char> &I1, const vpImage<unsigned char> &I2, vpImage<unsigned char> &Idiff)
+namespace
+{
+void regularImageDifference(const vpImage<unsigned char> &I1, const vpImage<unsigned char> &I2,
+                            vpImage<unsigned char> &Idiff)
 {
   if ((I1.getHeight() != I2.getHeight()) || (I1.getWidth() != I2.getWidth())) {
     throw(vpException(vpException::dimensionError, "The two images have not the same size"));
@@ -65,8 +66,9 @@ void regularImageDifference(const vpImage<unsigned char> &I1, const vpImage<unsi
 void regularImageDifference(const vpImage<vpRGBa> &I1, const vpImage<vpRGBa> &I2, vpImage<vpRGBa> &Idiff)
 {
   if ((I1.getHeight() != I2.getHeight()) || (I1.getWidth() != I2.getWidth())) {
-    throw(vpException(vpException::dimensionError, "Cannot compute image difference. The two images "
-                                                   "(%ux%u) and (%ux%u) have not the same size",
+    throw(vpException(vpException::dimensionError,
+                      "Cannot compute image difference. The two images "
+                      "(%ux%u) and (%ux%u) have not the same size",
                       I1.getWidth(), I1.getHeight(), I2.getWidth(), I2.getHeight()));
   }
 
@@ -85,17 +87,18 @@ void regularImageDifference(const vpImage<vpRGBa> &I1, const vpImage<vpRGBa> &I2
     Idiff.bitmap[b].A = static_cast<unsigned char>(vpMath::maximum(vpMath::minimum(diffA, 255), 0));
   }
 }
-}
+} // namespace
 
 int main()
 {
   unsigned int width = 501, height = 447;
-  vpImage<unsigned char> I1(height,width), I2(height,width), Idiff_regular(height,width), Idiff_sse(height,width);
-  vpImage<vpRGBa> I1_color(height, width), I2_color(height, width), Idiff_regular_color(height, width), Idiff_sse_color(height, width);
+  vpImage<unsigned char> I1(height, width), I2(height, width), Idiff_regular(height, width), Idiff_sse(height, width);
+  vpImage<vpRGBa> I1_color(height, width), I2_color(height, width), Idiff_regular_color(height, width),
+      Idiff_sse_color(height, width);
   for (unsigned int i = 0; i < I1.getRows(); i++) {
     for (unsigned int j = 0; j < I1.getCols(); j++) {
-      I1[i][j] = static_cast<unsigned char>(i*I1.getCols() + j);
-      I1_color[i][j] = vpRGBa(static_cast<unsigned char>(i*I1.getCols() + j));
+      I1[i][j] = static_cast<unsigned char>(i * I1.getCols() + j);
+      I1_color[i][j] = vpRGBa(static_cast<unsigned char>(i * I1.getCols() + j));
     }
   }
 
@@ -106,7 +109,7 @@ int main()
     for (unsigned int cpt = 0; cpt < 256; cpt++) {
       for (unsigned int i = 0; i < I2.getRows(); i++) {
         for (unsigned int j = 0; j < I2.getCols(); j++) {
-          I2[i][j] = static_cast<unsigned char>(i*I2.getCols() + j + cpt);
+          I2[i][j] = static_cast<unsigned char>(i * I2.getCols() + j + cpt);
         }
       }
 
@@ -125,9 +128,9 @@ int main()
     }
 
     std::cout << "(Idiff_regular == Idiff_sse)" << std::endl;
-    std::cout << "t_regular: " << t_regular << " ms ; mean t_regular: " << t_regular/256 << " ms" << std::endl;
-    std::cout << "t_sse: " << t_sse << " ms ; mean t_sse: " << t_sse/256 << " ms" << std::endl;
-    std::cout << "speed-up: " << t_regular / t_sse << " X" << std::endl;
+    std::cout << "t_regular: " << t_regular << " ms ; mean t_regular: " << t_regular / 256 << " ms" << std::endl;
+    std::cout << "t_sse: " << t_sse << " ms ; mean t_sse: " << t_sse / 256 << " ms" << std::endl;
+    std::cout << "speed-up: " << t_regular / t_sse << " times" << std::endl;
   }
 
   {
@@ -137,7 +140,7 @@ int main()
     for (unsigned int cpt = 0; cpt < 256; cpt++) {
       for (unsigned int i = 0; i < I2.getRows(); i++) {
         for (unsigned int j = 0; j < I2.getCols(); j++) {
-          I2_color[i][j] = vpRGBa(static_cast<unsigned char>(i*I2.getCols() + j + cpt));
+          I2_color[i][j] = vpRGBa(static_cast<unsigned char>(i * I2.getCols() + j + cpt));
         }
       }
 
@@ -156,10 +159,107 @@ int main()
     }
 
     std::cout << "(Idiff_regular_color == Idiff_sse_color)" << std::endl;
-    std::cout << "t_regular: " << t_regular << " ms ; mean t_regular: " << t_regular/256 << " ms" << std::endl;
-    std::cout << "t_sse: " << t_sse << " ms ; mean t_sse: " << t_sse/256 << " ms" << std::endl;
-    std::cout << "speed-up: " << t_regular / t_sse << " X" << std::endl;
+    std::cout << "t_regular: " << t_regular << " ms ; mean t_regular: " << t_regular / 256 << " ms" << std::endl;
+    std::cout << "t_sse: " << t_sse << " ms ; mean t_sse: " << t_sse / 256 << " ms" << std::endl;
+    std::cout << "speed-up: " << t_regular / t_sse << " times" << std::endl;
   }
 
+  {
+    std::cout << "Test vpRGBa" << std::endl;
+    vpRGBa rgba_1(10, 20, 30);
+    vpRGBa rgba_2(10, 20, 30);
+
+    if (rgba_1 == rgba_2) {
+      std::cout << "Test ok: same rgba" << std::endl;
+    }
+    else {
+      std::cerr << "Error in rgba operator==" << std::endl;
+      return EXIT_FAILURE;
+    }
+    if (rgba_1 != rgba_2) {
+      std::cerr << "Error in rgba operator!=" << std::endl;
+      return EXIT_FAILURE;
+    }
+    {
+      vpRGBa rgba_3(1, 0, 0);
+      if (rgba_1 == (rgba_2 + rgba_3)) {
+        std::cerr << "Error in rgba operator==" << std::endl;
+        return EXIT_FAILURE;
+      }
+      if (rgba_1 != (rgba_2 + rgba_3)) {
+        std::cerr << "Test ok: R value differ" << std::endl;
+      }
+    }
+    {
+      vpRGBa rgba_3(0, 1, 0);
+      if (rgba_1 == (rgba_2 + rgba_3)) {
+        std::cerr << "Error in rgba operator==" << std::endl;
+        return EXIT_FAILURE;
+      }
+      if (rgba_1 != (rgba_2 + rgba_3)) {
+        std::cerr << "Test ok: G value differ" << std::endl;
+      }
+    }
+    {
+      vpRGBa rgba_3(0, 0, 1);
+      if (rgba_1 == (rgba_2 + rgba_3)) {
+        std::cerr << "Error in rgba operator==" << std::endl;
+        return EXIT_FAILURE;
+      }
+      if (rgba_1 != (rgba_2 + rgba_3)) {
+        std::cerr << "Test ok: B value differ" << std::endl;
+      }
+    }
+  }
+
+    {
+    std::cout << "Test vpRGBf" << std::endl;
+    vpRGBf rgbf_1(10.f, 20.f, 30.f);
+    vpRGBf rgbf_2(10.f, 20.f, 30.f);
+
+    if (rgbf_1 == rgbf_2) {
+      std::cout << "Test ok: same rgbf" << std::endl;
+    }
+    else {
+      std::cerr << "Error in rgbf operator==" << std::endl;
+      return EXIT_FAILURE;
+    }
+    if (rgbf_1 != rgbf_2) {
+      std::cerr << "Error in rgbf operator!=" << std::endl;
+      return EXIT_FAILURE;
+    }
+    {
+      vpRGBf rgbf_3(1e-6f, 0.f, 0.f);
+      if (rgbf_1 == (rgbf_2 + rgbf_3)) {
+        std::cerr << "Rf Error in rgbf operator==" << std::endl;
+        return EXIT_FAILURE;
+      }
+      if (rgbf_1 != (rgbf_2 + rgbf_3)) {
+        std::cerr << "Test ok: Rf value differ" << std::endl;
+      }
+    }
+    {
+      vpRGBf rgbf_3(0.f, 1e-6f, 0.f);
+      if (rgbf_1 == (rgbf_2 + rgbf_3)) {
+        std::cerr << "Gf Error in rgbf operator==" << std::endl;
+        return EXIT_FAILURE;
+      }
+      if (rgbf_1 != (rgbf_2 + rgbf_3)) {
+        std::cerr << "Test ok: Gf value differ" << std::endl;
+      }
+    }
+    {
+      vpRGBf rgbf_3(0.f, 0.f, 1e-6f);
+      if (rgbf_1 == (rgbf_2 + rgbf_3)) {
+        std::cerr << "Bf Error in rgbf operator==" << std::endl;
+        return EXIT_FAILURE;
+      }
+      if (rgbf_1 != (rgbf_2 + rgbf_3)) {
+        std::cerr << "Test ok: Bf value differ" << std::endl;
+      }
+    }
+  }
+
+  std::cout << "Test succeed" << std::endl;
   return EXIT_SUCCESS;
 }
