@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,28 +31,33 @@
  * Description:
  * Test image morphology.
  *
- *****************************************************************************/
+*****************************************************************************/
 
- /*!
-   \example testImageMorphology.cpp
+/*!
+  \example testImageMorphology.cpp
 
-   \brief Test image morphology.
- */
+  \brief Test image morphology.
+*/
 
 #include <visp3/core/vpConfig.h>
 
 #if defined(VISP_HAVE_CATCH2)
 #define CATCH_CONFIG_RUNNER
-#include <catch.hpp>
-#include <visp3/core/vpImageMorphology.h>
 #include "common.hpp"
+#include <catch.hpp>
+#include <visp3/core/vpImageFilter.h>
+#include <visp3/core/vpImageMorphology.h>
 
-TEST_CASE("Binary image morphology", "[image_morphology]") {
-  unsigned char image_data[8 * 16] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0,
-                                       0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 0, 1, 1,
-                                       1, 1, 1, 0, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0,
-                                       0, 1, 1, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 1,
-                                       0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0 };
+TEST_CASE("Binary image morphology", "[image_morphology]")
+{
+  unsigned char image_data[8 * 16] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+                                      0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 0, 0, 0, 1, 0, 0,
+                                      0, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 1, 1, 0,
+                                      0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 1, 0, 0, 0, 1, 1,
+                                      0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1,
+                                      1, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0,
+                                      1, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1,
+                                      1, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0 };
 
   vpImage<unsigned char> I(image_data, 8, 16, true);
 
@@ -67,7 +72,7 @@ TEST_CASE("Binary image morphology", "[image_morphology]") {
 
       common_tools::imageDilatationRef(I_morpho_ref, connexity);
       vpImageMorphology::dilatation(I_morpho_tpl, (unsigned char)1, (unsigned char)0, connexity);
-      vpImageMorphology::dilatation(I_morpho, connexity);
+      vpImageMorphology::dilatation<unsigned char>(I_morpho, connexity);
 
       CHECK((I_morpho_ref == I_morpho_tpl));
       CHECK((I_morpho_ref == I_morpho));
@@ -81,7 +86,7 @@ TEST_CASE("Binary image morphology", "[image_morphology]") {
 
       common_tools::imageDilatationRef(I_morpho_ref, connexity);
       vpImageMorphology::dilatation(I_morpho_tpl, (unsigned char)1, (unsigned char)0, connexity);
-      vpImageMorphology::dilatation(I_morpho, connexity);
+      vpImageMorphology::dilatation<unsigned char>(I_morpho, connexity);
 
       CHECK((I_morpho_ref == I_morpho_tpl));
       CHECK((I_morpho_ref == I_morpho));
@@ -99,7 +104,7 @@ TEST_CASE("Binary image morphology", "[image_morphology]") {
 
       common_tools::imageErosionRef(I_morpho_ref, connexity);
       vpImageMorphology::erosion(I_morpho_tpl, (unsigned char)1, (unsigned char)0, connexity);
-      vpImageMorphology::erosion(I_morpho, connexity);
+      vpImageMorphology::erosion<unsigned char>(I_morpho, connexity);
 
       CHECK((I_morpho_ref == I_morpho_tpl));
       CHECK((I_morpho_ref == I_morpho));
@@ -114,7 +119,7 @@ TEST_CASE("Binary image morphology", "[image_morphology]") {
 
       common_tools::imageErosionRef(I_morpho_ref, connexity);
       vpImageMorphology::erosion(I_morpho_tpl, (unsigned char)1, (unsigned char)0, connexity);
-      vpImageMorphology::erosion(I_morpho, connexity);
+      vpImageMorphology::erosion<unsigned char>(I_morpho, connexity);
 
       CHECK((I_morpho_ref == I_morpho_tpl));
       CHECK((I_morpho_ref == I_morpho));
@@ -127,7 +132,7 @@ TEST_CASE("Binary image morphology", "[image_morphology]") {
     {
       const vpImageMorphology::vpConnexityType connexity = vpImageMorphology::CONNEXITY_4;
       vpImage<unsigned char> I_dilatation = I;
-      vpImageMorphology::dilatation(I_dilatation, connexity);
+      vpImageMorphology::dilatation<unsigned char>(I_dilatation, connexity);
 
       unsigned char image_data_dilatation[8 * 16] = {
           0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 0,
@@ -138,7 +143,7 @@ TEST_CASE("Binary image morphology", "[image_morphology]") {
       CHECK((I_dilatation_ref == I_dilatation));
 
       vpImage<unsigned char> I_erosion = I_dilatation;
-      vpImageMorphology::erosion(I_erosion, connexity);
+      vpImageMorphology::erosion<unsigned char>(I_erosion, connexity);
 
       unsigned char image_data_erosion[8 * 16] = {
           0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 0, 0, 0, 0, 1, 0, 0,
@@ -153,7 +158,7 @@ TEST_CASE("Binary image morphology", "[image_morphology]") {
     {
       const vpImageMorphology::vpConnexityType connexity = vpImageMorphology::CONNEXITY_8;
       vpImage<unsigned char> I_dilatation = I;
-      vpImageMorphology::dilatation(I_dilatation, connexity);
+      vpImageMorphology::dilatation<unsigned char>(I_dilatation, connexity);
 
       unsigned char image_data_dilatation[8 * 16] = {
           0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1,
@@ -164,7 +169,7 @@ TEST_CASE("Binary image morphology", "[image_morphology]") {
       CHECK((I_dilatation_ref == I_dilatation));
 
       vpImage<unsigned char> I_erosion = I_dilatation;
-      vpImageMorphology::erosion(I_erosion, connexity);
+      vpImageMorphology::erosion<unsigned char>(I_erosion, connexity);
 
       unsigned char image_data_erosion[8 * 16] = {
           0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 0,
@@ -177,7 +182,8 @@ TEST_CASE("Binary image morphology", "[image_morphology]") {
   }
 }
 
-TEST_CASE("Gray image morphology", "[image_morphology]") {
+TEST_CASE("Gray image morphology", "[image_morphology]")
+{
   vpImage<unsigned char> I;
   common_tools::magicSquare(I, 17);
 
@@ -190,7 +196,7 @@ TEST_CASE("Gray image morphology", "[image_morphology]") {
       vpImage<unsigned char> I_morpho = I;
 
       common_tools::imageDilatationRef(I_morpho_ref, connexity);
-      vpImageMorphology::dilatation(I_morpho, connexity);
+      vpImageMorphology::dilatation<unsigned char>(I_morpho, connexity);
 
       CHECK((I_morpho_ref == I_morpho));
     }
@@ -201,7 +207,7 @@ TEST_CASE("Gray image morphology", "[image_morphology]") {
       vpImage<unsigned char> I_morpho = I;
 
       common_tools::imageDilatationRef(I_morpho_ref, connexity);
-      vpImageMorphology::dilatation(I_morpho, connexity);
+      vpImageMorphology::dilatation<unsigned char>(I_morpho, connexity);
 
       CHECK((I_morpho_ref == I_morpho));
     }
@@ -216,7 +222,7 @@ TEST_CASE("Gray image morphology", "[image_morphology]") {
       vpImage<unsigned char> I_morpho = I;
 
       common_tools::imageErosionRef(I_morpho_ref, connexity);
-      vpImageMorphology::erosion(I_morpho, connexity);
+      vpImageMorphology::erosion<unsigned char>(I_morpho, connexity);
 
       CHECK((I_morpho_ref == I_morpho));
     }
@@ -228,7 +234,7 @@ TEST_CASE("Gray image morphology", "[image_morphology]") {
       vpImage<unsigned char> I_morpho = I;
 
       common_tools::imageErosionRef(I_morpho_ref, connexity);
-      vpImageMorphology::erosion(I_morpho, connexity);
+      vpImageMorphology::erosion<unsigned char>(I_morpho, connexity);
 
       CHECK((I_morpho_ref == I_morpho));
     }
@@ -240,7 +246,7 @@ TEST_CASE("Gray image morphology", "[image_morphology]") {
     {
       const vpImageMorphology::vpConnexityType connexity = vpImageMorphology::CONNEXITY_4;
       vpImage<unsigned char> I_dilatation = I;
-      vpImageMorphology::dilatation(I_dilatation, connexity);
+      vpImageMorphology::dilatation<unsigned char>(I_dilatation, connexity);
 
       unsigned char image_data_dilatation[17 * 17] = {
           174, 193, 212, 231, 250, 255, 255, 255, 255, 39,  58,  77,  96,  115, 134, 153, 154, 192, 211, 230, 249,
@@ -261,7 +267,7 @@ TEST_CASE("Gray image morphology", "[image_morphology]") {
       CHECK((I_dilatation_ref == I_dilatation));
 
       vpImage<unsigned char> I_erosion = I_dilatation;
-      vpImageMorphology::erosion(I_erosion, connexity);
+      vpImageMorphology::erosion<unsigned char>(I_erosion, connexity);
 
       unsigned char image_data_erosion[17 * 17] = {
           174, 174, 193, 212, 231, 250, 255, 255, 38,  39,  39,  58,  77,  96,  115, 134, 153, 174, 192, 211, 230,
@@ -286,7 +292,7 @@ TEST_CASE("Gray image morphology", "[image_morphology]") {
     {
       const vpImageMorphology::vpConnexityType connexity = vpImageMorphology::CONNEXITY_8;
       vpImage<unsigned char> I_dilatation = I;
-      vpImageMorphology::dilatation(I_dilatation, connexity);
+      vpImageMorphology::dilatation<unsigned char>(I_dilatation, connexity);
 
       unsigned char image_data_dilatation[17 * 17] = {
           192, 211, 230, 249, 255, 255, 255, 255, 255, 57,  76,  95,  114, 133, 152, 154, 154, 210, 229, 248, 255,
@@ -307,7 +313,7 @@ TEST_CASE("Gray image morphology", "[image_morphology]") {
       CHECK((I_dilatation_ref == I_dilatation));
 
       vpImage<unsigned char> I_erosion = I_dilatation;
-      vpImageMorphology::erosion(I_erosion, connexity);
+      vpImageMorphology::erosion<unsigned char>(I_erosion, connexity);
 
       unsigned char image_data_erosion[17 * 17] = {
           192, 192, 211, 230, 249, 255, 255, 255, 57,  57,  57,  76,  95,  114, 133, 152, 154, 192, 192, 211, 230,
@@ -330,7 +336,7 @@ TEST_CASE("Gray image morphology", "[image_morphology]") {
   }
 }
 
-int main(int argc, char *argv[])
+int main(int argc, char *argv [])
 {
   Catch::Session session; // There must be exactly one instance
 
@@ -345,8 +351,5 @@ int main(int argc, char *argv[])
   return numFailed;
 }
 #else
-int main()
-{
-  return 0;
-}
+int main() { return EXIT_SUCCESS; }
 #endif
