@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,7 +31,7 @@
  * Description:
  * Benchmark matrix multiplication.
  *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpConfig.h>
 
@@ -56,12 +56,9 @@ namespace
 bool runBenchmark = false;
 bool runBenchmarkAll = false;
 
-double getRandomValues(double min, double max)
-{
-  return (max - min) * ((double)rand() / (double)RAND_MAX) + min;
-}
+double getRandomValues(double min, double max) { return (max - min) * ((double)rand() / (double)RAND_MAX) + min; }
 
-vpMatrix generateRandomMatrix(unsigned int rows, unsigned int cols, double min=-1, double max=1)
+vpMatrix generateRandomMatrix(unsigned int rows, unsigned int cols, double min = -1, double max = 1)
 {
   vpMatrix M(rows, cols);
 
@@ -74,7 +71,7 @@ vpMatrix generateRandomMatrix(unsigned int rows, unsigned int cols, double min=-
   return M;
 }
 
-vpColVector generateRandomVector(unsigned int rows, double min=-1, double max=1)
+vpColVector generateRandomVector(unsigned int rows, double min = -1, double max = 1)
 {
   vpColVector v(rows);
 
@@ -86,7 +83,7 @@ vpColVector generateRandomVector(unsigned int rows, double min=-1, double max=1)
 }
 
 // Copy of vpMatrix::mult2Matrices
-vpMatrix dgemm_regular(const vpMatrix& A, const vpMatrix& B)
+vpMatrix dgemm_regular(const vpMatrix &A, const vpMatrix &B)
 {
   vpMatrix C;
 
@@ -119,7 +116,7 @@ vpMatrix dgemm_regular(const vpMatrix& A, const vpMatrix& B)
 }
 
 // Copy of vpMatrix::AtA
-vpMatrix AtA_regular(const vpMatrix& A)
+vpMatrix AtA_regular(const vpMatrix &A)
 {
   vpMatrix B;
   B.resize(A.getCols(), A.getCols(), false);
@@ -149,7 +146,7 @@ vpMatrix AtA_regular(const vpMatrix& A)
 }
 
 // Copy of vpMatrix::AAt()
-vpMatrix AAt_regular(const vpMatrix& A)
+vpMatrix AAt_regular(const vpMatrix &A)
 {
   vpMatrix B;
   B.resize(A.getRows(), A.getRows(), false);
@@ -174,7 +171,7 @@ vpMatrix AAt_regular(const vpMatrix& A)
 }
 
 // Copy of vpMatrix::multMatrixVector
-vpColVector dgemv_regular(const vpMatrix& A, const vpColVector& v)
+vpColVector dgemv_regular(const vpMatrix &A, const vpColVector &v)
 {
   vpColVector w;
 
@@ -195,7 +192,7 @@ vpColVector dgemv_regular(const vpMatrix& A, const vpColVector& v)
   return w;
 }
 
-bool equalMatrix(const vpMatrix& A, const vpMatrix& B, double tol=1e-9)
+bool equalMatrix(const vpMatrix &A, const vpMatrix &B, double tol = 1e-9)
 {
   if (A.getRows() != B.getRows() || A.getCols() != B.getCols()) {
     return false;
@@ -212,11 +209,13 @@ bool equalMatrix(const vpMatrix& A, const vpMatrix& B, double tol=1e-9)
   return true;
 }
 
-}
+} // namespace
 
-TEST_CASE("Benchmark matrix-matrix multiplication", "[benchmark]") {
+TEST_CASE("Benchmark matrix-matrix multiplication", "[benchmark]")
+{
   if (runBenchmark || runBenchmarkAll) {
-    std::vector<std::pair<int, int>> sizes = { {3, 3}, {6, 6}, {8, 8}, {10, 10}, {20, 20}, {6, 200}, {200, 6}, {207, 119}, {83, 201}, {600, 400}, {400, 600} };
+    std::vector<std::pair<int, int> > sizes = {{3, 3},   {6, 6},     {8, 8},    {10, 10},   {20, 20},  {6, 200},
+                                               {200, 6}, {207, 119}, {83, 201}, {600, 400}, {400, 600}};
 
     for (auto sz : sizes) {
       vpMatrix A = generateRandomMatrix(sz.first, sz.second);
@@ -225,20 +224,22 @@ TEST_CASE("Benchmark matrix-matrix multiplication", "[benchmark]") {
       std::ostringstream oss;
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(" << B.getRows() << "x" << B.getCols() << ") - Naive code";
       vpMatrix C, C_true;
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         C_true = dgemm_regular(A, B);
         return C_true;
       };
 
       oss.str("");
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(" << B.getRows() << "x" << B.getCols() << ") - ViSP";
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         C = A * B;
         return C;
       };
       REQUIRE(equalMatrix(C, C_true));
 
-      if(runBenchmarkAll) {
+      if (runBenchmarkAll) {
 #if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
         cv::Mat matA(sz.first, sz.second, CV_64FC1);
         cv::Mat matB(sz.second, sz.first, CV_64FC1);
@@ -252,7 +253,8 @@ TEST_CASE("Benchmark matrix-matrix multiplication", "[benchmark]") {
 
         oss.str("");
         oss << "(" << matA.rows << "x" << matA.cols << ")x(" << matB.rows << "x" << matB.cols << ") - OpenCV";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           cv::Mat matC = matA * matB;
           return matC;
         };
@@ -270,8 +272,10 @@ TEST_CASE("Benchmark matrix-matrix multiplication", "[benchmark]") {
         }
 
         oss.str("");
-        oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ")x(" << eigenB.rows() << "x" << eigenB.cols() << ") - Eigen";
-        BENCHMARK(oss.str().c_str()) {
+        oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ")x(" << eigenB.rows() << "x" << eigenB.cols()
+            << ") - Eigen";
+        BENCHMARK(oss.str().c_str())
+        {
           Eigen::MatrixXd eigenC = eigenA * eigenB;
           return eigenC;
         };
@@ -291,31 +295,35 @@ TEST_CASE("Benchmark matrix-matrix multiplication", "[benchmark]") {
   }
 }
 
-TEST_CASE("Benchmark matrix-rotation matrix multiplication", "[benchmark]") {
+TEST_CASE("Benchmark matrix-rotation matrix multiplication", "[benchmark]")
+{
   if (runBenchmark || runBenchmarkAll) {
-    std::vector<std::pair<int, int>> sizes = { {3, 3} };
+    std::vector<std::pair<int, int> > sizes = {{3, 3}};
 
     for (auto sz : sizes) {
       vpMatrix A = generateRandomMatrix(sz.first, sz.second);
-      vpRotationMatrix B(vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)));
+      vpRotationMatrix B(vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)),
+                         vpMath::deg(getRandomValues(0, 360)));
 
       std::ostringstream oss;
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(" << B.getRows() << "x" << B.getCols() << ") - Naive code";
       vpMatrix AB, AB_true;
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AB_true = dgemm_regular(A, B);
         return AB_true;
       };
 
       oss.str("");
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(" << B.getRows() << "x" << B.getCols() << ") - ViSP";
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AB = A * B;
         return AB;
       };
       REQUIRE(equalMatrix(AB, AB_true));
 
-      if(runBenchmarkAll) {
+      if (runBenchmarkAll) {
 #if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
         cv::Mat matA(sz.first, sz.second, CV_64FC1);
         cv::Mat matB(3, 3, CV_64FC1);
@@ -333,7 +341,8 @@ TEST_CASE("Benchmark matrix-rotation matrix multiplication", "[benchmark]") {
 
         oss.str("");
         oss << "(" << matA.rows << "x" << matA.cols << ")x(" << matB.rows << "x" << matB.cols << ") - OpenCV";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           cv::Mat matC = matA * matB;
           return matC;
         };
@@ -355,8 +364,10 @@ TEST_CASE("Benchmark matrix-rotation matrix multiplication", "[benchmark]") {
         }
 
         oss.str("");
-        oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ")x(" << eigenB.rows() << "x" << eigenB.cols() << ") - Eigen";
-        BENCHMARK(oss.str().c_str()) {
+        oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ")x(" << eigenB.rows() << "x" << eigenB.cols()
+            << ") - Eigen";
+        BENCHMARK(oss.str().c_str())
+        {
           Eigen::MatrixXd eigenC = eigenA * eigenB;
           return eigenC;
         };
@@ -368,7 +379,8 @@ TEST_CASE("Benchmark matrix-rotation matrix multiplication", "[benchmark]") {
   {
     const unsigned int rows = 3, cols = 3;
     vpMatrix A = generateRandomMatrix(rows, cols);
-    vpRotationMatrix B(vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)));
+    vpRotationMatrix B(vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)),
+                       vpMath::deg(getRandomValues(0, 360)));
 
     vpMatrix AB_true = dgemm_regular(A, B);
     vpMatrix AB = A * B;
@@ -376,32 +388,36 @@ TEST_CASE("Benchmark matrix-rotation matrix multiplication", "[benchmark]") {
   }
 }
 
-TEST_CASE("Benchmark matrix-homogeneous matrix multiplication", "[benchmark]") {
+TEST_CASE("Benchmark matrix-homogeneous matrix multiplication", "[benchmark]")
+{
   if (runBenchmark || runBenchmarkAll) {
-    std::vector<std::pair<int, int>> sizes = { {4, 4} };
+    std::vector<std::pair<int, int> > sizes = {{4, 4}};
 
     for (auto sz : sizes) {
       vpMatrix A = generateRandomMatrix(sz.first, sz.second);
       vpHomogeneousMatrix B(getRandomValues(0, 1), getRandomValues(0, 1), getRandomValues(0, 1),
-                           vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)));
+                            vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)),
+                            vpMath::deg(getRandomValues(0, 360)));
 
       std::ostringstream oss;
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(" << B.getRows() << "x" << B.getCols() << ") - Naive code";
       vpMatrix AB, AB_true;
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AB_true = dgemm_regular(A, B);
         return AB_true;
       };
 
       oss.str("");
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(" << B.getRows() << "x" << B.getCols() << ") - ViSP";
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AB = A * B;
         return AB;
       };
       REQUIRE(equalMatrix(AB, AB_true));
 
-      if(runBenchmarkAll) {
+      if (runBenchmarkAll) {
 #if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
         cv::Mat matA(sz.first, sz.second, CV_64FC1);
         cv::Mat matB(4, 4, CV_64FC1);
@@ -419,7 +435,8 @@ TEST_CASE("Benchmark matrix-homogeneous matrix multiplication", "[benchmark]") {
 
         oss.str("");
         oss << "(" << matA.rows << "x" << matA.cols << ")x(" << matB.rows << "x" << matB.cols << ") - OpenCV";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           cv::Mat matC = matA * matB;
           return matC;
         };
@@ -441,8 +458,10 @@ TEST_CASE("Benchmark matrix-homogeneous matrix multiplication", "[benchmark]") {
         }
 
         oss.str("");
-        oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ")x(" << eigenB.rows() << "x" << eigenB.cols() << ") - Eigen";
-        BENCHMARK(oss.str().c_str()) {
+        oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ")x(" << eigenB.rows() << "x" << eigenB.cols()
+            << ") - Eigen";
+        BENCHMARK(oss.str().c_str())
+        {
           Eigen::MatrixXd eigenC = eigenA * eigenB;
           return eigenC;
         };
@@ -455,7 +474,8 @@ TEST_CASE("Benchmark matrix-homogeneous matrix multiplication", "[benchmark]") {
     const unsigned int rows = 4, cols = 4;
     vpMatrix A = generateRandomMatrix(rows, cols);
     vpHomogeneousMatrix B(getRandomValues(0, 1), getRandomValues(0, 1), getRandomValues(0, 1),
-                         vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)));
+                          vpMath::deg(getRandomValues(0, 360)), vpMath::deg(getRandomValues(0, 360)),
+                          vpMath::deg(getRandomValues(0, 360)));
 
     vpMatrix AB_true = dgemm_regular(A, B);
     vpMatrix AB;
@@ -464,9 +484,11 @@ TEST_CASE("Benchmark matrix-homogeneous matrix multiplication", "[benchmark]") {
   }
 }
 
-TEST_CASE("Benchmark matrix-vector multiplication", "[benchmark]") {
+TEST_CASE("Benchmark matrix-vector multiplication", "[benchmark]")
+{
   if (runBenchmark || runBenchmarkAll) {
-    std::vector<std::pair<int, int>> sizes = { {3, 3}, {6, 6}, {8, 8}, {10, 10}, {20, 20}, {6, 200}, {200, 6}, {207, 119}, {83, 201}, {600, 400}, {400, 600} };
+    std::vector<std::pair<int, int> > sizes = {{3, 3},   {6, 6},     {8, 8},    {10, 10},   {20, 20},  {6, 200},
+                                               {200, 6}, {207, 119}, {83, 201}, {600, 400}, {400, 600}};
 
     for (auto sz : sizes) {
       vpMatrix A = generateRandomMatrix(sz.first, sz.second);
@@ -475,20 +497,22 @@ TEST_CASE("Benchmark matrix-vector multiplication", "[benchmark]") {
       std::ostringstream oss;
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(" << B.getRows() << "x" << B.getCols() << ") - Naive code";
       vpColVector C, C_true;
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         C_true = dgemv_regular(A, B);
         return C_true;
       };
 
       oss.str("");
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(" << B.getRows() << "x" << B.getCols() << ") - ViSP";
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         C = A * B;
         return C;
       };
       REQUIRE(equalMatrix(C, C_true));
 
-      if(runBenchmarkAll) {
+      if (runBenchmarkAll) {
 #if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
         cv::Mat matA(sz.first, sz.second, CV_64FC1);
         cv::Mat matB(sz.second, 1, CV_64FC1);
@@ -504,7 +528,8 @@ TEST_CASE("Benchmark matrix-vector multiplication", "[benchmark]") {
 
         oss.str("");
         oss << "(" << matA.rows << "x" << matA.cols << ")x(" << matB.rows << "x" << matB.cols << ") - OpenCV";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           cv::Mat matC = matA * matB;
           return matC;
         };
@@ -524,8 +549,10 @@ TEST_CASE("Benchmark matrix-vector multiplication", "[benchmark]") {
         }
 
         oss.str("");
-        oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ")x(" << eigenB.rows() << "x" << eigenB.cols() << ") - Eigen";
-        BENCHMARK(oss.str().c_str()) {
+        oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ")x(" << eigenB.rows() << "x" << eigenB.cols()
+            << ") - Eigen";
+        BENCHMARK(oss.str().c_str())
+        {
           Eigen::MatrixXd eigenC = eigenA * eigenB;
           return eigenC;
         };
@@ -545,9 +572,11 @@ TEST_CASE("Benchmark matrix-vector multiplication", "[benchmark]") {
   }
 }
 
-TEST_CASE("Benchmark AtA", "[benchmark]") {
+TEST_CASE("Benchmark AtA", "[benchmark]")
+{
   if (runBenchmark || runBenchmarkAll) {
-    std::vector<std::pair<int, int>> sizes = { {3, 3}, {6, 6}, {8, 8}, {10, 10}, {20, 20}, {6, 200}, {200, 6}, {207, 119}, {83, 201}, {600, 400}, {400, 600} };
+    std::vector<std::pair<int, int> > sizes = {{3, 3},   {6, 6},     {8, 8},    {10, 10},   {20, 20},  {6, 200},
+                                               {200, 6}, {207, 119}, {83, 201}, {600, 400}, {400, 600}};
 
     for (auto sz : sizes) {
       vpMatrix A = generateRandomMatrix(sz.first, sz.second);
@@ -555,20 +584,22 @@ TEST_CASE("Benchmark AtA", "[benchmark]") {
       std::ostringstream oss;
       oss << "(" << A.getRows() << "x" << A.getCols() << ") - Naive code";
       vpMatrix AtA, AtA_true;
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AtA_true = AtA_regular(A);
         return AtA_true;
       };
 
       oss.str("");
       oss << "(" << A.getRows() << "x" << A.getCols() << ") - ViSP";
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AtA = A.AtA();
         return AtA;
       };
       REQUIRE(equalMatrix(AtA, AtA_true));
 
-      if(runBenchmarkAll) {
+      if (runBenchmarkAll) {
 #if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
         cv::Mat matA(sz.first, sz.second, CV_64FC1);
 
@@ -580,7 +611,8 @@ TEST_CASE("Benchmark AtA", "[benchmark]") {
 
         oss.str("");
         oss << "(" << matA.rows << "x" << matA.cols << ") - OpenCV";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           cv::Mat matAtA = matA.t() * matA;
           return matAtA;
         };
@@ -597,7 +629,8 @@ TEST_CASE("Benchmark AtA", "[benchmark]") {
 
         oss.str("");
         oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ") - Eigen";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           Eigen::MatrixXd eigenAtA = eigenA.transpose() * eigenA;
           return eigenAtA;
         };
@@ -616,9 +649,12 @@ TEST_CASE("Benchmark AtA", "[benchmark]") {
   }
 }
 
-TEST_CASE("Benchmark AAt", "[benchmark]") {
+TEST_CASE("Benchmark AAt", "[benchmark]")
+{
   if (runBenchmark || runBenchmarkAll) {
-    std::vector<std::pair<int, int>> sizes = { {3, 3}, {6, 6}, {8, 8}, {10, 10}, {20, 20}, {6, 200}, {200, 6} };//, {207, 119}, {83, 201}, {600, 400}, {400, 600} };
+    std::vector<std::pair<int, int> > sizes = {
+        {3, 3},   {6, 6},   {8, 8},  {10, 10},
+        {20, 20}, {6, 200}, {200, 6}}; //, {207, 119}, {83, 201}, {600, 400}, {400, 600} };
 
     for (auto sz : sizes) {
       vpMatrix A = generateRandomMatrix(sz.first, sz.second);
@@ -626,20 +662,22 @@ TEST_CASE("Benchmark AAt", "[benchmark]") {
       std::ostringstream oss;
       oss << "(" << A.getRows() << "x" << A.getCols() << ") - Naive code";
       vpMatrix AAt_true, AAt;
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AAt_true = AAt_regular(A);
         return AAt_true;
       };
 
       oss.str("");
       oss << "(" << A.getRows() << "x" << A.getCols() << ") - ViSP";
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AAt = A.AAt();
         return AAt;
       };
       REQUIRE(equalMatrix(AAt, AAt_true));
 
-      if(runBenchmarkAll) {
+      if (runBenchmarkAll) {
 #if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
         cv::Mat matA(sz.first, sz.second, CV_64FC1);
 
@@ -651,7 +689,8 @@ TEST_CASE("Benchmark AAt", "[benchmark]") {
 
         oss.str("");
         oss << "(" << matA.rows << "x" << matA.cols << ") - OpenCV";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           cv::Mat matAAt = matA * matA.t();
           return matAAt;
         };
@@ -668,7 +707,8 @@ TEST_CASE("Benchmark AAt", "[benchmark]") {
 
         oss.str("");
         oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ") - Eigen";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           Eigen::MatrixXd eigenAAt = eigenA * eigenA.transpose();
           return eigenAAt;
         };
@@ -687,9 +727,10 @@ TEST_CASE("Benchmark AAt", "[benchmark]") {
   }
 }
 
-TEST_CASE("Benchmark matrix-velocity twist multiplication", "[benchmark]") {
+TEST_CASE("Benchmark matrix-velocity twist multiplication", "[benchmark]")
+{
   if (runBenchmark || runBenchmarkAll) {
-    std::vector<std::pair<int, int>> sizes = { {6, 6}, {20, 6}, {207, 6}, {600, 6}, {1201, 6} };
+    std::vector<std::pair<int, int> > sizes = {{6, 6}, {20, 6}, {207, 6}, {600, 6}, {1201, 6}};
 
     for (auto sz : sizes) {
       vpMatrix A = generateRandomMatrix(sz.first, sz.second);
@@ -698,20 +739,22 @@ TEST_CASE("Benchmark matrix-velocity twist multiplication", "[benchmark]") {
       std::ostringstream oss;
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(6x6) - Naive code";
       vpMatrix AV, AV_true;
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AV_true = dgemm_regular(A, V);
         return AV_true;
       };
 
       oss.str("");
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(6x6) - ViSP";
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AV = A * V;
         return AV;
       };
       REQUIRE(equalMatrix(AV, AV_true));
 
-      if(runBenchmarkAll) {
+      if (runBenchmarkAll) {
 #if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
         cv::Mat matA(sz.first, sz.second, CV_64FC1);
         cv::Mat matV(6, 6, CV_64FC1);
@@ -729,7 +772,8 @@ TEST_CASE("Benchmark matrix-velocity twist multiplication", "[benchmark]") {
 
         oss.str("");
         oss << "(" << matA.rows << "x" << matA.cols << ")x(6x6) - OpenCV";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           cv::Mat matAV = matA * matV;
           return matAV;
         };
@@ -752,7 +796,8 @@ TEST_CASE("Benchmark matrix-velocity twist multiplication", "[benchmark]") {
 
         oss.str("");
         oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ")x(6x6) - Eigen";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           Eigen::MatrixXd eigenAV = eigenA * eigenV;
           return eigenAV;
         };
@@ -772,9 +817,10 @@ TEST_CASE("Benchmark matrix-velocity twist multiplication", "[benchmark]") {
   }
 }
 
-TEST_CASE("Benchmark matrix-force twist multiplication", "[benchmark]") {
+TEST_CASE("Benchmark matrix-force twist multiplication", "[benchmark]")
+{
   if (runBenchmark || runBenchmarkAll) {
-    std::vector<std::pair<int, int>> sizes = { {6, 6}, {20, 6}, {207, 6}, {600, 6}, {1201, 6} };
+    std::vector<std::pair<int, int> > sizes = {{6, 6}, {20, 6}, {207, 6}, {600, 6}, {1201, 6}};
 
     for (auto sz : sizes) {
       vpMatrix A = generateRandomMatrix(sz.first, sz.second);
@@ -783,20 +829,22 @@ TEST_CASE("Benchmark matrix-force twist multiplication", "[benchmark]") {
       std::ostringstream oss;
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(6x6) - Naive code";
       vpMatrix AV, AV_true;
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AV_true = dgemm_regular(A, V);
         return AV_true;
       };
 
       oss.str("");
       oss << "(" << A.getRows() << "x" << A.getCols() << ")x(6x6) - ViSP";
-      BENCHMARK(oss.str().c_str()) {
+      BENCHMARK(oss.str().c_str())
+      {
         AV = A * V;
         return AV;
       };
       REQUIRE(equalMatrix(AV, AV_true));
 
-      if(runBenchmarkAll) {
+      if (runBenchmarkAll) {
 #if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
         cv::Mat matA(sz.first, sz.second, CV_64FC1);
         cv::Mat matV(6, 6, CV_64FC1);
@@ -814,7 +862,8 @@ TEST_CASE("Benchmark matrix-force twist multiplication", "[benchmark]") {
 
         oss.str("");
         oss << "(" << matA.rows << "x" << matA.cols << ")x(6x6) - OpenCV";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           cv::Mat matAV = matA * matV;
           return matAV;
         };
@@ -837,7 +886,8 @@ TEST_CASE("Benchmark matrix-force twist multiplication", "[benchmark]") {
 
         oss.str("");
         oss << "(" << eigenA.rows() << "x" << eigenA.cols() << ")x(6x6) - Eigen";
-        BENCHMARK(oss.str().c_str()) {
+        BENCHMARK(oss.str().c_str())
+        {
           Eigen::MatrixXd eigenAV = eigenA * eigenV;
           return eigenAV;
         };
@@ -867,20 +917,20 @@ int main(int argc, char *argv[])
   Catch::Session session; // There must be exactly one instance
   unsigned int lapackMinSize = vpMatrix::getLapackMatrixMinSize();
 
-  std::cout << "Default matrix/vector min size to enable Blas/Lapack optimization: "
-            << lapackMinSize << std::endl;
+  std::cout << "Default matrix/vector min size to enable Blas/Lapack optimization: " << lapackMinSize << std::endl;
   // Build a new parser on top of Catch's
   using namespace Catch::clara;
-  auto cli = session.cli()   // Get Catch's composite command line parser
-      | Opt(runBenchmark)    // bind variable to a new option, with a hint string
-      ["--benchmark"]        // the option names it will respond to
-      ("run benchmark comparing naive code with ViSP implementation")     // description string for the help output
-      | Opt(runBenchmarkAll) // bind variable to a new option, with a hint string
-      ["--benchmark-all"]    // the option names it will respond to
-      ("run benchmark comparing naive code with ViSP, OpenCV, Eigen implementation")    // description string for the help output
-      | Opt(lapackMinSize, "min size")   // bind variable to a new option, with a hint string
-      ["--lapack-min-size"]  // the option names it will respond to
-      ("matrix/vector min size to enable blas/lapack usage");    // description string for the help output
+  auto cli = session.cli()         // Get Catch's composite command line parser
+             | Opt(runBenchmark)   // bind variable to a new option, with a hint string
+                   ["--benchmark"] // the option names it will respond to
+             ("run benchmark comparing naive code with ViSP implementation") // description string for the help output
+             | Opt(runBenchmarkAll)    // bind variable to a new option, with a hint string
+                   ["--benchmark-all"] // the option names it will respond to
+             ("run benchmark comparing naive code with ViSP, OpenCV, Eigen implementation") // description string for
+                                                                                            // the help output
+             | Opt(lapackMinSize, "min size") // bind variable to a new option, with a hint string
+                   ["--lapack-min-size"]      // the option names it will respond to
+             ("matrix/vector min size to enable blas/lapack usage"); // description string for the help output
 
   // Now pass the new composite back to Catch so it uses that
   session.cli(cli);
@@ -889,8 +939,8 @@ int main(int argc, char *argv[])
   session.applyCommandLine(argc, argv);
 
   vpMatrix::setLapackMatrixMinSize(lapackMinSize);
-  std::cout << "Used matrix/vector min size to enable Blas/Lapack optimization: "
-            << vpMatrix::getLapackMatrixMinSize() << std::endl;
+  std::cout << "Used matrix/vector min size to enable Blas/Lapack optimization: " << vpMatrix::getLapackMatrixMinSize()
+            << std::endl;
 
   int numFailed = session.run();
 
@@ -902,8 +952,5 @@ int main(int argc, char *argv[])
 #else
 #include <iostream>
 
-int main()
-{
-  return 0;
-}
+int main() { return EXIT_SUCCESS; }
 #endif
