@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Test some vpMatrix functionalities.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example testMatrix.cpp
@@ -75,10 +72,7 @@ bool test(const std::string &s, const vpMatrix &M, const std::vector<double> &be
   return true;
 }
 
-double getRandomValues(double min, double max)
-{
-  return (max - min) * ((double)rand() / (double)RAND_MAX) + min;
-}
+double getRandomValues(double min, double max) { return (max - min) * ((double)rand() / (double)RAND_MAX) + min; }
 
 bool equalMatrix(const vpMatrix &A, const vpMatrix &B, double tol = std::numeric_limits<double>::epsilon())
 {
@@ -110,11 +104,10 @@ vpMatrix generateRandomMatrix(unsigned int rows, unsigned int cols, double min,
   return M;
 }
 
-std::vector<double> computeHadamard(const std::vector<double>& v1, const std::vector<double>& v2)
+std::vector<double> computeHadamard(const std::vector<double> &v1, const std::vector<double> &v2)
 {
   std::vector<double> result;
-  std::transform(v1.begin(), v1.end(), v2.begin(),
-                 std::back_inserter(result), std::multiplies<double>());
+  std::transform(v1.begin(), v1.end(), v2.begin(), std::back_inserter(result), std::multiplies<double>());
   return result;
 }
 } // namespace
@@ -275,7 +268,7 @@ int main(int argc, char *argv[])
       M[1][1] = 12.345;
       M[1][2] = .12345;
       std::cout << "call std::cout << M;" << std::endl;
-      std::cout << M;
+      std::cout << M << std::endl;
       std::cout << "call M.print (std::cout, 6);" << std::endl;
       M.print(std::cout, 6);
       std::cout << std::endl;
@@ -298,18 +291,44 @@ int main(int argc, char *argv[])
       std::cout << "------------------------" << std::endl;
       M.resize(3, 3);
       M.eye(3);
-      M[0][2] = -0.0000000876;
+      M[0][2] = -0.0000876;
       std::cout << "call std::cout << M;" << std::endl;
       std::cout << M << std::endl;
 
       std::cout << "call M.print (std::cout, 4);" << std::endl;
       M.print(std::cout, 4);
       std::cout << std::endl;
+      std::cout << "call M.print (std::cout, 6, \"M\");" << std::endl;
+      M.print(std::cout, 6, "M");
+      std::cout << std::endl;
       std::cout << "call M.print (std::cout, 10, \"M\");" << std::endl;
       M.print(std::cout, 10, "M");
       std::cout << std::endl;
-      std::cout << "call M.print (std::cout, 20, \"M\");" << std::endl;
-      M.print(std::cout, 20, "M");
+
+      M.resize(2, 3);
+      M[0][0] = -1;
+      M[0][1] = -2;
+      M[0][2] = -3;
+      M[1][0] = 4;
+      M[1][1] = 5.5;
+      M[1][2] = 6.0f;
+      std::cout << "call std::cout << M;" << std::endl;
+      std::cout << M << std::endl;
+      std::cout << "call M.print (std::cout, 5, \"M\");" << std::endl;
+      M.print(std::cout, 5, "M");
+      std::cout << std::endl;
+
+      M.resize(2, 3);
+      M[0][0] = -1;
+      M[0][1] = -2;
+      M[0][2] = -3;
+      M[1][0] = 4;
+      M[1][1] = 5.;
+      M[1][2] = 6;
+      std::cout << "call std::cout << M;" << std::endl;
+      std::cout << M << std::endl;
+      std::cout << "call M.print (std::cout, 5, \"M\");" << std::endl;
+      M.print(std::cout, 5, "M");
       std::cout << std::endl;
 
       std::cout << "------------------------" << std::endl;
@@ -542,7 +561,8 @@ int main(int argc, char *argv[])
       std::cout << "------------------------" << std::endl;
 
       vpMatrix m_big_stack_static = generateRandomMatrix(ctest ? 100 : 1000, ctest ? 10 : 100, -1000.0, 1000.0);
-      std::cout << "m_big_stack_static: " << m_big_stack_static.getRows() << "x" << m_big_stack_static.getCols() << std::endl;
+      std::cout << "m_big_stack_static: " << m_big_stack_static.getRows() << "x" << m_big_stack_static.getCols()
+                << std::endl;
 
       vpMatrix m_big_stack_static_row, m_big_stack_static_row_tmp;
       t = vpTime::measureTimeMs();
@@ -699,7 +719,7 @@ int main(int argc, char *argv[])
       vpMatrix M(3, 5);
       for (unsigned int j = 0; j < M.getCols(); j++) {
         for (unsigned int i = 0; i < M.getRows(); i++) {
-          M[i][j] = i + j*M.getRows();
+          M[i][j] = i + j * M.getRows();
         }
       }
       std::cout << "M:\n" << M << std::endl;
@@ -709,8 +729,8 @@ int main(int argc, char *argv[])
         std::cerr << "Problem in vpMatrix::stackColumns(): size differ" << std::endl;
         return EXIT_FAILURE;
       }
-      for (unsigned int i=0; i < v.size(); i++) {
-        if (std::fabs(v[i]-static_cast<double>(i)) > std::numeric_limits<double>::epsilon()) {
+      for (unsigned int i = 0; i < v.size(); i++) {
+        if (std::fabs(v[i] - static_cast<double>(i)) > std::numeric_limits<double>::epsilon()) {
           std::cerr << "Problem in vpMatrix::stackColumns(): content differ" << std::endl;
           return EXIT_FAILURE;
         }
@@ -724,7 +744,7 @@ int main(int argc, char *argv[])
       vpMatrix M(3, 5);
       for (unsigned int i = 0; i < M.getRows(); i++) {
         for (unsigned int j = 0; j < M.getCols(); j++) {
-          M[i][j] = i*M.getCols() + j;
+          M[i][j] = i * M.getCols() + j;
         }
       }
       std::cout << "M:\n" << M << std::endl;
@@ -734,8 +754,8 @@ int main(int argc, char *argv[])
         std::cerr << "Problem in vpMatrix::stackRows(): size differ" << std::endl;
         return EXIT_FAILURE;
       }
-      for (unsigned int i=0; i < v.size(); i++) {
-        if (std::fabs(v[i]-static_cast<double>(i)) > std::numeric_limits<double>::epsilon()) {
+      for (unsigned int i = 0; i < v.size(); i++) {
+        if (std::fabs(v[i] - static_cast<double>(i)) > std::numeric_limits<double>::epsilon()) {
           std::cerr << "Problem in vpMatrix::stackRows(): content differ" << std::endl;
           return EXIT_FAILURE;
         }
@@ -746,10 +766,10 @@ int main(int argc, char *argv[])
       std::cout << "\n------------------------" << std::endl;
       std::cout << "--- TEST vpMatrix::getCol()" << std::endl;
       std::cout << "------------------------" << std::endl;
-      vpMatrix A(4,4);
-      for(unsigned int i=0; i < A.getRows(); i++)
-        for(unsigned int j=0; j < A.getCols(); j++)
-          A[i][j] = i*A.getCols()+j;
+      vpMatrix A(4, 4);
+      for (unsigned int i = 0; i < A.getRows(); i++)
+        for (unsigned int j = 0; j < A.getCols(); j++)
+          A[i][j] = i * A.getCols() + j;
 
       {
         vpColVector cv = A.getCol(1, 1, 3);
@@ -775,10 +795,10 @@ int main(int argc, char *argv[])
       std::cout << "\n------------------------" << std::endl;
       std::cout << "--- TEST vpMatrix::getRow()" << std::endl;
       std::cout << "------------------------" << std::endl;
-      vpMatrix A(4,4);
-      for(unsigned int i=0; i < A.getRows(); i++)
-        for(unsigned int j=0; j < A.getCols(); j++)
-          A[i][j] = i*A.getCols()+j;
+      vpMatrix A(4, 4);
+      for (unsigned int i = 0; i < A.getRows(); i++)
+        for (unsigned int j = 0; j < A.getCols(); j++)
+          A[i][j] = i * A.getCols() + j;
 
       {
         vpRowVector rv = A.getRow(1, 1, 3);
@@ -804,10 +824,10 @@ int main(int argc, char *argv[])
       std::cout << "\n------------------------" << std::endl;
       std::cout << "--- TEST vpMatrix::getDiag()" << std::endl;
       std::cout << "------------------------" << std::endl;
-      vpMatrix A(3,4);
-      for(unsigned int i=0; i < A.getRows(); i++)
-        for(unsigned int j=0; j < A.getCols(); j++)
-          A[i][j] = i*A.getCols()+j;
+      vpMatrix A(3, 4);
+      for (unsigned int i = 0; i < A.getRows(); i++)
+        for (unsigned int j = 0; j < A.getCols(); j++)
+          A[i][j] = i * A.getCols() + j;
 
       vpColVector diag = A.getDiag();
       vpColVector ref;
