@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Test some vpMath functionalities.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example testRobust.cpp
@@ -79,7 +76,8 @@ plot '%s' title \"Tukey Estimator\" lw 2, 1 title \"Least-Squares\" lw 2\n\
 \n\
 \n\
 SYNOPSIS\n\
-  %s [-o <output filename>] [-h]\n", ofilename.c_str(), name);
+  %s [-o <output filename>] [-h]\n",
+          ofilename.c_str(), name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                              Default\n\
@@ -88,7 +86,8 @@ OPTIONS:                                              Default\n\
      weights.\n\
 \n\
   -h\n\
-     Print the help.\n", ofilename.c_str());
+     Print the help.\n",
+          ofilename.c_str());
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
@@ -168,7 +167,7 @@ int main(int argc, const char **argv)
         std::cerr << std::endl << "ERROR:" << std::endl;
         std::cerr << "  Cannot create " << ofilename << std::endl;
         std::cerr << "  Check your -o " << ofilename << " option " << std::endl;
-        exit(-1);
+        return EXIT_FAILURE;
       }
     }
 
@@ -177,7 +176,7 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, ofilename) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     double sig = 1;
@@ -191,7 +190,7 @@ int main(int argc, const char **argv)
       std::cerr << std::endl << "ERROR:" << std::endl;
       std::cerr << "  Cannot create the file: " << ofilename << std::endl;
       std::cerr << "  Check your -o " << ofilename << " option " << std::endl;
-      exit(-1);
+      return EXIT_FAILURE;
     }
     double x = -10;
     while (x < 10) {
@@ -203,9 +202,9 @@ int main(int argc, const char **argv)
       f << x << "  " << w << std::endl;
       x += 0.01;
     }
-    return 0;
+    return EXIT_SUCCESS;
   } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
-    return 1;
+    return EXIT_FAILURE;
   }
 }
