@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * Tests transformation from various representations of rotation.
  *
- * Authors:
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file testRotation.cpp
@@ -104,6 +100,18 @@ bool test(const std::string &s, const vpRotationVector &v, const double &bench)
   return true;
 }
 
+bool test_matrix_equal(const vpHomogeneousMatrix &M1, const vpHomogeneousMatrix &M2, double epsilon = 1e-10)
+{
+  for (unsigned int i = 0; i < 4; i++) {
+    for (unsigned int j = 0; j < 4; j++) {
+      if (!vpMath::equal(M1[i][j], M2[i][j], epsilon)) {
+        return false;
+      }
+    }
+  }
+  return true;
+}
+
 int main()
 {
   try {
@@ -414,9 +422,48 @@ int main()
         std::cout << rzyx_final << std::endl;
       }
     }
+    {
+      // Test rotation_matrix * homogeneous_matrix
+      vpHomogeneousMatrix  _1_M_2_truth;
+      _1_M_2_truth[0][0] = 0.9835;
+      _1_M_2_truth[0][1] = -0.0581;
+      _1_M_2_truth[0][2] = 0.1716;
+      _1_M_2_truth[0][3] = 0;
+      _1_M_2_truth[1][0] = -0.0489;
+      _1_M_2_truth[1][1] = -0.9972;
+      _1_M_2_truth[1][2] = -0.0571;
+      _1_M_2_truth[1][3] = 0;
+      _1_M_2_truth[2][0] = 0.1744;
+      _1_M_2_truth[2][1] = 0.0478;
+      _1_M_2_truth[2][2] = -0.9835;
+      _1_M_2_truth[2][3] = 0;
+      vpHomogeneousMatrix _2_M_3_;
+      _2_M_3_[0][0] = 0.9835;
+      _2_M_3_[0][1] = -0.0581;
+      _2_M_3_[0][2] = 0.1716;
+      _2_M_3_[0][3] = 0.0072;
+      _2_M_3_[1][0] = -0.0489;
+      _2_M_3_[1][1] = -0.9972;
+      _2_M_3_[1][2] = -0.0571;
+      _2_M_3_[1][3] = 0.0352;
+      _2_M_3_[2][0] = 0.1744;
+      _2_M_3_[2][1] = 0.0478;
+      _2_M_3_[2][2] = -0.9835;
+      _2_M_3_[2][3] = 0.9470;
+
+      vpRotationMatrix _1_R_2_ = _1_M_2_truth.getRotationMatrix();
+      vpHomogeneousMatrix _1_M_3_(_1_R_2_* _2_M_3_);
+      vpHomogeneousMatrix _1_M_3_truth(_1_M_2_truth * _2_M_3_);
+      bool success = test_matrix_equal(_1_M_3_, _1_M_3_truth);
+      std::cout << "Test vpHomogeneousMatrix vpRotationMatrix::operator*(vpHomogeneousMatrix) " << (success ? "succeed" : "failed") << std::endl;
+      if (!success) {
+        return EXIT_FAILURE;
+      }
+    }
     std::cout << "All tests succeed" << std::endl;
     return EXIT_SUCCESS;
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
     return EXIT_FAILURE;
   }
