@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,7 +31,7 @@
  * Description:
  * Test for UDP client.
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example testUDPClient.cpp
@@ -46,14 +46,14 @@
 
 namespace
 {
-struct DataType {
+struct vpDataType_t {
   double double_val;
   int int_val;
 
-  DataType() : double_val(0.0), int_val(0) {}
-  DataType(double dbl, int i) : double_val(dbl), int_val(i) {}
+  vpDataType_t() : double_val(0.0), int_val(0) {}
+  vpDataType_t(double dbl, int i) : double_val(dbl), int_val(i) {}
 };
-}
+} // namespace
 
 int main(int argc, char **argv)
 {
@@ -65,10 +65,9 @@ int main(int argc, char **argv)
     for (int i = 1; i < argc; i++) {
       if (std::string(argv[i]) == "--ip" && i + 1 < argc) {
         servername = std::string(argv[i + 1]);
-      }
-      else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
+      } else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
         std::cout << argv[0] << " [--ip <address> (default: 127.0.0.1)] [--help] [-h]"
-                             << "\n";
+                  << "\n";
         return EXIT_SUCCESS;
       }
     }
@@ -77,7 +76,7 @@ int main(int argc, char **argv)
     vpUDPClient client(servername, port);
 
     // Send custom data type
-    DataType data_type(1234.56789, 123450);
+    vpDataType_t data_type(1234.56789, 123450);
     char data[sizeof(data_type.double_val) + sizeof(data_type.int_val)];
     memcpy(data, &data_type.double_val, sizeof(data_type.double_val));
     memcpy(data + sizeof(data_type.double_val), &data_type.int_val, sizeof(data_type.int_val));
