@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Test functions in vpIoTools.
  *
- * Authors:
- * Souriya Trinh
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
 
@@ -46,6 +43,8 @@
 
 #include <iostream> // std::cout
 #include <limits>   // std::numeric_limits
+#include <math.h>   // fabs
+
 #include <visp3/core/vpConfig.h>
 #include <visp3/core/vpConvert.h>
 
@@ -53,7 +52,7 @@ bool areSame(double a, double b) { return fabs(a - b) < std::numeric_limits<doub
 
 void testConvertFromImagePointToPoint2f()
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_FEATURES2D)
   vpImagePoint imPt1(12.5f, .85f);
   vpImagePoint imPt2(-44.26f, 125.11f);
   vpImagePoint imPt3(0.0f, -1.756e-10f);
@@ -92,7 +91,8 @@ void testConvertFromImagePointToPoint2f()
       else
         nbNOk++;
     }
-  } else {
+  }
+  else {
     nbNOk += 3;
   }
 
@@ -102,7 +102,7 @@ void testConvertFromImagePointToPoint2f()
 
 void testConvertFromPoint2fToImagePoint()
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_FEATURES2D)
   vpImagePoint imPt1, imPt2, imPt3;
 
   cv::Point2f pt1(12.5f, .85f), pt2(-44.26f, 125.11f), pt3(0.0f, -1.756e-10f);
@@ -140,7 +140,8 @@ void testConvertFromPoint2fToImagePoint()
       else
         nbNOk++;
     }
-  } else {
+  }
+  else {
     nbNOk += 3;
   }
 
@@ -150,7 +151,7 @@ void testConvertFromPoint2fToImagePoint()
 
 void testConvertFromImagePointToPoint2d()
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_FEATURES2D)
   vpImagePoint imPt1(12.5, .85);
   vpImagePoint imPt2(-44.26, 125.11);
   vpImagePoint imPt3(0, -1.756e-10);
@@ -189,7 +190,8 @@ void testConvertFromImagePointToPoint2d()
       else
         nbNOk++;
     }
-  } else {
+  }
+  else {
     nbNOk += 3;
   }
 
@@ -199,7 +201,7 @@ void testConvertFromImagePointToPoint2d()
 
 void testConvertFromPoint2dToImagePoint()
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_FEATURES2D)
   vpImagePoint imPt1, imPt2, imPt3;
 
   cv::Point2d pt1(12.5, .85), pt2(-44.26, 125.11), pt3(0, -1.756e-10);
@@ -237,7 +239,8 @@ void testConvertFromPoint2dToImagePoint()
       else
         nbNOk++;
     }
-  } else {
+  }
+  else {
     nbNOk += 3;
   }
 
@@ -247,7 +250,7 @@ void testConvertFromPoint2dToImagePoint()
 
 void testConvertFromKeyPointToImagePoint()
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_FEATURES2D)
   cv::KeyPoint kp1(12.5f, .85f, 0), kp2(-44.26f, 125.11f, 0), kp3(0.0f, -1.756e-10f, 0);
   vpImagePoint imPt1, imPt2, imPt3;
 
@@ -280,12 +283,13 @@ void testConvertFromKeyPointToImagePoint()
   if (listOfImPts.size() == listOfKeyPoints.size()) {
     for (size_t i = 0; i < 3; i++) {
       if (areSame(listOfImPts[i].get_u(), listOfKeyPoints[i].pt.x) &&
-          areSame(listOfImPts[i].get_v(), listOfKeyPoints[i].pt.y))
+        areSame(listOfImPts[i].get_v(), listOfKeyPoints[i].pt.y))
         nbOk++;
       else
         nbNOk++;
     }
-  } else {
+  }
+  else {
     nbNOk += 3;
   }
 
@@ -295,7 +299,7 @@ void testConvertFromKeyPointToImagePoint()
 
 void testConvertFromPoint3fToPoint()
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_FEATURES2D)
   cv::Point3f pt1(12.5f, .85f, 110.0f), pt2(-44.26f, 125.11f, -98e2f), pt3(0.0f, -1.756e-10f, 0.00015f);
   vpPoint point1, point2, point3;
 
@@ -328,12 +332,13 @@ void testConvertFromPoint3fToPoint()
   if (listOfPoints3f.size() == listOfPts.size()) {
     for (size_t i = 0; i < 3; i++) {
       if (areSame(listOfPts[i].get_oX(), listOfPoints3f[i].x) && areSame(listOfPts[i].get_oY(), listOfPoints3f[i].y) &&
-          areSame(listOfPts[i].get_oZ(), listOfPoints3f[i].z))
+        areSame(listOfPts[i].get_oZ(), listOfPoints3f[i].z))
         nbOk++;
       else
         nbNOk++;
     }
-  } else {
+  }
+  else {
     nbNOk += 3;
   }
 
@@ -343,7 +348,7 @@ void testConvertFromPoint3fToPoint()
 
 void testConvertFromPointToPoint3f()
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_FEATURES2D)
   cv::Point3f pt1, pt2, pt3;
   vpPoint point1, point2, point3;
   point1.set_oX(12.5f);
@@ -387,12 +392,13 @@ void testConvertFromPointToPoint3f()
   if (listOfPoints3f.size() == listOfPts.size()) {
     for (size_t i = 0; i < 3; i++) {
       if (areSame(listOfPts[i].get_oX(), listOfPoints3f[i].x) && areSame(listOfPts[i].get_oY(), listOfPoints3f[i].y) &&
-          areSame(listOfPts[i].get_oZ(), listOfPoints3f[i].z))
+        areSame(listOfPts[i].get_oZ(), listOfPoints3f[i].z))
         nbOk++;
       else
         nbNOk++;
     }
-  } else {
+  }
+  else {
     nbNOk += 3;
   }
 
@@ -410,5 +416,5 @@ int main()
   testConvertFromKeyPointToImagePoint();
   testConvertFromPoint3fToPoint();
   testConvertFromPointToPoint3f();
-  return 0;
+  return EXIT_SUCCESS;
 }
