@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,7 +31,7 @@
  * Description:
  * Test functions in vpIoTools.
  *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \example testIoTools.cpp
 
@@ -45,8 +45,7 @@
 
 namespace
 {
-template <typename T>
-void checkReadBinaryValue(std::ifstream &file, const T checkValue)
+template <typename T> void checkReadBinaryValue(std::ifstream &file, const T checkValue)
 {
   T value = (T)10;
   vpIoTools::readBinaryValueLE(file, value);
@@ -57,8 +56,7 @@ void checkReadBinaryValue(std::ifstream &file, const T checkValue)
   }
 }
 
-template <>
-void checkReadBinaryValue<float>(std::ifstream &file, const float checkValue)
+template <> void checkReadBinaryValue<float>(std::ifstream &file, const float checkValue)
 {
   float value = 10.0f;
   vpIoTools::readBinaryValueLE(file, value);
@@ -69,8 +67,7 @@ void checkReadBinaryValue<float>(std::ifstream &file, const float checkValue)
   }
 }
 
-template <>
-void checkReadBinaryValue<double>(std::ifstream &file, const double checkValue)
+template <> void checkReadBinaryValue<double>(std::ifstream &file, const double checkValue)
 {
   double value = 10.0;
   vpIoTools::readBinaryValueLE(file, value);
@@ -80,7 +77,7 @@ void checkReadBinaryValue<double>(std::ifstream &file, const double checkValue)
     throw vpException(vpException::badValue, ss.str());
   }
 }
-}
+} // namespace
 
 int main(int argc, const char **argv)
 {
@@ -464,7 +461,7 @@ int main(int argc, const char **argv)
     vpIoTools::makeDirectory(directory_filename);
     std::cout << "Create directories: " << directory_filename << std::endl;
 
-    if (! vpIoTools::checkDirectory(directory_filename)) {
+    if (!vpIoTools::checkDirectory(directory_filename)) {
       std::cerr << "Error: " << directory_filename << " is not a directory" << std::endl;
       return EXIT_FAILURE;
     }
@@ -477,7 +474,7 @@ int main(int argc, const char **argv)
     vpIoTools::makeDirectory(directory_filename);
     std::cout << "Create directories: " << directory_filename << std::endl;
 
-    if (! vpIoTools::checkDirectory(directory_filename)) {
+    if (!vpIoTools::checkDirectory(directory_filename)) {
       std::cerr << "Error: " << directory_filename << " is not a directory" << std::endl;
       return EXIT_FAILURE;
     }
@@ -491,7 +488,7 @@ int main(int argc, const char **argv)
     vpIoTools::makeDirectory(directory_filename);
     std::cout << "Create directories: " << directory_filename << std::endl;
 
-    if (! vpIoTools::checkDirectory(directory_filename)) {
+    if (!vpIoTools::checkDirectory(directory_filename)) {
       std::cerr << "Error: " << directory_filename << " is not a directory" << std::endl;
       return EXIT_FAILURE;
     }
@@ -504,12 +501,12 @@ int main(int argc, const char **argv)
     vpIoTools::makeDirectory(directory_filename);
     std::cout << "Create directories: " << directory_filename << std::endl;
 
-    if (! vpIoTools::checkDirectory(directory_filename)) {
+    if (!vpIoTools::checkDirectory(directory_filename)) {
       std::cerr << "Error: " << directory_filename << " is not a directory" << std::endl;
       return EXIT_FAILURE;
     }
 
-    //Delete test directory
+    // Delete test directory
     if (!vpIoTools::remove(tmp_dir + "/test_directory1")) {
       std::cerr << "Error: cannot remove directory: " << tmp_dir << "/test_directory1" << std::endl;
       return EXIT_FAILURE;
@@ -536,7 +533,7 @@ int main(int argc, const char **argv)
     vpIoTools::makeFifo(fifo_file);
     std::cout << "Create fifo file: " << fifo_file << std::endl;
 
-    if (! vpIoTools::checkFifo(fifo_file)) {
+    if (!vpIoTools::checkFifo(fifo_file)) {
       std::cerr << "Error: file " << fifo_file << " is not a fifo file as expected" << std::endl;
       return EXIT_FAILURE;
     }
@@ -558,7 +555,8 @@ int main(int argc, const char **argv)
 #endif
 
   // Test makeTempDirectory()
-#if defined(_WIN32) || (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX or Windows
+#if defined(_WIN32) ||                                                                                                 \
+    (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) // UNIX or Windows
   try {
     std::string directory_filename_tmp;
     std::string tmp_dir = vpIoTools::getTempPath();
@@ -570,7 +568,7 @@ int main(int argc, const char **argv)
 
     std::cout << "Create temp directory: " << converted_dirname_tmp << std::endl;
 
-    if (! vpIoTools::checkDirectory(converted_dirname_tmp)) {
+    if (!vpIoTools::checkDirectory(converted_dirname_tmp)) {
       std::cerr << "Error: " << converted_dirname_tmp << " is not a tmp directory" << std::endl;
       return EXIT_FAILURE;
     }
@@ -587,7 +585,7 @@ int main(int argc, const char **argv)
 
     std::cout << "Create temp directory: " << converted_dirname_tmp << std::endl;
 
-    if (! vpIoTools::checkDirectory(converted_dirname_tmp)) {
+    if (!vpIoTools::checkDirectory(converted_dirname_tmp)) {
       std::cerr << "Error: " << converted_dirname_tmp << " is not a temp directory" << std::endl;
       return EXIT_FAILURE;
     }
@@ -696,12 +694,14 @@ int main(int argc, const char **argv)
   std::cout << "Test vpIoTools::isSamePathname (Unix platform) - passed: " << nbOk << "/" << (nbOk + nbFail)
             << std::endl;
 
-  //Delete test directory
+  // Delete test directory
   if (!vpIoTools::remove("/tmp/" + username + "/test")) {
-    std::cerr << "Cannot remove directory: " << "/tmp/" << username << "/test" << std::endl;
+    std::cerr << "Cannot remove directory: "
+              << "/tmp/" << username << "/test" << std::endl;
   }
   if (!vpIoTools::remove("/tmp/" + username + "/dummy dir")) {
-    std::cerr << "Cannot remove directory: " << "/tmp/" << username << "/dummy dir" << std::endl;
+    std::cerr << "Cannot remove directory: "
+              << "/tmp/" << username << "/dummy dir" << std::endl;
   }
 
   if (nbFail) {
@@ -741,14 +741,16 @@ int main(int argc, const char **argv)
   }
   std::cout << "Test vpIoTools::checkFilename() is ok." << std::endl;
 
-  //Delete test directory
+  // Delete test directory
   if (!vpIoTools::remove("/tmp/" + username + "/directory (1) with ' quote and spaces")) {
-    std::cerr << "Cannot remove directory: " << "/tmp/" << username << "/directory (1) with ' quote and spaces" << std::endl;
+    std::cerr << "Cannot remove directory: "
+              << "/tmp/" << username << "/directory (1) with ' quote and spaces" << std::endl;
   }
 
   // Test endianness
   {
-    std::string filename_endianness =  vpIoTools::createFilePath(vpIoTools::getViSPImagesDataPath(), "endianness/test_endianness_little_endian.bin");
+    std::string filename_endianness =
+        vpIoTools::createFilePath(vpIoTools::getViSPImagesDataPath(), "endianness/test_endianness_little_endian.bin");
     std::ifstream file_endianness(filename_endianness.c_str(), std::ios::in | std::ios::binary);
     if (file_endianness.is_open()) {
       checkReadBinaryValue<short>(file_endianness, std::numeric_limits<short>::min());
@@ -775,6 +777,62 @@ int main(int argc, const char **argv)
     }
   }
 
+  // Test vpIoTools::toLowerCase
+  {
+    int nbFail = 0;
+    int nbOk = 0;
+    std::string testString = std::string("Yolo-V3");
+    std::string expectedLower = std::string("yolo-v3");
+    std::string expectedUpper = std::string("YOLO-V3");
+    #if defined(_WIN32)
+
+    if (strcmp(vpIoTools::toLowerCase(testString).c_str(), expectedLower.c_str()) == 0) {
+      nbOk++;
+    } else {
+      nbFail++;
+      std::cout << "Fail=" <<vpIoTools::toLowerCase(testString).c_str() << " should be=" << expectedLower << std::endl;
+    }
+
+    if (strcmp(vpIoTools::toUpperCase(testString).c_str(), expectedUpper.c_str()) == 0) {
+      nbOk++;
+    } else {
+      nbFail++;
+      std::cout << "Fail=" <<vpIoTools::toUpperCase(testString).c_str() << " should be=" << expectedUpper << std::endl;
+    }
+
+    std::cout << "Test vpIoTools::toLowerCase (WIN32 platform) - passed: " << nbOk << "/" << (nbOk + nbFail)
+              << std::endl;
+
+    if (nbFail) {
+      std::cerr << "Failed test: vpIoTools::toLowerCase (WIN32 platform)" << std::endl;
+      return EXIT_FAILURE;
+    }
+  #else
+    if (strcmp(vpIoTools::toLowerCase(testString).c_str(), expectedLower.c_str()) == 0) {
+      nbOk++;
+    } else {
+      nbFail++;
+      std::cout << "Fail=" <<vpIoTools::toLowerCase(testString).c_str() << " should be=" << expectedLower << std::endl;
+    }
+
+    if (strcmp(vpIoTools::toUpperCase(testString).c_str(), expectedUpper.c_str()) == 0) {
+      nbOk++;
+    } else {
+      nbFail++;
+      std::cout << "Fail=" <<vpIoTools::toUpperCase(testString).c_str() << " should be=" << expectedUpper << std::endl;
+    }
+
+    std::cout << "Test vpIoTools::toLowerCase (Unix-like platform) - passed: " << nbOk << "/" << (nbOk + nbFail)
+              << std::endl;
+
+    if (nbFail) {
+      std::cerr << "Failed test: vpIoTools::toLowerCase (Unix-like platform)" << std::endl;
+      return EXIT_FAILURE;
+    }
+  #endif
+  }
+
+
   std::cout << std::endl << "Test succeed" << std::endl;
   return EXIT_SUCCESS;
 }
