@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,12 +31,7 @@
  * Description:
  * Image display.
  *
- * Authors:
- * Christophe Collewet
- * Eric Marchand
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpDisplayOpenCV.cpp
@@ -45,7 +40,7 @@
 
 #include <visp3/core/vpConfig.h>
 
-#if defined(VISP_HAVE_OPENCV)
+#if defined(HAVE_OPENCV_HIGHGUI)
 
 #include <cmath> // std::fabs
 #include <iostream>
@@ -64,15 +59,15 @@
 #include <visp3/core/vpDebug.h>
 #include <visp3/core/vpDisplayException.h>
 
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020408)
-
 #include <opencv2/core/core_c.h> // for CV_FILLED versus cv::FILLED
+
+#if defined(HAVE_OPENCV_IMGPROC)
 #include <opencv2/imgproc/imgproc.hpp>
+#endif
 
 #ifndef CV_RGB
 #define CV_RGB(r, g, b) cv::Scalar((b), (g), (r), 0)
 #endif
-#endif
 
 #ifdef VISP_HAVE_X11
 #include <visp3/gui/vpDisplayX.h> // to get screen resolution
@@ -870,8 +865,7 @@ void vpDisplayOpenCV::displayImage(const vpImage<vpRGBa> &I)
 
   \sa init(), closeDisplay()
 */
-void vpDisplayOpenCV::displayImageROI(const vpImage<vpRGBa> &I, const vpImagePoint &iP, unsigned int w,
-                                      unsigned int h)
+void vpDisplayOpenCV::displayImageROI(const vpImage<vpRGBa> &I, const vpImagePoint &iP, unsigned int w, unsigned int h)
 {
   if (m_displayHasBeenInitialized) {
 #if (VISP_HAVE_OPENCV_VERSION < 0x020408)
@@ -1172,27 +1166,16 @@ void vpDisplayOpenCV::displayCircle(const vpImagePoint &center, unsigned int rad
     cv::Scalar cv_color;
     if (color.id < vpColor::id_unknown) {
       cv_color = col[color.id];
-    }
-    else{
+    } else {
       cv_color = CV_RGB(color.R, color.G, color.B);
     }
 
     if (fill == false) {
       int cv_thickness = static_cast<int>(thickness);
 #if VISP_HAVE_OPENCV_VERSION < 0x020408
-      cvCircle(
-        m_background,
-        cvPoint(x, y),
-        r,
-        cv_color,
-        cv_thickness);
+      cvCircle(m_background, cvPoint(x, y), r, cv_color, cv_thickness);
 #else
-      cv::circle(
-        m_background,
-        cv::Point(x, y),
-        r,
-        cv_color,
-        cv_thickness);
+      cv::circle(m_background, cv::Point(x, y), r, cv_color, cv_thickness);
 #endif
     } else {
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
@@ -1202,45 +1185,19 @@ void vpDisplayOpenCV::displayCircle(const vpImagePoint &center, unsigned int rad
 #endif
 #if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
       double opacity = static_cast<double>(color.A) / 255.0;
-#  if VISP_HAVE_OPENCV_VERSION < 0x020408
-      overlay(
-        [x, y, r, cv_color, filled](cv::Mat image) {
-          cvCircle(
-            image,
-            cvPoint(x, y),
-            r,
-            cv_color,
-            filled);
-        },
-        opacity);
-#  else
-      overlay(
-        [x, y, r, cv_color, filled](cv::Mat image) {
-          cv::circle(
-            image,
-            cv::Point(x, y),
-            r,
-            cv_color,
-            filled);
-        },
-        opacity);
-#  endif
+#if VISP_HAVE_OPENCV_VERSION < 0x020408
+      overlay([x, y, r, cv_color, filled](cv::Mat image) { cvCircle(image, cvPoint(x, y), r, cv_color, filled); },
+              opacity);
 #else
-#  if VISP_HAVE_OPENCV_VERSION < 0x020408
-      cvCircle(
-        m_background,
-        cvPoint(x, y),
-        r,
-        cv_color,
-        filled);
-#  else
-      cv::circle(
-        m_background,
-        cv::Point(x, y),
-        r,
-        cv_color,
-        filled);
-#  endif
+      overlay([x, y, r, cv_color, filled](cv::Mat image) { cv::circle(image, cv::Point(x, y), r, cv_color, filled); },
+              opacity);
+#endif
+#else
+#if VISP_HAVE_OPENCV_VERSION < 0x020408
+      cvCircle(m_background, cvPoint(x, y), r, cv_color, filled);
+#else
+      cv::circle(m_background, cv::Point(x, y), r, cv_color, filled);
+#endif
 #endif
     }
   } else {
@@ -1423,27 +1380,16 @@ void vpDisplayOpenCV::displayRectangle(const vpImagePoint &topLeft, unsigned int
     cv::Scalar cv_color;
     if (color.id < vpColor::id_unknown) {
       cv_color = col[color.id];
-    }
-    else {
+    } else {
       cv_color = CV_RGB(color.R, color.G, color.B);
     }
 
     if (fill == false) {
       int cv_thickness = static_cast<int>(thickness);
 #if VISP_HAVE_OPENCV_VERSION < 0x020408
-      cvRectangle(
-        m_background,
-        cvPoint(left, top),
-        cvPoint(right, bottom),
-        cv_color,
-        cv_thickness);
+      cvRectangle(m_background, cvPoint(left, top), cvPoint(right, bottom), cv_color, cv_thickness);
 #else
-      cv::rectangle(
-        m_background,
-        cv::Point(left, top),
-        cv::Point(right, bottom),
-        cv_color,
-        cv_thickness);
+      cv::rectangle(m_background, cv::Point(left, top), cv::Point(right, bottom), cv_color, cv_thickness);
 #endif
     } else {
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
@@ -1453,43 +1399,23 @@ void vpDisplayOpenCV::displayRectangle(const vpImagePoint &topLeft, unsigned int
 #endif
 #if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
       double opacity = static_cast<double>(color.A) / 255.0;
-#  if VISP_HAVE_OPENCV_VERSION < 0x020408
-      overlay(
-        [left, top, right, bottom, cv_color, filled](cv::Mat image) {
-          cvRectangle(
-              image,
-              cvPoint(left, top),
-              cvPoint(right, bottom),
-              cv_color,
-              filled);
-        },
-        opacity);
-#  else
-      overlay(
-        [left, top, right, bottom, cv_color, filled](cv::Mat image) {
-          cv::rectangle(
-            image,
-            cv::Point(left, top),
-            cv::Point(right, bottom),
-            cv_color,
-            filled);
-        },
-        opacity);
-#  endif
+#if VISP_HAVE_OPENCV_VERSION < 0x020408
+      overlay([left, top, right, bottom, cv_color, filled](
+                  cv::Mat image) { cvRectangle(image, cvPoint(left, top), cvPoint(right, bottom), cv_color, filled); },
+              opacity);
 #else
-#  if VISP_HAVE_OPENCV_VERSION < 0x020408
-      cvRectangle(m_background,
-                  cvPoint(left, top),
-                  cvPoint(right, bottom),
-                  cv_color,
-                  filled);
-#  else
-      cv::rectangle(m_background,
-                    cv::Point(left, top),
-                    cv::Point(right, bottom),
-                    cv_color,
-                    filled);
-#  endif
+      overlay(
+          [left, top, right, bottom, cv_color, filled](cv::Mat image) {
+            cv::rectangle(image, cv::Point(left, top), cv::Point(right, bottom), cv_color, filled);
+          },
+          opacity);
+#endif
+#else
+#if VISP_HAVE_OPENCV_VERSION < 0x020408
+      cvRectangle(m_background, cvPoint(left, top), cvPoint(right, bottom), cv_color, filled);
+#else
+      cv::rectangle(m_background, cv::Point(left, top), cv::Point(right, bottom), cv_color, filled);
+#endif
 #endif
     }
   } else {
@@ -1521,27 +1447,16 @@ void vpDisplayOpenCV::displayRectangle(const vpImagePoint &topLeft, const vpImag
     cv::Scalar cv_color;
     if (color.id < vpColor::id_unknown) {
       cv_color = col[color.id];
-    }
-    else {
+    } else {
       cv_color = CV_RGB(color.R, color.G, color.B);
     }
 
     if (fill == false) {
       int cv_thickness = static_cast<int>(thickness);
 #if VISP_HAVE_OPENCV_VERSION < 0x020408
-      cvRectangle(
-        m_background,
-        cvPoint(left, top),
-        cvPoint(right, bottom),
-        cv_color,
-        cv_thickness);
+      cvRectangle(m_background, cvPoint(left, top), cvPoint(right, bottom), cv_color, cv_thickness);
 #else
-      cv::rectangle(
-        m_background,
-        cv::Point(left, top),
-        cv::Point(right, bottom),
-        cv_color,
-        cv_thickness);
+      cv::rectangle(m_background, cv::Point(left, top), cv::Point(right, bottom), cv_color, cv_thickness);
 #endif
     } else {
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
@@ -1551,43 +1466,23 @@ void vpDisplayOpenCV::displayRectangle(const vpImagePoint &topLeft, const vpImag
 #endif
 #if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
       double opacity = static_cast<double>(color.A) / 255.0;
-#  if VISP_HAVE_OPENCV_VERSION < 0x020408
-      overlay(
-        [left, top, right, bottom, cv_color, filled](cv::Mat image) {
-          cvRectangle(
-            image,
-            cvPoint(left, top),
-            cvPoint(right, bottom),
-            cv_color,
-            filled);
-        },
-        opacity);
-#  else
-      overlay(
-        [left, top, right, bottom, cv_color, filled](cv::Mat image) {
-          cv::rectangle(
-            image,
-            cv::Point(left, top),
-            cv::Point(right, bottom),
-            cv_color,
-            filled);
-        },
-        opacity);
-#  endif
+#if VISP_HAVE_OPENCV_VERSION < 0x020408
+      overlay([left, top, right, bottom, cv_color, filled](
+                  cv::Mat image) { cvRectangle(image, cvPoint(left, top), cvPoint(right, bottom), cv_color, filled); },
+              opacity);
 #else
-#  if VISP_HAVE_OPENCV_VERSION < 0x020408
-      cvRectangle(m_background,
-                  cvPoint(left, top),
-                  cvPoint(right, bottom),
-                  cv_color,
-                  filled);
-#  else
-      cv::rectangle(m_background,
-                    cv::Point(left, top),
-                    cv::Point(right, bottom),
-                    cv_color,
-                    filled);
-#  endif
+      overlay(
+          [left, top, right, bottom, cv_color, filled](cv::Mat image) {
+            cv::rectangle(image, cv::Point(left, top), cv::Point(right, bottom), cv_color, filled);
+          },
+          opacity);
+#endif
+#else
+#if VISP_HAVE_OPENCV_VERSION < 0x020408
+      cvRectangle(m_background, cvPoint(left, top), cvPoint(right, bottom), cv_color, filled);
+#else
+      cv::rectangle(m_background, cv::Point(left, top), cv::Point(right, bottom), cv_color, filled);
+#endif
 #endif
     }
   } else {
@@ -1618,27 +1513,16 @@ void vpDisplayOpenCV::displayRectangle(const vpRect &rectangle, const vpColor &c
     cv::Scalar cv_color;
     if (color.id < vpColor::id_unknown) {
       cv_color = col[color.id];
-    }
-    else {
+    } else {
       cv_color = CV_RGB(color.R, color.G, color.B);
     }
 
     if (fill == false) {
       int cv_thickness = static_cast<int>(thickness);
 #if VISP_HAVE_OPENCV_VERSION < 0x020408
-      cvRectangle(
-        m_background,
-        cvPoint(left, top),
-        cvPoint(right, bottom),
-        cv_color,
-        cv_thickness);
+      cvRectangle(m_background, cvPoint(left, top), cvPoint(right, bottom), cv_color, cv_thickness);
 #else
-      cv::rectangle(
-        m_background,
-        cv::Point(left, top),
-        cv::Point(right, bottom),
-        cv_color,
-        cv_thickness);
+      cv::rectangle(m_background, cv::Point(left, top), cv::Point(right, bottom), cv_color, cv_thickness);
 #endif
     } else {
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
@@ -1648,45 +1532,25 @@ void vpDisplayOpenCV::displayRectangle(const vpRect &rectangle, const vpColor &c
 #endif
 #if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
       double opacity = static_cast<double>(color.A) / 255.0;
-#  if VISP_HAVE_OPENCV_VERSION < 0x020408
-      overlay(
-        [left, top, right, bottom, cv_color, filled](cv::Mat image) {
-          cvRectangle(
-              image,
-              cvPoint(left, top),
-              cvPoint(right, bottom),
-              cv_color,
-              filled);
-        },
-        opacity);
-#  else
-      overlay(
-        [left, top, right, bottom, cv_color, filled](cv::Mat image) {
-          cv::rectangle(
-              image,
-              cv::Point(left, top),
-              cv::Point(right, bottom),
-              cv_color,
-              filled);
-        },
-        opacity);
-#  endif
+#if VISP_HAVE_OPENCV_VERSION < 0x020408
+      overlay([left, top, right, bottom, cv_color, filled](
+                  cv::Mat image) { cvRectangle(image, cvPoint(left, top), cvPoint(right, bottom), cv_color, filled); },
+              opacity);
 #else
-#  if VISP_HAVE_OPENCV_VERSION < 0x020408
-      cvRectangle(m_background,
-                  cvPoint(left, top),
-                  cvPoint(right, bottom),
-                  cv_color,
-                  filled);
-#  else
-      cv::rectangle(m_background,
-                    cv::Point(left, top),
-                    cv::Point(right, bottom),
-                    cv_color,
-                    filled);
-#  endif
+      overlay(
+          [left, top, right, bottom, cv_color, filled](cv::Mat image) {
+            cv::rectangle(image, cv::Point(left, top), cv::Point(right, bottom), cv_color, filled);
+          },
+          opacity);
 #endif
-      }
+#else
+#if VISP_HAVE_OPENCV_VERSION < 0x020408
+      cvRectangle(m_background, cvPoint(left, top), cvPoint(right, bottom), cv_color, filled);
+#else
+      cv::rectangle(m_background, cv::Point(left, top), cv::Point(right, bottom), cv_color, filled);
+#endif
+#endif
+    }
   } else {
     throw(vpDisplayException(vpDisplayException::notInitializedError, "OpenCV not initialized"));
   }
@@ -2270,15 +2134,14 @@ unsigned int vpDisplayOpenCV::getScreenHeight()
  * \param overlay_function : Overlay function
  * \param opacity : Opacity between 0 and 1.
  */
-void vpDisplayOpenCV::overlay(std::function<void(cv::Mat&)> overlay_function, double opacity)
+void vpDisplayOpenCV::overlay(std::function<void(cv::Mat &)> overlay_function, double opacity)
 {
   // Initialize overlay layer for transparency
   cv::Mat overlay;
   if (opacity < 1.0) {
     // Deep copy
     overlay = m_background.clone();
-  }
-  else {
+  } else {
     // Shallow copy
     overlay = m_background;
   }
@@ -2293,7 +2156,7 @@ void vpDisplayOpenCV::overlay(std::function<void(cv::Mat&)> overlay_function, do
 #endif
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_core.a(vpDisplayOpenCV.cpp.o) has no
+// Work around to avoid warning: libvisp_core.a(vpDisplayOpenCV.cpp.o) has no
 // symbols
 void dummy_vpDisplayOpenCV(){};
 #endif
