@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Bruno Renier
  *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpConfig.h>
 #define GDI_ROBUST
@@ -150,8 +150,7 @@ void vpGDIRenderer::setImg(const vpImage<vpRGBa> &I)
   \param iP : Top left coordinates of the ROI.
   \param width, height : ROI width and height.
 */
-void vpGDIRenderer::setImgROI(const vpImage<vpRGBa> &I, const vpImagePoint &iP, unsigned int width,
-                              unsigned int height)
+void vpGDIRenderer::setImgROI(const vpImage<vpRGBa> &I, const vpImagePoint &iP, unsigned int width, unsigned int height)
 {
   // converts the image into a HBITMAP
   convertROI(I, iP, width, height);
@@ -887,8 +886,7 @@ void vpGDIRenderer::drawCross(const vpImagePoint &ip, unsigned int size, const v
     LineTo(hDCMem, vpMath::round(ip.get_u() / m_rscale), vpMath::round(ip.get_v() / m_rscale) + half_size);
 
     // display the result (flush)
-    //  BitBlt(hDCScreen, j-(size/2), i-(size/2), size, size,
-    //	   hDCMem, j-(size/2), i-(size/2), SRCCOPY);
+    //  BitBlt(hDCScreen, j-(size/2), i-(size/2), size, size, hDCMem, j-(size/2), i-(size/2), SRCCOPY);
 
     LeaveCriticalSection(&m_criticalSection);
 
@@ -1020,7 +1018,7 @@ void vpGDIRenderer::getImage(vpImage<vpRGBa> &I)
 }
 #endif
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_core.a(vpGDIRenderer.cpp.o) has no
+// Work around to avoid warning: libvisp_core.a(vpGDIRenderer.cpp.o) has no
 // symbols
 void dummy_vpGDIRenderer(){};
 #endif
