@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Plot curves.
  *
- * Authors:
- * Nicolas Melchior
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpConfig.h>
 
@@ -59,8 +56,7 @@
 
 */
 vpPlot::vpPlot() : I(), display(NULL), graphNbr(1), graphList(NULL), margei(30), margej(40), factori(1.f), factorj(1.)
-{
-}
+{ }
 /*!
   This constructor creates a new window where the curves
   will be drawn. The number of graphics in the window must be set.
@@ -78,8 +74,7 @@ vpPlot::vpPlot() : I(), display(NULL), graphNbr(1), graphList(NULL), margei(30),
   \param x,y : The window is set at position x,y (column index, row index).
   \param title : Window title.
 */
-vpPlot::vpPlot(unsigned int graph_nbr, unsigned int height, unsigned int width, int x,
-               int y, const std::string &title)
+vpPlot::vpPlot(unsigned int graph_nbr, unsigned int height, unsigned int width, int x, int y, const std::string &title)
   : I(), display(NULL), graphNbr(1), graphList(NULL), margei(30), margej(40), factori(1.f), factorj(1.)
 {
   init(graph_nbr, height, width, x, y, title);
@@ -97,24 +92,24 @@ vpPlot::vpPlot(unsigned int graph_nbr, unsigned int height, unsigned int width,
   \param x,y : The window is set at position x,y (column index, row index).
   \param title : Window title.
 */
-void vpPlot::init(unsigned int graph_nbr, unsigned int height, unsigned int width, int x,
-                  int y, const std::string &title)
+void vpPlot::init(unsigned int graph_nbr, unsigned int height, unsigned int width, int x, int y,
+                  const std::string &title)
 {
   I.init(height, width, 255);
 
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
   display = new vpDisplayX;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
   display = new vpDisplayGDI;
-#elif defined VISP_HAVE_OPENCV
+#elif defined(HAVE_OPENCV_HIGHGUI)
   display = new vpDisplayOpenCV;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
   display = new vpDisplayGTK;
-#elif defined VISP_HAVE_D3D9
+#elif defined(VISP_HAVE_D3D9)
   display = new vpDisplayD3D;
 #endif
 
-  display->init(I, x, y, title.c_str());
+  display->init(I, x, y, title);
 
   vpDisplay::display(I);
 
@@ -201,29 +196,20 @@ void vpPlot::initNbGraph(unsigned int nbGraph)
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param curveNbr : The number of curves belonging to the graphic
+  and 3.
+  \param curveNbr : The number of curves belonging to the graphic
 */
 void vpPlot::initGraph(unsigned int graphNum, unsigned int curveNbr) { (graphList + graphNum)->initGraph(curveNbr); }
 
-// void
-// vpPlot::initRange (const int graphNum,
-// 		   double xmin, double xmax, double /*xdelt*/,
-// 		   double ymin, double ymax, double /*ydelt*/,
-// 		   bool gx, bool gy)
-// {
-//   (graphList+graphNum)->initScale(I,xmin,xmax,10,ymin,ymax,10,gx,gy);
-// }
-
 /*!
   This method enables to set the initial range of the selected graphic.
 
   \param graphNum : The index of the graph in the window. As the number of
-  graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param xmin : The initial minimum value along the x axis given in the
-  user coordinates. \param xmax : The initial maximum value along the x axis
-  given in the user coordinates. \param ymin : The initial minimum value along
-  the y axis given in the user coordinates. \param ymax : The initial maximum
-  value along the y axis given in the user coordinates.
+  graphic in a window is less or equal to 4, this parameter is between 0 and 3.
+  \param xmin : The initial minimum value along the x axis given in the user coordinates.
+  \param xmax : The initial maximum value along the x axis given in the user coordinates.
+  \param ymin : The initial minimum value along the y axis given in the user coordinates.
+  \param ymax : The initial maximum value along the y axis given in the user coordinates.
 */
 void vpPlot::initRange(unsigned int graphNum, double xmin, double xmax, double ymin, double ymax)
 {
@@ -234,15 +220,13 @@ void vpPlot::initRange(unsigned int graphNum, double xmin, double xmax, double y
   This method enables to set the initial range of the selected graphic.
 
   \param graphNum : The index of the graph in the window. As the number of
-  graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param xmin : The initial minimum value along the x axis given in the
-  user coordinates. \param xmax : The initial maximum value along the x axis
-  given in the user coordinates. \param ymin : The initial minimum value along
-  the y axis given in the user coordinates. \param ymax : The initial maximum
-  value along the y axis given in the user coordinates. \param zmin : The
-  initial minimum value along the z axis given in the user coordinates. \param
-  zmax : The initial maximum value along the z axis given in the user
-  coordinates.
+  graphic in a window is less or equal to 4, this parameter is between 0 and 3.
+  \param xmin : The initial minimum value along the x axis given in the user coordinates.
+  \param xmax : The initial maximum value along the x axis given in the user coordinates.
+  \param ymin : The initial minimum value along the y axis given in the user coordinates.
+  \param ymax : The initial maximum value along the y axis given in the user coordinates.
+  \param zmin : The initial minimum value along the z axis given in the user coordinates.
+  \param zmax : The initial maximum value along the z axis given in the user coordinates.
 */
 void vpPlot::initRange(unsigned int graphNum, double xmin, double xmax, double ymin, double ymax, double zmin,
                        double zmax)
@@ -254,9 +238,9 @@ void vpPlot::initRange(unsigned int graphNum, double xmin, double xmax, double y
   This function enables you to choose the color used to draw a given curve.
 
   \param graphNum : The index of the graph in the window. As the number of
-  graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param curveNum : The index of the curve in the list of the curves
-  belonging to the graphic. \param color : The color you want to use
+  graphic in a window is less or equal to 4, this parameter is between 0 and 3.
+  \param curveNum : The index of the curve in the list of the curves belonging to the graphic.
+  \param color : The color you want to use
 */
 void vpPlot::setColor(unsigned int graphNum, unsigned int curveNum, vpColor color)
 {
@@ -277,11 +261,10 @@ void vpPlot::displayGrid()
   drawn with the parameters of the curve.
 
   \param graphNum : The index of the graph in the window. As the number of
-  graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param curveNum : The index of the curve in the list of the curves
-  belonging to the graphic. \param x : The coordinate of the new point along
-  the x axis and given in the user unit system. \param y : The coordinate of
-  the new point along the y axis and given in the user unit system.
+  graphic in a window is less or equal to 4, this parameter is between 0 and 3.
+  \param curveNum : The index of the curve in the list of the curves belonging to the graphic.
+  \param x : The coordinate of the new point along the x axis and given in the user unit system.
+  \param y : The coordinate of the new point along the y axis and given in the user unit system.
 */
 void vpPlot::plot(unsigned int graphNum, unsigned int curveNum, double x, double y)
 {
@@ -293,18 +276,19 @@ void vpPlot::plot(unsigned int graphNum, unsigned int curveNum, double x, double
   points are drawn with the parameters of the curves.
 
   \param graphNum : The index of the graph in the window. As the number of
-  graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param x : The coordinate of the new points along the x axis and
-  given in the user unit system. \param v_y : y coordinates vector. The
-  coordinates of the new points along the y axis and given in the user unit
-  system.
+  graphic in a window is less or equal to 4, this parameter is between 0 and 3.
+  \param x : The coordinate of the new points along the x axis and
+  given in the user unit system.
+  \param v_y : y coordinates vector. The coordinates of the new points along the
+  y axis and given in the user unit system.
 */
 void vpPlot::plot(unsigned int graphNum, double x, const vpColVector &v_y)
 {
   if ((graphList + graphNum)->curveNbr == v_y.getRows()) {
     for (unsigned int i = 0; i < v_y.getRows(); ++i)
       this->plot(graphNum, i, x, v_y[i]);
-  } else
+  }
+  else
     vpTRACE("error in plot vector : not the right dimension");
 }
 /*!
@@ -313,17 +297,19 @@ void vpPlot::plot(unsigned int graphNum, double x, const vpColVector &v_y)
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param x : The coordinate of the new points along the x axis and
-  given in the user unit system. \param v_y : y coordinates vector. The
-  coordinates of the new points along the y axis and given in the user unit
-  system.
+  and 3.
+  \param x : The coordinate of the new points along the x axis and
+  given in the user unit system.
+  \param v_y : y coordinates vector. The coordinates of the new points along
+  the y axis and given in the user unit system.
 */
 void vpPlot::plot(unsigned int graphNum, double x, const vpRowVector &v_y)
 {
   if ((graphList + graphNum)->curveNbr == v_y.getRows()) {
     for (unsigned int i = 0; i < v_y.getRows(); ++i)
       this->plot(graphNum, i, x, v_y[i]);
-  } else
+  }
+  else
     vpTRACE("error in plot vector : not the right dimension");
 }
 
@@ -333,8 +319,10 @@ void vpPlot::plot(unsigned int graphNum, double x, const vpRowVector &v_y)
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param x : The coordinate of the new points along the x axis and
-  given in the user unit system. \param v_y : y coordinates vector. The
+  and 3.
+  \param x : The coordinate of the new points along the x axis and
+  given in the user unit system.
+  \param v_y : y coordinates vector. The
   coordinates of the new points along the y axis and given in the user unit
   system.
 */
@@ -343,7 +331,8 @@ void vpPlot::plot(unsigned int graphNum, double x, const vpPoseVector &v_y)
   if ((graphList + graphNum)->curveNbr == v_y.getRows()) {
     for (unsigned int i = 0; i < v_y.getRows(); ++i)
       this->plot(graphNum, i, x, v_y[i]);
-  } else
+  }
+  else
     vpTRACE("error in plot vector : not the right dimension");
 }
 /*!
@@ -352,8 +341,10 @@ void vpPlot::plot(unsigned int graphNum, double x, const vpPoseVector &v_y)
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param x : The coordinate of the new points along the x axis and
-  given in the user unit system. \param v_y : y coordinates vector. The
+  and 3.
+  \param x : The coordinate of the new points along the x axis and
+  given in the user unit system.
+  \param v_y : y coordinates vector. The
   coordinates of the new points along the y axis and given in the user unit
   system.
 */
@@ -362,7 +353,8 @@ void vpPlot::plot(unsigned int graphNum, double x, const vpTranslationVector &v_
   if ((graphList + graphNum)->curveNbr == v_y.getRows()) {
     for (unsigned int i = 0; i < v_y.getRows(); ++i)
       this->plot(graphNum, i, x, v_y[i]);
-  } else
+  }
+  else
     vpTRACE("error in plot vector : not the right dimension");
 }
 
@@ -372,8 +364,10 @@ void vpPlot::plot(unsigned int graphNum, double x, const vpTranslationVector &v_
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param x : The coordinate of the new points along the x axis and
-  given in the user unit system. \param v_y : y coordinates vector. The
+  and 3.
+  \param x : The coordinate of the new points along the x axis and
+  given in the user unit system.
+  \param v_y : y coordinates vector. The
   coordinates of the new points along the y axis and given in the user unit
   system.
 */
@@ -382,7 +376,8 @@ void vpPlot::plot(unsigned int graphNum, double x, const vpRotationVector &v_y)
   if ((graphList + graphNum)->curveNbr == v_y.size()) {
     for (unsigned int i = 0; i < v_y.size(); ++i)
       this->plot(graphNum, i, x, v_y[i]);
-  } else
+  }
+  else
     vpTRACE("error in plot vector : not the right dimension");
 }
 
@@ -392,15 +387,19 @@ void vpPlot::plot(unsigned int graphNum, double x, const vpRotationVector &v_y)
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param curveNum : The index of the curve in the list of the curves
-  belonging to the graphic. \param x : The coordinate of the new point along
-  the x axis and given in the user unit system. \param y : The coordinate of
-  the new point along the y axis and given in the user unit system. \param z :
+  and 3.
+  \param curveNum : The index of the curve in the list of the curves
+  belonging to the graphic.
+  \param x : The coordinate of the new point along
+  the x axis and given in the user unit system.
+  \param y : The coordinate of
+  the new point along the y axis and given in the user unit system.
+  \param z :
   The coordinate of the new point along the z axis and given in the user unit
   system.
 */
-vpMouseButton::vpMouseButtonType vpPlot::plot(unsigned int graphNum, unsigned int curveNum, double x,
-                                              double y, double z)
+vpMouseButton::vpMouseButtonType vpPlot::plot(unsigned int graphNum, unsigned int curveNum, double x, double y,
+                                              double z)
 {
   return (graphList + graphNum)->plot(I, curveNum, x, y, z);
 }
@@ -411,10 +410,13 @@ vpMouseButton::vpMouseButtonType vpPlot::plot(unsigned int graphNum, unsigned in
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param x : The coordinate of the new points along the x axis and
-  given in the user unit system. \param v_y : y coordinates vector. The
+  and 3.
+  \param x : The coordinate of the new points along the x axis and
+  given in the user unit system.
+  \param v_y : y coordinates vector. The
   coordinates of the new points along the y axis and given in the user unit
-  system. \param v_z : z coordinates vector. The coordinates of the new points
+  system.
+  \param v_z : z coordinates vector. The coordinates of the new points
   along the z axis and given in the user unit system.
 */
 vpMouseButton::vpMouseButtonType vpPlot::plot(unsigned int graphNum, double x, const vpColVector &v_y,
@@ -424,7 +426,8 @@ vpMouseButton::vpMouseButtonType vpPlot::plot(unsigned int graphNum, double x, c
   if ((graphList + graphNum)->curveNbr == v_y.getRows() && (graphList + graphNum)->curveNbr == v_z.getRows()) {
     for (unsigned int i = 0; i < v_y.getRows(); ++i)
       button = this->plot(graphNum, i, x, v_y[i], v_z[i]);
-  } else
+  }
+  else
     vpTRACE("error in plot vector : not the right dimension");
   return button;
 }
@@ -434,7 +437,7 @@ vpMouseButton::vpMouseButtonType vpPlot::plot(unsigned int graphNum, double x, c
   3D graphic. The navigation is performed using the mouse.
   - A click on left mouse button allows rotations
   - A click on middle mouse button allows zoom
-  - A click on rigt mouse button quit the infinite navigation loop.
+  - A click on right mouse button quit the infinite navigation loop.
 */
 void vpPlot::navigate()
 {
@@ -457,7 +460,8 @@ void vpPlot::navigate()
         (graphList + iblocked)->replot3D(I);
       }
       blocked = (graphList + iblocked)->blocked;
-    } else {
+    }
+    else {
       if ((graphList + iblocked)->move(I, b)) {
         (graphList + iblocked)->replot3D(I);
       }
@@ -493,56 +497,50 @@ void vpPlot::getPixelValue(bool block)
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param title : The graphic title.
+  and 3.
+  \param title : The graphic title.
 */
-void vpPlot::setTitle(unsigned int graphNum, const std::string &title)
-{
-  (graphList + graphNum)->setTitle(title);
-}
+void vpPlot::setTitle(unsigned int graphNum, const std::string &title) { (graphList + graphNum)->setTitle(title); }
 
 /*!
   Sets the unit system of the x axis.
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param unitx : The name of the unit of the x axis.
+  and 3.
+  \param unitx : The name of the unit of the x axis.
 */
-void vpPlot::setUnitX(unsigned int graphNum, const std::string &unitx)
-{
-  (graphList + graphNum)->setUnitX(unitx);
-}
+void vpPlot::setUnitX(unsigned int graphNum, const std::string &unitx) { (graphList + graphNum)->setUnitX(unitx); }
 
 /*!
   Sets the unit system of the y axis.
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param unity : The name of the unit of the y axis.
+  and 3.
+  \param unity : The name of the unit of the y axis.
 */
-void vpPlot::setUnitY(unsigned int graphNum, const std::string &unity)
-{
-  (graphList + graphNum)->setUnitY(unity);
-}
+void vpPlot::setUnitY(unsigned int graphNum, const std::string &unity) { (graphList + graphNum)->setUnitY(unity); }
 
 /*!
   Sets the unit system of the z axis.
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param unitz : The name of the unit of the z axis.
+  and 3.
+  \param unitz : The name of the unit of the z axis.
 */
-void vpPlot::setUnitZ(unsigned int graphNum, const std::string &unitz)
-{
-  (graphList + graphNum)->setUnitZ(unitz);
-}
+void vpPlot::setUnitZ(unsigned int graphNum, const std::string &unitz) { (graphList + graphNum)->setUnitZ(unitz); }
 
 /*!
   Sets the legend of a curve.
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param curveNum : The index of the curve in the list of the curves
-  belonging to the graphic. \param legend : The legend of the curve.
+  and 3.
+  \param curveNum : The index of the curve in the list of the curves
+  belonging to the graphic.
+  \param legend : The legend of the curve.
 */
 void vpPlot::setLegend(unsigned int graphNum, unsigned int curveNum, const std::string &legend)
 {
@@ -564,12 +562,13 @@ void vpPlot::resetPointList(unsigned int graphNum)
 }
 
 /*!
-This function enables you to choose the thickness used to draw a given curve.
+  This function enables you to choose the thickness used to draw a given curve.
 
   \param graphNum : The index of the graph in the window. As the number of
-graphic in a window is less or equal to 4, this parameter is between 0 and 3.
+  graphic in a window is less or equal to 4, this parameter is between 0 and 3.
   \param curveNum : The index of the curve in the list of the curves belonging
-to the graphic. \param thickness : The thickness you want to use
+  to the graphic.
+  \param thickness : The thickness you want to use
 */
 void vpPlot::setThickness(unsigned int graphNum, unsigned int curveNum, unsigned int thickness)
 {
@@ -577,11 +576,11 @@ void vpPlot::setThickness(unsigned int graphNum, unsigned int curveNum, unsigned
 }
 
 /*!
-This function enables you to choose the thickness used to draw all the curves
-belonging to a given graphic.
+  This function enables you to choose the thickness used to draw all the curves
+  belonging to a given graphic.
 
   \param graphNum : The index of the graph in the window. As the number of
-graphic in a window is less or equal to 4, this parameter is between 0 and 3.
+  graphic in a window is less or equal to 4, this parameter is between 0 and 3.
   \param thickness : The thickness you want to use
 */
 void vpPlot::setGraphThickness(unsigned int graphNum, unsigned int thickness)
@@ -596,7 +595,8 @@ void vpPlot::setGraphThickness(unsigned int graphNum, unsigned int thickness)
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param thickness : The thickness you want to use
+  and 3.
+  \param thickness : The thickness you want to use
 */
 void vpPlot::setGridThickness(unsigned int graphNum, unsigned int thickness)
 {
@@ -609,7 +609,8 @@ void vpPlot::setGridThickness(unsigned int graphNum, unsigned int thickness)
 
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param curveNum : The index of the curve in the list of the curves
+  and 3.
+  \param curveNum : The index of the curve in the list of the curves
   belonging to the graphic.
 */
 void vpPlot::resetPointList(unsigned int graphNum, unsigned int curveNum)
@@ -635,13 +636,14 @@ void vpPlot::resetPointList(unsigned int graphNum, unsigned int curveNum)
 
   The columns are delimited thanks to tabulations.
 
-  \param title_prefix : Prefix introducted in the first line of the saved
+  \param title_prefix : Prefix introduced in the first line of the saved
   file. To exploit a posteriori the resulting curves:
   - with gnuplot, set title_prefix to "# ".
   - with Matlab, set title_prefix to "% ".
   \param graphNum : The index of the graph in the window. As the number of
   graphic in a window is less or equal to 4, this parameter is between 0
-  and 3. \param dataFile : Name of the text file.
+  and 3.
+  \param dataFile : Name of the text file.
 */
 void vpPlot::saveData(unsigned int graphNum, const std::string &dataFile, const std::string &title_prefix)
 {
@@ -704,7 +706,8 @@ void vpPlot::saveData(unsigned int graphNum, const std::string &dataFile, const
             (vec_iter_pointListy[ind] != (graphList + graphNum)->curveList[ind].pointListy.end()) &&
             (vec_iter_pointListz[ind] != (graphList + graphNum)->curveList[ind].pointListz.end()))
           end = false;
-      } else {
+      }
+      else {
         //        p[0] =
         //        (graphList+graphNum)->curveList[ind].pointListx.value();
         //        p[1] =
@@ -725,6 +728,6 @@ void vpPlot::saveData(unsigned int graphNum, const std::string &dataFile, const
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_core.a(vpPlot.cpp.o) has no symbols
-void dummy_vpPlot(){};
+// Work around to avoid warning: libvisp_core.a(vpPlot.cpp.o) has no symbols
+void dummy_vpPlot() { };
 #endif
