@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Anthony Saunier
  *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpConfig.h>
 #include <visp3/core/vpDebug.h>
@@ -43,8 +43,7 @@
 #include <stdlib.h>
 #include <string>
 
-#if (defined(VISP_HAVE_GTK) || defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_D3D9) ||          \
-     defined(VISP_HAVE_OPENCV))
+#if defined(VISP_HAVE_GTK) || defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_D3D9) || defined(VISP_HAVE_OPENCV)
 
 #include <visp3/core/vpImage.h>
 #include <visp3/core/vpIoTools.h>
@@ -80,13 +79,14 @@ Test video devices or display.\n\
 \n\
 SYNOPSIS\n\
   %s [-l] [-c] [-d] [-h]\n\
-", name);
+",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               Default\n\
   -c\n\
-     Disable the mouse click. Useful to automaze the \n\
-     execution of this program without humain intervention.\n\
+     Disable the mouse click. Useful to automate the \n\
+     execution of this program without human intervention.\n\
 \n\
   -d \n\
      Turn off the display.\n\
@@ -270,7 +270,7 @@ template <typename Type> static void runTest(bool opt_display, bool opt_click_al
   vpImage<Type> Igdi;
   vpImage<Type> Id3d;
 
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
   vpDisplayX *displayX = new vpDisplayX;
   Ix.init(480, 640, 255);
   if (opt_display) {
@@ -283,7 +283,7 @@ template <typename Type> static void runTest(bool opt_display, bool opt_click_al
   }
 #endif
 
-#if defined(VISP_HAVE_OPENCV)
+#if defined(HAVE_OPENCV_HIGHGUI)
   vpDisplayOpenCV *displayCv = new vpDisplayOpenCV;
   Icv.init(480, 640, 255);
   if (opt_display) {
@@ -296,7 +296,7 @@ template <typename Type> static void runTest(bool opt_display, bool opt_click_al
   }
 #endif
 
-#if defined VISP_HAVE_GTK
+#if defined(VISP_HAVE_GTK)
   vpDisplayGTK *displayGtk = new vpDisplayGTK;
   Igtk.init(480, 640, 255);
   if (opt_display) {
@@ -309,7 +309,8 @@ template <typename Type> static void runTest(bool opt_display, bool opt_click_al
   }
 #endif
 
-#if defined VISP_HAVE_GDI
+#if defined(VISP_HAVE_GDI)
+
   vpDisplayGDI *displayGdi = new vpDisplayGDI;
   Igdi.init(480, 640, 255);
   if (opt_display) {
@@ -322,7 +323,7 @@ template <typename Type> static void runTest(bool opt_display, bool opt_click_al
   }
 #endif
 
-#if defined VISP_HAVE_D3D9
+#if defined(VISP_HAVE_D3D9)
   vpDisplayD3D *displayD3d = new vpDisplayD3D;
   Id3d.init(480, 640, 255);
   if (opt_display) {
@@ -335,23 +336,24 @@ template <typename Type> static void runTest(bool opt_display, bool opt_click_al
   }
 #endif
 
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
   delete displayX;
 #endif
 
-#if defined VISP_HAVE_GTK
+#if defined(VISP_HAVE_GTK)
   delete displayGtk;
 #endif
 
-#if defined(VISP_HAVE_OPENCV)
+#if defined(HAVE_OPENCV_HIGHGUI)
   delete displayCv;
 #endif
 
-#if defined VISP_HAVE_GDI
+#if defined(VISP_HAVE_GDI)
+
   delete displayGdi;
 #endif
 
-#if defined VISP_HAVE_D3D9
+#if defined(VISP_HAVE_D3D9)
   delete displayD3d;
 #endif
 }
@@ -365,26 +367,27 @@ int main(int argc, const char **argv)
 
     // Read the command line options
     if (getOptions(argc, argv, opt_list, opt_click_allowed, opt_display) == false) {
-      exit(-1);
+      return EXIT_FAILURE;
     }
 
     // Print the list of video-devices available
     if (opt_list) {
       unsigned nbDevices = 0;
       std::cout << "List of video-devices available: \n";
-#if defined VISP_HAVE_GTK
+#if defined(VISP_HAVE_GTK)
       std::cout << "  GTK\n";
       nbDevices++;
 #endif
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
       std::cout << "  X11\n";
       nbDevices++;
 #endif
-#if defined VISP_HAVE_GDI
+#if defined(VISP_HAVE_GDI)
+
       std::cout << "  GDI\n";
       nbDevices++;
 #endif
-#if defined VISP_HAVE_D3D9
+#if defined(VISP_HAVE_D3D9)
       std::cout << "  D3D\n";
       nbDevices++;
 #endif
@@ -395,7 +398,7 @@ int main(int argc, const char **argv)
       if (!nbDevices) {
         std::cout << "  No display is available\n";
       }
-      return (0);
+      return EXIT_FAILURE;
     }
 
     // Create a color image for each display.
@@ -404,15 +407,16 @@ int main(int argc, const char **argv)
     // Create a grayscale image for each display.
     runTest<unsigned char>(opt_display, opt_click_allowed);
 
+    return EXIT_SUCCESS;
   } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e.getMessage() << std::endl;
-    return (-1);
+    return EXIT_FAILURE;
   }
 }
 #else
 int main()
 {
   std::cout << "You do not have display functionalities..." << std::endl;
-  return 0;
+  return EXIT_SUCCESS;
 }
 #endif
