@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * CLAHE (Contrast Limited Adaptive Histogram Equalization) algorithm.
- *
- * Authors:
- * Souriya Trinh
- *
- *****************************************************************************/
+ */
 /**
  * License: GPL
  *
@@ -50,7 +45,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- */
+*/
 /**
  * &lsquot;Contrast Limited Adaptive Histogram Equalization&rsquot; as
  * described in
@@ -74,7 +69,7 @@
  *
  * @author Stephan Saalfeld <saalfeld@mpi-cbg.de>
  * @version 0.3b
- */
+*/
 
 /*!
   \file vpCLAHE.cpp
@@ -120,8 +115,8 @@ void clipHistogram(const std::vector<int> &hist, std::vector<int> &clippedHist,
   } while (clippedEntries != clippedEntriesBefore);
 }
 
-void createHistogram(int blockRadius, int bins, int blockXCenter, int blockYCenter,
-                     const vpImage<unsigned char> &I, std::vector<int> &hist)
+void createHistogram(int blockRadius, int bins, int blockXCenter, int blockYCenter, const vpImage<unsigned char> &I,
+                     std::vector<int> &hist)
 {
   std::fill(hist.begin(), hist.end(), 0);
 
@@ -194,39 +189,11 @@ float transferValue(int v, const std::vector<int> &hist, std::vector<int> &clipp
 
   return transferValue(v, clippedHist);
 }
-}
+} // namespace
 
-/*!
-  \ingroup group_imgproc_brightness
-
-  Adjust the contrast of a grayscale image locally using the Contrast Limited
-  Adaptative Histogram Equalization method. The limit parameter allows to
-  limit the slope of the transformation function to prevent the
-  overamplification of noise. This method is a transcription of the CLAHE
-  ImageJ plugin code by Stephan Saalfeld.
-
-  \param I1 : The first grayscale image.
-  \param I2 : The second grayscale image after application of the CLAHE
-  method.
-  \param blockRadius : The size (2*blockRadius+1) of the local region
-  around a pixel for which the histogram is equalized. This size should be
-  larger than the size of features to be preserved.
-  \param bins : The number
-  of histogram bins used for histogram equalization (between 1 and 256). The
-  number of histogram bins should be smaller than the number of pixels in a
-  block.
-  \param slope : Limits the contrast stretch in the intensity transfer
-  function. Very large values will let the histogram equalization do whatever
-  it wants to do, that is result in maximal local contrast. The value 1 will
-  result in the original image.
-  \param fast : Use the fast but less accurate
-  version of the filter. The fast version does not evaluate the intensity
-  transfer function for each pixel independently but for a grid of adjacent
-  boxes of the given block size only and interpolates for locations in
-  between.
-*/
-void vp::clahe(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, int blockRadius, int bins,
-               float slope, bool fast)
+namespace vp
+{
+void clahe(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, int blockRadius, int bins, float slope, bool fast)
 {
   if (blockRadius < 0) {
     std::cerr << "Error: blockRadius < 0!" << std::endl;
@@ -240,8 +207,8 @@ void vp::clahe(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, int
 
   if ((unsigned int)(2 * blockRadius + 1) > I1.getWidth() || (unsigned int)(2 * blockRadius + 1) > I1.getHeight()) {
     std::cerr << "Error: (unsigned int) (2*blockRadius+1) > I1.getWidth() || "
-                 "(unsigned int) (2*blockRadius+1) > I1.getHeight()!"
-              << std::endl;
+      "(unsigned int) (2*blockRadius+1) > I1.getHeight()!"
+      << std::endl;
     return;
   }
 
@@ -328,7 +295,8 @@ void vp::clahe(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, int
       tr = createTransfer(hist, limit, cdfs);
       if (r0 == r1) {
         br = tr;
-      } else {
+      }
+      else {
         createHistogram(blockRadius, bins, cs[0], rs[r1], I1, hist);
         br = createTransfer(hist, limit, cdfs);
       }
@@ -349,7 +317,8 @@ void vp::clahe(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, int
           tr = createTransfer(hist, limit, cdfs);
           if (r0 == r1) {
             br = tr;
-          } else {
+          }
+          else {
             createHistogram(blockRadius, bins, cs[c1], rs[r1], I1, hist);
             br = createTransfer(hist, limit, cdfs);
           }
@@ -372,7 +341,8 @@ void vp::clahe(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, int
             if (c0 == c1) {
               t0 = t00;
               t1 = t10;
-            } else {
+            }
+            else {
               t0 = wx * t00 + (1.0f - wx) * t01;
               t1 = wx * t10 + (1.0f - wx) * t11;
             }
@@ -383,7 +353,8 @@ void vp::clahe(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, int
         }
       }
     }
-  } else {
+  }
+  else {
     std::vector<int> hist(bins + 1), prev_hist(bins + 1);
     std::vector<int> clippedHist(bins + 1);
 
@@ -413,7 +384,8 @@ void vp::clahe(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, int
             ++hist[fastRound(I1[yi][xi] / 255.0f * bins)];
           }
         }
-      } else {
+      }
+      else {
         hist = prev_hist;
 
         if (yMin > 0) {
@@ -465,33 +437,7 @@ void vp::clahe(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, int
   }
 }
 
-/*!
-  \ingroup group_imgproc_brightness
-
-  Adjust the contrast of a color image locally using the Contrast Limited
-  Adaptative Histogram Equalization method. The limit parameter allows to
-  limit the slope of the transformation function to prevent the
-  overamplification of noise. This method is a transcription of the CLAHE
-  ImageJ plugin code by Stephan Saalfeld.
-
-  \param I1 : The first color image.
-  \param I2 : The second color image after application of the CLAHE method.
-  \param blockRadius : The size (2*blockRadius+1) of the local region around a
-  pixel for which the histogram is equalized. This size should be larger than
-  the size of features to be preserved. \param  bins : The number of histogram
-  bins used for histogram equalization (between 1 and 256). The number of
-  histogram bins should be smaller than the number of pixels in a block.
-  \param slope : Limits the contrast stretch in the intensity transfer
-  function. Very large values will let the histogram equalization do whatever
-  it wants to do, that is result in maximal local contrast. The value 1 will
-  result in the original image. \param fast : Use the fast but less accurate
-  version of the filter. The fast version does not evaluate the intensity
-  transfer function for each pixel independently but for a grid of adjacent
-  boxes of the given block size only and interpolates for locations in
-  between.
-*/
-void vp::clahe(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, int blockRadius, int bins, float slope,
-               bool fast)
+void clahe(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, int blockRadius, int bins, float slope, bool fast)
 {
   // Split
   vpImage<unsigned char> pR(I1.getHeight(), I1.getWidth());
@@ -530,3 +476,4 @@ void vp::clahe(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, int blockRadius,
     cpt++;
   }
 }
+};
