@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * Flood fill algorithm.
- *
- * Authors:
- * Souriya Trinh
- *
- *****************************************************************************/
+ */
 /*
  * Copyright (c) 2004-2007, Lode Vandevenne
  *
@@ -61,7 +56,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- */
+*/
 
 /*!
   \file vpFloodFill.cpp
@@ -71,19 +66,10 @@
 #include <queue>
 #include <visp3/imgproc/vpImgproc.h>
 
-/*!
-  \ingroup group_imgproc_connected_components
-
-  Perform the flood fill algorithm.
-
-  \param I : Input image to flood fill.
-  \param seedPoint : Seed position in the image.
-  \param oldValue : Old value to replace.
-  \param newValue : New value to flood fill.
-  \param connexity : Type of connexity.
-*/
-void vp::floodFill(vpImage<unsigned char> &I, const vpImagePoint &seedPoint, const unsigned char oldValue,
-                   const unsigned char newValue, const vpImageMorphology::vpConnexityType &connexity)
+namespace vp
+{
+void floodFill(vpImage<unsigned char> &I, const vpImagePoint &seedPoint, const unsigned char oldValue,
+               const unsigned char newValue, const vpImageMorphology::vpConnexityType &connexity)
 {
   // Code from Lode Vandevenne tutorial.
   // Naive modification for 8-connexity implementation
@@ -134,7 +120,8 @@ void vp::floodFill(vpImage<unsigned char> &I, const vpImagePoint &seedPoint, con
             seed_queue.push(vpImagePoint(y - 1, x1 + 1));
           }
         }
-      } else if (spanAbove && y > 0 && I[y - 1][x1] != oldValue) {
+      }
+      else if (spanAbove && y > 0 && I[y - 1][x1] != oldValue) {
         spanAbove = false;
       }
 
@@ -157,7 +144,8 @@ void vp::floodFill(vpImage<unsigned char> &I, const vpImagePoint &seedPoint, con
             spanBelow = true;
           }
         }
-      } else if (spanBelow && y < I.getHeight() - 1 && I[y + 1][x1] != oldValue) {
+      }
+      else if (spanBelow && y < I.getHeight() - 1 && I[y + 1][x1] != oldValue) {
         spanBelow = false;
       }
 
@@ -171,3 +159,4 @@ void vp::floodFill(vpImage<unsigned char> &I, const vpImagePoint &seedPoint, con
     }
   }
 }
+};
