@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * Convert image types.
- *
- * Authors:
- * Souriya Trinh
- *
- *****************************************************************************/
+ */
 /* Autostretch HSV 0.10 --- image filter plug-in for GIMP
  *
  * Copyright (C) 1997 Scott Goehring
@@ -54,31 +49,23 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+*/
 
 /*!
   \file vpImgproc.cpp
   \brief Basic image processing functions.
 */
 
+#include <visp3/core/vpGaussianFilter.h>
 #include <visp3/core/vpHistogram.h>
 #include <visp3/core/vpImageConvert.h>
 #include <visp3/core/vpImageFilter.h>
 #include <visp3/core/vpMath.h>
-#include <visp3/core/vpGaussianFilter.h>
 #include <visp3/imgproc/vpImgproc.h>
 
-/*!
-  \ingroup group_imgproc_brightness
-
-  Adjust the brightness of a grayscale image such as the new intensity is
-  alpha x old_intensity + beta.
-
-  \param I : The grayscale image to adjust the brightness.
-  \param alpha : Multiplication coefficient.
-  \param beta : Constant value added to the old intensity.
-*/
-void vp::adjust(vpImage<unsigned char> &I, double alpha, double beta)
+namespace vp
+{
+void adjust(vpImage<unsigned char> &I, double alpha, double beta)
 {
   // Construct the look-up table
   unsigned char lut[256];
@@ -90,18 +77,7 @@ void vp::adjust(vpImage<unsigned char> &I, double alpha, double beta)
   I.performLut(lut);
 }
 
-/*!
-  \ingroup group_imgproc_brightness
-
-  Adjust the brightness of a grayscale image such as the new intensity is
-  alpha x old_intensity + beta.
-
-  \param I1 : The original grayscale image.
-  \param I2 : The grayscale image after adjusting pixel intensities.
-  \param alpha : Multiplication coefficient.
-  \param beta : Constant value added to the old intensity.
-*/
-void vp::adjust(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, double alpha, double beta)
+void adjust(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, double alpha, double beta)
 {
   // Copy I1 to I2
   I2 = I1;
@@ -109,17 +85,7 @@ void vp::adjust(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, do
   vp::adjust(I2, alpha, beta);
 }
 
-/*!
-  \ingroup group_imgproc_brightness
-
-  Adjust the brightness of a color image such as the new intensity is alpha x
-  old_intensity + beta.
-
-  \param I : The color image to adjust the brightness.
-  \param alpha : Multiplication coefficient.
-  \param beta : Constant value added to the old intensity.
-*/
-void vp::adjust(vpImage<vpRGBa> &I, double alpha, double beta)
+void adjust(vpImage<vpRGBa> &I, double alpha, double beta)
 {
   // Construct the look-up table
   vpRGBa lut[256];
@@ -134,18 +100,7 @@ void vp::adjust(vpImage<vpRGBa> &I, double alpha, double beta)
   I.performLut(lut);
 }
 
-/*!
-  \ingroup group_imgproc_brightness
-
-  Adjust the brightness of a color image such as the new intensity is alpha x
-  old_intensity + beta.
-
-  \param I1 : The original color image.
-  \param I2 : The color image after adjusting pixel intensities.
-  \param alpha : Multiplication coefficient.
-  \param beta : Constant value added to the old intensity.
-*/
-void vp::adjust(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, double alpha, double beta)
+void adjust(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, double alpha, double beta)
 {
   // Copy I1 to I2
   I2 = I1;
@@ -153,16 +108,7 @@ void vp::adjust(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, double alpha, do
   vp::adjust(I2, alpha, beta);
 }
 
-/*!
-  \ingroup group_imgproc_histogram
-
-  Adjust the contrast of a grayscale image by performing an histogram
-  equalization. The intensity distribution is redistributed over the full [0 -
-  255] range such as the cumulative histogram distribution becomes linear.
-
-  \param I : The grayscale image to apply histogram equalization.
-*/
-void vp::equalizeHistogram(vpImage<unsigned char> &I)
+void equalizeHistogram(vpImage<unsigned char> &I)
 {
   if (I.getWidth() * I.getHeight() == 0) {
     return;
@@ -176,8 +122,8 @@ void vp::equalizeHistogram(vpImage<unsigned char> &I)
   unsigned int cdf[256];
   unsigned int cdfMin = /*std::numeric_limits<unsigned int>::max()*/ UINT_MAX, cdfMax = 0;
   unsigned int minValue =
-                   /*std::numeric_limits<unsigned int>::max()*/ UINT_MAX,
-               maxValue = 0;
+    /*std::numeric_limits<unsigned int>::max()*/ UINT_MAX,
+    maxValue = 0;
   cdf[0] = hist[0];
 
   if (cdf[0] < cdfMin && cdf[0] > 0) {
@@ -214,36 +160,13 @@ void vp::equalizeHistogram(vpImage<unsigned char> &I)
   I.performLut(lut);
 }
 
-/*!
-  \ingroup group_imgproc_histogram
-
-  Adjust the contrast of a grayscale image by performing an histogram
-  equalization. The intensity distribution is redistributed over the full [0 -
-  255] range such as the cumulative histogram distribution becomes linear.
-
-  \param I1 : The first grayscale image.
-  \param I2 : The second grayscale image after histogram equalization.
-*/
-void vp::equalizeHistogram(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2)
+void equalizeHistogram(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2)
 {
   I2 = I1;
   vp::equalizeHistogram(I2);
 }
 
-/*!
-  \ingroup group_imgproc_histogram
-
-  Adjust the contrast of a color image by performing an histogram
-  equalization. The intensity distribution is redistributed over the full [0 -
-  255] range such as the cumulative histogram distribution becomes linear. The
-  alpha channel is ignored / copied from the source alpha channel.
-
-  \param I : The color image to apply histogram equalization.
-  \param useHSV : If true, the histogram equalization is performed on the
-  value channel (in HSV space), otherwise the histogram equalization is
-  performed independently on the RGB channels.
-*/
-void vp::equalizeHistogram(vpImage<vpRGBa> &I, bool useHSV)
+void equalizeHistogram(vpImage<vpRGBa> &I, bool useHSV)
 {
   if (I.getWidth() * I.getHeight() == 0) {
     return;
@@ -285,7 +208,8 @@ void vp::equalizeHistogram(vpImage<vpRGBa> &I, bool useHSV)
 
       cpt++;
     }
-  } else {
+  }
+  else {
     vpImage<unsigned char> hue(I.getHeight(), I.getWidth());
     vpImage<unsigned char> saturation(I.getHeight(), I.getWidth());
     vpImage<unsigned char> value(I.getHeight(), I.getWidth());
@@ -304,40 +228,19 @@ void vp::equalizeHistogram(vpImage<vpRGBa> &I, bool useHSV)
   }
 }
 
-/*!
-  \ingroup group_imgproc_histogram
-
-  Adjust the contrast of a color image by performing an histogram
-  equalization. The intensity distribution is redistributed over the full [0 -
-  255] range such as the cumulative histogram distribution becomes linear. The
-  alpha channel is ignored / copied from the source alpha channel.
-
-  \param I1 : The first color image.
-  \param I2 : The second color image after histogram equalization.
-  \param useHSV : If true, the histogram equalization is performed on the
-  value channel (in HSV space), otherwise the histogram equalization is
-  performed independently on the RGB channels.
-*/
-void vp::equalizeHistogram(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, bool useHSV)
+void equalizeHistogram(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, bool useHSV)
 {
   I2 = I1;
   vp::equalizeHistogram(I2, useHSV);
 }
 
-/*!
-  \ingroup group_imgproc_gamma
-
-  Perform a gamma correction on a grayscale image.
-
-  \param I : The grayscale image to apply gamma correction.
-  \param gamma : Gamma value.
-*/
-void vp::gammaCorrection(vpImage<unsigned char> &I, double gamma)
+void gammaCorrection(vpImage<unsigned char> &I, double gamma)
 {
   double inverse_gamma = 1.0;
   if (gamma > 0) {
     inverse_gamma = 1.0 / gamma;
-  } else {
+  }
+  else {
     throw vpException(vpException::badValue, "The gamma value must be positive !");
   }
 
@@ -350,35 +253,19 @@ void vp::gammaCorrection(vpImage<unsigned char> &I, double gamma)
   I.performLut(lut);
 }
 
-/*!
-  \ingroup group_imgproc_gamma
-
-  Perform a gamma correction on a grayscale image.
-
-  \param I1 : The first grayscale image.
-  \param I2 : The second grayscale image after gamma correction.
-  \param gamma : Gamma value.
-*/
-void vp::gammaCorrection(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, double gamma)
+void gammaCorrection(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, double gamma)
 {
   I2 = I1;
   vp::gammaCorrection(I2, gamma);
 }
 
-/*!
-  \ingroup group_imgproc_gamma
-
-  Perform a gamma correction on a color image.
-
-  \param I : The color image to apply gamma correction.
-  \param gamma : Gamma value.
-*/
-void vp::gammaCorrection(vpImage<vpRGBa> &I, double gamma)
+void gammaCorrection(vpImage<vpRGBa> &I, double gamma)
 {
   double inverse_gamma = 1.0;
   if (gamma > 0) {
     inverse_gamma = 1.0 / gamma;
-  } else {
+  }
+  else {
     throw vpException(vpException::badValue, "The gamma value must be positive !");
   }
 
@@ -394,29 +281,13 @@ void vp::gammaCorrection(vpImage<vpRGBa> &I, double gamma)
   I.performLut(lut);
 }
 
-/*!
-  \ingroup group_imgproc_gamma
-
-  Perform a gamma correction on a color image.
-
-  \param I1 : The first color image.
-  \param I2 : The second color image after gamma correction.
-  \param gamma : Gamma value.
-*/
-void vp::gammaCorrection(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, double gamma)
+void gammaCorrection(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, double gamma)
 {
   I2 = I1;
   vp::gammaCorrection(I2, gamma);
 }
 
-/*!
-  \ingroup group_imgproc_contrast
-
-  Stretch the contrast of a grayscale image.
-
-  \param I : The grayscale image to stretch the contrast.
-*/
-void vp::stretchContrast(vpImage<unsigned char> &I)
+void stretchContrast(vpImage<unsigned char> &I)
 {
   // Find min and max intensity values
   unsigned char min = 255, max = 0;
@@ -430,36 +301,22 @@ void vp::stretchContrast(vpImage<unsigned char> &I)
     for (unsigned int x = min; x <= max; x++) {
       lut[x] = 255 * (x - min) / range;
     }
-  } else {
+  }
+  else {
     lut[min] = min;
   }
 
   I.performLut(lut);
 }
 
-/*!
-  \ingroup group_imgproc_contrast
-
-  Stretch the contrast of a grayscale image.
-
-  \param I1 : The first input grayscale image.
-  \param I2 : The second output grayscale image.
-*/
-void vp::stretchContrast(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2)
+void stretchContrast(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2)
 {
   // Copy I1 to I2
   I2 = I1;
   vp::stretchContrast(I2);
 }
 
-/*!
-  \ingroup group_imgproc_contrast
-
-  Stretch the contrast of a color image.
-
-  \param I : The color image to stretch the contrast.
-*/
-void vp::stretchContrast(vpImage<vpRGBa> &I)
+void stretchContrast(vpImage<vpRGBa> &I)
 {
   // Find min and max intensity values
   vpRGBa min = 255, max = 0;
@@ -496,7 +353,8 @@ void vp::stretchContrast(vpImage<vpRGBa> &I)
     for (unsigned int x = min.R; x <= max.R; x++) {
       lut[x].R = 255 * (x - min.R) / rangeR;
     }
-  } else {
+  }
+  else {
     lut[min.R].R = min.R;
   }
 
@@ -505,7 +363,8 @@ void vp::stretchContrast(vpImage<vpRGBa> &I)
     for (unsigned int x = min.G; x <= max.G; x++) {
       lut[x].G = 255 * (x - min.G) / rangeG;
     }
-  } else {
+  }
+  else {
     lut[min.G].G = min.G;
   }
 
@@ -514,7 +373,8 @@ void vp::stretchContrast(vpImage<vpRGBa> &I)
     for (unsigned int x = min.B; x <= max.B; x++) {
       lut[x].B = 255 * (x - min.B) / rangeB;
     }
-  } else {
+  }
+  else {
     lut[min.B].B = min.B;
   }
 
@@ -523,43 +383,28 @@ void vp::stretchContrast(vpImage<vpRGBa> &I)
     for (unsigned int x = min.A; x <= max.A; x++) {
       lut[x].A = 255 * (x - min.A) / rangeA;
     }
-  } else {
+  }
+  else {
     lut[min.A].A = min.A;
   }
 
   I.performLut(lut);
 }
 
-/*!
-  \ingroup group_imgproc_contrast
-
-  Stretch the contrast of a color image.
-
-  \param I1 : The first input color image.
-  \param I2 : The second output color image.
-*/
-void vp::stretchContrast(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2)
+void stretchContrast(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2)
 {
   // Copy I1 to I2
   I2 = I1;
   vp::stretchContrast(I2);
 }
 
-/*!
-  \ingroup group_imgproc_contrast
-
-  Stretch the contrast of a color image in the HSV color space.
-  The saturation and value components are stretch so the hue is preserved.
-
-  \param I : The color image to stetch the contrast in the HSV color space.
-*/
-void vp::stretchContrastHSV(vpImage<vpRGBa> &I)
+void stretchContrastHSV(vpImage<vpRGBa> &I)
 {
   unsigned int size = I.getWidth() * I.getHeight();
 
   // Convert RGB to HSV
   vpImage<double> hueImage(I.getHeight(), I.getWidth()), saturationImage(I.getHeight(), I.getWidth()),
-      valueImage(I.getHeight(), I.getWidth());
+    valueImage(I.getHeight(), I.getWidth());
   vpImageConvert::RGBaToHSV((unsigned char *)I.bitmap, hueImage.bitmap, saturationImage.bitmap, valueImage.bitmap,
                             size);
 
@@ -597,32 +442,14 @@ void vp::stretchContrastHSV(vpImage<vpRGBa> &I)
                             size);
 }
 
-/*!
-  \ingroup group_imgproc_contrast
-
-  Stretch the contrast of a color image in the HSV color space.
-  The saturation and value components are stretch so the hue is preserved.
-
-  \param I1 : The first input color image.
-  \param I2 : The second output color image.
-*/
-void vp::stretchContrastHSV(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2)
+void stretchContrastHSV(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2)
 {
   // Copy I1 to I2
   I2 = I1;
   vp::stretchContrastHSV(I2);
 }
 
-/*!
-  \ingroup group_imgproc_sharpening
-
-  Sharpen a grayscale image using the unsharp mask technique.
-
-  \param I : The grayscale image to sharpen.
-  \param sigma : Standard deviation for Gaussian kernel.
-  \param weight : Weight (between [0 - 1[) for the sharpening process.
- */
-void vp::unsharpMask(vpImage<unsigned char> &I, float sigma, double weight)
+void unsharpMask(vpImage<unsigned char> &I, float sigma, double weight)
 {
   if (weight < 1.0 && weight >= 0.0) {
     // Gaussian blurred image
@@ -638,34 +465,14 @@ void vp::unsharpMask(vpImage<unsigned char> &I, float sigma, double weight)
   }
 }
 
-/*!
-  \ingroup group_imgproc_sharpening
-
-  Sharpen a grayscale image using the unsharp mask technique.
-
-  \param I1 : The first input grayscale image.
-  \param I2 : The second output grayscale image.
-  \param sigma : Standard deviation for Gaussian kernel.
-  \param weight : Weight (between [0 - 1[) for the sharpening process.
-*/
-void vp::unsharpMask(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, float sigma,
-                     double weight)
+void unsharpMask(const vpImage<unsigned char> &I, vpImage<unsigned char> &Ires, float sigma, double weight)
 {
-  // Copy I1 to I2
-  I2 = I1;
-  vp::unsharpMask(I2, sigma, weight);
+  // Copy I to Ires
+  Ires = I;
+  vp::unsharpMask(Ires, sigma, weight);
 }
 
-/*!
-  \ingroup group_imgproc_sharpening
-
-  Sharpen a color image using the unsharp mask technique.
-
-  \param I : The color image to sharpen.
-  \param sigma : Standard deviation for Gaussian kernel.
-  \param weight : Weight (between [0 - 1[) for the sharpening process.
- */
-void vp::unsharpMask(vpImage<vpRGBa> &I, float sigma, double weight)
+void unsharpMask(vpImage<vpRGBa> &I, float sigma, double weight)
 {
   if (weight < 1.0 && weight >= 0.0) {
     // Gaussian blurred image
@@ -686,21 +493,11 @@ void vp::unsharpMask(vpImage<vpRGBa> &I, float sigma, double weight)
   }
 }
 
-/*!
-  \ingroup group_imgproc_sharpening
-
-  Sharpen a color image using the unsharp mask technique.
-
-  \param I1 : The first input color image.
-  \param I2 : The second output color image.
-  \param sigma : Standard deviation for Gaussian kernel.
-  \param weight : Weight (between [0 - 1[) for the sharpening process.
-*/
-void vp::unsharpMask(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, float sigma, double weight)
+void unsharpMask(const vpImage<vpRGBa> &I, vpImage<vpRGBa> &Ires, float sigma, double weight)
 {
-  // Copy I1 to I2
-  I2 = I1;
-  vp::unsharpMask(I2, sigma, weight);
+  // Copy I to Ires
+  Ires = I;
+  vp::unsharpMask(Ires, sigma, weight);
 }
 
 #ifdef VISP_BUILD_DEPRECATED_FUNCTIONS
@@ -716,7 +513,7 @@ void vp::unsharpMask(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, float sigma
   \param size : Size (must be odd) of the Gaussian blur kernel.
   \param weight : Weight (between [0 - 1[) for the sharpening process.
  */
-void vp::unsharpMask(vpImage<unsigned char> &I, unsigned int size, double weight)
+void unsharpMask(vpImage<unsigned char> &I, unsigned int size, double weight)
 {
   if (weight < 1.0 && weight >= 0.0) {
     // Gaussian blurred image
@@ -744,16 +541,16 @@ void vp::unsharpMask(vpImage<unsigned char> &I, unsigned int size, double weight
   \param size : Size (must be odd) of the Gaussian blur kernel.
   \param weight : Weight (between [0 - 1[) for the sharpening process.
 */
-void vp::unsharpMask(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, unsigned int size,
-                     double weight)
+void unsharpMask(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I2, unsigned int size, double weight)
 {
   // Copy I1 to I2
   I2 = I1;
 #if 0
   vp::unsharpMask(I2, size, weight);
 #else
-  //To avoid:
-  //warning: ‘void vp::unsharpMask(vpImage<unsigned char>&, unsigned int, double)’ is deprecated [-Wdeprecated-declarations]
+  // To avoid:
+  // warning: ‘void vp::unsharpMask(vpImage<unsigned char>&, unsigned int, double)’ is deprecated
+  // [-Wdeprecated-declarations]
   if (weight < 1.0 && weight >= 0.0) {
     // Gaussian blurred image
     vpImage<double> I_blurred;
@@ -780,7 +577,7 @@ void vp::unsharpMask(const vpImage<unsigned char> &I1, vpImage<unsigned char> &I
   \param size : Size (must be odd) of the Gaussian blur kernel.
   \param weight : Weight (between [0 - 1[) for the sharpening process.
  */
-void vp::unsharpMask(vpImage<vpRGBa> &I, unsigned int size, double weight)
+void unsharpMask(vpImage<vpRGBa> &I, unsigned int size, double weight)
 {
   if (weight < 1.0 && weight >= 0.0) {
     // Gaussian blurred image
@@ -818,15 +615,15 @@ void vp::unsharpMask(vpImage<vpRGBa> &I, unsigned int size, double weight)
   \param size : Size (must be odd) of the Gaussian blur kernel.
   \param weight : Weight (between [0 - 1[) for the sharpening process.
 */
-void vp::unsharpMask(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, unsigned int size, double weight)
+void unsharpMask(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, unsigned int size, double weight)
 {
   // Copy I1 to I2
   I2 = I1;
 #if 0
   vp::unsharpMask(I2, size, weight);
 #else
-  //To avoid:
-  //warning: ‘void vp::unsharpMask(vpImage<vpRGBa>&, unsigned int, double)’ is deprecated [-Wdeprecated-declarations]
+  // To avoid:
+  // warning: ‘void vp::unsharpMask(vpImage<vpRGBa>&, unsigned int, double)’ is deprecated [-Wdeprecated-declarations]
   if (weight < 1.0 && weight >= 0.0) {
     // Gaussian blurred image
     vpImage<double> I_blurred_R, I_blurred_G, I_blurred_B;
@@ -851,3 +648,4 @@ void vp::unsharpMask(const vpImage<vpRGBa> &I1, vpImage<vpRGBa> &I2, unsigned in
 #endif
 }
 #endif // Deprecated
+};
