@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * Additional image morphology functions.
- *
- * Authors:
- * Souriya Trinh
- *
- *****************************************************************************/
+ */
 
 /*!
   \file vpMorph.cpp
@@ -44,17 +39,13 @@
 #include <visp3/core/vpImageTools.h>
 #include <visp3/imgproc/vpImgproc.h>
 
-/*!
-  \ingroup group_imgproc_morph
+namespace vp
+{
 
-  Fill the holes in a binary image.
-
-  \param I : Input binary image (0 means background, 255 means foreground).
-*/
-void vp::fillHoles(vpImage<unsigned char> &I
+void fillHoles(vpImage<unsigned char> &I
 #if USE_OLD_FILL_HOLE
-                   ,
-                   const vpImageMorphology::vpConnexityType &connexity
+  ,
+  const vpImageMorphology::vpConnexityType &connexity
 #endif
 )
 {
@@ -86,7 +77,8 @@ void vp::fillHoles(vpImage<unsigned char> &I
       for (unsigned int j = 0; j < marker.getWidth(); j++) {
         marker[i][j] = 255;
       }
-    } else {
+    }
+    else {
       marker[i][0] = 255;
       marker[i][marker.getWidth() - 1] = 255;
     }
@@ -124,31 +116,13 @@ void vp::fillHoles(vpImage<unsigned char> &I
 #endif
 }
 
-/*!
-  \ingroup group_imgproc_morph
-
-  Perform morphological reconstruction of the image \a marker under the image
-  \a mask. Definition from Gleb V. Tcheslavsk: > The morphological
-  reconstruction by dilation of a grayscale image \f$ g \f$ by a grayscale
-  marker image \f$ f \f$ > is defined as the geodesic dilation of \f$ f \f$
-  with respect to \f$ g \f$ repeated (iterated) until stability is reached:
-  \f[
-    R_{g}^{D} \left ( f \right ) = D_{g}^{\left ( k \right )} \left ( f \right
-  ) \f] with \f$ k \f$ such that: \f$ D_{g}^{\left ( k \right )} \left ( f
-  \right ) = D_{g}^{\left ( k+1 \right )} \left ( f \right ) \f$
-
-  \param marker : Grayscale image marker.
-  \param mask : Grayscale image mask.
-  \param h_kp1 : Image morphologically reconstructed.
-  \param connexity : Type of connexity.
-*/
-void vp::reconstruct(const vpImage<unsigned char> &marker, const vpImage<unsigned char> &mask,
-                     vpImage<unsigned char> &h_kp1 /*alias I */, const vpImageMorphology::vpConnexityType &connexity)
+void reconstruct(const vpImage<unsigned char> &marker, const vpImage<unsigned char> &mask,
+                 vpImage<unsigned char> &h_kp1 /*alias I */, const vpImageMorphology::vpConnexityType &connexity)
 {
   if (marker.getHeight() != mask.getHeight() || marker.getWidth() != mask.getWidth()) {
     std::cerr << "marker.getHeight() != mask.getHeight() || "
-                 "marker.getWidth() != mask.getWidth()"
-              << std::endl;
+      "marker.getWidth() != mask.getWidth()"
+      << std::endl;
     return;
   }
 
@@ -162,7 +136,7 @@ void vp::reconstruct(const vpImage<unsigned char> &marker, const vpImage<unsigne
 
   do {
     // Dilatation
-    vpImageMorphology::dilatation(h_kp1, connexity);
+    vpImageMorphology::dilatation<unsigned char>(h_kp1, connexity);
 
     // Keep min
     for (unsigned int i = 0; i < h_kp1.getHeight(); i++) {
@@ -178,3 +152,4 @@ void vp::reconstruct(const vpImage<unsigned char> &marker, const vpImage<unsigne
     h_k = h_kp1;
   } while (true);
 }
+};
