@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * Parallel port management.
- *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+ */
 
 #ifndef vpParallelPort_h
 #define vpParallelPort_h
@@ -53,6 +48,7 @@
 #include <linux/parport.h>
 #include <linux/ppdev.h>
 #include <stdio.h>
+#include <string>
 
 #include <visp3/io/vpParallelPortException.h>
 
@@ -94,7 +90,7 @@ private:
 
 private:
   int fd; // parallel port descriptor
-  char device[FILENAME_MAX];
+  std::string device;
 };
 
 #endif
