@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -29,66 +28,47 @@
  * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  *
  * Description:
- * Exceptions that can be emited by the vpParallelPort class and its
- *derivates.
- *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+ * Exceptions that can be emitted by the vpParallelPort class and its
+ * derivates.
+ */
 
 #ifndef _vpParallelPortException_h_
 #define _vpParallelPortException_h_
 
-/* -------------------------------------------------------------------------
- */
-/* --- INCLUDE -------------------------------------------------------------
- */
-/* -------------------------------------------------------------------------
- */
-
 /*!
-
-  \file vpParallelPortException.h
-
-  \brief Error that can be emited by the vpParallelPort class and its
-  derivates.
-
-*/
-
-/* Classes standards. */
+ * \file vpParallelPortException.h
+ * \brief Error that can be emitted by the vpParallelPort class and its
+ * derivates.
+ */
 
 #include <visp3/core/vpException.h>
 
-#include <iostream> /* Classe std::ostream.    */
-#include <string>   /* Classe string.     */
-
-/* -------------------------------------------------------------------------
- */
-/* --- CLASS ---------------------------------------------------------------
- */
-/* -------------------------------------------------------------------------
- */
+#include <iostream>
+#include <string>
 
 /*!
-  \class vpParallelPortException
-
-  \brief Error that can be emited by the vpParallelPort class and its
-  derivates.
+ * \class vpParallelPortException
+ *
+ * \brief Error that can be emitted by the vpParallelPort class and its
+ * derivates.
  */
 class VISP_EXPORT vpParallelPortException : public vpException
 {
 public:
   /*!
-  \brief Lists the possible errors than can be emmited while calling
-  vpParallelPort member
- */
-  enum error {
+   * \brief Lists the possible errors than can be emitted while calling
+   * vpParallelPort member
+   */
+  enum error
+  {
     opening, /*!< Cannot access to the parallel port device. */
     closing  /*!< Cannot close the parallel port device. */
   };
 
 public:
+  /*!
+   * Constructor.
+   */
   vpParallelPortException(int id, const char *format, ...)
   {
     this->code = id;
@@ -97,8 +77,16 @@ public:
     setMessage(format, args);
     va_end(args);
   }
-  vpParallelPortException(int id, const std::string &msg) : vpException(id, msg) { ; }
-  explicit vpParallelPortException(int id) : vpException(id) { ; }
+
+  /*!
+   * Constructor.
+   */
+  vpParallelPortException(int id, const std::string &msg) : vpException(id, msg) { }
+
+  /*!
+   * Constructor.
+   */
+  explicit vpParallelPortException(int id) : vpException(id) { }
 };
 
 #endif
