@@ -1,5 +1,4 @@
-/****************************************************************************
- *
+/*
  * Declarations for Tk-related things that are visible
  * outside of the Tk module itself.
  *
@@ -15,13 +14,9 @@
  * This file has been modified to be used only for argv parsing without
  * reference to tk, tcl or X11. Base on tk.h from tk2.3
  *
- * Description:
- * Command line argument parsing.
- *
- * Authors:
- * Fabien Spindler (modification of the original version)
- *
- *****************************************************************************/
+ * Modifications by Peter Neelin (November 27, 1992)
+ * Modifications by Fabien Spindler (June 20, 2006)
+ */
 
 /*!
   \file vpParseArgv.h
@@ -96,11 +91,11 @@ int main(int argc, const char ** argv)
   \code
 #include <stdio.h>
 #include <stdlib.h>
-#include <visp3/io/vpParseArgv.h>
 #include <visp3/core/vpMath.h>
+#include <visp3/io/vpParseArgv.h>
 
 // List of allowed command line options
-#define GETOPTARGS	"bi:l:f:d:h" // double point mean here that the preceding option request an argument
+#define GETOPTARGS "bi:l:f:d:h" // double point mean here that the preceding option request an argument
 
 // Usage : [-b] [-i <integer value>] [-l <long value>]
 //         [-f <float value>] [-d <double value>] [-s <string value>] [-h]
@@ -112,11 +107,11 @@ int main(int argc, const char ** argv)
   long   l_val = 123456;
   float  f_val = 0.1f;
   double d_val = M_PI;
-  char   *s_val;
+  std::string s_val;
 
   // Parse the command line to set the variables
   const char *optarg;
-  int	c;
+  int c;
   while ((c = vpParseArgv::parse(argc, argv, GETOPTARGS, &optarg)) > 1) {
 
     switch (c) {
@@ -125,7 +120,7 @@ int main(int argc, const char ** argv)
     case 'l': l_val = atol(optarg); break;
     case 'f': f_val = static_cast<float>(atof(optarg)); break;
     case 'd': d_val = atof(optarg); break;
-    case 's': sprintf(s_val, "%s", optarg); break;
+    case 's': s_val = std::string(optarg); break;
     case 'h': printf("Usage: ...\n"); return EXIT_SUCCESS; break;
 
     default:
@@ -158,21 +153,22 @@ public:
     ARGV_LONG,          ///< Argument is associated to a long.
     ARGV_STRING,        ///< Argument is associated to a char * string.
     ARGV_REST,
-    ARGV_FLOAT,         ///< Argument is associated to a float.
-    ARGV_DOUBLE,        ///< Argument is associated to a double.
+    ARGV_FLOAT,  ///< Argument is associated to a float.
+    ARGV_DOUBLE, ///< Argument is associated to a double.
     ARGV_FUNC,
     ARGV_GENFUNC,
-    ARGV_HELP,          ///< Argument is for help displaying.
-    ARGV_END            ///< End of the argument list.
+    ARGV_HELP, ///< Argument is for help displaying.
+    ARGV_END   ///< End of the argument list.
   } vpArgvType;
 
   /*!
     Flag bits.
    */
   typedef enum {
-    ARGV_NO_DEFAULTS = 0x1,         ///< No default options like -help.
-    ARGV_NO_LEFTOVERS = 0x2,        ///< Print an error message if an option is not in the argument list.
-    ARGV_NO_ABBREV = 0x4,           ///< No abrevation. Print an error message if an option is abrevated (ie "-i" in place of "-int" which is requested).
+    ARGV_NO_DEFAULTS = 0x1,  ///< No default options like -help.
+    ARGV_NO_LEFTOVERS = 0x2, ///< Print an error message if an option is not in the argument list.
+    ARGV_NO_ABBREV = 0x4,    ///< No abrevation. Print an error message if an option is abrevated (ie "-i" in place of
+                             ///< "-int" which is requested).
     ARGV_DONT_SKIP_FIRST_ARG = 0x8, ///< Don't skip first argument.
     ARGV_NO_PRINT = 0x10            ///< No printings.
   } vpArgvFlags;
