@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * Read/write images.
- *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+ */
 
 /*!
   \file vpImageIo.cpp
@@ -46,7 +41,6 @@
 
 #include "private/vpImageIoBackend.h"
 
-
 vpImageIo::vpImageFormatType vpImageIo::getFormat(const std::string &filename)
 {
   std::string ext = vpImageIo::getExtension(filename);
@@ -119,7 +113,7 @@ std::string vpImageIo::getExtension(const std::string &filename)
 
 /*!
   Read the contents of the image filename, allocate memory for the
-  corresponding greyscale image, update its content, and return a reference to
+  corresponding grayscale image, update its content, and return a reference to
   the image.
 
   If the image has been already initialized, memory allocation is done
@@ -132,10 +126,10 @@ std::string vpImageIo::getExtension(const std::string &filename)
   - portable float map: `*.pfm` file
   - jpeg: `*.jpg`, `*.jpeg` files
   - png: `*.png` file
-  
+
   If ViSP is build with OpenCV support, additional formats are considered:
   - `*.jp2`, `*.rs`, `*.ras`, `*.tiff`, `*.tif`, `*.png`, `*.bmp`, `*.pbm` files.
-  
+
   If EXIF information is embedded in the image file, the EXIF orientation is ignored.
 
   \param I : Image to set with the \e filename content.
@@ -184,7 +178,7 @@ void vpImageIo::read(vpImage<unsigned char> &I, const std::string &filename, int
   }
 
   if (try_opencv_reader) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     readOpenCV(I, filename);
 #else
     std::string message = "Cannot read file \"" + filename + "\": No backend able to support this image format";
@@ -195,7 +189,7 @@ void vpImageIo::read(vpImage<unsigned char> &I, const std::string &filename, int
 
 /*!
   Read the contents of the image filename, allocate memory for the
-  corresponding greyscale image, update its content, and return a reference to
+  corresponding grayscale image, update its content, and return a reference to
   the image.
 
   If the image has been already initialized, memory allocation is done
@@ -208,10 +202,10 @@ void vpImageIo::read(vpImage<unsigned char> &I, const std::string &filename, int
   - portable float map: `*.pfm` file
   - jpeg: `*.jpg`, `*.jpeg` files
   - png: `*.png` file
-  
+
   If ViSP is build with OpenCV support, additional formats are considered:
   - `*.jp2`, `*.rs`, `*.ras`, `*.tiff`, `*.tif`, `*.png`, `*.bmp`, `*.pbm` files.
-  
+
   If EXIF information is embedded in the image file, the EXIF orientation is ignored.
 
   \param I : Image to set with the \e filename content.
@@ -259,7 +253,7 @@ void vpImageIo::read(vpImage<vpRGBa> &I, const std::string &filename, int backen
   }
 
   if (try_opencv_reader) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     readOpenCV(I, filename);
 #else
     std::string message = "Cannot read file \"" + filename + "\": No backend able to support this image format";
@@ -278,7 +272,7 @@ void vpImageIo::read(vpImage<vpRGBa> &I, const std::string &filename, int backen
   - portable float map: `*.pfm` file
   - jpeg: `*.jpg`, `*.jpeg` files
   - png: `*.png` file
-  
+
   If ViSP is build with OpenCV support, additional formats are considered:
   - `*.jp2`, `*.rs`, `*.ras`, `*.tiff`, `*.tif`, `*.png`, `*.bmp`, `*.pbm` files.
 
@@ -319,7 +313,7 @@ void vpImageIo::write(const vpImage<unsigned char> &I, const std::string &filena
   }
 
   if (try_opencv_writer) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     writeOpenCV(I, filename, 90);
 #else
     std::string message = "Cannot write file \"" + filename + "\": No backend able to support this image format";
@@ -338,7 +332,7 @@ void vpImageIo::write(const vpImage<unsigned char> &I, const std::string &filena
   - portable float map: `*.pfm` file
   - jpeg: `*.jpg`, `*.jpeg` files
   - png: `*.png` file
-  
+
   If ViSP is build with OpenCV support, additional formats are considered:
   - `*.jp2`, `*.rs`, `*.ras`, `*.tiff`, `*.tif`, `*.png`, `*.bmp`, `*.pbm` files.
 
@@ -379,7 +373,7 @@ void vpImageIo::write(const vpImage<vpRGBa> &I, const std::string &filename, int
   }
 
   if (try_opencv_writer) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     writeOpenCV(I, filename, 90);
 #else
     std::string message = "Cannot write file \"" + filename + "\": No backend able to support this image format";
@@ -393,8 +387,8 @@ void vpImageIo::write(const vpImage<vpRGBa> &I, const std::string &filename, int
   \param[out] I : Gray level image.
   \param[in] filename : Image location.
   \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
-  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order: 
-  vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_STB_IMAGE_BACKEND. 
+  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order:
+  vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_STB_IMAGE_BACKEND.
  */
 // Strategy based on benchmark: see https://github.com/lagadic/visp/pull/1004
 // Default: 1. opencv, 2. system, 3. stb_image
@@ -402,18 +396,18 @@ void vpImageIo::readJPEG(vpImage<unsigned char> &I, const std::string &filename,
 {
   if (backend == IO_SYSTEM_LIB_BACKEND) {
 #if !defined(VISP_HAVE_JPEG)
-    std::string message = "Libjpeg backend is not available to read file \"" + filename + "\": switch to stb_image backend";
+    std::string message =
+        "Libjpeg backend is not available to read file \"" + filename + "\": switch to stb_image backend";
     backend = IO_STB_IMAGE_BACKEND;
 #endif
-  }
-  else if (backend == IO_OPENCV_BACKEND) {
-#if !(defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100)
-    std::string message = "OpenCV backend is not available to read file \"" + filename + "\": switch to stb_image backend";
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
+    std::string message =
+        "OpenCV backend is not available to read file \"" + filename + "\": switch to stb_image backend";
     backend = IO_STB_IMAGE_BACKEND;
 #endif
-  }
-  else if (backend == IO_DEFAULT_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+  } else if (backend == IO_DEFAULT_BACKEND) {
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     backend = IO_OPENCV_BACKEND;
 #elif defined(VISP_HAVE_JPEG)
     backend = IO_SYSTEM_LIB_BACKEND;
@@ -427,7 +421,7 @@ void vpImageIo::readJPEG(vpImage<unsigned char> &I, const std::string &filename,
     readJPEGLibjpeg(I, filename);
 #endif
   } else if (backend == IO_OPENCV_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     readOpenCV(I, filename);
 #endif
   } else if (backend == IO_STB_IMAGE_BACKEND) {
@@ -442,8 +436,8 @@ void vpImageIo::readJPEG(vpImage<unsigned char> &I, const std::string &filename,
   \param[out] I : Color image.
   \param[in] filename : Image location.
   \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
-  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order: 
-  vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_STB_IMAGE_BACKEND. 
+  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order:
+  vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_STB_IMAGE_BACKEND.
  */
 // Strategy based on benchmark: see https://github.com/lagadic/visp/pull/1004
 // Default: 1. opencv, 2. system, 3. stb_image
@@ -451,18 +445,18 @@ void vpImageIo::readJPEG(vpImage<vpRGBa> &I, const std::string &filename, int ba
 {
   if (backend == IO_SYSTEM_LIB_BACKEND) {
 #if !defined(VISP_HAVE_JPEG)
-    std::string message = "Libjpeg backend is not available to read file \"" + filename + "\": switch to stb_image backend";
+    std::string message =
+        "Libjpeg backend is not available to read file \"" + filename + "\": switch to stb_image backend";
     backend = IO_STB_IMAGE_BACKEND;
 #endif
-  }
-  else if (backend == IO_OPENCV_BACKEND) {
-#if !(defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100)
-    std::string message = "OpenCV backend is not available to read file \"" + filename + "\": switch to stb_image backend";
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
+    std::string message =
+        "OpenCV backend is not available to read file \"" + filename + "\": switch to stb_image backend";
     backend = IO_STB_IMAGE_BACKEND;
 #endif
-  }
-  else if (backend == IO_DEFAULT_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+  } else if (backend == IO_DEFAULT_BACKEND) {
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS)
     backend = IO_OPENCV_BACKEND;
 #elif defined(VISP_HAVE_JPEG)
     backend = IO_SYSTEM_LIB_BACKEND;
@@ -476,7 +470,7 @@ void vpImageIo::readJPEG(vpImage<vpRGBa> &I, const std::string &filename, int ba
     readJPEGLibjpeg(I, filename);
 #endif
   } else if (backend == IO_OPENCV_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     readOpenCV(I, filename);
 #endif
   } else if (backend == IO_STB_IMAGE_BACKEND) {
@@ -491,8 +485,8 @@ void vpImageIo::readJPEG(vpImage<vpRGBa> &I, const std::string &filename, int ba
   \param[out] I : Gray level image.
   \param[in] filename : Image location.
   \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
-  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order: 
-  vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_STB_IMAGE_BACKEND. 
+  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order:
+  vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_STB_IMAGE_BACKEND.
  */
 // Strategy based on benchmark: see https://github.com/lagadic/visp/pull/1004
 // Default: 1. system, 2. opencv, 3. stb_image
@@ -500,20 +494,20 @@ void vpImageIo::readPNG(vpImage<unsigned char> &I, const std::string &filename,
 {
   if (backend == IO_SYSTEM_LIB_BACKEND) {
 #if !defined(VISP_HAVE_PNG)
-    std::string message = "Libpng backend is not available to read file \"" + filename + "\": switch to stb_image backend";
+    std::string message =
+        "Libpng backend is not available to read file \"" + filename + "\": switch to stb_image backend";
     backend = IO_STB_IMAGE_BACKEND;
 #endif
-  }
-  else if (backend == IO_OPENCV_BACKEND) {
-#if !(defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100)
-    std::string message = "OpenCV backend is not available to read file \"" + filename + "\": switch to stb_image backend";
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
+    std::string message =
+        "OpenCV backend is not available to read file \"" + filename + "\": switch to stb_image backend";
     backend = IO_STB_IMAGE_BACKEND;
 #endif
-  }
-  else if (backend == IO_DEFAULT_BACKEND) {
+  } else if (backend == IO_DEFAULT_BACKEND) {
 #if defined(VISP_HAVE_PNG)
     backend = IO_SYSTEM_LIB_BACKEND;
-#elif defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#elif defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS)
     backend = IO_OPENCV_BACKEND;
 #else
     backend = IO_STB_IMAGE_BACKEND;
@@ -525,7 +519,7 @@ void vpImageIo::readPNG(vpImage<unsigned char> &I, const std::string &filename,
     readPNGLibpng(I, filename);
 #endif
   } else if (backend == IO_OPENCV_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     readOpenCV(I, filename);
 #endif
   } else if (backend == IO_STB_IMAGE_BACKEND) {
@@ -540,8 +534,8 @@ void vpImageIo::readPNG(vpImage<unsigned char> &I, const std::string &filename,
   \param[out] I : Color image.
   \param[in] filename : Image location.
   \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
-  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order: 
-  vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_STB_IMAGE_BACKEND. 
+  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order:
+  vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_STB_IMAGE_BACKEND.
  */
 // Strategy based on benchmark: see https://github.com/lagadic/visp/pull/1004
 // Default: 1. opencv, 2. stb_image
@@ -549,18 +543,18 @@ void vpImageIo::readPNG(vpImage<vpRGBa> &I, const std::string &filename, int bac
 {
   if (backend == IO_SYSTEM_LIB_BACKEND) {
 #if !defined(VISP_HAVE_PNG)
-    std::string message = "Libpng backend is not available to read file \"" + filename + "\": switch to stb_image backend";
+    std::string message =
+        "Libpng backend is not available to read file \"" + filename + "\": switch to stb_image backend";
     backend = IO_STB_IMAGE_BACKEND;
 #endif
-  }
-  else if (backend == IO_OPENCV_BACKEND) {
-#if !(defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100)
-    std::string message = "OpenCV backend is not available to read file \"" + filename + "\": switch to stb_image backend";
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
+    std::string message =
+        "OpenCV backend is not available to read file \"" + filename + "\": switch to stb_image backend";
     backend = IO_STB_IMAGE_BACKEND;
 #endif
-  }
-  else if (backend == IO_DEFAULT_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+  } else if (backend == IO_DEFAULT_BACKEND) {
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     backend = IO_OPENCV_BACKEND;
 #else
     backend = IO_STB_IMAGE_BACKEND;
@@ -572,7 +566,7 @@ void vpImageIo::readPNG(vpImage<vpRGBa> &I, const std::string &filename, int bac
     readPNGLibpng(I, filename);
 #endif
   } else if (backend == IO_OPENCV_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     readOpenCV(I, filename);
 #endif
   } else if (backend == IO_STB_IMAGE_BACKEND) {
@@ -582,13 +576,89 @@ void vpImageIo::readPNG(vpImage<vpRGBa> &I, const std::string &filename, int bac
   }
 }
 
+/*!
+  Load an image in EXR format.
+  \param[out] I : Floating-point single channel image.
+  \param[in] filename : Image location.
+  \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
+  Only OpenCV and the Tiny OpenEXR image libraries can currently read EXR image.
+  The default backend vpImageIo::IO_DEFAULT_BACKEND is the Tiny OpenEXR image library.
+ */
+void vpImageIo::readEXR(vpImage<float> &I, const std::string &filename, int backend)
+{
+  if (backend == IO_SYSTEM_LIB_BACKEND || backend == IO_SIMDLIB_BACKEND || backend == IO_STB_IMAGE_BACKEND) {
+    std::string message =
+        "This backend cannot read file \"" + filename + "\": switch to the default TinyEXR backend";
+    backend = IO_DEFAULT_BACKEND;
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
+    std::string message =
+        "OpenCV backend is not available to read file \"" + filename + "\": switch to the default TinyEXR backend";
+    backend = IO_DEFAULT_BACKEND;
+#endif
+  }
+
+  if (backend == IO_OPENCV_BACKEND) {
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
+    readOpenCV(I, filename);
+#endif
+  } else if (backend == IO_DEFAULT_BACKEND) {
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
+    readEXRTiny(I, filename);
+#else
+    (void)I;
+    std::string message =
+        "TinyEXR backend is not available to read file \"" + filename + "\": cxx standard should be greater or equal to cxx11";
+    throw(vpImageException(vpImageException::ioError, message));
+#endif
+  }
+}
+
+/*!
+  Load an image in EXR format.
+  \param[out] I : Floating-point three channels image.
+  \param[in] filename : Image location.
+  \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
+  Only OpenCV and the Tiny OpenEXR image libraries can currently read EXR image.
+  The default backend vpImageIo::IO_DEFAULT_BACKEND is the Tiny OpenEXR image library.
+ */
+void vpImageIo::readEXR(vpImage<vpRGBf> &I, const std::string &filename, int backend)
+{
+  if (backend == IO_SYSTEM_LIB_BACKEND || backend == IO_SIMDLIB_BACKEND || backend == IO_STB_IMAGE_BACKEND) {
+    std::string message =
+        "This backend cannot read file \"" + filename + "\": switch to the default TinyEXR backend";
+    backend = IO_DEFAULT_BACKEND;
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
+    std::string message =
+        "OpenCV backend is not available to read file \"" + filename + "\": switch to the default TinyEXR backend";
+    backend = IO_DEFAULT_BACKEND;
+#endif
+  }
+
+  if (backend == IO_OPENCV_BACKEND) {
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
+    readOpenCV(I, filename);
+#endif
+  } else if (backend == IO_DEFAULT_BACKEND) {
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
+    readEXRTiny(I, filename);
+#else
+    (void)I;
+    std::string message =
+        "TinyEXR backend is not available to read file \"" + filename + "\": cxx standard should be greater or equal to cxx11";
+    throw(vpImageException(vpImageException::ioError, message));
+#endif
+  }
+}
+
 /*!
   Save an image in jpeg format.
   \param[in] I : Gray level image.
   \param[in] filename : Image location.
   \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
-  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order: 
-  vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SIMDLIB_BACKEND. 
+  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order:
+  vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SIMDLIB_BACKEND.
   \param[in] quality : Image quality percentage in range 0-100.
  */
 // Strategy based on benchmark: see https://github.com/lagadic/visp/pull/1004
@@ -600,17 +670,15 @@ void vpImageIo::writeJPEG(const vpImage<unsigned char> &I, const std::string &fi
     std::string message = "Libjpeg backend is not available to save file \"" + filename + "\": switch to simd backend";
     backend = IO_SIMDLIB_BACKEND;
 #endif
-  }
-  else if (backend == IO_OPENCV_BACKEND) {
-#if !(defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100)
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
     std::string message = "OpenCV backend is not available to save file \"" + filename + "\": switch to simd backend";
     backend = IO_SIMDLIB_BACKEND;
 #endif
-  }
-  else if (backend == IO_DEFAULT_BACKEND) {
+  } else if (backend == IO_DEFAULT_BACKEND) {
 #if defined(VISP_HAVE_JPEG)
     backend = IO_SYSTEM_LIB_BACKEND;
-#elif defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#elif defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS)
     backend = IO_OPENCV_BACKEND;
 #else
     backend = IO_SIMDLIB_BACKEND;
@@ -622,7 +690,7 @@ void vpImageIo::writeJPEG(const vpImage<unsigned char> &I, const std::string &fi
     writeJPEGLibjpeg(I, filename, quality);
 #endif
   } else if (backend == IO_OPENCV_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     writeOpenCV(I, filename, quality);
 #endif
   } else if (backend == IO_SIMDLIB_BACKEND) {
@@ -637,8 +705,8 @@ void vpImageIo::writeJPEG(const vpImage<unsigned char> &I, const std::string &fi
   \param[in] I : Color image.
   \param[in] filename : Image location.
   \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
-  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order: 
-  vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SIMDLIB_BACKEND. 
+  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order:
+  vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SIMDLIB_BACKEND.
   \param[in] quality : Image quality percentage in range 0-100.
  */
 // Strategy based on benchmark: see https://github.com/lagadic/visp/pull/1004
@@ -650,17 +718,15 @@ void vpImageIo::writeJPEG(const vpImage<vpRGBa> &I, const std::string &filename,
     std::string message = "Libjpeg backend is not available to save file \"" + filename + "\": switch to simd backend";
     backend = IO_SIMDLIB_BACKEND;
 #endif
-  }
-  else if (backend == IO_OPENCV_BACKEND) {
-#if !(defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100)
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
     std::string message = "OpenCV backend is not available to save file \"" + filename + "\": switch to simd backend";
     backend = IO_SIMDLIB_BACKEND;
 #endif
-  }
-  else if (backend == IO_DEFAULT_BACKEND) {
+  } else if (backend == IO_DEFAULT_BACKEND) {
 #if defined(VISP_HAVE_JPEG)
     backend = IO_SYSTEM_LIB_BACKEND;
-#elif defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#elif defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS)
     backend = IO_OPENCV_BACKEND;
 #else
     backend = IO_SIMDLIB_BACKEND;
@@ -672,7 +738,7 @@ void vpImageIo::writeJPEG(const vpImage<vpRGBa> &I, const std::string &filename,
     writeJPEGLibjpeg(I, filename, quality);
 #endif
   } else if (backend == IO_OPENCV_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     writeOpenCV(I, filename, quality);
 #endif
   } else if (backend == IO_SIMDLIB_BACKEND) {
@@ -687,8 +753,8 @@ void vpImageIo::writeJPEG(const vpImage<vpRGBa> &I, const std::string &filename,
   \param[in] I : Gray level image.
   \param[in] filename : Image location.
   \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
-  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order: 
-  vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SIMDLIB_BACKEND. 
+  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order:
+  vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SIMDLIB_BACKEND.
  */
 // Strategy based on benchmark: see https://github.com/lagadic/visp/pull/1004
 // Default: 1. opencv, 2. simd
@@ -699,15 +765,13 @@ void vpImageIo::writePNG(const vpImage<unsigned char> &I, const std::string &fil
     std::string message = "Libpng backend is not available to save file \"" + filename + "\": switch to simd backend";
     backend = IO_SIMDLIB_BACKEND;
 #endif
-  }
-  else if (backend == IO_OPENCV_BACKEND) {
-#if !(defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100)
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
     std::string message = "OpenCV backend is not available to save file \"" + filename + "\": switch to simd backend";
     backend = IO_SIMDLIB_BACKEND;
 #endif
-  }
-  else if (backend == IO_DEFAULT_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+  } else if (backend == IO_DEFAULT_BACKEND) {
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     backend = IO_OPENCV_BACKEND;
 #else
     backend = IO_SIMDLIB_BACKEND;
@@ -715,8 +779,8 @@ void vpImageIo::writePNG(const vpImage<unsigned char> &I, const std::string &fil
   }
 
   if (backend == IO_OPENCV_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
-      writeOpenCV(I, filename, 90);
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
+    writeOpenCV(I, filename, 90);
 #endif
   } else if (backend == IO_SIMDLIB_BACKEND) {
     writePNGSimdlib(I, filename);
@@ -734,8 +798,8 @@ void vpImageIo::writePNG(const vpImage<unsigned char> &I, const std::string &fil
   \param[in] I : Color image.
   \param[in] filename : Image location.
   \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
-  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order: 
-  vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_SIMDLIB_BACKEND. 
+  Depending on its availability, the default backend vpImageIo::IO_DEFAULT_BACKEND is chosen in the following order:
+  vpImageIo::IO_OPENCV_BACKEND, vpImageIo::IO_SYSTEM_LIB_BACKEND, vpImageIo::IO_SIMDLIB_BACKEND.
  */
 // Strategy based on benchmark: see https://github.com/lagadic/visp/pull/1004
 // Default: 1. opencv, 2. system, 3. simd
@@ -746,15 +810,13 @@ void vpImageIo::writePNG(const vpImage<vpRGBa> &I, const std::string &filename,
     std::string message = "Libpng backend is not available to save file \"" + filename + "\": switch to simd backend";
     backend = IO_SIMDLIB_BACKEND;
 #endif
-  }
-  else if (backend == IO_OPENCV_BACKEND) {
-#if !(defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100)
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
     std::string message = "OpenCV backend is not available to save file \"" + filename + "\": switch to simd backend";
     backend = IO_SIMDLIB_BACKEND;
 #endif
-  }
-  else if (backend == IO_DEFAULT_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
+  } else if (backend == IO_DEFAULT_BACKEND) {
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
     backend = IO_OPENCV_BACKEND;
 #else
     backend = IO_SIMDLIB_BACKEND;
@@ -762,8 +824,8 @@ void vpImageIo::writePNG(const vpImage<vpRGBa> &I, const std::string &filename,
   }
 
   if (backend == IO_OPENCV_BACKEND) {
-#if defined(VISP_HAVE_OPENCV) && VISP_HAVE_OPENCV_VERSION >= 0x020100
-      writeOpenCV(I, filename, 90);
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
+    writeOpenCV(I, filename, 90);
 #endif
   } else if (backend == IO_SIMDLIB_BACKEND) {
     writePNGSimdlib(I, filename);
@@ -776,112 +838,185 @@ void vpImageIo::writePNG(const vpImage<vpRGBa> &I, const std::string &filename,
   }
 }
 
+/*!
+  Save an image in EXR format.
+  \param[in] I : Floating-point single channel image.
+  \param[in] filename : Image location.
+  \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
+  Only OpenCV and the Tiny OpenEXR image libraries can currently save EXR image.
+  The default backend vpImageIo::IO_DEFAULT_BACKEND is the Tiny OpenEXR image library.
+ */
+void vpImageIo::writeEXR(const vpImage<float> &I, const std::string &filename, int backend)
+{
+  if (backend == IO_SYSTEM_LIB_BACKEND || backend == IO_SIMDLIB_BACKEND || backend == IO_STB_IMAGE_BACKEND) {
+    std::string message =
+        "This backend cannot save file \"" + filename + "\": switch to the default TinyEXR backend";
+    backend = IO_DEFAULT_BACKEND;
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
+    (void)I;
+    std::string message =
+        "OpenCV backend is not available to save file \"" + filename + "\": switch to the default TinyEXR backend";
+    backend = IO_DEFAULT_BACKEND;
+#endif
+  }
+
+  if (backend == IO_OPENCV_BACKEND) {
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
+    writeOpenCV(I, filename);
+#endif
+  } else if (backend == IO_DEFAULT_BACKEND) {
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
+    writeEXRTiny(I, filename);
+#else
+    std::string message =
+        "TinyEXR backend is not available to save file \"" + filename + "\": cxx standard should be greater or equal to cxx11";
+    throw(vpImageException(vpImageException::ioError, message));
+#endif
+  }
+}
+
+/*!
+  Save an image in EXR format.
+  \param[in] I : Floating-point three channels image.
+  \param[in] filename : Image location.
+  \param[in] backend : Supported backends are described in vpImageIo::vpImageIoBackendType.
+  Only OpenCV and the Tiny OpenEXR image libraries can currently save EXR image.
+  The default backend vpImageIo::IO_DEFAULT_BACKEND is the Tiny OpenEXR image library.
+ */
+void vpImageIo::writeEXR(const vpImage<vpRGBf> &I, const std::string &filename, int backend)
+{
+  if (backend == IO_SYSTEM_LIB_BACKEND || backend == IO_SIMDLIB_BACKEND || backend == IO_STB_IMAGE_BACKEND) {
+    std::string message =
+        "This backend cannot save file \"" + filename + "\": switch to the default TinyEXR backend";
+    backend = IO_DEFAULT_BACKEND;
+  } else if (backend == IO_OPENCV_BACKEND) {
+#if !(defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGCODECS))
+    (void)I;
+    std::string message =
+        "OpenCV backend is not available to save file \"" + filename + "\": switch to the default TinyEXR backend";
+    backend = IO_DEFAULT_BACKEND;
+#endif
+  }
+
+  if (backend == IO_OPENCV_BACKEND) {
+#if ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(HAVE_OPENCV_IMGCODECS)) || ((VISP_HAVE_OPENCV_VERSION < 0x030000) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC))
+    writeOpenCV(I, filename);
+#endif
+  } else if (backend == IO_DEFAULT_BACKEND) {
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
+    writeEXRTiny(I, filename);
+#else
+    std::string message =
+        "TinyEXR backend is not available to save file \"" + filename + "\": cxx standard should be greater or equal to cxx11";
+    throw(vpImageException(vpImageException::ioError, message));
+#endif
+  }
+}
+
 /*!
   Save an image in portable float map format.
   \param[in] I : Image to save.
   \param[in] filename : Image location.
  */
-void vpImageIo::writePFM(const vpImage<float> &I, const std::string &filename)
-{
-  vp_writePFM(I, filename);
-}
+void vpImageIo::writePFM(const vpImage<float> &I, const std::string &filename) { vp_writePFM(I, filename); }
+
+/*!
+  Save a high-dynamic range (not restricted to the [0-255] intensity range) floating-point image
+  in portable float map format.
+  \param[in] I : Grayscale floating-point image to save.
+  \param[in] filename : Image location.
+ */
+void vpImageIo::writePFM_HDR(const vpImage<float> &I, const std::string &filename) { vp_writePFM_HDR(I, filename); }
+
+/*!
+  Save a RGB high-dynamic range (not restricted to the [0-255] intensity range) floating-point image
+  in portable float map format.
+  \param[in] I : RGB floating-point image to save.
+  \param[in] filename : Image location.
+ */
+void vpImageIo::writePFM_HDR(const vpImage<vpRGBf> &I, const std::string &filename) { vp_writePFM_HDR(I, filename); }
 
 /*!
   Save an image in portable gray map format.
   \param[in] I : Image to save.
   \param[in] filename : Image location.
  */
-void vpImageIo::writePGM(const vpImage<unsigned char> &I, const std::string &filename)
-{
-  vp_writePGM(I, filename);
-}
+void vpImageIo::writePGM(const vpImage<unsigned char> &I, const std::string &filename) { vp_writePGM(I, filename); }
 
 /*!
   Save a gray level image in portable gray map format.
   \param[in] I : Image to save.
   \param[in] filename : Image location.
  */
-void vpImageIo::writePGM(const vpImage<short> &I, const std::string &filename)
-{
-  vp_writePGM(I, filename);
-}
+void vpImageIo::writePGM(const vpImage<short> &I, const std::string &filename) { vp_writePGM(I, filename); }
 
 /*!
   Save a color image in portable gray map format.
   \param[in] I : Image to save.
   \param[in] filename : Image location.
  */
-void vpImageIo::writePGM(const vpImage<vpRGBa> &I, const std::string &filename)
-{
-  vp_writePGM(I, filename);
-}
+void vpImageIo::writePGM(const vpImage<vpRGBa> &I, const std::string &filename) { vp_writePGM(I, filename); }
 
 /*!
   Load an image in portable float map format.
   \param[out] I : Image read from filename.
   \param[in] filename : Image location.
  */
-void vpImageIo::readPFM(vpImage<float> &I, const std::string &filename)
-{
-  vp_readPFM(I, filename);
-}
+void vpImageIo::readPFM(vpImage<float> &I, const std::string &filename) { vp_readPFM(I, filename); }
+
+/*!
+  Load an image in portable float map format and not restricted to the [0, 255] dynamic range.
+  \param[out] I : Image read from filename.
+  \param[in] filename : Image location.
+ */
+void vpImageIo::readPFM_HDR(vpImage<float> &I, const std::string &filename) { vp_readPFM_HDR(I, filename); }
+
+/*!
+  Load an image in portable float map format and not restricted to the [0, 255] dynamic range.
+  \param[out] I : Image read from filename and with three channels.
+  \param[in] filename : Image location.
+ */
+void vpImageIo::readPFM_HDR(vpImage<vpRGBf> &I, const std::string &filename) { vp_readPFM_HDR(I, filename); }
 
 /*!
   Load an image in portable gray map format. If the image is in color, it is converted in gray level.
   \param[out] I : Image read from filename.
   \param[in] filename : Image location.
  */
-void vpImageIo::readPGM(vpImage<unsigned char> &I, const std::string &filename)
-{
-  vp_readPGM(I, filename);
-}
+void vpImageIo::readPGM(vpImage<unsigned char> &I, const std::string &filename) { vp_readPGM(I, filename); }
 
 /*!
   Load an image in portable float map format. If the image is in gray, it is converted in color.
   \param[out] I : Image read from filename.
   \param[in] filename : Image location.
  */
-void vpImageIo::readPGM(vpImage<vpRGBa> &I, const std::string &filename)
-{
-  vp_readPGM(I, filename);
-}
+void vpImageIo::readPGM(vpImage<vpRGBa> &I, const std::string &filename) { vp_readPGM(I, filename); }
 
 /*!
   Load an image in portable pixmap format. If the image is in color, it is converted in gray level.
   \param[out] I : Image read from filename.
   \param[in] filename : Image location.
  */
-void vpImageIo::readPPM(vpImage<unsigned char> &I, const std::string &filename)
-{
-  vp_readPPM(I, filename);
-}
+void vpImageIo::readPPM(vpImage<unsigned char> &I, const std::string &filename) { vp_readPPM(I, filename); }
 
 /*!
   Load an image in portable pixmap format. If the image is in gray, it is converted in color.
   \param[out] I : Image read from filename.
   \param[in] filename : Image location.
  */
-void vpImageIo::readPPM(vpImage<vpRGBa> &I, const std::string &filename)
-{
-  vp_readPPM(I, filename);
-}
+void vpImageIo::readPPM(vpImage<vpRGBa> &I, const std::string &filename) { vp_readPPM(I, filename); }
 
 /*!
   Save a gray level image in portable pixmap format.
   \param[in] I : Image to save.
   \param[in] filename : Image location.
  */
-void vpImageIo::writePPM(const vpImage<unsigned char> &I, const std::string &filename)
-{
-  vp_writePPM(I, filename);
-}
+void vpImageIo::writePPM(const vpImage<unsigned char> &I, const std::string &filename) { vp_writePPM(I, filename); }
 
 /*!
   Save a color level image in portable pixmap format.
   \param[in] I : Image to save.
   \param[in] filename : Image location.
  */
-void vpImageIo::writePPM(const vpImage<vpRGBa> &I, const std::string &filename)
-{
-  vp_writePPM(I, filename);
-}
+void vpImageIo::writePPM(const vpImage<vpRGBa> &I, const std::string &filename) { vp_writePPM(I, filename); }
