@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * Parallel port management.
- *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+ */
 
 #include <visp3/core/vpConfig.h>
 
@@ -57,7 +52,7 @@ static unsigned char vpParallelPortData;
 
 /*!
 
-  Constructor to acces to a parallel port.
+  Constructor to access to a parallel port.
 
   Open and initialise the parallel port by sending 0 to the data bus.
 
@@ -70,7 +65,7 @@ static unsigned char vpParallelPortData;
 */
 vpParallelPort::vpParallelPort() : fd(0), device()
 {
-  sprintf(device, "/dev/parport0");
+  device = "/dev/parport0";
 
   this->open();
 
@@ -97,7 +92,7 @@ vpParallelPort::~vpParallelPort() { this->close(); }
 */
 void vpParallelPort::open()
 {
-  fd = ::open("/dev/parport0", O_WRONLY);
+  fd = ::open(device.c_str(), O_WRONLY);
   if (fd < 0) {
     printf("Can't open /dev/parport0\n");
     printf("Check if you have write access to /dev/parport0\n");
@@ -126,10 +121,7 @@ void vpParallelPort::open()
 
   unsigned char data = 5; // 0x00000101 = 5 in decimal
   parport.sendData(data); // D0 and D2 are set to logical level 1
-
   \endcode
-
-  \return true if the device was close, false if an error occurs.
 */
 void vpParallelPort::sendData(unsigned char &data)
 {
@@ -167,7 +159,7 @@ void vpParallelPort::close()
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_core.a(vpParallelPort.cpp.o) has no
+// Work around to avoid warning: libvisp_core.a(vpParallelPort.cpp.o) has no
 // symbols
 void dummy_vpParallelPort(){};
 #endif
