@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -29,32 +28,48 @@
  * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  *
  * Description:
- * Keybord management.
- *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+ * Keyboard management.
+ */
+
+#include <stdio.h>
 
 #if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__)))
-#include <stdio.h>
 #include <sys/select.h>
+#elif defined(_WIN32)
+#include <conio.h>
+#endif
+#include <visp3/core/vpException.h>
 #include <visp3/io/vpKeyboard.h>
 
 /*!
   \file vpKeyboard.cpp
-  \brief Keybord management under unix.
+  \brief Keyboard management under unix.
 */
 
 /*!
   Activates the raw mode to read keys in an non blocking way.
 */
-vpKeyboard::vpKeyboard() : initial_settings(), new_settings() { init(); }
+vpKeyboard::vpKeyboard()
+#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__)))
+  : initial_settings(), new_settings()
+{
+  init();
+}
+#else
+{}
+#endif
+
+
 
 /*!
   Stops the raw mode.
 */
-vpKeyboard::~vpKeyboard() { end(); }
+vpKeyboard::~vpKeyboard()
+{
+#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__)))
+  end();
+#endif
+}
 
 /*!
 
@@ -62,9 +77,15 @@ vpKeyboard::~vpKeyboard() { end(); }
 */
 int vpKeyboard::getchar()
 {
+#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__)))
   int c;
   c = ::getchar();
   return c;
+#elif defined(_WIN32) && !defined(WINRT)
+  return _getch();
+#elif defined(_WIN32) && defined(WINRT)
+  throw(vpException(vpException::fatalError, "vpKeyboard::getchar() is not supported on UWP platform!"));
+#endif
 }
 
 /*!
@@ -74,26 +95,39 @@ int vpKeyboard::getchar()
 */
 int vpKeyboard::kbhit()
 {
-  struct timeval tv = {0, 0};
+#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__)))
+  struct timeval tv = { 0, 0 };
   fd_set readfds;
 
   FD_ZERO(&readfds);
   FD_SET(STDIN_FILENO, &readfds);
 
   return select(STDIN_FILENO + 1, &readfds, NULL, NULL, &tv) == 1;
+#elif defined(_WIN32) && !defined(WINRT)
+  return _kbhit();
+#elif defined(_WIN32) && defined(WINRT)
+  throw(vpException(vpException::fatalError, "vpKeyboard::kbhit() is not supported on UWP platform!"));
+#endif
 }
 
+#if !defined(_WIN32) && (defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__)))
 /*!
 
   Activates the raw mode to read keys in an non blocking way.
 */
-void vpKeyboard::init() { setRawMode(true); }
+void vpKeyboard::init()
+{
+  setRawMode(true);
+}
 
 /*!
 
   Stops the raw mode.
 */
-void vpKeyboard::end() { setRawMode(false); }
+void vpKeyboard::end()
+{
+  setRawMode(false);
+}
 
 /*!
   Turns on/off the 'raw' mode.
@@ -122,7 +156,8 @@ void vpKeyboard::setRawMode(bool active)
     new_settings.c_cc[VTIME] = 0;
     tcsetattr(STDIN_FILENO, TCSANOW, &new_settings);
 
-  } else {
+  }
+  else {
     tcsetattr(STDIN_FILENO, TCSANOW, &initial_settings);
   }
 }
