@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,12 +29,7 @@
  *
  * Description:
  * Read videos and image sequences.
- *
- * Authors:
- * Nicolas Melchior
- * Fabien Spindler
- *
- *****************************************************************************/
+ */
 
 /*!
 \file vpVideoReader.cpp
@@ -56,11 +50,12 @@
 */
 vpVideoReader::vpVideoReader()
   : vpFrameGrabber(), m_imSequence(NULL),
-#if VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO)
     m_capture(), m_frame(), m_lastframe_unknown(false),
 #endif
-    m_formatType(FORMAT_UNKNOWN), m_videoName(), m_frameName(), m_initFileName(false), m_isOpen(false), m_frameCount(0), m_firstFrame(0), m_lastFrame(0),
-    m_firstFrameIndexIsSet(false), m_lastFrameIndexIsSet(false), m_frameStep(1), m_frameRate(0.)
+    m_formatType(FORMAT_UNKNOWN), m_videoName(), m_frameName(), m_initFileName(false), m_isOpen(false), m_frameCount(0),
+    m_firstFrame(0), m_lastFrame(0), m_firstFrameIndexIsSet(false), m_lastFrameIndexIsSet(false), m_frameStep(1),
+    m_frameRate(0.)
 {
 }
 
@@ -137,7 +132,7 @@ void vpVideoReader::getProperties()
     }
     m_frameRate = -1.;
   } else if (isVideoExtensionSupported()) {
-#if VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO)
     m_capture.open(m_videoName.c_str());
 
     if (!m_capture.isOpened()) {
@@ -191,7 +186,7 @@ void vpVideoReader::open(vpImage<vpRGBa> &I)
   m_frameCount = m_firstFrame;
 
   if (isVideoExtensionSupported()) {
-#if VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO)
 
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
     m_capture.set(cv::CAP_PROP_POS_FRAMES, m_firstFrame - 1);
@@ -224,7 +219,7 @@ void vpVideoReader::open(vpImage<unsigned char> &I)
   m_frameCount = m_firstFrame;
 
   if (isVideoExtensionSupported()) {
-#if VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO)
 
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
     m_capture.set(cv::CAP_PROP_POS_FRAMES, m_firstFrame - 1);
@@ -258,7 +253,7 @@ void vpVideoReader::acquire(vpImage<vpRGBa> &I)
       try {
         m_imSequence->acquire(I);
         skip_frame = false;
-      }  catch (...) {
+      } catch (...) {
         skip_frame = true;
       }
     } while (skip_frame && m_imSequence->getImageNumber() < m_lastFrame);
@@ -270,7 +265,7 @@ void vpVideoReader::acquire(vpImage<vpRGBa> &I)
       m_imSequence->setImageNumber(m_frameCount);
     }
   }
-#if VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO)
   else {
     m_capture >> m_frame;
     if (m_frameStep == 1) {
@@ -315,8 +310,7 @@ void vpVideoReader::acquire(vpImage<vpRGBa> &I)
         // Set last frame to this image index
         setLastFrameIndex(m_frameCount - m_frameStep);
       }
-    }
-    else {
+    } else {
       vpImageConvert::convert(m_frame, I);
     }
   }
@@ -344,7 +338,7 @@ void vpVideoReader::acquire(vpImage<unsigned char> &I)
       try {
         m_imSequence->acquire(I);
         skip_frame = false;
-      }  catch (...) {
+      } catch (...) {
         skip_frame = true;
       }
     } while (skip_frame && m_imSequence->getImageNumber() < m_lastFrame);
@@ -356,7 +350,7 @@ void vpVideoReader::acquire(vpImage<unsigned char> &I)
       m_imSequence->setImageNumber(m_frameCount);
     }
   }
-#if VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO)
   else {
     m_capture >> m_frame;
     if (m_frameStep == 1) {
@@ -397,8 +391,7 @@ void vpVideoReader::acquire(vpImage<unsigned char> &I)
 
     if (m_frame.empty()) {
       std::cout << "Warning: Unable to decode image " << m_frameCount - m_frameStep << std::endl;
-    }
-    else {
+    } else {
       vpImageConvert::convert(m_frame, I);
     }
   }
@@ -437,7 +430,8 @@ bool vpVideoReader::getFrame(vpImage<vpRGBa> &I, long frame_index)
       return false;
     }
   } else {
-#if defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x030000)
+#if defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO)
+#if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
     if (!m_capture.set(cv::CAP_PROP_POS_FRAMES, frame_index)) {
       vpERROR_TRACE("Couldn't find the %ld th frame", frame_index);
       return false;
@@ -457,7 +451,7 @@ bool vpVideoReader::getFrame(vpImage<vpRGBa> &I, long frame_index)
       }
     } else
       vpImageConvert::convert(m_frame, I);
-#elif defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100)
+#else
     if (!m_capture.set(CV_CAP_PROP_POS_FRAMES, frame_index)) {
       vpERROR_TRACE("Couldn't find the %ld th frame", frame_index);
       return false;
@@ -470,6 +464,7 @@ bool vpVideoReader::getFrame(vpImage<vpRGBa> &I, long frame_index)
       setLastFrameIndex(m_frameCount - m_frameStep);
     else
       vpImageConvert::convert(m_frame, I);
+#endif
 #endif
   }
   return true;
@@ -507,6 +502,7 @@ bool vpVideoReader::getFrame(vpImage<unsigned char> &I, long frame_index)
       return false;
     }
   } else {
+#if defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO)
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
     if (!m_capture.set(cv::CAP_PROP_POS_FRAMES, frame_index)) {
       vpERROR_TRACE("Couldn't find the %ld th frame", frame_index);
@@ -525,7 +521,7 @@ bool vpVideoReader::getFrame(vpImage<unsigned char> &I, long frame_index)
     } else {
       vpImageConvert::convert(m_frame, I);
     }
-#elif VISP_HAVE_OPENCV_VERSION >= 0x020100
+#else
     if (!m_capture.set(CV_CAP_PROP_POS_FRAMES, frame_index)) {
       vpERROR_TRACE("Couldn't find the %ld th frame",
                     frame_index); // next index
@@ -544,6 +540,7 @@ bool vpVideoReader::getFrame(vpImage<unsigned char> &I, long frame_index)
       setLastFrameIndex(m_frameCount - m_frameStep);
     else
       vpImageConvert::convert(m_frame, I);
+#endif
 #endif
   }
   return true;
@@ -693,6 +690,7 @@ void vpVideoReader::findLastFrameIndex()
     }
   }
 
+#if defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO)
 #if VISP_HAVE_OPENCV_VERSION >= 0x030000
   else if (!m_lastFrameIndexIsSet) {
     m_lastFrame = (long)m_capture.get(cv::CAP_PROP_FRAME_COUNT);
@@ -704,7 +702,7 @@ void vpVideoReader::findLastFrameIndex()
       m_lastFrame = 100000; // Set lastFrame to an arbitrary value
     }
   }
-#elif VISP_HAVE_OPENCV_VERSION >= 0x020100
+#else
   else if (!m_lastFrameIndexIsSet) {
     m_lastFrame = (long)m_capture.get(CV_CAP_PROP_FRAME_COUNT);
     if (m_lastFrame <= 2) {
@@ -716,6 +714,7 @@ void vpVideoReader::findLastFrameIndex()
     }
   }
 #endif
+#endif
 }
 
 /*!
@@ -736,6 +735,7 @@ void vpVideoReader::findFirstFrameIndex()
         // Checking that file name satisfies image format, specified by
         // imageNameFormat, and extracting imageIndex
         long imageIndex = vpIoTools::getIndex(files[i], imageNameFormat);
+
         if ((imageIndex != -1) && (imageIndex < m_firstFrame || m_firstFrame == -1)) {
           m_firstFrame = imageIndex;
         }
@@ -743,7 +743,8 @@ void vpVideoReader::findFirstFrameIndex()
       m_imSequence->setImageNumber(m_firstFrame);
     }
   }
-#if VISP_HAVE_OPENCV_VERSION >= 0x020100
+#if defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO)
+
   else if (!m_firstFrameIndexIsSet) {
     m_firstFrame = 1L;
   }
