@@ -709,6 +709,9 @@ class JavaWrapperGenerator(object):
 
             if fi.name in ['detByLUGsl', 'svdGsl', 'inverseByLUGsl', 'pseudoInverseGsl', 'inverseByGsl', 'inverseByCholeskyGsl', 'inverseByQRGsl']:
                 c_prologue.append('#if defined(VISP_BUILD_DEPRECATED_FUNCTIONS) && defined(VISP_HAVE_LAPACK)')
+            if fi.name in ['from_json', 'to_json', 'loadConfigFileJSON', 'saveConfigFile']:
+                c_prologue.append('#if defined(VISP_HAVE_NLOHMANN_JSON)')
+
 
             if type_dict[fi.ctype]["jni_type"] == "jdoubleArray" and type_dict[fi.ctype]["suffix"] != "[D":
                 fields = type_dict[fi.ctype]["jn_args"]
@@ -1001,6 +1004,8 @@ class JavaWrapperGenerator(object):
 
             if fi.name in ['detByLUGsl', 'svdGsl', 'inverseByLUGsl', 'pseudoInverseGsl', 'inverseByGsl', 'inverseByCholeskyGsl', 'inverseByQRGsl']:
                 ret += '\n    #endif'
+            if fi.name in ['from_json', 'to_json', 'loadConfigFileJSON', 'saveConfigFile']:
+                ret += '\n    #endif'
 
             rtype = type_dict[fi.ctype].get("jni_type", "jdoubleArray")
             clazz = ci.jname
