@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Generic virtual robot.
  *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #ifndef vpRobot_H
 #define vpRobot_H
@@ -52,8 +49,9 @@
 /*!
   \class vpRobot
   \ingroup group_robot_real_gantry group_robot_real_cylindrical
-  group_robot_real_arm \ingroup group_robot_real_ptu group_robot_real_unicycle
-  group_robot_real_template \brief Class that defines a generic virtual robot.
+  group_robot_real_arm group_robot_real_ptu group_robot_real_unicycle
+  group_robot_real_template
+  \brief Class that defines a generic virtual robot.
 */
 class VISP_EXPORT vpRobot
 {
@@ -73,19 +71,19 @@ public:
     Robot control frames.
   */
   typedef enum {
-    REFERENCE_FRAME, /*!< Corresponds to a fixed reference frame
-  attached to the robot structure. */
-    ARTICULAR_FRAME, /*!< Corresponds to the joint state. This value is deprecated.
-  You should rather use vpRobot::JOINT_STATE. */
+    REFERENCE_FRAME,               /*!< Corresponds to a fixed reference frame
+                attached to the robot structure. */
+    ARTICULAR_FRAME,               /*!< Corresponds to the joint state. This value is deprecated.
+                You should rather use vpRobot::JOINT_STATE. */
     JOINT_STATE = ARTICULAR_FRAME, /*!< Corresponds to the joint state. */
-    END_EFFECTOR_FRAME,    /*!< Corresponds to robot end-effector frame. */
-    CAMERA_FRAME,    /*!< Corresponds to a frame attached to the
-  camera mounted on the robot end-effector. */
-    TOOL_FRAME = CAMERA_FRAME,    /*!< Corresponds to a frame attached to the
-  tool (camera, gripper...) mounted on the robot end-effector. This value is equal to vpRobot::CAMERA_FRAME. */
-    MIXT_FRAME       /*!< Corresponds to a "virtual" frame where
-        translations are expressed in the reference frame, and
-        rotations in the camera frame.*/
+    END_EFFECTOR_FRAME,            /*!< Corresponds to robot end-effector frame. */
+    CAMERA_FRAME,                  /*!< Corresponds to a frame attached to the
+                camera mounted on the robot end-effector. */
+    TOOL_FRAME = CAMERA_FRAME,     /*!< Corresponds to a frame attached to the
+   tool (camera, gripper...) mounted on the robot end-effector. This value is equal to vpRobot::CAMERA_FRAME. */
+    MIXT_FRAME                     /*!< Corresponds to a "virtual" frame where
+                      translations are expressed in the reference frame, and
+                      rotations in the camera frame.*/
   } vpControlFrameType;
 
 private: /* Membres privees */
@@ -137,7 +135,7 @@ public:
   double getMaxTranslationVelocity(void) const;
   double getMaxRotationVelocity(void) const;
   //! Get the robot position (frame has to be specified).
-  virtual void getPosition(const vpRobot::vpControlFrameType frame, vpColVector &q) = 0;
+  virtual void getPosition(const vpRobot::vpControlFrameType frame, vpColVector &position) = 0;
 
   // Return the robot position (frame has to be specified).
   vpColVector getPosition(const vpRobot::vpControlFrameType frame);
