@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Interface for the Irisa's Afma6 robot controlled by an Adept MotionBlox.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #ifndef vpRobotAfma6_h
 #define vpRobotAfma6_h
@@ -302,8 +299,8 @@ public: /* Methode publiques */
   /* --- POSITIONNEMENT --------------------------------------------------- */
   void setPosition(const vpRobot::vpControlFrameType frame, const vpPoseVector &pose);
   void setPosition(const vpRobot::vpControlFrameType frame, const vpColVector &position);
-  void setPosition(const vpRobot::vpControlFrameType frame, double pos1, double pos2, double pos3,
-                   double pos4, double pos5, double pos6);
+  void setPosition(const vpRobot::vpControlFrameType frame, double pos1, double pos2, double pos3, double pos4,
+                   double pos5, double pos6);
   void setPosition(const std::string &filename);
   void setPositioningVelocity(double velocity);
   void set_eMc(const vpHomogeneousMatrix &eMc);
