@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Class which provides a simulator for the robot Afma6.
  *
- * Authors:
- * Nicolas Melchior
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #ifndef vpSimulatorAfma6_HH
 #define vpSimulatorAfma6_HH
@@ -59,8 +56,8 @@
   \brief Simulator of Irisa's gantry robot named Afma6.
 
   Implementation of the vpRobotWireFrameSimulator class in order to simulate
-Irisa's Afma6 robot. This robot is a gantry robot with six degrees of freedom
-manufactured in 1992 by the french Afma-Robots company.
+  Irisa's Afma6 robot. This robot is a gantry robot with six degrees of freedom
+  manufactured in 1992 by the french Afma-Robots company.
 
   \warning This class uses threading capabilities. Thus on Unix-like
   platforms, the libpthread third-party library need to be
@@ -229,8 +226,8 @@ public:
   void setJointLimit(const vpColVector &limitMin, const vpColVector &limitMax);
 
   void setPosition(const vpRobot::vpControlFrameType frame, const vpColVector &q);
-  void setPosition(const vpRobot::vpControlFrameType frame, double pos1, double pos2, double pos3,
-                   double pos4, double pos5, double pos6);
+  void setPosition(const vpRobot::vpControlFrameType frame, double pos1, double pos2, double pos3, double pos4,
+                   double pos5, double pos6);
   void setPosition(const char *filename);
   void setPositioningVelocity(double vel) { positioningVelocity = vel; }
   bool setPosition(const vpHomogeneousMatrix &cdMo, vpImage<unsigned char> *Iint = NULL, const double &errMax = 0.001);
@@ -249,21 +246,12 @@ protected:
   void getExternalImage(vpImage<vpRGBa> &I);
   inline void get_fMi(vpHomogeneousMatrix *fMit)
   {
-#if defined(_WIN32)
-#if defined(WINRT_8_1)
-    WaitForSingleObjectEx(mutex_fMi, INFINITE, FALSE);
-#else // pure win32
-    WaitForSingleObject(mutex_fMi, INFINITE);
-#endif
-    for (int i = 0; i < 8; i++)
+    m_mutex_fMi.lock();
+    for (int i = 0; i < 8; i++) {
       fMit[i] = fMi[i];
-    ReleaseMutex(mutex_fMi);
-#elif defined(VISP_HAVE_PTHREAD)
-    pthread_mutex_lock(&mutex_fMi);
-    for (int i = 0; i < 8; i++)
-      fMit[i] = fMi[i];
-    pthread_mutex_unlock(&mutex_fMi);
-#endif
+    }
+
+    m_mutex_fMi.unlock();
   }
   void init();
   void initArms();
