@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description: Class which enables to project an image in the 3D space
  * and get the view of a virtual camera.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpVirtuose.cpp
@@ -74,10 +71,7 @@ void vpVirtuose::close()
 /*!
  * Default destructor that delete the VirtContext object.
  */
-vpVirtuose::~vpVirtuose()
-{
-  close();
-}
+vpVirtuose::~vpVirtuose() { close(); }
 
 /*!
  * Set haptic device ip address and communication port.
@@ -143,8 +137,7 @@ vpColVector vpVirtuose::getArticularPosition() const
     throw(vpException(vpException::fatalError, "Device not initialized. Call init()."));
   }
 
-
-  float articular_position_[20] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+  float articular_position_[20] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 
   if (virtGetArticularPosition(m_virtContext, articular_position_)) {
     int err = virtGetErrorCode(m_virtContext);
@@ -167,7 +160,7 @@ vpColVector vpVirtuose::getArticularVelocity() const
     throw(vpException(vpException::fatalError, "Device not initialized. Call init()."));
   }
 
-  float articular_velocity_[20] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+  float articular_velocity_[20] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 
   if (virtGetArticularSpeed(m_virtContext, articular_velocity_)) {
     int err = virtGetErrorCode(m_virtContext);
@@ -376,7 +369,6 @@ unsigned int vpVirtuose::getJointsNumber() const
   return m_njoints;
 }
 
-
 /*!
  * Return the cartesian current position of the observation reference frame
  * with respect to the environment reference frame.
@@ -548,7 +540,8 @@ void vpVirtuose::init()
 
     if (m_virtContext == NULL) {
       int err = virtGetErrorCode(m_virtContext);
-      throw(vpException(vpException::fatalError, "Cannot open communication with haptic device using %s: %s. Check ip and port values",
+      throw(vpException(vpException::fatalError,
+                        "Cannot open communication with haptic device using %s: %s. Check ip and port values",
                         m_ip_port.c_str(), virtGetErrorMessage(err)));
     }
 
@@ -574,15 +567,16 @@ void vpVirtuose::init()
     }
 
     // Update number of joints
-    float articular_position_[20] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+    float articular_position_[20] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 
     if (virtGetArticularPosition(m_virtContext, articular_position_)) {
       int err = virtGetErrorCode(m_virtContext);
-      throw(vpException(vpException::fatalError, "Error calling virtGetArticularPosition() in int(): error code %d", err));
+      throw(vpException(vpException::fatalError, "Error calling virtGetArticularPosition() in int(): error code %d",
+                        err));
     }
 
     m_njoints = 6; // At least 6 joints
-    for (unsigned int i=m_njoints; i < 20; i++) {
+    for (unsigned int i = m_njoints; i < 20; i++) {
       m_njoints = i;
       if (std::fabs(articular_position_[i]) <= std::numeric_limits<float>::epsilon()) {
         break;
@@ -611,7 +605,7 @@ void vpVirtuose::setArticularForce(const vpColVector &articularForce)
                       articularForce.size()));
   }
 
-  float *articular_force = new float [m_njoints];
+  float *articular_force = new float[m_njoints];
   for (unsigned int i = 0; i < m_njoints; i++)
     articular_force[i] = (float)articularForce[i];
 
@@ -621,7 +615,7 @@ void vpVirtuose::setArticularForce(const vpColVector &articularForce)
     throw(vpException(vpException::fatalError, "Error calling virtSetArticularForce: error code %d", err));
   }
 
-  delete [] articular_force;
+  delete[] articular_force;
 }
 
 /*!
@@ -648,7 +642,7 @@ void vpVirtuose::setArticularPosition(const vpColVector &articularPosition)
 
   if (virtSetArticularPosition(m_virtContext, articular_position)) {
     int err = virtGetErrorCode(m_virtContext);
-    delete [] articular_position;
+    delete[] articular_position;
     throw(vpException(vpException::fatalError, "Error calling virtSetArticularPosition: error code %d", err));
   }
   delete[] articular_position;
@@ -672,13 +666,13 @@ void vpVirtuose::setArticularVelocity(const vpColVector &articularVelocity)
                       m_njoints, articularVelocity.size()));
   }
 
-  float *articular_velocity = new float [m_njoints];
+  float *articular_velocity = new float[m_njoints];
   for (unsigned int i = 0; i < m_njoints; i++)
     articular_velocity[i] = (float)articularVelocity[i];
 
   if (virtSetArticularSpeed(m_virtContext, articular_velocity)) {
     int err = virtGetErrorCode(m_virtContext);
-    delete [] articular_velocity;
+    delete[] articular_velocity;
     throw(vpException(vpException::fatalError, "Error calling virtSetArticularVelocity: error code %d", err));
   }
   delete[] articular_velocity;
