@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Interface for the Irisa's Afma4 robot.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpConfig.h>
 
@@ -134,22 +131,22 @@ vpRobotAfma4::vpRobotAfma4(bool verbose) : vpAfma4(), vpRobot()
 {
 
   /*
-    #define	SIGHUP	1	// hangup
-    #define	SIGINT	2	// interrupt (rubout)
-    #define	SIGQUIT	3	// quit (ASCII FS)
-    #define	SIGILL	4	// illegal instruction (not reset when caught)
-    #define	SIGTRAP	5	// trace trap (not reset when caught)
-    #define	SIGIOT	6	// IOT instruction
-    #define	SIGABRT 6	// used by abort, replace SIGIOT in the future
-    #define	SIGEMT	7	// EMT instruction
-    #define	SIGFPE	8	// floating point exception
-    #define	SIGKILL	9	// kill (cannot be caught or ignored)
-    #define	SIGBUS	10	// bus error
-    #define	SIGSEGV	11	// segmentation violation
-    #define	SIGSYS	12	// bad argument to system call
-    #define	SIGPIPE	13	// write on a pipe with no one to read it
-    #define	SIGALRM	14	// alarm clock
-    #define	SIGTERM	15	// software termination signal from kill
+    #define  SIGHUP   1  // hangup
+    #define  SIGINT   2  // interrupt (rubout)
+    #define  SIGQUIT  3  // quit (ASCII FS)
+    #define  SIGILL   4  // illegal instruction (not reset when caught)
+    #define  SIGTRAP  5  // trace trap (not reset when caught)
+    #define  SIGIOT   6  // IOT instruction
+    #define  SIGABRT  6  // used by abort, replace SIGIOT in the future
+    #define  SIGEMT   7  // EMT instruction
+    #define  SIGFPE   8  // floating point exception
+    #define  SIGKILL  9  // kill (cannot be caught or ignored)
+    #define  SIGBUS  10  // bus error
+    #define  SIGSEGV 11  // segmentation violation
+    #define  SIGSYS  12  // bad argument to system call
+    #define  SIGPIPE 13  // write on a pipe with no one to read it
+    #define  SIGALRM 14  // alarm clock
+    #define  SIGTERM 15  // software termination signal from kill
   */
 
   signal(SIGINT, emergencyStopAfma4);
@@ -576,7 +573,7 @@ void vpRobotAfma4::get_cMe(vpHomogeneousMatrix &cMe) const { vpAfma4::get_cMe(cM
 /*!
 
   Get the robot jacobian expressed in the end-effector frame. To have
-  acces to the analytic form of this jacobian see vpAfma4::get_eJe().
+  access to the analytic form of this jacobian see vpAfma4::get_eJe().
 
   To compute eJe, we communicate with the low level controller to get
   the articular joint position of the robot.
@@ -610,7 +607,7 @@ void vpRobotAfma4::get_eJe(vpMatrix &eJe)
 /*!
 
   Get the robot jacobian expressed in the robot reference frame also
-  called fix frame. To have acces to the analytic form of this
+  called fix frame. To have access to the analytic form of this
   jacobian see vpAfma4::get_fJe().
 
   To compute fJe, we communicate with the low level controller to get
@@ -763,19 +760,19 @@ void vpRobotAfma4::setPosition(const vpRobot::vpControlFrameType frame, const vp
 
   switch (frame) {
   case vpRobot::REFERENCE_FRAME:
-    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
+    throw vpRobotException(vpRobotException::lowLevelError, "Positioning error: "
                                                             "Reference frame not implemented.");
     break;
   case vpRobot::CAMERA_FRAME:
-    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
+    throw vpRobotException(vpRobotException::lowLevelError, "Positioning error: "
                                                             "Camera frame not implemented.");
     break;
   case vpRobot::MIXT_FRAME:
-    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
+    throw vpRobotException(vpRobotException::lowLevelError, "Positioning error: "
                                                             "Mixt frame not implemented.");
     break;
   case vpRobot::END_EFFECTOR_FRAME:
-    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
+    throw vpRobotException(vpRobotException::lowLevelError, "Positioning error: "
                                                             "End-effector frame not implemented.");
     break;
 
@@ -784,8 +781,8 @@ void vpRobotAfma4::setPosition(const vpRobot::vpControlFrameType frame, const vp
   }
   }
   if (position.getRows() != this->njoint) {
-    vpERROR_TRACE("Positionning error: bad vector dimension.");
-    throw vpRobotException(vpRobotException::positionOutOfRangeError, "Positionning error: bad vector dimension.");
+    vpERROR_TRACE("Positioning error: bad vector dimension.");
+    throw vpRobotException(vpRobotException::positionOutOfRangeError, "Positioning error: bad vector dimension.");
   }
 
   InitTry;
@@ -802,7 +799,7 @@ void vpRobotAfma4::setPosition(const vpRobot::vpControlFrameType frame, const vp
     std::cout << "Position out of range.\n";
 
   if (TryStt < 0 || error < 0) {
-    vpERROR_TRACE("Positionning error.");
+    vpERROR_TRACE("Positioning error.");
     throw vpRobotException(vpRobotException::positionOutOfRangeError, "Position out of range.");
   }
 
@@ -1218,7 +1215,7 @@ void vpRobotAfma4::setVelocity(const vpRobot::vpControlFrameType frame, const vp
     joint_vel = eJe_inverse * eVc * velocity;
 
     //     printf("Vitesse art: %f %f %f %f\n", joint_vel[0], joint_vel[1],
-    // 	   joint_vel[2], joint_vel[3]);
+    //      joint_vel[2], joint_vel[3]);
   }
 
   // Case of the joint control where we control all the joints
@@ -1744,7 +1741,7 @@ void vpRobotAfma4::getDisplacement(vpRobot::vpControlFrameType frame, vpColVecto
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_robot.a(vpRobotAfma4.cpp.o) has no
+// Work around to avoid warning: libvisp_robot.a(vpRobotAfma4.cpp.o) has no
 // symbols
 void dummy_vpRobotAfma4(){};
 #endif
