@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Interface for the Irisa's Afma6 robot.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
 
@@ -288,7 +285,8 @@ void vpAfma6::init(vpAfma6::vpAfma6ToolType tool, vpCameraParameters::vpCameraPa
       filename_eMc = CONST_EMC_CCMOP_WITH_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_CCMOP is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_CCMOP is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -302,7 +300,8 @@ void vpAfma6::init(vpAfma6::vpAfma6ToolType tool, vpCameraParameters::vpCameraPa
       filename_eMc = CONST_EMC_GRIPPER_WITH_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_GRIPPER is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_GRIPPER is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -316,7 +315,8 @@ void vpAfma6::init(vpAfma6::vpAfma6ToolType tool, vpCameraParameters::vpCameraPa
       filename_eMc = CONST_EMC_VACUUM_WITH_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_VACUUM is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_VACUUM is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -330,7 +330,8 @@ void vpAfma6::init(vpAfma6::vpAfma6ToolType tool, vpCameraParameters::vpCameraPa
       filename_eMc = CONST_EMC_INTEL_D435_WITH_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_INTEL_D435_CAMERA is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_INTEL_D435_CAMERA is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -344,21 +345,14 @@ void vpAfma6::init(vpAfma6::vpAfma6ToolType tool, vpCameraParameters::vpCameraPa
       filename_eMc = CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_GENERIC_CAMERA is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_GENERIC_CAMERA is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
   }
   default: {
     vpERROR_TRACE("This error should not occur!");
-    //       vpERROR_TRACE ("Si elle survient malgre tout, c'est sans doute "
-    // 		   "que les specs de la classe ont ete modifiee, "
-    // 		   "et que le code n'a pas ete mis a jour "
-    // 		   "correctement.");
-    //       vpERROR_TRACE ("Verifiez les valeurs possibles du type "
-    // 		   "vpAfma6::vpAfma6ToolType, et controlez que "
-    // 		   "tous les cas ont ete pris en compte dans la "
-    // 		   "fonction init(camera).");
     break;
   }
   }
@@ -388,7 +382,8 @@ void vpAfma6::init(vpAfma6::vpAfma6ToolType tool, vpCameraParameters::vpCameraPa
       _etc[2] = 0.2286;             // tz
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_CCMOP is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_CCMOP is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -412,7 +407,8 @@ void vpAfma6::init(vpAfma6::vpAfma6ToolType tool, vpCameraParameters::vpCameraPa
       _etc[2] = 0.1642;             // tz
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_GRIPPER is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_GRIPPER is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -436,7 +432,8 @@ void vpAfma6::init(vpAfma6::vpAfma6ToolType tool, vpCameraParameters::vpCameraPa
       _etc[2] = 0.1658;             // tz
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_VACUUM is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_VACUUM is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -460,7 +457,8 @@ void vpAfma6::init(vpAfma6::vpAfma6ToolType tool, vpCameraParameters::vpCameraPa
       _etc[2] = 0.1357;              // tz
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_INTEL_D435_CAMERA is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_INTEL_D435_CAMERA is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -479,7 +477,8 @@ void vpAfma6::init(vpAfma6::vpAfma6ToolType tool, vpCameraParameters::vpCameraPa
       _etc[2] = 0; // tz
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_GENERIC_CAMERA is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_GENERIC_CAMERA is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -633,7 +632,7 @@ int vpAfma6::getInverseKinematics(const vpHomogeneousMatrix &fMc, vpColVector &q
     q_[1][5] = q_[0][5] = t - q_[0][3];
 
     while ((q_[1][5] + vpMath::rad(2)) >= this->_joint_max[5])
-    /*			-> a cause du couplage 4/5	*/
+    /*      -> a cause du couplage 4/5  */
     {
       q_[1][5] -= vpMath::rad(10);
       q_[1][3] += vpMath::rad(10);
@@ -649,7 +648,7 @@ int vpAfma6::getInverseKinematics(const vpHomogeneousMatrix &fMc, vpColVector &q
     q_[1][3] = q_[0][3] = q[3];
     q_[1][5] = q_[0][5] = q_[0][3] - t;
     while ((q_[1][5] + vpMath::rad(2)) >= this->_joint_max[5])
-    /*			-> a cause du couplage 4/5	*/
+    /*      -> a cause du couplage 4/5  */
     {
       q_[1][5] -= vpMath::rad(10);
       q_[1][3] -= vpMath::rad(10);
@@ -683,7 +682,7 @@ int vpAfma6::getInverseKinematics(const vpHomogeneousMatrix &fMc, vpColVector &q
   q_[1][1] = fMe[1][3] - this->_long_56 * sin(q_[1][3]);
   q_[0][2] = q_[1][2] = fMe[2][3];
 
-  /* prise en compte du couplage axes 5/6	*/
+  /* prise en compte du couplage axes 5/6  */
   q_[0][5] += this->_coupl_56 * q_[0][4];
   q_[1][5] += this->_coupl_56 * q_[1][4];
 
@@ -1333,7 +1332,8 @@ void vpAfma6::getCameraParameters(vpCameraParameters &cam, const unsigned int &i
         cam.initPersProjWithDistortion(1090.6, 1090.0, 310.1, 260.8, -0.2114, 0.2217);
         break;
       case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-        throw vpException(vpException::notImplementedError, "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
+        throw vpException(vpException::notImplementedError,
+                          "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
         break;
       }
     } else {
@@ -1356,7 +1356,8 @@ void vpAfma6::getCameraParameters(vpCameraParameters &cam, const unsigned int &i
         cam.initPersProjWithDistortion(837.0, 837.5, 308.7, 251.6, -0.1455, 0.1511);
         break;
       case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-        throw vpException(vpException::notImplementedError, "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
+        throw vpException(vpException::notImplementedError,
+                          "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
         break;
       }
     } else {
@@ -1379,7 +1380,8 @@ void vpAfma6::getCameraParameters(vpCameraParameters &cam, const unsigned int &i
         cam.initPersProjWithDistortion(828.5, 829.0, 322.5, 232.9, -0.1921, 0.2057);
         break;
       case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-        throw vpException(vpException::notImplementedError, "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
+        throw vpException(vpException::notImplementedError,
+                          "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
         break;
       }
     } else {
@@ -1402,7 +1404,8 @@ void vpAfma6::getCameraParameters(vpCameraParameters &cam, const unsigned int &i
         cam.initPersProjWithDistortion(611.8, 612.6, 327.8, 241.7, 0.0436, -0.04265);
         break;
       case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-        throw vpException(vpException::notImplementedError, "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
+        throw vpException(vpException::notImplementedError,
+                          "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
         break;
       }
     } else {
@@ -1425,7 +1428,8 @@ void vpAfma6::getCameraParameters(vpCameraParameters &cam, const unsigned int &i
         cam.initPersProjWithDistortion(828.5, 829.0, 322.5, 232.9, -0.1921, 0.2057);
         break;
       case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-        throw vpException(vpException::notImplementedError, "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
+        throw vpException(vpException::notImplementedError,
+                          "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
         break;
       }
     } else {
