@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Interface for the Irisa's Afma6 robot.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpConfig.h>
 
@@ -133,12 +130,12 @@ void emergencyStopAfma6(int signo)
 
   To set the extrinsic camera parameters related to the eMc matrix
   obtained with a camera perspective projection model including the
-  distorsion, use the code below:
+  distortion, use the code below:
 
   \code
   vpRobotAfma6 robot;
   // Set the extrinsic camera parameters obtained with a perpective
-  // projection model including a distorsion parameter
+  // projection model including a distortion parameter
   robot.init(vpAfma6::TOOL_CCMOP,
   vpCameraParameters::perspectiveProjWithDistortion); \endcode
 
@@ -149,7 +146,7 @@ void emergencyStopAfma6(int signo)
   vpCameraParameters cam;
   robot.getCameraParameters(cam, I);
   // In cam, you get the intrinsic parameters of the projection model
-  // with distorsion.
+  // with distortion.
   \endcode
 
   \sa vpCameraParameters, init(vpAfma6::vpAfma6CameraRobotType,
@@ -160,22 +157,22 @@ vpRobotAfma6::vpRobotAfma6(bool verbose) : vpAfma6(), vpRobot()
 {
 
   /*
-    #define	SIGHUP	1	// hangup
-    #define	SIGINT	2	// interrupt (rubout)
-    #define	SIGQUIT	3	// quit (ASCII FS)
-    #define	SIGILL	4	// illegal instruction (not reset when caught)
-    #define	SIGTRAP	5	// trace trap (not reset when caught)
-    #define	SIGIOT	6	// IOT instruction
-    #define	SIGABRT 6	// used by abort, replace SIGIOT in the future
-    #define	SIGEMT	7	// EMT instruction
-    #define	SIGFPE	8	// floating point exception
-    #define	SIGKILL	9	// kill (cannot be caught or ignored)
-    #define	SIGBUS	10	// bus error
-    #define	SIGSEGV	11	// segmentation violation
-    #define	SIGSYS	12	// bad argument to system call
-    #define	SIGPIPE	13	// write on a pipe with no one to read it
-    #define	SIGALRM	14	// alarm clock
-    #define	SIGTERM	15	// software termination signal from kill
+    #define  SIGHUP  1  // hangup
+    #define  SIGINT  2  // interrupt (rubout)
+    #define  SIGQUIT  3  // quit (ASCII FS)
+    #define  SIGILL  4  // illegal instruction (not reset when caught)
+    #define  SIGTRAP  5  // trace trap (not reset when caught)
+    #define  SIGIOT  6  // IOT instruction
+    #define  SIGABRT 6  // used by abort, replace SIGIOT in the future
+    #define  SIGEMT  7  // EMT instruction
+    #define  SIGFPE  8  // floating point exception
+    #define  SIGKILL  9  // kill (cannot be caught or ignored)
+    #define  SIGBUS  10  // bus error
+    #define  SIGSEGV  11  // segmentation violation
+    #define  SIGSYS  12  // bad argument to system call
+    #define  SIGPIPE  13  // write on a pipe with no one to read it
+    #define  SIGALRM  14  // alarm clock
+    #define  SIGTERM  15  // software termination signal from kill
   */
 
   signal(SIGINT, emergencyStopAfma6);
@@ -214,10 +211,10 @@ vpRobotAfma6::vpRobotAfma6(bool verbose) : vpAfma6(), vpRobot()
 
   \warning This method sets the camera extrinsic parameters (matrix
   eMc) to the one obtained by calibration with a camera projection
-  model without distorsion by calling
+  model without distortion by calling
   init(vpAfma6::defaultCameraRobot). If you want to set the extrinsic
   camera parameters to those obtained with a camera perspective model
-  including the distorsion you have to call the
+  including the distortion you have to call the
   init(vpAfma6::vpAfma6CameraRobotType,
   vpCameraParameters::vpCameraParametersProjType) method.
 
@@ -323,12 +320,12 @@ void vpRobotAfma6::init(void)
 
   To set the extrinsic camera parameters related to the eMc matrix
   obtained with a camera perspective projection model including the
-  distorsion, use the code below:
+  distortion, use the code below:
 
   \code
   vpRobotAfma6 robot;
   // Set the extrinsic camera parameters obtained with a perpective
-  // projection model including a distorsion parameter
+  // projection model including a distortion parameter
   robot.init(vpAfma6::TOOL_CCMOP,
   vpCameraParameters::perspectiveProjWithDistortion); \endcode
 
@@ -339,7 +336,7 @@ void vpRobotAfma6::init(void)
   vpCameraParameters cam;
   robot.getCameraParameters(cam, I);
   // In cam, you get the intrinsic parameters of the projection model
-  // with distorsion.
+  // with distortion.
   \endcode
 
   \sa vpCameraParameters, init()
@@ -1014,8 +1011,8 @@ void vpRobotAfma6::setPosition(const vpRobot::vpControlFrameType frame, const vp
     position[i + 3] = rxyz[i];
   }
   if (frame == vpRobot::ARTICULAR_FRAME) {
-    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
-                                                            "Joint frame not implemented for pose positionning.");
+    throw vpRobotException(vpRobotException::lowLevelError, "Positioning error: "
+                                                            "Joint frame not implemented for pose positioning.");
   }
   setPosition(frame, position);
 }
@@ -1197,11 +1194,11 @@ void vpRobotAfma6::setPosition(const vpRobot::vpControlFrameType frame, const vp
     break;
   }
   case vpRobot::MIXT_FRAME: {
-    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
+    throw vpRobotException(vpRobotException::lowLevelError, "Positioning error: "
                                                             "Mixt frame not implemented.");
   }
   case vpRobot::END_EFFECTOR_FRAME: {
-    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
+    throw vpRobotException(vpRobotException::lowLevelError, "Positioning error: "
                                                             "end-effector frame not implemented.");
   }
   }
@@ -1215,7 +1212,7 @@ void vpRobotAfma6::setPosition(const vpRobot::vpControlFrameType frame, const vp
     std::cout << "Position out of range.\n";
 
   if (TryStt < 0 || error < 0) {
-    vpERROR_TRACE("Positionning error.");
+    vpERROR_TRACE("Positioning error.");
     throw vpRobotException(vpRobotException::positionOutOfRangeError, "Position out of range.");
   }
 
@@ -1288,8 +1285,8 @@ int main()
 
   \sa setPosition()
 */
-void vpRobotAfma6::setPosition(const vpRobot::vpControlFrameType frame, double pos1, double pos2,
-                               double pos3, double pos4, double pos5, double pos6)
+void vpRobotAfma6::setPosition(const vpRobot::vpControlFrameType frame, double pos1, double pos2, double pos3,
+                               double pos4, double pos5, double pos6)
 {
   try {
     vpColVector position(6);
@@ -2297,7 +2294,7 @@ bool vpRobotAfma6::checkJointLimits(vpColVector &jointsStatus)
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_robot.a(vpRobotAfma6.cpp.o) has no
+// Work around to avoid warning: libvisp_robot.a(vpRobotAfma6.cpp.o) has no
 // symbols
 void dummy_vpRobotAfma6(){};
 #endif
