@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Interface for the Biclops robot.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <cmath> // std::fabs
 #include <errno.h>
@@ -46,9 +43,9 @@
 
 #ifdef VISP_HAVE_BICLOPS
 
-#include <visp3/core/vpTime.h>
 #include <visp3/core/vpExponentialMap.h>
 #include <visp3/core/vpIoTools.h>
+#include <visp3/core/vpTime.h>
 #include <visp3/robot/vpBiclops.h>
 #include <visp3/robot/vpRobotBiclops.h>
 #include <visp3/robot/vpRobotException.h>
@@ -269,7 +266,7 @@ void vpRobotBiclops::init()
 /*
   Control loop to manage the biclops joint limits in speed control.
 
-  This control loop is running in a seperate thread in order to detect each 5
+  This control loop is running in a separate thread in order to detect each 5
   ms joint limits during the speed control. If a joint limit is detected the
   axis should be halted.
 
@@ -682,8 +679,8 @@ void vpRobotBiclops::get_fJe(vpMatrix &_fJe)
 void vpRobotBiclops::setPositioningVelocity(double velocity)
 {
   if (velocity < 0 || velocity > 100) {
-    vpERROR_TRACE("Bad positionning velocity");
-    throw vpRobotException(vpRobotException::constructionError, "Bad positionning velocity");
+    vpERROR_TRACE("Bad positioning velocity");
+    throw vpRobotException(vpRobotException::constructionError, "Bad positioning velocity");
   }
 
   positioningVelocity = velocity;
@@ -691,8 +688,8 @@ void vpRobotBiclops::setPositioningVelocity(double velocity)
 /*!
   Get the velocity in % used for a position control.
 
-  \return Positionning velocity in [0, 100.0]. The
-  maximum positionning velocity is given vpBiclops::speedLimit.
+  \return Positioning velocity in [0, 100.0]. The
+  maximum positioning velocity is given vpBiclops::speedLimit.
 
 */
 double vpRobotBiclops::getPositioningVelocity(void) { return positioningVelocity; }
@@ -701,7 +698,7 @@ double vpRobotBiclops::getPositioningVelocity(void) { return positioningVelocity
    Move the robot in position control.
 
    \warning This method is blocking. That mean that it waits the end of the
-   positionning.
+   positioning.
 
    \param frame : Control frame. This biclops head can only be controlled in
    articular.
@@ -742,14 +739,6 @@ void vpRobotBiclops::setPosition(const vpRobot::vpControlFrameType frame, const
     break;
   }
 
-  // test if position reachable
-  //   if ( (fabs(q[0]) > vpBiclops::panJointLimit) ||
-  //        (fabs(q[1]) > vpBiclops::tiltJointLimit) ) {
-  //     vpERROR_TRACE ("Positionning error.");
-  //     throw vpRobotException (vpRobotException::wrongStateError,
-  // 			    "Positionning error.");
-  //   }
-
   vpDEBUG_TRACE(12, "Lock mutex vpEndThread_mutex");
   pthread_mutex_lock(&vpEndThread_mutex);
   controller.setPosition(q, positioningVelocity);
@@ -762,7 +751,7 @@ void vpRobotBiclops::setPosition(const vpRobot::vpControlFrameType frame, const
    Move the robot in position control.
 
    \warning This method is blocking. That mean that it wait the end of the
-   positionning.
+   positioning.
 
    \param frame : Control frame. This biclops head can only be controlled in
    articular.
@@ -814,7 +803,7 @@ void vpRobotBiclops::setPosition(const char *filename)
 /*!
 
   Return the position of each axis.
-  - In positionning control mode, call vpRobotBiclopsController::getPosition()
+  - In positioning control mode, call vpRobotBiclopsController::getPosition()
   - In speed control mode, call vpRobotBiclopsController::getActualPosition()
 
   \param frame : Control frame. This biclops head can only be controlled in
@@ -1253,7 +1242,7 @@ void vpRobotBiclops::getDisplacement(vpRobot::vpControlFrameType frame, vpColVec
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_robot.a(vpRobotBiclops.cpp.o) has no
+// Work around to avoid warning: libvisp_robot.a(vpRobotBiclops.cpp.o) has no
 // symbols
 void dummy_vpRobotBiclops(){};
 #endif
