@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Interface for the Biclops robot.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <signal.h>
 #include <string.h>
@@ -177,7 +174,7 @@ void vpRobotBiclopsController::init(const std::string &configfile)
   Set the biclops axis position. The motion of the axis is synchronized to end
   on the same time.
 
-  \warning Wait the end of the positionning.
+  \warning Wait the end of the positioning.
 
   \param q : The position to set for each axis.
 
@@ -446,7 +443,7 @@ vpRobotBiclopsController::shmType vpRobotBiclopsController::readShm()
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning:
+// Work around to avoid warning:
 // libvisp_robot.a(vpRobotBiclopsController.cpp.o) has no symbols
 void dummy_vpRobotBiclopsController(){};
 #endif
