@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Interface for the ptu-46 robot.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <signal.h>
 #include <string.h>
@@ -69,17 +66,14 @@ const double vpRobotPtu46::defaultPositioningVelocity = 10.0;
   \sa init()
 
 */
-vpRobotPtu46::vpRobotPtu46(const char *device) : vpRobot()
+vpRobotPtu46::vpRobotPtu46(const std::string &device) : vpRobot()
 {
-  this->device = new char[FILENAME_MAX];
-
-  sprintf(this->device, "%s", device);
+  this->device = device;
 
   vpDEBUG_TRACE(12, "Open communication with Ptu-46.");
   try {
     init();
   } catch (...) {
-    delete[] this->device;
     vpERROR_TRACE("Error caught");
     throw;
   }
@@ -87,7 +81,6 @@ vpRobotPtu46::vpRobotPtu46(const char *device) : vpRobot()
   try {
     setRobotState(vpRobot::STATE_STOP);
   } catch (...) {
-    delete[] this->device;
     vpERROR_TRACE("Error caught");
     throw;
   }
@@ -116,8 +109,6 @@ vpRobotPtu46::~vpRobotPtu46(void)
 
   vpRobotPtu46::robotAlreadyCreated = false;
 
-  delete[] device;
-
   return;
 }
 
@@ -139,9 +130,8 @@ vpRobotPtu46::~vpRobotPtu46(void)
 */
 void vpRobotPtu46::init()
 {
-
   vpDEBUG_TRACE(12, "Open connection Ptu-46.");
-  if (0 != ptu.init(device)) {
+  if (0 != ptu.init(device.c_str())) {
     vpERROR_TRACE("Cannot open connection with ptu-46.");
     throw vpRobotException(vpRobotException::constructionError, "Cannot open connection with ptu-46");
   }
@@ -280,7 +270,7 @@ void vpRobotPtu46::setPositioningVelocity(double velocity) { positioningVelocity
 /*!
   Get the velocity in % used for a position control.
 
-  \return Positionning velocity in [0, 100]
+  \return Positioning velocity in [0, 100]
 
 */
 double vpRobotPtu46::getPositioningVelocity(void) { return positioningVelocity; }
@@ -289,7 +279,7 @@ double vpRobotPtu46::getPositioningVelocity(void) { return positioningVelocity;
    Move the robot in position control.
 
    \warning This method is blocking. That mean that it waits the end of the
-   positionning.
+   positioning.
 
    \param frame : Control frame. This head can only be controlled in
    articular.
@@ -338,8 +328,8 @@ void vpRobotPtu46::setPosition(const vpRobot::vpControlFrameType frame, const vp
   artpos[1] = q[1];
 
   if (0 != ptu.move(artpos, positioningVelocity, PTU_ABSOLUTE_MODE)) {
-    vpERROR_TRACE("Positionning error.");
-    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error.");
+    vpERROR_TRACE("Positioning error.");
+    throw vpRobotException(vpRobotException::lowLevelError, "Positioning error.");
   }
 
   return;
@@ -349,7 +339,7 @@ void vpRobotPtu46::setPosition(const vpRobot::vpControlFrameType frame, const vp
    Move the robot in position control.
 
    \warning This method is blocking. That mean that it wait the end of the
-   positionning.
+   positioning.
 
    \param frame : Control frame. This head can only be controlled in
    articular.
@@ -774,7 +764,7 @@ void vpRobotPtu46::getDisplacement(vpRobot::vpControlFrameType frame, vpColVecto
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_robot.a(vpRobotPtu46.cpp.o) has no
+// Work around to avoid warning: libvisp_robot.a(vpRobotPtu46.cpp.o) has no
 // symbols
 void dummy_vpRobotPtu46(){};
 #endif
