@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Interface for the Irisa's Viper S850 robot.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpConfig.h>
 
@@ -132,7 +129,7 @@ void emergencyStopViper850(int signo)
 
   To set the extrinsic camera parameters related to the \f$^e{\bf
   M}_c\f$ matrix obtained with a camera perspective projection model
-  including the distorsion, use the code below:
+  including the distortion, use the code below:
 
   \code
 #include <visp3/core/vpCameraParameters.h>
@@ -146,7 +143,7 @@ int main()
   vpRobotViper850 robot;
 
   // Set the extrinsic camera parameters obtained with a perpective
-  // projection model including a distorsion parameter
+  // projection model including a distortion parameter
   robot.init(vpViper850::TOOL_MARLIN_F033C_CAMERA, vpCameraParameters::perspectiveProjWithDistortion);
   \endcode
 
@@ -164,7 +161,7 @@ int main()
   vpCameraParameters cam;
   robot.getCameraParameters(cam, I);
   // In cam, you get the intrinsic parameters of the projection model
-  // with distorsion.
+  // with distortion.
 #endif
 }
   \endcode
@@ -177,22 +174,22 @@ vpRobotViper850::vpRobotViper850(bool verbose) : vpViper850(), vpRobot()
 {
 
   /*
-    #define	SIGHUP	1	// hangup
-    #define	SIGINT	2	// interrupt (rubout)
-    #define	SIGQUIT	3	// quit (ASCII FS)
-    #define	SIGILL	4	// illegal instruction (not reset when caught)
-    #define	SIGTRAP	5	// trace trap (not reset when caught)
-    #define	SIGIOT	6	// IOT instruction
-    #define	SIGABRT 6	// used by abort, replace SIGIOT in the future
-    #define	SIGEMT	7	// EMT instruction
-    #define	SIGFPE	8	// floating point exception
-    #define	SIGKILL	9	// kill (cannot be caught or ignored)
-    #define	SIGBUS	10	// bus error
-    #define	SIGSEGV	11	// segmentation violation
-    #define	SIGSYS	12	// bad argument to system call
-    #define	SIGPIPE	13	// write on a pipe with no one to read it
-    #define	SIGALRM	14	// alarm clock
-    #define	SIGTERM	15	// software termination signal from kill
+    #define  SIGHUP  1  // hangup
+    #define  SIGINT  2  // interrupt (rubout)
+    #define  SIGQUIT  3  // quit (ASCII FS)
+    #define  SIGILL  4  // illegal instruction (not reset when caught)
+    #define  SIGTRAP  5  // trace trap (not reset when caught)
+    #define  SIGIOT  6  // IOT instruction
+    #define  SIGABRT 6  // used by abort, replace SIGIOT in the future
+    #define  SIGEMT  7  // EMT instruction
+    #define  SIGFPE  8  // floating point exception
+    #define  SIGKILL  9  // kill (cannot be caught or ignored)
+    #define  SIGBUS  10  // bus error
+    #define  SIGSEGV  11  // segmentation violation
+    #define  SIGSYS  12  // bad argument to system call
+    #define  SIGPIPE  13  // write on a pipe with no one to read it
+    #define  SIGALRM  14  // alarm clock
+    #define  SIGTERM  15  // software termination signal from kill
   */
 
   signal(SIGINT, emergencyStopViper850);
@@ -233,10 +230,10 @@ vpRobotViper850::vpRobotViper850(bool verbose) : vpViper850(), vpRobot()
 
   \warning This method sets the camera extrinsic parameters (matrix
   eMc) to the one obtained by calibration with a camera projection
-  model without distorsion by calling
+  model without distortion by calling
   init(vpViper850::defaultCameraRobot). If you want to set the extrinsic
   camera parameters to those obtained with a camera perspective model
-  including the distorsion you have to call the
+  including the distortion you have to call the
   init(vpViper850::vpViper850CameraRobotType,
   vpCameraParameters::vpCameraParametersProjType) method. If you want to set
   custom extrinsic camera parameters you have to call the
@@ -271,7 +268,7 @@ void vpRobotViper850::init(void)
     throw(vpException(vpException::ioError, "ATI F/T calib file \"%s\" doesn't exist", calibfile.c_str()));
 #else
   throw(vpException(vpException::ioError, "You don't have access to Viper850 "
-                                          "data to retrive ATI F/T calib "
+                                          "data to retrieve ATI F/T calib "
                                           "file"));
 #endif
   m_ati.setCalibrationFile(calibfile);
@@ -378,7 +375,7 @@ void vpRobotViper850::init(void)
 
   To set the extrinsic camera parameters related to the \f$^e{\bf
   M}_c\f$ matrix obtained with a camera perspective projection model
-  including the distorsion, use the code below:
+  including the distortion, use the code below:
 
   \code
 #include <visp3/core/vpCameraParameters.h>
@@ -392,7 +389,7 @@ int main()
   vpRobotViper850 robot;
 
   // Set the extrinsic camera parameters obtained with a perpective
-  // projection model including a distorsion parameter
+  // projection model including a distortion parameter
   robot.init(vpViper850::TOOL_MARLIN_F033C_CAMERA, vpCameraParameters::perspectiveProjWithDistortion);
   \endcode
 
@@ -410,7 +407,7 @@ int main()
   vpCameraParameters cam;
   robot.getCameraParameters(cam, I);
   // In cam, you get the intrinsic parameters of the projection model
-  // with distorsion.
+  // with distortion.
 #endif
 }
   \endcode
@@ -1067,11 +1064,10 @@ double vpRobotViper850::getPositioningVelocity(void) const { return m_positionin
 
   \param frame : Frame in which the position is expressed.
 
-  - In the joint space, positions are the six joint rotations starting
-    from the base to the end-effector.
+  - In the joint space, positions are the six joint positions.
 
   - In the camera and the reference frame, positions are respectively
-  X,Y,Z translations and 3 rotations arround the X, Y and Z
+  X,Y,Z translations and 3 rotations around the X, Y and Z
   axis. Rotations are represented by a vpRxyzVector.
 
   - Mixt frame is not implemented. By mixt frame we mean, translations
@@ -1214,11 +1210,11 @@ void vpRobotViper850::setPosition(const vpRobot::vpControlFrameType frame, const
     break;
   }
   case vpRobot::MIXT_FRAME: {
-    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
+    throw vpRobotException(vpRobotException::lowLevelError, "Positioning error: "
                                                             "Mixt frame not implemented.");
   }
   case vpRobot::END_EFFECTOR_FRAME: {
-    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
+    throw vpRobotException(vpRobotException::lowLevelError, "Positioning error: "
                                                             "End-effector frame not implemented.");
   }
   }
@@ -1238,7 +1234,7 @@ void vpRobotViper850::setPosition(const vpRobot::vpControlFrameType frame, const
     std::cout << "Position out of range.\n";
 
   if (TryStt < 0 || error < 0) {
-    vpERROR_TRACE("Positionning error.");
+    vpERROR_TRACE("Positioning error.");
     throw vpRobotException(vpRobotException::positionOutOfRangeError, "Position out of range.");
   }
 
@@ -1309,8 +1305,8 @@ int main()
 
   \sa setPosition()
 */
-void vpRobotViper850::setPosition(const vpRobot::vpControlFrameType frame, double pos1, double pos2,
-                                  double pos3, double pos4, double pos5, double pos6)
+void vpRobotViper850::setPosition(const vpRobot::vpControlFrameType frame, double pos1, double pos2, double pos3,
+                                  double pos4, double pos5, double pos6)
 {
   try {
     vpColVector position(6);
@@ -1652,7 +1648,7 @@ int main()
   qvel[4] = 0;               // Joint 5 velocity in rad/s
   qvel[5] = 0;               // Joint 6 velocity in rad/s
 
-  // Initialize the controller to position control
+  // Initialize the controller to velocity control
   robot.setRobotState(vpRobot::STATE_VELOCITY_CONTROL);
 
   while (1) {
@@ -1746,7 +1742,7 @@ void vpRobotViper850::setVelocity(const vpRobot::vpControlFrameType frame, const
   }
   case vpRobot::REFERENCE_FRAME: {
     // Send velocities in m/s and rad/s
-    //std::cout << "Vitesse ref appliquee: " << vel_sat.t();
+    // std::cout << "Vitesse ref appliquee: " << vel_sat.t();
     Try(PrimitiveMOVESPEED_CART_Viper850(vel_sat.data, REPFIX_VIPER850));
     break;
   }
@@ -2621,7 +2617,7 @@ void vpRobotViper850::setMaxRotationVelocityJoint6(double w6_max)
 double vpRobotViper850::getMaxRotationVelocityJoint6() const { return maxRotationVelocity_joint6; }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_robot.a(vpRobotViper850.cpp.o) has
+// Work around to avoid warning: libvisp_robot.a(vpRobotViper850.cpp.o) has
 // no symbols
 void dummy_vpRobotViper850(){};
 #endif
