@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Interface for the ADEPT Viper 850 robot.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
 
@@ -195,7 +192,8 @@ void vpViper850::init(vpViper850::vpToolType tool, vpCameraParameters::vpCameraP
       filename_eMc = CONST_EMC_MARLIN_F033C_WITH_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_MARLIN_F033C_CAMERA is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_MARLIN_F033C_CAMERA is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -209,7 +207,8 @@ void vpViper850::init(vpViper850::vpToolType tool, vpCameraParameters::vpCameraP
       filename_eMc = CONST_EMC_PTGREY_FLEA2_WITH_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_PTGREY_FLEA2_CAMERA is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_PTGREY_FLEA2_CAMERA is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -223,7 +222,9 @@ void vpViper850::init(vpViper850::vpToolType tool, vpCameraParameters::vpCameraP
       filename_eMc = CONST_EMC_SCHUNK_GRIPPER_WITH_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_SCHUNK_GRIPPER_CAMERA is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(
+          vpException::notImplementedError,
+          "Feature TOOL_SCHUNK_GRIPPER_CAMERA is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -237,7 +238,8 @@ void vpViper850::init(vpViper850::vpToolType tool, vpCameraParameters::vpCameraP
       filename_eMc = CONST_EMC_GENERIC_WITH_DISTORTION_FILENAME;
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_GENERIC_CAMERA is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_GENERIC_CAMERA is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -250,14 +252,6 @@ void vpViper850::init(vpViper850::vpToolType tool, vpCameraParameters::vpCameraP
   }
   default: {
     vpERROR_TRACE("This error should not occur!");
-    //       vpERROR_TRACE ("Si elle survient malgre tout, c'est sans doute "
-    // 		   "que les specs de la classe ont ete modifiee, "
-    // 		   "et que le code n'a pas ete mis a jour "
-    // 		   "correctement.");
-    //       vpERROR_TRACE ("Verifiez les valeurs possibles du type "
-    // 		   "vpViper850::vpViper850ToolType, et controlez que "
-    // 		   "tous les cas ont ete pris en compte dans la "
-    // 		   "fonction init(camera).");
     break;
   }
   }
@@ -287,7 +281,8 @@ void vpViper850::init(vpViper850::vpToolType tool, vpCameraParameters::vpCameraP
       etc[2] = 0.1022;              // tz
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_MARLIN_F033C_CAMERA is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_MARLIN_F033C_CAMERA is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -312,7 +307,8 @@ void vpViper850::init(vpViper850::vpToolType tool, vpCameraParameters::vpCameraP
       etc[2] = 0.078;              // tz
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_PTGREY_FLEA2_CAMERA is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_PTGREY_FLEA2_CAMERA is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -330,7 +326,8 @@ void vpViper850::init(vpViper850::vpToolType tool, vpCameraParameters::vpCameraP
       etc[2] = 0; // tz
       break;
     case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-      throw vpException(vpException::notImplementedError, "Feature TOOL_GENERIC_CAMERA is not implemented for Kannala-Brandt projection model yet.");
+      throw vpException(vpException::notImplementedError,
+                        "Feature TOOL_GENERIC_CAMERA is not implemented for Kannala-Brandt projection model yet.");
       break;
     }
     break;
@@ -632,7 +629,8 @@ void vpViper850::getCameraParameters(vpCameraParameters &cam, const unsigned int
         cam.initPersProjWithDistortion(1214.0, 1213.0, 323.1, 240.0, -0.1824, 0.1881);
         break;
       case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-        throw vpException(vpException::notImplementedError, "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
+        throw vpException(vpException::notImplementedError,
+                          "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
         break;
       }
     } else {
@@ -656,7 +654,8 @@ void vpViper850::getCameraParameters(vpCameraParameters &cam, const unsigned int
         cam.initPersProjWithDistortion(831.3, 831.6, 322.7, 265.8, -0.1955, 0.2047);
         break;
       case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-        throw vpException(vpException::notImplementedError, "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
+        throw vpException(vpException::notImplementedError,
+                          "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
         break;
       }
     } else {
@@ -679,7 +678,8 @@ void vpViper850::getCameraParameters(vpCameraParameters &cam, const unsigned int
         cam.initPersProjWithDistortion(831.3, 831.6, 322.7, 265.8, -0.1955, 0.2047);
         break;
       case vpCameraParameters::ProjWithKannalaBrandtDistortion:
-        throw vpException(vpException::notImplementedError, "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
+        throw vpException(vpException::notImplementedError,
+                          "Feature getCameraParameters is not implemented for Kannala-Brandt projection model yet.");
         break;
       }
     } else {
