@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Basic class used to make robot simulators.
  *
- * Authors:
- * Nicolas Melchior
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpConfig.h>
 
@@ -56,7 +53,8 @@ vpRobotWireFrameSimulator::vpRobotWireFrameSimulator()
 #elif defined(VISP_HAVE_PTHREAD)
     thread(), attr(),
 #endif
-    mutex_fMi(), mutex_artVel(), mutex_artCoord(), mutex_velocity(), mutex_display(), displayBusy(false),
+    m_mutex_fMi(), m_mutex_eMc(), m_mutex_artVel(), m_mutex_artCoord(), m_mutex_velocity(), m_mutex_display(), m_mutex_robotStop(), m_mutex_frame(), m_mutex_setVelocityCalled(), m_mutex_scene(),
+    displayBusy(false),
     robotStop(false), jointLimit(false), jointLimitArt(false), singularityManagement(true), cameraParam(),
 #if defined(VISP_HAVE_DISPLAY)
     display(),
@@ -71,9 +69,6 @@ vpRobotWireFrameSimulator::vpRobotWireFrameSimulator()
 #if defined(VISP_HAVE_DISPLAY)
   display.init(I, 0, 0, "The External view");
 #endif
-
-  // pid_t pid = getpid();
-  // setpriority (PRIO_PROCESS, pid, 19);
 }
 
 /*!
@@ -87,7 +82,7 @@ vpRobotWireFrameSimulator::vpRobotWireFrameSimulator(bool do_display)
 #elif defined(VISP_HAVE_PTHREAD)
     thread(), attr(),
 #endif
-    /* thread(), attr(), */ mutex_fMi(), mutex_artVel(), mutex_artCoord(), mutex_velocity(), mutex_display(),
+    m_mutex_fMi(), m_mutex_eMc(), m_mutex_artVel(), m_mutex_artCoord(), m_mutex_velocity(), m_mutex_display(), m_mutex_robotStop(), m_mutex_frame(), m_mutex_setVelocityCalled(), m_mutex_scene(),
     displayBusy(false), robotStop(false), jointLimit(false), jointLimitArt(false), singularityManagement(true),
     cameraParam(),
 #if defined(VISP_HAVE_DISPLAY)
@@ -105,15 +100,14 @@ vpRobotWireFrameSimulator::vpRobotWireFrameSimulator(bool do_display)
   if (do_display)
     this->display.init(I, 0, 0, "The External view");
 #endif
-
-  // pid_t pid = getpid();
-  // setpriority (PRIO_PROCESS, pid, 19);
 }
 
 /*!
   Basic destructor
 */
-vpRobotWireFrameSimulator::~vpRobotWireFrameSimulator() {}
+vpRobotWireFrameSimulator::~vpRobotWireFrameSimulator()
+{
+}
 
 /*!
   Initialize the display. It enables to choose the type of scene which will be
@@ -125,12 +119,13 @@ vpRobotWireFrameSimulator::~vpRobotWireFrameSimulator() {}
   corresponding files are stored in the "data" folder which is in the ViSP
   build directory.
 
-  \param obj : Type of scene used to display the object at the current
-  position. \param desired_object : Type of scene used to display the object
-  at the desired pose (in the internal view).
+  \param obj : Type of scene used to display the object at the current position.
+
+  \param desired_object : Type of scene used to display the object at the desired pose (in the internal view).
 */
 void vpRobotWireFrameSimulator::initScene(const vpSceneObject &obj, const vpSceneDesiredObject &desired_object)
 {
+  m_mutex_scene.lock();
   if (displayCamera) {
     free_Bound_scene(&(this->camera));
   }
@@ -139,6 +134,7 @@ void vpRobotWireFrameSimulator::initScene(const vpSceneObject &obj, const vpScen
     free_Bound_scene(&(this->camera));
   }
   displayCamera = false;
+  m_mutex_scene.unlock();
 }
 
 /*!
@@ -373,7 +369,7 @@ vpHomogeneousMatrix vpRobotWireFrameSimulator::get_cMo()
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning:
+// Work around to avoid warning:
 // libvisp_robot.a(vpRobotWireFrameSimulator.cpp.o) has no symbols
 void dummy_vpRobotWireFrameSimulator(){};
 #endif
