@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Pioneer mobile robot simulator without display.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpSimulatorPioneer.cpp
@@ -101,7 +98,7 @@ void vpSimulatorPioneer::get_eJe(vpMatrix &_eJe) { _eJe = vpUnicycle::get_eJe();
 
   \param v : Velocity vector \f$(v_x, \omega_z)\f$ to apply to the robot,
   where \f$v_x\f$ is the linear translational velocity in m/s and
-  \f$\omega_z\f$ is the rotational velocity in rad/s arround the vertical
+  \f$\omega_z\f$ is the rotational velocity in rad/s around the vertical
   axis.
 
   Depending on the velocity specified as input, the robot position is updated
