@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Pioneer mobile robot equipped with a pan head simulator without display.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpSimulatorPioneerPan.cpp
@@ -109,7 +106,7 @@ void vpSimulatorPioneerPan::get_eJe(vpMatrix &_eJe) { _eJe = vpUnicycle::get_eJe
 
   \param v : Velocity vector \f$(v_x, \omega_z, \dot q)\f$ to apply to the
   robot, where \f$v_x\f$ is the linear translational velocity in m/s and
-  \f$\omega_z\f$ is the rotational velocity in rad/s arround the vertical axis
+  \f$\omega_z\f$ is the rotational velocity in rad/s around the vertical axis
   of the mobile base, and, \f$\dot q\f$ is the pan velocity in rad/s of the
   camera.
 
