@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Test for Afma 6 dof robot.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example testRobotViper850Pose.cpp
@@ -78,7 +75,7 @@ int main()
 // Create an image viewer for the image
 #ifdef VISP_HAVE_X11
     vpDisplayX display(I, 100, 100, "Current image");
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display(I, 100, 100, "Current image");
 #elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display(I, 100, 100, "Current image");
@@ -166,10 +163,9 @@ int main()
     vpHomogeneousMatrix cMo;
     vpRotationMatrix R;
     vpRxyzVector r;
-    // Compute the pose: initialisation is done by Lagrange method, and the
-    // final pose is computed by the more accurate Virtual Visual Servoing
-    // method.
-    pose.computePose(vpPose::LAGRANGE_VIRTUAL_VS, cMo);
+    // Compute the pose: initialisation is done by Dementhon or Lagrange method, and the
+    // final pose is computed by the more accurate Virtual Visual Servoing method.
+    pose.computePose(vpPose::DEMENTHON_LAGRANGE_VIRTUAL_VS, cMo);
 
     std::cout << "Pose cMo: " << std::endl << cMo;
     cMo.extract(R);
@@ -218,17 +214,17 @@ int main()
     std::cout << "  rotation: " << vpMath::deg(r[0]) << " " << vpMath::deg(r[1]) << " " << vpMath::deg(r[2]) << " deg"
               << std::endl
               << std::endl;
-
+    return EXIT_SUCCESS;
   } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
+    return EXIT_FAILURE;
   }
-  return 0;
 }
 #else
 int main()
 {
   std::cout << "Sorry, test not valid. You should have an Viper850 robot..." << std::endl;
-  return 0;
+  return EXIT_SUCCESS;
 }
 
 #endif
