@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Test for Virtuose SDK wrapper.
  *
- * Author:
- * Nicolò Pedemonte
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example testVirtuose.cpp
@@ -56,20 +53,20 @@ int main(int argc, char **argv)
       opt_port = std::atoi(argv[i + 1]);
     else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
       std::cout << "\nUsage: " << argv[0]
-                << " [--ip <localhost>] [--port <port>]"
-                   " [--help] [-h]\n"
-                << std::endl
-                << "Description: " << std::endl
-                << " --ip <localhost>" << std::endl
-                << "\tHost IP address. Default value: \"localhost\"." << std::endl
-                << std::endl
-                << " --port <port>" << std::endl
-                << "\tCommunication port. Default value: 5000." << std::endl
-                << "\tSuggested values: " << std::endl
-                << "\t- 5000 to communicate with the Virtuose." << std::endl
-                << "\t- 53210 to communicate with the Virtuose equipped with the Glove." << std::endl
-                << std::endl;
-      return 0;
+        << " [--ip <localhost>] [--port <port>]"
+        " [--help] [-h]\n"
+        << std::endl
+        << "Description: " << std::endl
+        << " --ip <localhost>" << std::endl
+        << "\tHost IP address. Default value: \"localhost\"." << std::endl
+        << std::endl
+        << " --port <port>" << std::endl
+        << "\tCommunication port. Default value: 5000." << std::endl
+        << "\tSuggested values: " << std::endl
+        << "\t- 5000 to communicate with the Virtuose." << std::endl
+        << "\t- 53210 to communicate with the Virtuose equipped with the Glove." << std::endl
+        << std::endl;
+      return EXIT_SUCCESS;
     }
   }
 
@@ -84,16 +81,20 @@ int main(int argc, char **argv)
       std::cout << "The system is operational." << std::endl;
       vpColVector q = virtuose.getArticularPosition();
       std::cout << "The current joint values are : " << q.t() << std::endl;
-    } else
+    }
+    else
       std::cout << "The system is not operational. \nPlease plug the "
-                   "emergency stop to the system (or untrigger it)."
-                << std::endl;
-  } catch (const vpException &e) {
+      "emergency stop to the system (or untrigger it)."
+      << std::endl;
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e.getStringMessage() << std::endl;
+    return EXIT_FAILURE;
   }
 #else
   (void)argc;
   (void)argv;
   std::cout << "You should install Virtuose SDK to use this binary..." << std::endl;
 #endif
+  return EXIT_SUCCESS;
 }
