@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -35,7 +35,7 @@
  * Nicolò Pedemonte
  * Firas Abi Farraj
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example testVirtuoseHapticBox.cpp
@@ -262,7 +262,7 @@ int main(int argc, char **argv)
                 << "\t- 5000 to communicate with the Virtuose." << std::endl
                 << "\t- 53210 to communicate with the Virtuose equipped with the Glove." << std::endl
                 << std::endl;
-      return 0;
+      return EXIT_SUCCESS;
     }
   }
 
@@ -290,7 +290,9 @@ int main(int argc, char **argv)
     std::cout << "The end" << std::endl;
   } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e.getStringMessage() << std::endl;
+    return EXIT_FAILURE;
   }
+  return EXIT_SUCCESS;
 }
 
 #else
@@ -299,5 +301,6 @@ int main()
   std::cout << "You should install pthread and/or Virtuose API to use this "
                "binary..."
             << std::endl;
+  return EXIT_SUCCESS;
 }
 #endif
