@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * DirectShow framegrabber Implementation.
  *
- * Authors:
- * Bruno Renier
- * Anthony Saunier
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #ifndef vpDirectShowGrabberImpl_hh
 #define vpDirectShowGrabberImpl_hh
@@ -192,7 +188,7 @@ private:
   bool connectSourceToGrabber(CComPtr<IBaseFilter> &pCapSource, CComPtr<IBaseFilter> &pGrabberFilter);
 
   // used to convert HRESULT-associated error message to a string
-  void HRtoStr(std::string str);
+  void HRtoStr(std::string &str);
 
   // create the list of the available devices
   bool createDeviceList(CComPtr<IEnumMoniker> &ppVideoInputEnum);
