@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * RealSense SDK wrapper.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #ifndef _vpRealSense_h_
 #define _vpRealSense_h_
@@ -81,7 +78,7 @@
   file that allows to build sample-realsense.cpp that uses vpRealSense class.
   \code
 project(sample)
-cmake_minimum_required(VERSION 3.0)
+cmake_minimum_required(VERSION 3.5)
 
 find_package(VISP REQUIRED)
 include_directories(${VISP_INCLUDE_DIRS})
@@ -203,7 +200,8 @@ int main() {
   rs.open();
 
   vpImage<vpRGBa> Ic(rs.getIntrinsics(rs::stream::color).height, rs.getIntrinsics(rs::stream::color).width);
-  vpImage<unsigned char> Ii(rs.getIntrinsics(rs::stream::infrared).height, rs.getIntrinsics(rs::stream::infrared).width);
+  vpImage<unsigned char> Ii(rs.getIntrinsics(rs::stream::infrared).height,
+rs.getIntrinsics(rs::stream::infrared).width);
 
 #ifdef VISP_HAVE_X11
   vpDisplayX dc(Ic, 0, 0, "Color");
