@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -32,10 +32,9 @@
  * Wrapper over IIT force-torque sensor.
  *
  * Authors:
- * Fabien Spindler
  * Alexander Oliva
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpForceTorqueIitSensor.cpp
@@ -52,8 +51,9 @@
   Establish communication with sensor(-s) and start data acquisition thread.
 */
 vpForceTorqueIitSensor::vpForceTorqueIitSensor()
-  : m_ftLib(), m_numSensorsInLib(0), m_ft(6, 0), m_ft_filt(6, 0), m_ftSensorsData(), m_acquisitionEnabled(false), m_dataValid(false),
-    m_connected(false), m_acquisitionThread(), m_timeCur(), m_timePrev(), m_mutex(), m_warmupMilliseconds(500)
+  : m_ftLib(), m_numSensorsInLib(0), m_ft(6, 0), m_ft_filt(6, 0), m_ftSensorsData(), m_acquisitionEnabled(false),
+    m_dataValid(false), m_connected(false), m_acquisitionThread(), m_timeCur(), m_timePrev(), m_mutex(),
+    m_warmupMilliseconds(500)
 {
   // Get number of connected in library sensors
   m_numSensorsInLib = m_ftLib._getNumberOfConnectedSensors();
@@ -186,7 +186,7 @@ bool vpForceTorqueIitSensor::connected(int timeout_ms) const
   \param[in] filtered : When true return filtered force-torque measurements,
   when false return raw data.
   If no filter is configured while getting filtered measurements, the SDK will
-  retun the raw data.
+  return the raw data.
   To configure the filter, you must access the sensor through the web interface.
   The default ip address is `192.168.1.1` if in default mode.
   Once in the web interface select NETWORK SETTINGS and you can configure the
@@ -207,13 +207,11 @@ vpColVector vpForceTorqueIitSensor::getForceTorque(bool filtered)
   const std::lock_guard<std::mutex> lock(m_mutex);
   if (filtered) {
     return m_ft_filt;
-  }
-  else {
+  } else {
     return m_ft;
   }
 }
 
-
 /*!
    Start acquisition thread and wait until data are available.
  */
@@ -239,7 +237,7 @@ void vpForceTorqueIitSensor::stopStreaming()
 }
 
 #else
-// Work arround to avoid warning:
+// Work around to avoid warning:
 // libvisp_sensor.a(vpForceTorqueIitSensor.cpp.o) has no symbols
 void dummy_vpForceTorqueIitSensor(){};
 #endif
