@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,12 +31,7 @@
  * Description:
  * Firewire cameras video capture based on CMU 1394 Digital Camera SDK.
  *
- * Authors:
- * Lucas Lopes Lemos FEMTO-ST, AS2M departement, Besancon
- * Guillaume Laurent FEMTO-ST, AS2M departement, Besancon
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpConfig.h>
 
@@ -511,7 +506,7 @@ void vp1394CMUGrabber::displayCameraModel()
   std::cout << "Vendor: " << vendor << std::endl;
   std::cout << "Model: " << model << std::endl;
 
-  sprintf(buf, "%08X%08X", ID.HighPart, ID.LowPart);
+  snprintf(buf, 256, "%08X%08X", ID.HighPart, ID.LowPart);
   std::cout << "UniqueID: " << buf << std::endl;
 }
 
@@ -756,7 +751,7 @@ vp1394CMUGrabber &vp1394CMUGrabber::operator>>(vpImage<vpRGBa> &I)
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_sensor.a(vp1394CMUGrabber.cpp.o) has
+// Work around to avoid warning: libvisp_sensor.a(vp1394CMUGrabber.cpp.o) has
 // no symbols
 void dummy_vp1394CMUGrabber(){};
 #endif
