@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * DirectShow framegrabber implementation.
  *
- * Authors:
- * Bruno Renier
- * Anthony Saunier
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 
@@ -50,7 +46,7 @@ unsigned int vpDirectShowGrabberImpl::nbDevices;
 /*!
         Converts a HRESULT into the corresponding error message
 */
-void vpDirectShowGrabberImpl::HRtoStr(std::string str)
+void vpDirectShowGrabberImpl::HRtoStr(std::string &str)
 {
   TCHAR szErr[MAX_ERROR_TEXT_LEN];
   DWORD res = AMGetErrorText(hr, szErr, MAX_ERROR_TEXT_LEN);
@@ -59,7 +55,7 @@ void vpDirectShowGrabberImpl::HRtoStr(std::string str)
     str = "Unknown Error: 0x%2x";
 
   char msg[MAX_ERROR_TEXT_LEN];
-  sprintf(msg, "%s", szErr);
+  snprintf(msg, MAX_ERROR_TEXT_LEN, "%s", szErr);
   str = msg;
 }
 
@@ -504,27 +500,10 @@ bool vpDirectShowGrabberImpl::connectSourceToGrabber(CComPtr<IBaseFilter> &_pCap
   if (FAILED(hr = pBuild->RenderStream(NULL, NULL, _pCapSource, NULL, _pGrabberFilter)))
     return false;
 
-  /*
-  //get the grabber's output pin
-  CComPtr<IPin> pGrabberOutputPin;
-  if(FAILED(pBuild->FindPin(_pGrabberFilter, PINDIR_OUTPUT, NULL, NULL, false,
-  0, &pGrabberOutputPin))) return false;
-  */
   // get the Null renderer
   CComPtr<IBaseFilter> pNull = NULL;
   if (FAILED(pNull.CoCreateInstance(CLSID_NullRenderer, NULL, CLSCTX_INPROC_SERVER)))
     return false;
-  /*
-          //get the null renderer's input pin
-          CComPtr<IPin> pNullInputPin;
-          if(FAILED(pBuild->FindPin(pNull, PINDIR_INPUT, NULL, NULL, false, 0,
-     &pNullInputPin))) return false;
-
-          //connect the grabber's output to the null renderer
-          if(	FAILED(pGraph->AddFilter(pNull, L"NullRenderer")) ||
-                  FAILED(pGraph->Connect(pGrabberOutputPin, pNullInputPin)))
-                  return false;
-  */
 
   if (FAILED(pGraph->AddFilter(pNull, L"NullRenderer")) ||
       FAILED(pBuild->RenderStream(NULL, NULL, _pGrabberFilter, NULL, pNull)))
@@ -542,8 +521,6 @@ bool vpDirectShowGrabberImpl::connectSourceToGrabber(CComPtr<IBaseFilter> &_pCap
   // release the remaining interfaces
   pCapSourcePin.Release();
   pNull.Release();
-  //	pGrabberOutputPin.Release();
-  //	pNullInputPin.Release();
 
   return true;
 }
@@ -807,17 +784,7 @@ bool vpDirectShowGrabberImpl::setFormat(unsigned int width, unsigned int height,
       VIDEO_STREAM_CONFIG_CAPS scc;
       AM_MEDIA_TYPE *pmtConfig;
       hr = pConfig->GetStreamCaps(iFormat, &pmtConfig, (BYTE *)&scc);
-      //			VIDEOINFOHEADER *pVih =
-      //(VIDEOINFOHEADER*)pmtConfig->pbFormat;
 
-      //			pVih->bmiHeader.biWidth;
-      //			pVih->bmiHeader.biHeight;
-      //			10000000 /pVih->AvgTimePerFrame;
-      //			std::cout<<"available image size :
-      //"<<pVih->bmiHeader.biWidth<<" x "<<pVih->bmiHeader.biHeight<<" at
-      //"<<10000000 /pVih->AvgTimePerFrame<<std::endl;
-      //			std::cout<<"compression :
-      //"<<pVih->bmiHeader.biCompression<<std::endl;
       if (SUCCEEDED(hr) && found == false) {
         /* Examine the format, and possibly use it. */
         if ((pmtConfig->majortype == sgCB.connectedMediaType.majortype) &&
@@ -941,12 +908,6 @@ bool vpDirectShowGrabberImpl::getStreamCapabilities()
         /* Examine the format, and possibly use it. */
         VIDEOINFOHEADER *pVih = (VIDEOINFOHEADER *)pmtConfig->pbFormat;
 
-        //				LONG lWidth = pVih->bmiHeader.biWidth;
-        //				LONG lHeight =
-        // pVih->bmiHeader.biHeight; 				SIZE
-        // dimensions={lWidth,lHeight};
-        //				LONGLONG lAvgTimePerFrame =
-        // pVih->AvgTimePerFrame;
         std::cout << "MediaType : " << iFormat << std::endl;
 
         if (pmtConfig->subtype == MEDIASUBTYPE_ARGB32)
@@ -1138,7 +1099,7 @@ void vpDirectShowGrabberImpl::MyFreeMediaType(AM_MEDIA_TYPE &mt)
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning:
+// Work around to avoid warning:
 // libvisp_sensor.a(vpDirectShowGrabberImpl.cpp.o) has no symbols
 void dummy_vpDirectShowGrabberImpl(){};
 #endif
