@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See httpS://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Framegrabber based on Video4Linux2 driver.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpV4l2Grabber.cpp
@@ -148,9 +145,9 @@ int main()
 */
 vpV4l2Grabber::vpV4l2Grabber()
   : fd(-1), device(), cap(), streamparm(), inp(NULL), std(NULL), fmt(NULL), ctl(NULL), fmt_v4l2(), fmt_me(), reqbufs(),
-    buf_v4l2(NULL), buf_me(NULL), queue(0), waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0),
-    streaming(false), m_input(vpV4l2Grabber::DEFAULT_INPUT), m_framerate(vpV4l2Grabber::framerate_25fps),
-    m_frameformat(vpV4l2Grabber::V4L2_FRAME_FORMAT), m_pixelformat(vpV4l2Grabber::V4L2_YUYV_FORMAT)
+  buf_v4l2(NULL), buf_me(NULL), queue(0), waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0),
+  streaming(false), m_input(vpV4l2Grabber::DEFAULT_INPUT), m_framerate(vpV4l2Grabber::framerate_25fps),
+  m_frameformat(vpV4l2Grabber::V4L2_FRAME_FORMAT), m_pixelformat(vpV4l2Grabber::V4L2_YUYV_FORMAT)
 {
   setDevice("/dev/video0");
   setNBuffers(3);
@@ -204,9 +201,9 @@ vpV4l2Grabber::vpV4l2Grabber()
 */
 vpV4l2Grabber::vpV4l2Grabber(bool verbose)
   : fd(-1), device(), cap(), streamparm(), inp(NULL), std(NULL), fmt(NULL), ctl(NULL), fmt_v4l2(), fmt_me(), reqbufs(),
-    buf_v4l2(NULL), buf_me(NULL), queue(0), waiton_cpt(0), index_buffer(0), m_verbose(verbose), m_nbuffers(3), field(0),
-    streaming(false), m_input(vpV4l2Grabber::DEFAULT_INPUT), m_framerate(vpV4l2Grabber::framerate_25fps),
-    m_frameformat(vpV4l2Grabber::V4L2_FRAME_FORMAT), m_pixelformat(vpV4l2Grabber::V4L2_YUYV_FORMAT)
+  buf_v4l2(NULL), buf_me(NULL), queue(0), waiton_cpt(0), index_buffer(0), m_verbose(verbose), m_nbuffers(3), field(0),
+  streaming(false), m_input(vpV4l2Grabber::DEFAULT_INPUT), m_framerate(vpV4l2Grabber::framerate_25fps),
+  m_frameformat(vpV4l2Grabber::V4L2_FRAME_FORMAT), m_pixelformat(vpV4l2Grabber::V4L2_YUYV_FORMAT)
 {
   setDevice("/dev/video0");
   setNBuffers(3);
@@ -250,9 +247,9 @@ vpV4l2Grabber::vpV4l2Grabber(bool verbose)
 */
 vpV4l2Grabber::vpV4l2Grabber(unsigned input, unsigned scale)
   : fd(-1), device(), cap(), streamparm(), inp(NULL), std(NULL), fmt(NULL), ctl(NULL), fmt_v4l2(), fmt_me(), reqbufs(),
-    buf_v4l2(NULL), buf_me(NULL), queue(0), waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0),
-    streaming(false), m_input(vpV4l2Grabber::DEFAULT_INPUT), m_framerate(vpV4l2Grabber::framerate_25fps),
-    m_frameformat(vpV4l2Grabber::V4L2_FRAME_FORMAT), m_pixelformat(vpV4l2Grabber::V4L2_YUYV_FORMAT)
+  buf_v4l2(NULL), buf_me(NULL), queue(0), waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0),
+  streaming(false), m_input(vpV4l2Grabber::DEFAULT_INPUT), m_framerate(vpV4l2Grabber::framerate_25fps),
+  m_frameformat(vpV4l2Grabber::V4L2_FRAME_FORMAT), m_pixelformat(vpV4l2Grabber::V4L2_YUYV_FORMAT)
 {
   setDevice("/dev/video0");
   setNBuffers(3);
@@ -296,9 +293,9 @@ vpV4l2Grabber::vpV4l2Grabber(unsigned input, unsigned scale)
 */
 vpV4l2Grabber::vpV4l2Grabber(vpImage<unsigned char> &I, unsigned input, unsigned scale)
   : fd(-1), device(), cap(), streamparm(), inp(NULL), std(NULL), fmt(NULL), ctl(NULL), fmt_v4l2(), fmt_me(), reqbufs(),
-    buf_v4l2(NULL), buf_me(NULL), queue(0), waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0),
-    streaming(false), m_input(vpV4l2Grabber::DEFAULT_INPUT), m_framerate(vpV4l2Grabber::framerate_25fps),
-    m_frameformat(vpV4l2Grabber::V4L2_FRAME_FORMAT), m_pixelformat(vpV4l2Grabber::V4L2_YUYV_FORMAT)
+  buf_v4l2(NULL), buf_me(NULL), queue(0), waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0),
+  streaming(false), m_input(vpV4l2Grabber::DEFAULT_INPUT), m_framerate(vpV4l2Grabber::framerate_25fps),
+  m_frameformat(vpV4l2Grabber::V4L2_FRAME_FORMAT), m_pixelformat(vpV4l2Grabber::V4L2_YUYV_FORMAT)
 {
   setDevice("/dev/video0");
   setNBuffers(3);
@@ -345,9 +342,9 @@ vpV4l2Grabber::vpV4l2Grabber(vpImage<unsigned char> &I, unsigned input, unsigned
 */
 vpV4l2Grabber::vpV4l2Grabber(vpImage<vpRGBa> &I, unsigned input, unsigned scale)
   : fd(-1), device(), cap(), streamparm(), inp(NULL), std(NULL), fmt(NULL), ctl(NULL), fmt_v4l2(), fmt_me(), reqbufs(),
-    buf_v4l2(NULL), buf_me(NULL), queue(0), waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0),
-    streaming(false), m_input(vpV4l2Grabber::DEFAULT_INPUT), m_framerate(vpV4l2Grabber::framerate_25fps),
-    m_frameformat(vpV4l2Grabber::V4L2_FRAME_FORMAT), m_pixelformat(vpV4l2Grabber::V4L2_YUYV_FORMAT)
+  buf_v4l2(NULL), buf_me(NULL), queue(0), waiton_cpt(0), index_buffer(0), m_verbose(false), m_nbuffers(3), field(0),
+  streaming(false), m_input(vpV4l2Grabber::DEFAULT_INPUT), m_framerate(vpV4l2Grabber::framerate_25fps),
+  m_frameformat(vpV4l2Grabber::V4L2_FRAME_FORMAT), m_pixelformat(vpV4l2Grabber::V4L2_YUYV_FORMAT)
 {
   setDevice("/dev/video0");
   setNBuffers(3);
@@ -421,7 +418,8 @@ void vpV4l2Grabber::open(vpImage<unsigned char> &I)
     setFormat();
 
     startStreaming();
-  } catch (...) {
+  }
+  catch (...) {
     if (m_verbose) {
       std::cout << "Requested pixel format [" << req_pixelformat << "] not compatible with camera" << std::endl;
       std::cout << "Try to found a compatible pixel format..." << std::endl;
@@ -440,7 +438,8 @@ void vpV4l2Grabber::open(vpImage<unsigned char> &I)
           std::cout << "This format [" << m_pixelformat << "] is compatible with camera" << std::endl;
 
         break;
-      } catch (...) {
+      }
+      catch (...) {
         if (m_verbose)
           std::cout << "This format [" << m_pixelformat << "] is not compatible with camera" << std::endl;
         if (format == (int)V4L2_MAX_FORMAT) {
@@ -448,7 +447,7 @@ void vpV4l2Grabber::open(vpImage<unsigned char> &I)
           close();
 
           throw(vpFrameGrabberException(vpFrameGrabberException::settingError,
-                                        "No pixel format compatible with the camera was found"));
+            "No pixel format compatible with the camera was found"));
         }
       }
     }
@@ -482,7 +481,8 @@ void vpV4l2Grabber::open(vpImage<vpRGBa> &I)
     setFormat();
 
     startStreaming();
-  } catch (...) {
+  }
+  catch (...) {
     if (m_verbose) {
       std::cout << "Requested pixel format [" << m_pixelformat << "] not compatible with camera" << std::endl;
       std::cout << "Try to found a compatible pixel format..." << std::endl;
@@ -501,7 +501,8 @@ void vpV4l2Grabber::open(vpImage<vpRGBa> &I)
           std::cout << "This format [" << m_pixelformat << "] is compatible with camera" << std::endl;
 
         break;
-      } catch (...) {
+      }
+      catch (...) {
         if (m_verbose)
           std::cout << "This format [" << m_pixelformat << "] is not compatible with camera" << std::endl;
       }
@@ -737,12 +738,14 @@ void vpV4l2Grabber::acquire(vpImage<vpRGBa> &I, struct timeval &timestamp, const
     if (roi == vpRect()) {
       // The framegrabber acquire aRGB format. We just shift the data
       // from 1 byte all the data and initialize the last byte
-      memcpy(static_cast<void*>(I.bitmap), static_cast<void*>(bitmap + 1), height * width * sizeof(vpRGBa) - 1);
+      memcpy(static_cast<void *>(I.bitmap), static_cast<void *>(bitmap + 1), height * width * sizeof(vpRGBa) - 1);
       I[height - 1][width - 1].A = 0;
-    } else {
+    }
+    else {
       for (unsigned int i = 0; i < I.getHeight(); i++) {
-        memcpy(static_cast<void*>(I.bitmap), static_cast<void*>(bitmap + 1 + (unsigned int)(roi.getTop() * width + roi.getLeft())),
-               I.getWidth() * sizeof(vpRGBa) - 1);
+        memcpy(static_cast<void *>(I.bitmap),
+          static_cast<void *>(bitmap + 1 + (unsigned int)(roi.getTop() * width + roi.getLeft())),
+          I.getWidth() * sizeof(vpRGBa) - 1);
         I[i][I.getWidth() - 1].A = 0;
       }
     }
@@ -851,27 +854,27 @@ void vpV4l2Grabber::close()
   }
 
   if (inp != NULL) {
-    delete[] inp;
+    delete [] inp;
     inp = NULL;
   }
   if (std != NULL) {
-    delete[] std;
+    delete [] std;
     std = NULL;
   }
   if (fmt != NULL) {
-    delete[] fmt;
+    delete [] fmt;
     fmt = NULL;
   }
   if (ctl != NULL) {
-    delete[] ctl;
+    delete [] ctl;
     ctl = NULL;
   }
   if (buf_v4l2 != NULL) {
-    delete[] buf_v4l2;
+    delete [] buf_v4l2;
     buf_v4l2 = NULL;
   }
   if (buf_me != NULL) {
-    delete[] buf_me;
+    delete [] buf_me;
     buf_me = NULL;
   }
 }
@@ -892,45 +895,45 @@ void vpV4l2Grabber::open()
   /* Open Video Device */
   struct stat st;
 
-  if (-1 == stat(device, &st)) {
-    fprintf(stderr, "Cannot identify '%s': %d, %s\n", device, errno, strerror(errno));
+  if (-1 == stat(device.c_str(), &st)) {
+    fprintf(stderr, "Cannot identify '%s': %d, %s\n", device.c_str(), errno, strerror(errno));
     throw(vpFrameGrabberException(vpFrameGrabberException::initializationError, "Cannot identify video device"));
   }
 
   if (!S_ISCHR(st.st_mode)) {
-    fprintf(stderr, "%s is no device\n", device);
+    fprintf(stderr, "%s is no device\n", device.c_str());
     throw(vpFrameGrabberException(vpFrameGrabberException::initializationError, "No device"));
   }
-  fd = v4l2_open(device, O_RDWR | O_NONBLOCK, 0);
+  fd = v4l2_open(device.c_str(), O_RDWR | O_NONBLOCK, 0);
   if (fd < 0) {
     close();
 
-    vpERROR_TRACE("No video device \"%s\"\n", device);
+    vpERROR_TRACE("No video device \"%s\"\n", device.c_str());
     throw(vpFrameGrabberException(vpFrameGrabberException::initializationError, "Can't access to video device"));
   }
 
   if (inp != NULL) {
-    delete[] inp;
+    delete [] inp;
     inp = NULL;
   }
   if (std != NULL) {
-    delete[] std;
+    delete [] std;
     std = NULL;
   }
   if (fmt != NULL) {
-    delete[] fmt;
+    delete [] fmt;
     fmt = NULL;
   }
   if (ctl != NULL) {
-    delete[] ctl;
+    delete [] ctl;
     ctl = NULL;
   }
   if (buf_v4l2 != NULL) {
-    delete[] buf_v4l2;
+    delete [] buf_v4l2;
     buf_v4l2 = NULL;
   }
   if (buf_me != NULL) {
-    delete[] buf_me;
+    delete [] buf_me;
     buf_me = NULL;
   }
 
@@ -944,16 +947,16 @@ void vpV4l2Grabber::open()
   /* Querry Video Device Capabilities */
   if (v4l2_ioctl(fd, VIDIOC_QUERYCAP, &cap) == -1) {
     close();
-    fprintf(stderr, "%s is no V4L2 device\n", device);
+    fprintf(stderr, "%s is no V4L2 device\n", device.c_str());
     throw(vpFrameGrabberException(vpFrameGrabberException::otherError, "Is not a V4L2 device"));
   }
   if (m_verbose) {
     fprintf(stdout,
-            "v4l2 info:\n"
-            "     device: %s\n"
-            "     %s %d.%d.%d / %s @ %s\n",
-            device, cap.driver, (cap.version >> 16) & 0xff, (cap.version >> 8) & 0xff, cap.version & 0xff, cap.card,
-            cap.bus_info);
+      "v4l2 info:\n"
+      "     device: %s\n"
+      "     %s %d.%d.%d / %s @ %s\n",
+      device.c_str(), cap.driver, (cap.version >> 16) & 0xff, (cap.version >> 8) & 0xff, cap.version & 0xff,
+      cap.card, cap.bus_info);
     if (cap.capabilities & V4L2_CAP_VIDEO_OVERLAY)
       fprintf(stdout, "     Support overlay\n");
     else
@@ -1139,11 +1142,11 @@ void vpV4l2Grabber::setFormat()
 
   if (m_verbose) {
     fprintf(stdout,
-            "v4l2: new capture params (%ux%u, %c%c%c%c, %d byte, %d bytes "
-            "per line)\n",
-            fmt_me.width, fmt_me.height, fmt_v4l2.fmt.pix.pixelformat & 0xff,
-            (fmt_v4l2.fmt.pix.pixelformat >> 8) & 0xff, (fmt_v4l2.fmt.pix.pixelformat >> 16) & 0xff,
-            (fmt_v4l2.fmt.pix.pixelformat >> 24) & 0xff, fmt_v4l2.fmt.pix.sizeimage, fmt_v4l2.fmt.pix.bytesperline);
+      "v4l2: new capture params (%ux%u, %c%c%c%c, %d byte, %d bytes "
+      "per line)\n",
+      fmt_me.width, fmt_me.height, fmt_v4l2.fmt.pix.pixelformat & 0xff,
+      (fmt_v4l2.fmt.pix.pixelformat >> 8) & 0xff, (fmt_v4l2.fmt.pix.pixelformat >> 16) & 0xff,
+      (fmt_v4l2.fmt.pix.pixelformat >> 24) & 0xff, fmt_v4l2.fmt.pix.sizeimage, fmt_v4l2.fmt.pix.bytesperline);
   }
 }
 /*!
@@ -1170,9 +1173,9 @@ void vpV4l2Grabber::startStreaming()
   if (v4l2_ioctl(fd, VIDIOC_REQBUFS, &reqbufs) == -1) {
     if (EINVAL == errno) {
       fprintf(stderr,
-              "%s does not support "
-              "memory mapping\n",
-              device);
+        "%s does not support "
+        "memory mapping\n",
+        device.c_str());
       throw(vpFrameGrabberException(vpFrameGrabberException::otherError, "Does not support memory mapping"));
     }
     throw(vpFrameGrabberException(vpFrameGrabberException::otherError, "Can't require video buffers"));
@@ -1191,14 +1194,8 @@ void vpV4l2Grabber::startStreaming()
     memcpy(&buf_me[i].fmt, &fmt_me, sizeof(ng_video_fmt));
     buf_me[i].size = buf_me[i].fmt.bytesperline * buf_me[i].fmt.height;
 
-    // if (m_verbose)
-    //   std::cout << "1: buf_v4l2[" << i << "].length: " <<
-    //   buf_v4l2[i].length
-    // 	   << " buf_v4l2[" << i << "].offset: " <<  buf_v4l2[i].m.offset
-    // 	   << std::endl;
-
     buf_me[i].data = (unsigned char *)v4l2_mmap(NULL, buf_v4l2[i].length, PROT_READ | PROT_WRITE, MAP_SHARED, fd,
-                                                (off_t)buf_v4l2[i].m.offset);
+      (off_t)buf_v4l2[i].m.offset);
 
     if (buf_me[i].data == MAP_FAILED) {
       throw(vpFrameGrabberException(vpFrameGrabberException::otherError, "Can't map memory"));
@@ -1206,16 +1203,6 @@ void vpV4l2Grabber::startStreaming()
 
     buf_me[i].refcount = 0;
 
-    //     if (m_verbose)
-    //     {
-    //       std::cout << "2: buf_v4l2[" << i << "].length: " <<
-    //       buf_v4l2[i].length
-    // 	   << " buf_v4l2[" << i << "].offset: " <<  buf_v4l2[i].m.offset
-    // 	   << std::endl;
-    //       std::cout << "2: buf_me[" << i << "].size: " << buf_me[i].size <<
-    //       std::endl;
-    //     }
-
     if (m_verbose)
       printBufInfo(buf_v4l2[i]);
   }
@@ -1283,7 +1270,7 @@ unsigned char *vpV4l2Grabber::waiton(__u32 &index, struct timeval &timestamp)
   struct timeval tv;
   fd_set rdset;
 
-/* wait for the next frame */
+  /* wait for the next frame */
 again:
 
   tv.tv_sec = 30;
@@ -1306,7 +1293,7 @@ again:
   /* get it */
   memset(&buf, 0, sizeof(buf));
   buf.type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
-  buf.memory = V4L2_MEMORY_MMAP; // Fabien manquait
+  buf.memory = V4L2_MEMORY_MMAP;
   if (-1 == v4l2_ioctl(fd, VIDIOC_DQBUF, &buf)) {
     index = 0;
     switch (errno) {
@@ -1409,31 +1396,31 @@ void vpV4l2Grabber::queueAll()
 */
 void vpV4l2Grabber::printBufInfo(struct v4l2_buffer buf)
 {
-  char type[40];
+  std::string type;
 
   switch (buf.type) {
   case V4L2_BUF_TYPE_VIDEO_CAPTURE:
-    sprintf(type, "video-cap");
+    type = "video-cap";
     break;
   case V4L2_BUF_TYPE_VIDEO_OVERLAY:
-    sprintf(type, "video-over");
+    type = "video-over";
     break;
   case V4L2_BUF_TYPE_VIDEO_OUTPUT:
-    sprintf(type, "video-out");
+    type = "video-out";
     break;
   case V4L2_BUF_TYPE_VBI_CAPTURE:
-    sprintf(type, "vbi-cap");
+    type = "vbi-cap";
     break;
   case V4L2_BUF_TYPE_VBI_OUTPUT:
-    sprintf(type, "vbi-out");
+    type = "vbi-out";
     break;
   default:
-    sprintf(type, "unknown");
+    type = "unknown";
     break;
   }
 
-  fprintf(stdout, "v4l2: buf %d: %d ad: 0x%lx offset 0x%x+%d (=0x%x),used %d\n", buf.index, buf.type, buf.m.userptr,
-          buf.m.offset, buf.length, buf.length, buf.bytesused);
+  fprintf(stdout, "v4l2: buf %d: type %d (%s) ad: 0x%lx offset 0x%x+%d (=0x%x),used %d\n", buf.index, buf.type,
+    type.c_str(), buf.m.userptr, buf.m.offset, buf.length, buf.length, buf.bytesused);
 }
 
 /*!
@@ -1481,7 +1468,7 @@ vpV4l2Grabber &vpV4l2Grabber::operator>>(vpImage<vpRGBa> &I)
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_sensor.a(vpV4l2Grabber.cpp.o) has no
+// Work around to avoid warning: libvisp_sensor.a(vpV4l2Grabber.cpp.o) has no
 // symbols
-void dummy_vpV4l2Grabber(){};
+void dummy_vpV4l2Grabber() { };
 #endif
