@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2021 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,7 +31,7 @@
  * Description:
  * Test Intel RealSense acquisition with librealsense2.
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \example testRealSense2_SR300.cpp
@@ -42,14 +42,14 @@
 
 #include <visp3/core/vpConfig.h>
 
-#if defined(VISP_HAVE_REALSENSE2) && (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11) &&                                         \
+#if defined(VISP_HAVE_REALSENSE2) && (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11) &&                                    \
     (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI))
 
 #ifdef VISP_HAVE_PCL
+#include <mutex>
 #include <pcl/visualization/cloud_viewer.h>
 #include <pcl/visualization/pcl_visualizer.h>
 #include <thread>
-#include <mutex>
 #endif
 
 #include <visp3/core/vpImage.h>
@@ -212,7 +212,7 @@ void frame_to_mat(const rs2::frame &f, cv::Mat &img)
   const int size = w * h;
 
   if (f.get_profile().format() == RS2_FORMAT_BGR8) {
-    memcpy(static_cast<void*>(img.ptr<cv::Vec3b>()), f.get_data(), size * 3);
+    memcpy(static_cast<void *>(img.ptr<cv::Vec3b>()), f.get_data(), size * 3);
   } else if (f.get_profile().format() == RS2_FORMAT_RGB8) {
     cv::Mat tmp(h, w, CV_8UC3, (void *)f.get_data(), cv::Mat::AUTO_STEP);
     cv::cvtColor(tmp, img, cv::COLOR_RGB2BGR);
@@ -221,7 +221,7 @@ void frame_to_mat(const rs2::frame &f, cv::Mat &img)
   }
 }
 #endif
-}
+} // namespace
 
 int main(int argc, char *argv[])
 {
@@ -242,10 +242,10 @@ int main(int argc, char *argv[])
     else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
       std::cout << argv[0] << " [--show_info]"
 #ifdef VISP_HAVE_PCL
-                           << " [--pcl_color]"
+                << " [--pcl_color]"
 #endif
-                           << " [--help] [-h]"
-                           << "\n";
+                << " [--help] [-h]"
+                << "\n";
       return EXIT_SUCCESS;
     }
   }
@@ -535,8 +535,8 @@ int main(int argc, char *argv[])
 #endif
 
 #ifdef VISP_HAVE_PCL
-  //Pointcloud acquisition using std::vector<vpColVector> + visualization
-  //See issue #355
+  // Pointcloud acquisition using std::vector<vpColVector> + visualization
+  // See issue #355
   ViewerWorker viewer_colvector2(false, mutex);
   std::thread viewer_colvector_thread2(&ViewerWorker::run, &viewer_colvector2);
   cancelled = false;
@@ -600,6 +600,6 @@ int main()
 #if !defined(VISP_HAVE_X11) && !defined(VISP_HAVE_GDI)
   std::cout << "X11 or GDI are needed." << std::endl;
 #endif
-  return 0;
+  return EXIT_SUCCESS;
 }
 #endif
