@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,10 +31,7 @@
  * Description:
  * Manage a circle used in the model-based tracker.
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
  \file vpMbtDistanceCircle.h
@@ -138,7 +135,7 @@ public:
   void displayMovingEdges(const vpImage<vpRGBa> &I);
 
   /*!
-   Get the camera paramters.
+   Get the camera parameters.
 
    \param camera : The vpCameraParameters used to store the camera parameters.
   */
@@ -162,8 +159,7 @@ public:
 
   std::vector<std::vector<double> > getFeaturesForDisplay();
 
-  std::vector<double> getModelForDisplay(const vpHomogeneousMatrix &cMo,
-                                         const vpCameraParameters &cam,
+  std::vector<double> getModelForDisplay(const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam,
                                          bool displayFullModel = false);
 
   /*!
@@ -173,13 +169,6 @@ public:
   */
   inline std::string getName() const { return name; }
 
-  /*!
-   Get the polygon associated to the circle.
-
-   \return poly.
-  */
-  //    inline vpMbtPolygon& getPolygon() {return poly;}
-
   void initInteractionMatrixError();
 
   bool initMovingEdge(const vpImage<unsigned char> &I, const vpHomogeneousMatrix &cMo, bool doNotTrack,
@@ -203,7 +192,7 @@ public:
                         const vpImage<bool> *mask = NULL);
 
   /*!
-   Set the camera paramters.
+   Set the camera parameters.
    \param camera : The camera parameters.
   */
   inline void setCameraParameters(const vpCameraParameters &camera) { this->cam = camera; }
