@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -32,11 +32,9 @@
  * Make the complete tracking of an object by using its CAD model
  *
  * Authors:
- * Nicolas Melchior
  * Romain Tallonneau
- * Eric Marchand
  *
- *****************************************************************************/
+*****************************************************************************/
 #include <visp3/core/vpConfig.h>
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 
@@ -93,8 +91,7 @@ vpMbtMeLine::~vpMbtMeLine() { list.clear(); }
   \param doNoTrack : If true, ME are not tracked
 */
 void vpMbtMeLine::initTracking(const vpImage<unsigned char> &I, const vpImagePoint &ip1, const vpImagePoint &ip2,
-                               double rho_, double theta_,
-                               bool doNoTrack)
+                               double rho_, double theta_, bool doNoTrack)
 {
   vpCDEBUG(1) << " begin vpMeLine::initTracking()" << std::endl;
 
@@ -174,7 +171,8 @@ void vpMbtMeLine::sample(const vpImage<unsigned char> &I, bool doNoTrack)
   for (int i = 0; i <= vpMath::round(n_sample); i++) {
     // If point is in the image, add to the sample list
     if (!outOfImage(vpMath::round(is), vpMath::round(js), (int)(me->getRange() + me->getMaskSize() + 1), (int)rows,
-      (int)cols) && vpMeTracker::inMask(m_mask, vpMath::round(is), vpMath::round(js))) {
+                    (int)cols) &&
+        vpMeTracker::inMask(m_mask, vpMath::round(is), vpMath::round(js))) {
       vpMeSite pix; //= list.value();
       pix.init((int)is, (int)js, delta, 0, sign);
 
@@ -212,20 +210,20 @@ void vpMbtMeLine::suppressPoints(const vpImage<unsigned char> &I)
     if (fabs(sin(theta)) > 0.9) // Vertical line management
     {
       if ((s.i < imin) || (s.i > imax)) {
-        s.setState(vpMeSite::CONSTRAST);
+        s.setState(vpMeSite::CONTRAST);
       }
     }
 
     else if (fabs(cos(theta)) > 0.9) // Horizontal line management
     {
       if ((s.j < jmin) || (s.j > jmax)) {
-        s.setState(vpMeSite::CONSTRAST);
+        s.setState(vpMeSite::CONTRAST);
       }
     }
 
     else {
       if ((s.i < imin) || (s.i > imax) || (s.j < jmin) || (s.j > jmax)) {
-        s.setState(vpMeSite::CONSTRAST);
+        s.setState(vpMeSite::CONTRAST);
       }
     }
 
@@ -348,10 +346,8 @@ void vpMbtMeLine::seekExtremities(const vpImage<unsigned char> &I)
   \param thickness : Thickness of arrows used to show gradient and model orientation.
 */
 void vpMbtMeLine::computeProjectionError(const vpImage<unsigned char> &_I, double &_sumErrorRad,
-                                         unsigned int &_nbFeatures,
-                                         const vpMatrix &SobelX, const vpMatrix &SobelY,
-                                         bool display, unsigned int length,
-                                         unsigned int thickness)
+                                         unsigned int &_nbFeatures, const vpMatrix &SobelX, const vpMatrix &SobelY,
+                                         bool display, unsigned int length, unsigned int thickness)
 {
   _sumErrorRad = 0;
   _nbFeatures = 0;
@@ -431,17 +427,17 @@ void vpMbtMeLine::computeProjectionError(const vpImage<unsigned char> &_I, doubl
       double angle2 = acos(vecLine * (-vecGrad));
 
       if (display) {
-        vpDisplay::displayArrow(_I, it->get_i(), it->get_j(), (int)(it->get_i() + length*cos(deltaNormalized)),
-                                (int)(it->get_j() + length*sin(deltaNormalized)), vpColor::blue,
-                                length >= 20 ? length/5 : 4, length >= 20 ? length/10 : 2, thickness);
+        vpDisplay::displayArrow(_I, it->get_i(), it->get_j(), (int)(it->get_i() + length * cos(deltaNormalized)),
+                                (int)(it->get_j() + length * sin(deltaNormalized)), vpColor::blue,
+                                length >= 20 ? length / 5 : 4, length >= 20 ? length / 10 : 2, thickness);
         if (angle1 < angle2) {
-          vpDisplay::displayArrow(_I, it->get_i(), it->get_j(), (int)(it->get_i() + length*cos(angle)),
-                                  (int)(it->get_j() + length*sin(angle)), vpColor::red,
-                                  length >= 20 ? length/5 : 4, length >= 20 ? length/10 : 2, thickness);
+          vpDisplay::displayArrow(_I, it->get_i(), it->get_j(), (int)(it->get_i() + length * cos(angle)),
+                                  (int)(it->get_j() + length * sin(angle)), vpColor::red, length >= 20 ? length / 5 : 4,
+                                  length >= 20 ? length / 10 : 2, thickness);
         } else {
-          vpDisplay::displayArrow(_I, it->get_i(), it->get_j(), (int)(it->get_i() + length*cos(angle+M_PI)),
-                                  (int)(it->get_j() + length*sin(angle+M_PI)), vpColor::red,
-                                  length >= 20 ? length/5 : 4, length >= 20 ? length/10 : 2, thickness);
+          vpDisplay::displayArrow(_I, it->get_i(), it->get_j(), (int)(it->get_i() + length * cos(angle + M_PI)),
+                                  (int)(it->get_j() + length * sin(angle + M_PI)), vpColor::red,
+                                  length >= 20 ? length / 5 : 4, length >= 20 ? length / 10 : 2, thickness);
         }
       }
 
