@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * Hybrid tracker based on edges (vpMbt) and points of interests (KLT)
  *
- * Authors:
- * Romain Tallonneau
- * Aurelien Yol
- *
- *****************************************************************************/
+*****************************************************************************/
 
 //#define VP_DEBUG_MODE 1 // Activate debug level 1
 
@@ -45,7 +41,7 @@
 #include <visp3/mbt/vpMbEdgeKltTracker.h>
 #include <visp3/mbt/vpMbtXmlGenericParser.h>
 
-#if defined(VISP_HAVE_MODULE_KLT) && (defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100))
+#if defined(VISP_HAVE_MODULE_KLT) && defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_VIDEO)
 
 vpMbEdgeKltTracker::vpMbEdgeKltTracker()
   : m_thresholdKLT(2.), m_thresholdMBT(2.), m_maxIterKlt(30), m_w_mbt(), m_w_klt(), m_error_hybrid(), m_w_hybrid()
@@ -64,7 +60,7 @@ vpMbEdgeKltTracker::vpMbEdgeKltTracker()
   Basic constructor
 
 */
-vpMbEdgeKltTracker::~vpMbEdgeKltTracker() {}
+vpMbEdgeKltTracker::~vpMbEdgeKltTracker() { }
 
 /*!
   Initialization of the tracker using a known initial pose.
@@ -193,7 +189,7 @@ unsigned int vpMbEdgeKltTracker::initMbtTracking(unsigned int lvl)
   }
 
   for (std::list<vpMbtDistanceCylinder *>::const_iterator it = cylinders[lvl].begin(); it != cylinders[lvl].end();
-       ++it) {
+    ++it) {
     vpMbtDistanceCylinder *cy = *it;
 
     if (cy->isTracked()) {
@@ -238,7 +234,8 @@ unsigned int vpMbEdgeKltTracker::initMbtTracking(unsigned int lvl)
       <tracking>10</tracking>
     </range>
     <contrast>
-      <edge_threshold>7000</edge_threshold>
+      <edge_threshold_type>1</edge_threshold_type>
+      <edge_threshold>20</edge_threshold>
       <mu1>0.5</mu1>
       <mu2>0.5</mu2>
     </contrast>
@@ -301,7 +298,8 @@ void vpMbEdgeKltTracker::loadConfigFile(const std::string &configFile, bool verb
       std::cout << " *********** Parsing XML for Mb Edge KLT Tracker ************ " << std::endl;
     }
     xmlp.parse(configFile.c_str());
-  } catch (...) {
+  }
+  catch (...) {
     vpERROR_TRACE("Can't open XML file \"%s\"\n ", configFile.c_str());
     throw vpException(vpException::ioError, "problem to parse configuration file.");
   }
@@ -356,7 +354,7 @@ void vpMbEdgeKltTracker::loadConfigFile(const std::string &configFile, bool verb
   Realize the post tracking operations. Mostly visibility tests
 */
 bool vpMbEdgeKltTracker::postTracking(const vpImage<unsigned char> &I, vpColVector &w_mbt, vpColVector &w_klt,
-                                      unsigned int lvl)
+  unsigned int lvl)
 {
   postTrackingMbt(w_mbt, lvl);
 
@@ -370,7 +368,7 @@ bool vpMbEdgeKltTracker::postTracking(const vpImage<unsigned char> &I, vpColVect
       }
 
       for (std::list<vpMbtDistanceCylinder *>::const_iterator it = cylinders[lvl].begin(); it != cylinders[lvl].end();
-           ++it) {
+        ++it) {
         vpMbtDistanceCylinder *cy = *it;
         // A cylinder is always visible: #FIXME AY: Still valid?
         if (cy->isTracked())
@@ -412,7 +410,7 @@ bool vpMbEdgeKltTracker::postTracking(const vpImage<unsigned char> &I, vpColVect
   Realize the post tracking operations. Mostly visibility tests
 */
 bool vpMbEdgeKltTracker::postTracking(const vpImage<vpRGBa> &I_color, vpColVector &w_mbt, vpColVector &w_klt,
-                                      unsigned int lvl)
+  unsigned int lvl)
 {
   postTrackingMbt(w_mbt, lvl);
 
@@ -426,7 +424,7 @@ bool vpMbEdgeKltTracker::postTracking(const vpImage<vpRGBa> &I_color, vpColVecto
       }
 
       for (std::list<vpMbtDistanceCylinder *>::const_iterator it = cylinders[lvl].begin(); it != cylinders[lvl].end();
-           ++it) {
+        ++it) {
         vpMbtDistanceCylinder *cy = *it;
         // A cylinder is always visible: #FIXME AY: Still valid?
         if (cy->isTracked())
@@ -523,7 +521,7 @@ void vpMbEdgeKltTracker::postTrackingMbt(vpColVector &w, unsigned int lvl)
   // Same thing with cylinders as with lines
   vpMbtDistanceCylinder *cy;
   for (std::list<vpMbtDistanceCylinder *>::const_iterator it = cylinders[lvl].begin(); it != cylinders[lvl].end();
-       ++it) {
+    ++it) {
     if ((*it)->isTracked()) {
       cy = *it;
       double wmean = 0;
@@ -628,22 +626,25 @@ void vpMbEdgeKltTracker::postTrackingMbt(vpColVector &w, unsigned int lvl)
 }
 
 /*!
-  Realize the VVS loop for the tracking
+  Achieve the VVS loop for the tracking using edges and KLT keypoints as visual features.
 
-  \param I : current image.
-  \param nbInfos : Size of the features (KLT).
-  \param nbrow : Size of the features (Edge).
-  \param lvl : level of the pyramid.
+  \param[in] I : current image.
+  \param[in] nbInfos : Size of the features (KLT).
+  \param[out] nbrow : Size of the features (Edge).
+  \param[in] lvl : Level of the pyramid.
+  \param[out] edge_residual : Residual considering edges as visual features.
+  \param[out] klt_residual : Residual considering KLT keypoints as visual features.
 */
 void vpMbEdgeKltTracker::computeVVS(const vpImage<unsigned char> &I, const unsigned int &nbInfos, unsigned int &nbrow,
-                                    unsigned int lvl)
+  unsigned int lvl, double *edge_residual, double *klt_residual)
 {
   vpColVector factor;
   nbrow = trackFirstLoop(I, factor, lvl);
 
   if (nbrow < 4 && nbInfos < 4) {
     throw vpTrackingException(vpTrackingException::notEnoughPointError, "Error: not enough features");
-  } else if (nbrow < 4)
+  }
+  else if (nbrow < 4)
     nbrow = 0;
 
   unsigned int totalNbRows = nbrow + 2 * nbInfos;
@@ -689,14 +690,20 @@ void vpMbEdgeKltTracker::computeVVS(const vpImage<unsigned char> &I, const unsig
   if (nbInfos < 4)
     factorMBT = 1.;
 
-  double residuMBT = 0;
-  double residuKLT = 0;
+  if (edge_residual != NULL)
+    *edge_residual = 0;
+  if (klt_residual != NULL)
+    *klt_residual = 0;
 
   vpHomogeneousMatrix cMoPrev;
   vpHomogeneousMatrix ctTc0_Prev;
   vpColVector m_error_prev;
   vpColVector m_w_prev;
 
+  bool isoJoIdentity = m_isoJoIdentity; // Backup since it can be modified if L is not full rank
+  if (isoJoIdentity)
+    oJo.eye();
+
   // Init size
   m_error_hybrid.resize(totalNbRows, false);
   m_w_hybrid.resize(totalNbRows, false);
@@ -721,7 +728,7 @@ void vpMbEdgeKltTracker::computeVVS(const vpImage<unsigned char> &I, const unsig
       unsigned int shift = 0;
 
       for (std::list<vpMbtDistanceKltPoints *>::const_iterator it = vpMbKltTracker::kltPolygons.begin();
-           it != vpMbKltTracker::kltPolygons.end(); ++it) {
+        it != vpMbKltTracker::kltPolygons.end(); ++it) {
         vpMbtDistanceKltPoints *kltpoly = *it;
         if (kltpoly->polygon->isVisible() && kltpoly->isTracked() && kltpoly->hasEnoughPoints()) {
           vpSubColVector subR(R_klt, shift, 2 * kltpoly->getCurrentNumberPoints());
@@ -733,7 +740,7 @@ void vpMbEdgeKltTracker::computeVVS(const vpImage<unsigned char> &I, const unsig
       }
 
       for (std::list<vpMbtDistanceKltCylinder *>::const_iterator it = kltCylinders.begin(); it != kltCylinders.end();
-           ++it) {
+        ++it) {
         vpMbtDistanceKltCylinder *kltPolyCylinder = *it;
 
         if (kltPolyCylinder->isTracked() && kltPolyCylinder->hasEnoughPoints()) {
@@ -741,7 +748,8 @@ void vpMbEdgeKltTracker::computeVVS(const vpImage<unsigned char> &I, const unsig
           vpSubMatrix subL(L_klt, shift, 0, 2 * kltPolyCylinder->getCurrentNumberPoints(), 6);
           try {
             kltPolyCylinder->computeInteractionMatrixAndResidu(ctTc0, subR, subL);
-          } catch (...) {
+          }
+          catch (...) {
             throw vpTrackingException(vpTrackingException::fatalError, "Cannot compute interaction matrix");
           }
 
@@ -763,7 +771,8 @@ void vpMbEdgeKltTracker::computeVVS(const vpImage<unsigned char> &I, const unsig
     while (cpt < (nbrow + 2 * nbInfos)) {
       if (cpt < (unsigned)nbrow) {
         m_w_hybrid[cpt] = ((m_w_mbt[cpt] * factor[cpt]) * factorMBT);
-      } else {
+      }
+      else {
         m_w_hybrid[cpt] = (m_w_klt[cpt - nbrow] * factorKLT);
       }
       cpt++;
@@ -771,7 +780,7 @@ void vpMbEdgeKltTracker::computeVVS(const vpImage<unsigned char> &I, const unsig
 
     bool reStartFromLastIncrement = false;
     computeVVSCheckLevenbergMarquardt(iter, m_error_hybrid, m_error_prev, cMoPrev, mu, reStartFromLastIncrement,
-                                      &m_w_prev);
+      &m_w_prev);
     if (reStartFromLastIncrement) {
       ctTc0 = ctTc0_Prev;
     }
@@ -779,10 +788,12 @@ void vpMbEdgeKltTracker::computeVVS(const vpImage<unsigned char> &I, const unsig
     if (!reStartFromLastIncrement) {
       /* robust */
       if (nbrow > 3) {
-        residuMBT = 0;
-        for (unsigned int i = 0; i < R_mbt.getRows(); i++)
-          residuMBT += fabs(R_mbt[i]);
-        residuMBT /= R_mbt.getRows();
+        if (edge_residual != NULL) {
+          *edge_residual = 0;
+          for (unsigned int i = 0; i < R_mbt.getRows(); i++)
+            *edge_residual += fabs(R_mbt[i]);
+          *edge_residual /= R_mbt.getRows();
+        }
 
         robust_mbt.setMinMedianAbsoluteDeviation(m_thresholdMBT / m_cam.get_px());
         robust_mbt.MEstimator(vpRobust::TUKEY, R_mbt, m_w_mbt);
@@ -791,10 +802,12 @@ void vpMbEdgeKltTracker::computeVVS(const vpImage<unsigned char> &I, const unsig
       }
 
       if (nbInfos > 3) {
-        residuKLT = 0;
-        for (unsigned int i = 0; i < R_klt.getRows(); i++)
-          residuKLT += fabs(R_klt[i]);
-        residuKLT /= R_klt.getRows();
+        if (klt_residual != NULL) {
+          *klt_residual = 0;
+          for (unsigned int i = 0; i < R_klt.getRows(); i++)
+            *klt_residual += fabs(R_klt[i]);
+          *klt_residual /= R_klt.getRows();
+        }
 
         robust_klt.setMinMedianAbsoluteDeviation(m_thresholdKLT / m_cam.get_px());
         robust_klt.MEstimator(vpRobust::TUKEY, R_klt, m_w_klt);
@@ -806,7 +819,8 @@ void vpMbEdgeKltTracker::computeVVS(const vpImage<unsigned char> &I, const unsig
       while (cpt < (nbrow + 2 * nbInfos)) {
         if (cpt < (unsigned)nbrow) {
           m_w_hybrid[cpt] = ((m_w_mbt[cpt] * factor[cpt]) * factorMBT);
-        } else {
+        }
+        else {
           m_w_hybrid[cpt] = (m_w_klt[cpt - nbrow] * factorKLT);
         }
         cpt++;
@@ -841,7 +855,7 @@ void vpMbEdgeKltTracker::computeVVS(const vpImage<unsigned char> &I, const unsig
       residu = sqrt(num / den);
 
       computeVVSPoseEstimation(isoJoIdentity, iter, L, LTL, weighted_error, m_error_hybrid, m_error_prev, LTR, mu, v,
-                               &m_w_hybrid, &m_w_prev);
+        &m_w_hybrid, &m_w_prev);
 
       cMoPrev = m_cMo;
       ctTc0_Prev = ctTc0;
@@ -863,8 +877,8 @@ void vpMbEdgeKltTracker::computeVVSInit()
 void vpMbEdgeKltTracker::computeVVSInteractionMatrixAndResidu()
 {
   throw vpException(vpException::fatalError, "vpMbEdgeKltTracker::"
-                                             "computeVVSInteractionMatrixAndR"
-                                             "esidu() should not be called!");
+    "computeVVSInteractionMatrixAndR"
+    "esidu() should not be called!");
 }
 
 /*!
@@ -878,7 +892,8 @@ void vpMbEdgeKltTracker::track(const vpImage<unsigned char> &I)
 {
   try {
     vpMbKltTracker::preTracking(I);
-  } catch (...) {
+  }
+  catch (...) {
   }
 
   if (m_nbInfos >= 4) {
@@ -886,7 +901,8 @@ void vpMbEdgeKltTracker::track(const vpImage<unsigned char> &I)
     m_maxIter = m_maxIterKlt;
     vpMbKltTracker::computeVVS();
     m_maxIter = old_maxIter;
-  } else {
+  }
+  else {
     m_nbInfos = 0;
     // std::cout << "[Warning] Unable to init with KLT" << std::endl;
   }
@@ -934,7 +950,8 @@ void vpMbEdgeKltTracker::track(const vpImage<vpRGBa> &I_color)
   vpImageConvert::convert(I_color, m_I);
   try {
     vpMbKltTracker::preTracking(m_I);
-  } catch (...) {
+  }
+  catch (...) {
   }
 
   if (m_nbInfos >= 4) {
@@ -942,7 +959,8 @@ void vpMbEdgeKltTracker::track(const vpImage<vpRGBa> &I_color)
     m_maxIter = m_maxIterKlt;
     vpMbKltTracker::computeVVS();
     m_maxIter = old_maxIter;
-  } else {
+  }
+  else {
     m_nbInfos = 0;
     // std::cout << "[Warning] Unable to init with KLT" << std::endl;
   }
@@ -978,8 +996,7 @@ void vpMbEdgeKltTracker::track(const vpImage<vpRGBa> &I_color)
   }
 }
 
-unsigned int vpMbEdgeKltTracker::trackFirstLoop(const vpImage<unsigned char> &I, vpColVector &factor,
-                                                unsigned int lvl)
+unsigned int vpMbEdgeKltTracker::trackFirstLoop(const vpImage<unsigned char> &I, vpColVector &factor, unsigned int lvl)
 {
   vpMbtDistanceLine *l;
   vpMbtDistanceCylinder *cy;
@@ -1008,7 +1025,7 @@ unsigned int vpMbEdgeKltTracker::trackFirstLoop(const vpImage<unsigned char> &I,
 
       double fac = 1;
       for (std::list<int>::const_iterator itindex = l->Lindex_polygon.begin(); itindex != l->Lindex_polygon.end();
-           ++itindex) {
+        ++itindex) {
         int index = *itindex;
         if (l->hiddenface->isAppearing((unsigned int)index)) {
           fac = 0.2;
@@ -1020,7 +1037,6 @@ unsigned int vpMbEdgeKltTracker::trackFirstLoop(const vpImage<unsigned char> &I,
         }
       }
 
-      unsigned int indexFeature = 0;
       for (size_t a = 0; a < l->meline.size(); a++) {
         std::list<vpMeSite>::const_iterator itListLine;
         if (l->meline[a] != NULL) {
@@ -1032,7 +1048,6 @@ unsigned int vpMbEdgeKltTracker::trackFirstLoop(const vpImage<unsigned char> &I,
             if (site.getState() != vpMeSite::NO_SUPPRESSION)
               factor[n + i] = 0.2;
             ++itListLine;
-            indexFeature++;
           }
           n += l->nbFeature[a];
         }
@@ -1041,7 +1056,7 @@ unsigned int vpMbEdgeKltTracker::trackFirstLoop(const vpImage<unsigned char> &I,
   }
 
   for (std::list<vpMbtDistanceCylinder *>::const_iterator it = cylinders[lvl].begin(); it != cylinders[lvl].end();
-       ++it) {
+    ++it) {
     if ((*it)->isTracked()) {
       cy = *it;
       cy->computeInteractionMatrixError(m_cMo, I);
@@ -1060,7 +1075,8 @@ unsigned int vpMbEdgeKltTracker::trackFirstLoop(const vpImage<unsigned char> &I,
         if (i < cy->nbFeaturel1) {
           site = *itCyl1;
           ++itCyl1;
-        } else {
+        }
+        else {
           site = *itCyl2;
           ++itCyl2;
         }
@@ -1099,7 +1115,7 @@ unsigned int vpMbEdgeKltTracker::trackFirstLoop(const vpImage<unsigned char> &I,
 }
 
 void vpMbEdgeKltTracker::trackSecondLoop(const vpImage<unsigned char> &I, vpMatrix &L, vpColVector &error,
-                                         const vpHomogeneousMatrix &cMo, unsigned int lvl)
+  const vpHomogeneousMatrix &cMo, unsigned int lvl)
 {
   vpMbtDistanceLine *l;
   vpMbtDistanceCylinder *cy;
@@ -1121,7 +1137,7 @@ void vpMbEdgeKltTracker::trackSecondLoop(const vpImage<unsigned char> &I, vpMatr
   }
 
   for (std::list<vpMbtDistanceCylinder *>::const_iterator it = cylinders[lvl].begin(); it != cylinders[lvl].end();
-       ++it) {
+    ++it) {
     if ((*it)->isTracked()) {
       cy = *it;
       cy->computeInteractionMatrixError(cMo, I);
@@ -1196,8 +1212,8 @@ void vpMbEdgeKltTracker::initFaceFromLines(vpMbtPolygon &polygon)
   circle. \param radius : Radius of the circle. \param idFace : Id of the face
   associated to the circle. \param name : The optional name of the circle.
 */
-void vpMbEdgeKltTracker::initCircle(const vpPoint &p1, const vpPoint &p2, const vpPoint &p3, double radius,
-                                    int idFace, const std::string &name)
+void vpMbEdgeKltTracker::initCircle(const vpPoint &p1, const vpPoint &p2, const vpPoint &p3, double radius, int idFace,
+  const std::string &name)
 {
   vpMbEdgeTracker::initCircle(p1, p2, p3, radius, idFace, name);
 }
@@ -1213,7 +1229,7 @@ void vpMbEdgeKltTracker::initCircle(const vpPoint &p1, const vpPoint &p2, const
   \param name : The optional name of the cylinder.
 */
 void vpMbEdgeKltTracker::initCylinder(const vpPoint &p1, const vpPoint &p2, double radius, int idFace,
-                                      const std::string &name)
+  const std::string &name)
 {
   vpMbEdgeTracker::initCylinder(p1, p2, radius, idFace, name);
   vpMbKltTracker::initCylinder(p1, p2, radius, idFace, name);
@@ -1231,17 +1247,19 @@ void vpMbEdgeKltTracker::initCylinder(const vpPoint &p1, const vpPoint &p2, doub
   displayed, even the faces that are not visible.
 */
 void vpMbEdgeKltTracker::display(const vpImage<unsigned char> &I, const vpHomogeneousMatrix &cMo,
-                                 const vpCameraParameters &cam, const vpColor &col, unsigned int thickness,
-                                 bool displayFullModel)
+  const vpCameraParameters &cam, const vpColor &col, unsigned int thickness,
+  bool displayFullModel)
 {
-  std::vector<std::vector<double> > models = vpMbEdgeKltTracker::getModelForDisplay(I.getWidth(), I.getHeight(), cMo, cam, displayFullModel);
+  std::vector<std::vector<double> > models =
+    vpMbEdgeKltTracker::getModelForDisplay(I.getWidth(), I.getHeight(), cMo, cam, displayFullModel);
 
   for (size_t i = 0; i < models.size(); i++) {
     if (vpMath::equal(models[i][0], 0)) {
       vpImagePoint ip1(models[i][1], models[i][2]);
       vpImagePoint ip2(models[i][3], models[i][4]);
       vpDisplay::displayLine(I, ip1, ip2, col, thickness);
-    } else if (vpMath::equal(models[i][0], 1)) {
+    }
+    else if (vpMath::equal(models[i][0], 1)) {
       vpImagePoint center(models[i][1], models[i][2]);
       double n20 = models[i][3];
       double n11 = models[i][4];
@@ -1283,17 +1301,19 @@ void vpMbEdgeKltTracker::display(const vpImage<unsigned char> &I, const vpHomoge
   displayed, even the faces that are not visible.
 */
 void vpMbEdgeKltTracker::display(const vpImage<vpRGBa> &I, const vpHomogeneousMatrix &cMo,
-                                 const vpCameraParameters &cam, const vpColor &col, unsigned int thickness,
-                                 bool displayFullModel)
+  const vpCameraParameters &cam, const vpColor &col, unsigned int thickness,
+  bool displayFullModel)
 {
-  std::vector<std::vector<double> > models = getModelForDisplay(I.getWidth(), I.getHeight(), cMo, cam, displayFullModel);
+  std::vector<std::vector<double> > models =
+    getModelForDisplay(I.getWidth(), I.getHeight(), cMo, cam, displayFullModel);
 
   for (size_t i = 0; i < models.size(); i++) {
     if (vpMath::equal(models[i][0], 0)) {
       vpImagePoint ip1(models[i][1], models[i][2]);
       vpImagePoint ip2(models[i][3], models[i][4]);
       vpDisplay::displayLine(I, ip1, ip2, col, thickness);
-    } else if (vpMath::equal(models[i][0], 1)) {
+    }
+    else if (vpMath::equal(models[i][0], 1)) {
       vpImagePoint center(models[i][1], models[i][2]);
       double n20 = models[i][3];
       double n11 = models[i][4];
@@ -1324,30 +1344,30 @@ void vpMbEdgeKltTracker::display(const vpImage<vpRGBa> &I, const vpHomogeneousMa
 }
 
 std::vector<std::vector<double> > vpMbEdgeKltTracker::getModelForDisplay(unsigned int width, unsigned int height,
-                                                                         const vpHomogeneousMatrix &cMo,
-                                                                         const vpCameraParameters &cam,
-                                                                         bool displayFullModel)
+  const vpHomogeneousMatrix &cMo,
+  const vpCameraParameters &cam,
+  bool displayFullModel)
 {
   std::vector<std::vector<double> > models;
 
   for (unsigned int i = 0; i < scales.size(); i += 1) {
     if (scales[i]) {
       for (std::list<vpMbtDistanceLine *>::const_iterator it = lines[scaleLevel].begin(); it != lines[scaleLevel].end();
-           ++it) {
+        ++it) {
         std::vector<std::vector<double> > currentModel =
           (*it)->getModelForDisplay(width, height, cMo, cam, displayFullModel);
         models.insert(models.end(), currentModel.begin(), currentModel.end());
       }
 
       for (std::list<vpMbtDistanceCylinder *>::const_iterator it = cylinders[scaleLevel].begin();
-           it != cylinders[scaleLevel].end(); ++it) {
+        it != cylinders[scaleLevel].end(); ++it) {
         std::vector<std::vector<double> > currentModel =
           (*it)->getModelForDisplay(width, height, cMo, cam, displayFullModel);
         models.insert(models.end(), currentModel.begin(), currentModel.end());
       }
 
       for (std::list<vpMbtDistanceCircle *>::const_iterator it = circles[scaleLevel].begin();
-           it != circles[scaleLevel].end(); ++it) {
+        it != circles[scaleLevel].end(); ++it) {
         std::vector<double> paramsCircle = (*it)->getModelForDisplay(cMo, cam, displayFullModel);
         models.push_back(paramsCircle);
       }
@@ -1377,103 +1397,96 @@ std::vector<std::vector<double> > vpMbEdgeKltTracker::getModelForDisplay(unsigne
   3D points expressed in the original object frame to the desired object frame.
 */
 void vpMbEdgeKltTracker::reInitModel(const vpImage<unsigned char> &I, const std::string &cad_name,
-                                     const vpHomogeneousMatrix &cMo, bool verbose,
-                                     const vpHomogeneousMatrix &T)
+  const vpHomogeneousMatrix &cMo, bool verbose, const vpHomogeneousMatrix &T)
 {
   // Reinit klt
-  #if (VISP_HAVE_OPENCV_VERSION < 0x020408)
-    if (cur != NULL) {
-      cvReleaseImage(&cur);
-      cur = NULL;
-    }
-  #endif
 
-    // delete the Klt Polygon features
-    for (std::list<vpMbtDistanceKltPoints *>::const_iterator it = kltPolygons.begin(); it != kltPolygons.end(); ++it) {
-      vpMbtDistanceKltPoints *kltpoly = *it;
-      if (kltpoly != NULL) {
-        delete kltpoly;
+  // delete the Klt Polygon features
+  for (std::list<vpMbtDistanceKltPoints *>::const_iterator it = kltPolygons.begin(); it != kltPolygons.end(); ++it) {
+    vpMbtDistanceKltPoints *kltpoly = *it;
+    if (kltpoly != NULL) {
+      delete kltpoly;
+    }
+    kltpoly = NULL;
+  }
+  kltPolygons.clear();
+
+  for (std::list<vpMbtDistanceKltCylinder *>::const_iterator it = kltCylinders.begin(); it != kltCylinders.end();
+    ++it) {
+    vpMbtDistanceKltCylinder *kltPolyCylinder = *it;
+    if (kltPolyCylinder != NULL) {
+      delete kltPolyCylinder;
+    }
+    kltPolyCylinder = NULL;
+  }
+  kltCylinders.clear();
+
+  // delete the structures used to display circles
+  vpMbtDistanceCircle *ci;
+  for (std::list<vpMbtDistanceCircle *>::const_iterator it = circles_disp.begin(); it != circles_disp.end(); ++it) {
+    ci = *it;
+    if (ci != NULL) {
+      delete ci;
+    }
+    ci = NULL;
+  }
+
+  circles_disp.clear();
+
+  firstInitialisation = true;
+
+  // Reinit edge
+  vpMbtDistanceLine *l;
+  vpMbtDistanceCylinder *cy;
+
+  for (unsigned int i = 0; i < scales.size(); i += 1) {
+    if (scales[i]) {
+      for (std::list<vpMbtDistanceLine *>::const_iterator it = lines[i].begin(); it != lines[i].end(); ++it) {
+        l = *it;
+        if (l != NULL)
+          delete l;
+        l = NULL;
       }
-      kltpoly = NULL;
-    }
-    kltPolygons.clear();
 
-    for (std::list<vpMbtDistanceKltCylinder *>::const_iterator it = kltCylinders.begin(); it != kltCylinders.end();
-         ++it) {
-      vpMbtDistanceKltCylinder *kltPolyCylinder = *it;
-      if (kltPolyCylinder != NULL) {
-        delete kltPolyCylinder;
+      for (std::list<vpMbtDistanceCylinder *>::const_iterator it = cylinders[i].begin(); it != cylinders[i].end();
+        ++it) {
+        cy = *it;
+        if (cy != NULL)
+          delete cy;
+        cy = NULL;
       }
-      kltPolyCylinder = NULL;
-    }
-    kltCylinders.clear();
 
-    // delete the structures used to display circles
-    vpMbtDistanceCircle *ci;
-    for (std::list<vpMbtDistanceCircle *>::const_iterator it = circles_disp.begin(); it != circles_disp.end(); ++it) {
-      ci = *it;
-      if (ci != NULL) {
-        delete ci;
+      for (std::list<vpMbtDistanceCircle *>::const_iterator it = circles[i].begin(); it != circles[i].end(); ++it) {
+        ci = *it;
+        if (ci != NULL)
+          delete ci;
+        ci = NULL;
       }
-      ci = NULL;
+
+      lines[i].clear();
+      cylinders[i].clear();
+      circles[i].clear();
     }
+  }
 
-    circles_disp.clear();
+  // compute_interaction=1;
+  nline = 0;
+  ncylinder = 0;
+  ncircle = 0;
+  // lambda = 1;
+  nbvisiblepolygone = 0;
 
-    firstInitialisation = true;
+  // Reinit common parts
+  faces.reset();
 
-    // Reinit edge
-    vpMbtDistanceLine *l;
-    vpMbtDistanceCylinder *cy;
+  loadModel(cad_name, verbose, T);
 
-    for (unsigned int i = 0; i < scales.size(); i += 1) {
-      if (scales[i]) {
-        for (std::list<vpMbtDistanceLine *>::const_iterator it = lines[i].begin(); it != lines[i].end(); ++it) {
-          l = *it;
-          if (l != NULL)
-            delete l;
-          l = NULL;
-        }
-
-        for (std::list<vpMbtDistanceCylinder *>::const_iterator it = cylinders[i].begin(); it != cylinders[i].end();
-             ++it) {
-          cy = *it;
-          if (cy != NULL)
-            delete cy;
-          cy = NULL;
-        }
-
-        for (std::list<vpMbtDistanceCircle *>::const_iterator it = circles[i].begin(); it != circles[i].end(); ++it) {
-          ci = *it;
-          if (ci != NULL)
-            delete ci;
-          ci = NULL;
-        }
-
-        lines[i].clear();
-        cylinders[i].clear();
-        circles[i].clear();
-      }
-    }
-
-    // compute_interaction=1;
-    nline = 0;
-    ncylinder = 0;
-    ncircle = 0;
-    // lambda = 1;
-    nbvisiblepolygone = 0;
-
-    // Reinit common parts
-    faces.reset();
-
-    loadModel(cad_name, verbose, T);
-
-    m_cMo = cMo;
-    init(I);
+  m_cMo = cMo;
+  init(I);
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_mbt.a(vpMbEdgeKltTracker.cpp.o) has
+// Work around to avoid warning: libvisp_mbt.a(vpMbEdgeKltTracker.cpp.o) has
 // no symbols
-void dummy_vpMbEdgeKltTracker(){};
+void dummy_vpMbEdgeKltTracker() { };
 #endif // VISP_HAVE_OPENCV
