@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,11 +31,7 @@
  * Description:
  * Model based tracker using only KLT
  *
- * Authors:
- * Romain Tallonneau
- * Aurelien Yol
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpImageConvert.h>
 #include <visp3/core/vpTrackingException.h>
@@ -43,17 +39,18 @@
 #include <visp3/mbt/vpMbKltTracker.h>
 #include <visp3/mbt/vpMbtXmlGenericParser.h>
 
-#if defined(VISP_HAVE_MODULE_KLT) && (defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100))
+#if defined(VISP_HAVE_MODULE_KLT) && defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_VIDEO)
 
 #if defined(__APPLE__) && defined(__MACH__) // Apple OSX and iOS (Darwin)
 #include <TargetConditionals.h>             // To detect OSX or IOS using TARGET_OS_IPHONE or TARGET_OS_IOS macro
 #endif
 
-namespace {
+namespace
+{
 /*!
  * Transform an homography from calibrated domain to pixel space.
  *
- * Given homography \f$\bf H\f$ in the Euclidian space or in the calibrated domain,
+ * Given homography \f$\bf H\f$ in the Euclidean space or in the calibrated domain,
  * compute the homography \f$\bf G\f$ corresponding to the collineation matrix in the pixel space using:
  * \f[ {\bf G} = {\bf K} {\bf H} {\bf K}^{-1} \f]
  * \param[in] H : Homography in the calibrated domain.
@@ -102,20 +99,15 @@ vpMatrix homography2collineation(const vpMatrix &H, const vpCameraParameters &ca
 
   G[0][2] = -A * u0_one_over_px - B * v0_one_over_py + C;
   G[1][2] = -D * u0_one_over_px - E * v0_one_over_py + F;
-  G[2][2] = - h20 * u0_one_over_px - h21 * v0_one_over_py + h22;
+  G[2][2] = -h20 * u0_one_over_px - h21 * v0_one_over_py + h22;
 
   return G;
 }
-}
+} // namespace
 
 vpMbKltTracker::vpMbKltTracker()
   :
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020408)
-    cur(),
-#else
-    cur(NULL),
-#endif
-    c0Mo(), firstInitialisation(true), maskBorder(5), threshold_outlier(0.5), percentGood(0.6), ctTc0(), tracker(),
+    cur(), c0Mo(), firstInitialisation(true), maskBorder(5), threshold_outlier(0.5), percentGood(0.6), ctTc0(), tracker(),
     kltPolygons(), kltCylinders(), circles_disp(), m_nbInfos(0), m_nbFaceUsed(0), m_L_klt(), m_error_klt(), m_w_klt(),
     m_weightedError_klt(), m_robust_klt(), m_featuresToBeDisplayedKlt()
 {
@@ -143,13 +135,6 @@ vpMbKltTracker::vpMbKltTracker()
 */
 vpMbKltTracker::~vpMbKltTracker()
 {
-#if (VISP_HAVE_OPENCV_VERSION < 0x020408)
-  if (cur != NULL) {
-    cvReleaseImage(&cur);
-    cur = NULL;
-  }
-#endif
-
   // delete the Klt Polygon features
   for (std::list<vpMbtDistanceKltPoints *>::const_iterator it = kltPolygons.begin(); it != kltPolygons.end(); ++it) {
     vpMbtDistanceKltPoints *kltpoly = *it;
@@ -226,13 +211,8 @@ void vpMbKltTracker::reinit(const vpImage<unsigned char> &I)
     faces.computeScanLineRender(m_cam, I.getWidth(), I.getHeight());
   }
 
-// mask
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020408)
+  // mask
   cv::Mat mask((int)I.getRows(), (int)I.getCols(), CV_8UC1, cv::Scalar(0));
-#else
-  IplImage *mask = cvCreateImage(cvSize((int)I.getWidth(), (int)I.getHeight()), IPL_DEPTH_8U, 1);
-  cvZero(mask);
-#endif
 
   vpMbtDistanceKltPoints *kltpoly;
   vpMbtDistanceKltCylinder *kltPolyCylinder;
@@ -288,10 +268,6 @@ void vpMbKltTracker::reinit(const vpImage<unsigned char> &I)
     if (kltPolyCylinder->isTracked())
       kltPolyCylinder->init(tracker, m_cMo);
   }
-
-#if (VISP_HAVE_OPENCV_VERSION < 0x020408)
-  cvReleaseImage(&mask);
-#endif
 }
 
 /*!
@@ -302,13 +278,6 @@ void vpMbKltTracker::resetTracker()
 {
   m_cMo.eye();
 
-#if (VISP_HAVE_OPENCV_VERSION < 0x020408)
-  if (cur != NULL) {
-    cvReleaseImage(&cur);
-    cur = NULL;
-  }
-#endif
-
   // delete the Klt Polygon features
   for (std::list<vpMbtDistanceKltPoints *>::const_iterator it = kltPolygons.begin(); it != kltPolygons.end(); ++it) {
     vpMbtDistanceKltPoints *kltpoly = *it;
@@ -414,7 +383,7 @@ std::map<int, vpImagePoint> vpMbKltTracker::getKltImagePointsWithId() const
     long id;
     float x_tmp, y_tmp;
     tracker.getFeature((int)i, id, x_tmp, y_tmp);
-#if TARGET_OS_IPHONE
+#ifdef TARGET_OS_IPHONE
     kltPoints[(int)id] = vpImagePoint(y_tmp, x_tmp);
 #else
     kltPoints[id] = vpImagePoint(y_tmp, x_tmp);
@@ -465,7 +434,7 @@ void vpMbKltTracker::setCameraParameters(const vpCameraParameters &cam)
   m_cam = cam;
 }
 
-void vpMbKltTracker::setPose(const vpImage<unsigned char> * const I, const vpImage<vpRGBa> * const I_color,
+void vpMbKltTracker::setPose(const vpImage<unsigned char> *const I, const vpImage<vpRGBa> *const I_color,
                              const vpHomogeneousMatrix &cdMo)
 {
   if (I_color) {
@@ -486,26 +455,9 @@ void vpMbKltTracker::setPose(const vpImage<unsigned char> * const I, const vpIma
   } else {
     vpMbtDistanceKltPoints *kltpoly;
 
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020408)
     std::vector<cv::Point2f> init_pts;
     std::vector<long> init_ids;
     std::vector<cv::Point2f> guess_pts;
-#else
-    unsigned int nbp = 0;
-    for (std::list<vpMbtDistanceKltPoints *>::const_iterator it = kltPolygons.begin(); it != kltPolygons.end(); ++it) {
-      kltpoly = *it;
-      if (kltpoly->polygon->isVisible() && kltpoly->polygon->getNbPoint() > 2)
-        nbp += (*it)->getCurrentNumberPoints();
-    }
-
-    CvPoint2D32f *init_pts = NULL;
-    init_pts = (CvPoint2D32f *)cvAlloc(tracker.getMaxFeatures() * sizeof(init_pts[0]));
-    long *init_ids = (long *)cvAlloc((unsigned int)tracker.getMaxFeatures() * sizeof(long));
-    unsigned int iter_pts = 0;
-
-    CvPoint2D32f *guess_pts = NULL;
-    guess_pts = (CvPoint2D32f *)cvAlloc(tracker.getMaxFeatures() * sizeof(guess_pts[0]));
-#endif
 
     vpHomogeneousMatrix cdMc = cdMo * m_cMo.inverse();
     vpHomogeneousMatrix cMcd = cdMc.inverse();
@@ -545,8 +497,7 @@ void vpMbKltTracker::setPose(const vpImage<unsigned char> * const I, const vpIma
         std::map<int, vpImagePoint>::const_iterator iter = kltpoly->getCurrentPoints().begin();
         // nbCur+= (unsigned int)kltpoly->getCurrentPoints().size();
         for (; iter != kltpoly->getCurrentPoints().end(); ++iter) {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020408)
-#if TARGET_OS_IPHONE
+#ifdef TARGET_OS_IPHONE
           if (std::find(init_ids.begin(), init_ids.end(), (long)(kltpoly->getCurrentPointsInd())[(int)iter->first]) !=
               init_ids.end())
 #else
@@ -558,26 +509,19 @@ void vpMbKltTracker::setPose(const vpImage<unsigned char> * const I, const vpIma
             // vpMbtDistanceKltPoints due to possible overlapping faces)
             continue;
           }
-#endif
 
           vpColVector cdp(3);
           cdp[0] = iter->second.get_j();
           cdp[1] = iter->second.get_i();
           cdp[2] = 1.0;
 
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020408)
           cv::Point2f p((float)cdp[0], (float)cdp[1]);
           init_pts.push_back(p);
-#if TARGET_OS_IPHONE
+#ifdef TARGET_OS_IPHONE
           init_ids.push_back((size_t)(kltpoly->getCurrentPointsInd())[(int)iter->first]);
 #else
           init_ids.push_back((size_t)(kltpoly->getCurrentPointsInd())[(size_t)iter->first]);
 #endif
-#else
-          init_pts[iter_pts].x = (float)cdp[0];
-          init_pts[iter_pts].y = (float)cdp[1];
-          init_ids[iter_pts] = (kltpoly->getCurrentPointsInd())[(size_t)iter->first];
-#endif
 
           double p_mu_t_2 = cdp[0] * cdGc[2][0] + cdp[1] * cdGc[2][1] + cdGc[2][2];
 
@@ -590,14 +534,9 @@ void vpMbKltTracker::setPose(const vpImage<unsigned char> * const I, const vpIma
           cdp[0] = (cdp[0] * cdGc[0][0] + cdp[1] * cdGc[0][1] + cdGc[0][2]) / p_mu_t_2;
           cdp[1] = (cdp[0] * cdGc[1][0] + cdp[1] * cdGc[1][1] + cdGc[1][2]) / p_mu_t_2;
 
-// Set value to the KLT tracker
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020408)
+          // Set value to the KLT tracker
           cv::Point2f p_guess((float)cdp[0], (float)cdp[1]);
           guess_pts.push_back(p_guess);
-#else
-          guess_pts[iter_pts].x = (float)cdp[0];
-          guess_pts[iter_pts++].y = (float)cdp[1];
-#endif
         }
       }
     }
@@ -608,23 +547,7 @@ void vpMbKltTracker::setPose(const vpImage<unsigned char> * const I, const vpIma
       vpImageConvert::convert(m_I, cur);
     }
 
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020408)
     tracker.setInitialGuess(init_pts, guess_pts, init_ids);
-#else
-    tracker.setInitialGuess(&init_pts, &guess_pts, init_ids, iter_pts);
-
-    if (init_pts)
-      cvFree(&init_pts);
-    init_pts = NULL;
-
-    if (guess_pts)
-      cvFree(&guess_pts);
-    guess_pts = NULL;
-
-    if (init_ids)
-      cvFree(&init_ids);
-    init_ids = NULL;
-#endif
 
     bool reInitialisation = false;
     if (!useOgre) {
@@ -636,9 +559,11 @@ void vpMbKltTracker::setPose(const vpImage<unsigned char> * const I, const vpIma
     } else {
 #ifdef VISP_HAVE_OGRE
       if (I) {
-        faces.setVisibleOgre(I->getWidth(), I->getHeight(), m_cam, cdMo, angleAppears, angleDisappears, reInitialisation);
+        faces.setVisibleOgre(I->getWidth(), I->getHeight(), m_cam, cdMo, angleAppears, angleDisappears,
+                             reInitialisation);
       } else {
-        faces.setVisibleOgre(m_I.getWidth(), m_I.getHeight(), m_cam, cdMo, angleAppears, angleDisappears, reInitialisation);
+        faces.setVisibleOgre(m_I.getWidth(), m_I.getHeight(), m_cam, cdMo, angleAppears, angleDisappears,
+                             reInitialisation);
       }
 #else
       if (I) {
@@ -862,6 +787,10 @@ void vpMbKltTracker::computeVVS()
   double normRes_1 = -1;
   unsigned int iter = 0;
 
+  bool isoJoIdentity = m_isoJoIdentity; // Backup since it can be modified if L is not full rank
+  if (isoJoIdentity)
+    oJo.eye();
+
   vpMbKltTracker::computeVVSInit();
 
   while (((int)((normRes - normRes_1) * 1e8) != 0) && (iter < m_maxIter)) {
@@ -901,8 +830,7 @@ void vpMbKltTracker::computeVVS()
         }
       }
 
-      computeVVSPoseEstimation(isoJoIdentity, iter, m_L_klt, LTL, m_weightedError_klt, m_error_klt, error_prev, LTR, mu,
-                               v);
+      computeVVSPoseEstimation(m_isoJoIdentity, iter, m_L_klt, LTL, m_weightedError_klt, m_error_klt, error_prev, LTR, mu, v);
 
       cMoPrev = m_cMo;
       ctTc0_Prev = ctTc0;
@@ -913,7 +841,7 @@ void vpMbKltTracker::computeVVS()
     iter++;
   }
 
-  computeCovarianceMatrixVVS(isoJoIdentity, m_w_klt, cMoPrev, L_true, LVJ_true, m_error_klt);
+  computeCovarianceMatrixVVS(m_isoJoIdentity, m_w_klt, cMoPrev, L_true, LVJ_true, m_error_klt);
 }
 
 void vpMbKltTracker::computeVVSInit()
@@ -1145,7 +1073,8 @@ void vpMbKltTracker::display(const vpImage<unsigned char> &I, const vpHomogeneou
                              const vpCameraParameters &cam, const vpColor &col, unsigned int thickness,
                              bool displayFullModel)
 {
-  std::vector<std::vector<double> > models = vpMbKltTracker::getModelForDisplay(I.getWidth(), I.getHeight(), cMo, cam, displayFullModel);
+  std::vector<std::vector<double> > models =
+      vpMbKltTracker::getModelForDisplay(I.getWidth(), I.getHeight(), cMo, cam, displayFullModel);
 
   for (size_t i = 0; i < models.size(); i++) {
     if (vpMath::equal(models[i][0], 0)) {
@@ -1193,11 +1122,11 @@ void vpMbKltTracker::display(const vpImage<unsigned char> &I, const vpHomogeneou
   \param displayFullModel : Boolean to say if all the model has to be
   displayed, even the faces that are not visible.
 */
-void vpMbKltTracker::display(const vpImage<vpRGBa> &I, const vpHomogeneousMatrix &cMo,
-                             const vpCameraParameters &cam, const vpColor &col, unsigned int thickness,
-                             bool displayFullModel)
+void vpMbKltTracker::display(const vpImage<vpRGBa> &I, const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam,
+                             const vpColor &col, unsigned int thickness, bool displayFullModel)
 {
-  std::vector<std::vector<double> > models = vpMbKltTracker::getModelForDisplay(I.getWidth(), I.getHeight(), cMo, cam, displayFullModel);
+  std::vector<std::vector<double> > models =
+      vpMbKltTracker::getModelForDisplay(I.getWidth(), I.getHeight(), cMo, cam, displayFullModel);
 
   for (size_t i = 0; i < models.size(); i++) {
     if (vpMath::equal(models[i][0], 0)) {
@@ -1266,7 +1195,8 @@ std::vector<std::vector<double> > vpMbKltTracker::getFeaturesForDisplayKlt()
   `<pt_end.i()>`, `<pt_end.j()>`
   - Ellipse parameters are: `<primitive id (here 1 for ellipse)>`, `<pt_center.i()>`, `<pt_center.j()>`,
   `<n_20>`, `<n_11>`, `<n_02>` where `<n_ij>` are the second order centered moments of the ellipse
-  normalized by its area (i.e., such that \f$n_{ij} = \mu_{ij}/a\f$ where \f$\mu_{ij}\f$ are the centered moments and a the area).
+  normalized by its area (i.e., such that \f$n_{ij} = \mu_{ij}/a\f$ where \f$\mu_{ij}\f$ are the centered moments and a
+  the area).
 
   \param width : Image width.
   \param height : Image height.
@@ -1303,14 +1233,14 @@ std::vector<std::vector<double> > vpMbKltTracker::getModelForDisplay(unsigned in
 
   for (std::list<vpMbtDistanceKltPoints *>::const_iterator it = kltPolygons.begin(); it != kltPolygons.end(); ++it) {
     vpMbtDistanceKltPoints *kltpoly = *it;
-    std::vector<std::vector<double> > modelLines =  kltpoly->getModelForDisplay(cam, displayFullModel);
+    std::vector<std::vector<double> > modelLines = kltpoly->getModelForDisplay(cam, displayFullModel);
     models.insert(models.end(), modelLines.begin(), modelLines.end());
   }
 
   for (std::list<vpMbtDistanceKltCylinder *>::const_iterator it = kltCylinders.begin(); it != kltCylinders.end();
        ++it) {
     vpMbtDistanceKltCylinder *kltPolyCylinder = *it;
-    std::vector<std::vector<double> > modelLines =  kltPolyCylinder->getModelForDisplay(cMo, cam);
+    std::vector<std::vector<double> > modelLines = kltPolyCylinder->getModelForDisplay(cMo, cam);
     models.insert(models.end(), modelLines.begin(), modelLines.end());
   }
 
@@ -1397,8 +1327,8 @@ void vpMbKltTracker::initCylinder(const vpPoint &p1, const vpPoint &p2, double r
   circle. \param radius : Radius of the circle. \param name : The optional
   name of the circle.
 */
-void vpMbKltTracker::initCircle(const vpPoint &p1, const vpPoint &p2, const vpPoint &p3, double radius,
-                                int /*idFace*/, const std::string &name)
+void vpMbKltTracker::initCircle(const vpPoint &p1, const vpPoint &p2, const vpPoint &p3, double radius, int /*idFace*/,
+                                const std::string &name)
 {
   addCircle(p1, p2, p3, radius, name);
 }
@@ -1452,18 +1382,10 @@ void vpMbKltTracker::addCircle(const vpPoint &P1, const vpPoint &P2, const vpPoi
   3D points expressed in the original object frame to the desired object frame.
 */
 void vpMbKltTracker::reInitModel(const vpImage<unsigned char> &I, const std::string &cad_name,
-                                 const vpHomogeneousMatrix &cMo, bool verbose,
-                                 const vpHomogeneousMatrix &T)
+                                 const vpHomogeneousMatrix &cMo, bool verbose, const vpHomogeneousMatrix &T)
 {
   m_cMo.eye();
 
-#if (VISP_HAVE_OPENCV_VERSION < 0x020408)
-  if (cur != NULL) {
-    cvReleaseImage(&cur);
-    cur = NULL;
-  }
-#endif
-
   firstInitialisation = true;
 
   // delete the Klt Polygon features
@@ -1519,7 +1441,7 @@ void vpMbKltTracker::setUseKltTracking(const std::string &name, const bool &useK
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_mbt.a(vpMbKltTracker.cpp.o) has no
+// Work around to avoid warning: libvisp_mbt.a(vpMbKltTracker.cpp.o) has no
 // symbols
 void dummy_vpMbKltTracker(){};
 #endif // VISP_HAVE_OPENCV
