@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,17 +31,13 @@
  * Description:
  * Klt polygon, containing points of interest.
  *
- * Authors:
- * Romain Tallonneau
- * Aurelien Yol
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpPolygon.h>
 #include <visp3/mbt/vpMbtDistanceKltPoints.h>
 #include <visp3/me/vpMeTracker.h>
 
-#if defined(VISP_HAVE_MODULE_KLT) && (defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100))
+#if defined(VISP_HAVE_MODULE_KLT) && defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_VIDEO)
 
 #if defined(VISP_HAVE_CLIPPER)
 #include <clipper.hpp> // clipper private library
@@ -75,7 +71,8 @@ vpMbtDistanceKltPoints::~vpMbtDistanceKltPoints() {}
   points that are indeed in the face.
 
   \param _tracker : ViSP OpenCV KLT Tracker.
-  \param mask: Mask image or NULL if not wanted. Mask values that are set to true are considered in the tracking. To disable a pixel, set false.
+  \param mask: Mask image or NULL if not wanted. Mask values that are set to true are considered in the tracking. To
+  disable a pixel, set false.
 */
 void vpMbtDistanceKltPoints::init(const vpKltOpencv &_tracker, const vpImage<bool> *mask)
 {
@@ -96,21 +93,20 @@ void vpMbtDistanceKltPoints::init(const vpKltOpencv &_tracker, const vpImage<boo
     bool add = false;
 
     // Add points inside visibility mask only
-    if (vpMeTracker::inMask(mask, (unsigned int) y_tmp, (unsigned int) x_tmp)) {
+    if (vpMeTracker::inMask(mask, (unsigned int)y_tmp, (unsigned int)x_tmp)) {
       if (useScanLine) {
         if ((unsigned int)y_tmp < hiddenface->getMbScanLineRenderer().getPrimitiveIDs().getHeight() &&
-          (unsigned int)x_tmp < hiddenface->getMbScanLineRenderer().getPrimitiveIDs().getWidth() &&
-          hiddenface->getMbScanLineRenderer().getPrimitiveIDs()[(unsigned int)y_tmp][(unsigned int)x_tmp] ==
-          polygon->getIndex())
+            (unsigned int)x_tmp < hiddenface->getMbScanLineRenderer().getPrimitiveIDs().getWidth() &&
+            hiddenface->getMbScanLineRenderer().getPrimitiveIDs()[(unsigned int)y_tmp][(unsigned int)x_tmp] ==
+                polygon->getIndex())
           add = true;
-      }
-      else if (vpPolygon::isInside(roi, y_tmp, x_tmp)) {
+      } else if (vpPolygon::isInside(roi, y_tmp, x_tmp)) {
         add = true;
       }
     }
 
     if (add) {
-#if TARGET_OS_IPHONE
+#ifdef TARGET_OS_IPHONE
       initPoints[(int)id] = vpImagePoint(y_tmp, x_tmp);
       curPoints[(int)id] = vpImagePoint(y_tmp, x_tmp);
       curPointsInd[(int)id] = (int)i;
@@ -148,7 +144,8 @@ void vpMbtDistanceKltPoints::init(const vpKltOpencv &_tracker, const vpImage<boo
   \param _tracker : the KLT tracker
   \return the number of points that are tracked in this face and in this
   instanciation of the tracker
-  \param mask: Mask image or NULL if not wanted. Mask values that are set to true are considered in the tracking. To disable a pixel, set false.
+  \param mask: Mask image or NULL if not wanted. Mask values that are set to true are considered in the tracking. To
+  disable a pixel, set false.
 */
 unsigned int vpMbtDistanceKltPoints::computeNbDetectedCurrent(const vpKltOpencv &_tracker, const vpImage<bool> *mask)
 {
@@ -160,8 +157,8 @@ unsigned int vpMbtDistanceKltPoints::computeNbDetectedCurrent(const vpKltOpencv
 
   for (unsigned int i = 0; i < static_cast<unsigned int>(_tracker.getNbFeatures()); i++) {
     _tracker.getFeature((int)i, id, x, y);
-    if (isTrackedFeature((int)id) && vpMeTracker::inMask(mask, (unsigned int) y, (unsigned int) x)) {
-#if TARGET_OS_IPHONE
+    if (isTrackedFeature((int)id) && vpMeTracker::inMask(mask, (unsigned int)y, (unsigned int)x)) {
+#ifdef TARGET_OS_IPHONE
       curPoints[(int)id] = vpImagePoint(static_cast<double>(y), static_cast<double>(x));
       curPointsInd[(int)id] = (int)i;
 #else
@@ -319,7 +316,7 @@ void vpMbtDistanceKltPoints::computeHomography(const vpHomogeneousMatrix &_cTc0,
 }
 
 /*!
-  Test whether the feature with identifier id in paramters is in the list of
+  Test whether the feature with identifier id in parameters is in the list of
   tracked features.
 
   \param _id : the id of the current feature to test
@@ -347,25 +344,16 @@ bool vpMbtDistanceKltPoints::isTrackedFeature(int _id)
   default is 255).
 
   \param mask : the mask to update (0, not in the object, _nb otherwise).
-  \param nb : Optionnal value to set to the pixels included in the face.
-  \param shiftBorder : Optionnal shift for the border in pixel (sort of
+  \param nb : Optional value to set to the pixels included in the face.
+  \param shiftBorder : Optional shift for the border in pixel (sort of
   built-in erosion) to avoid to consider pixels near the limits of the face.
 */
 void vpMbtDistanceKltPoints::updateMask(
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020408)
     cv::Mat &mask,
-#else
-    IplImage *mask,
-#endif
     unsigned char nb, unsigned int shiftBorder)
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020408)
   int width = mask.cols;
   int height = mask.rows;
-#else
-  int width = mask->width;
-  int height = mask->height;
-#endif
 
   int i_min, i_max, j_min, j_max;
   std::vector<vpImagePoint> roi;
@@ -440,7 +428,6 @@ void vpMbtDistanceKltPoints::updateMask(
     j_max = width;
   }
 
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020408)
   for (int i = i_min; i < i_max; i++) {
     double i_d = (double)i;
 
@@ -468,32 +455,6 @@ void vpMbtDistanceKltPoints::updateMask(
 #endif
     }
   }
-#else
-  unsigned char *ptrData = (unsigned char *)mask->imageData + i_min * mask->widthStep + j_min;
-  for (int i = i_min; i < i_max; i++) {
-    double i_d = (double)i;
-    for (int j = j_min; j < j_max; j++) {
-      double j_d = (double)j;
-      if (shiftBorder != 0) {
-        if (vpPolygon::isInside(roi, i_d, j_d) && vpPolygon::isInside(roi, i_d + shiftBorder_d, j_d + shiftBorder_d) &&
-            vpPolygon::isInside(roi, i_d - shiftBorder_d, j_d + shiftBorder_d) &&
-            vpPolygon::isInside(roi, i_d + shiftBorder_d, j_d - shiftBorder_d) &&
-            vpPolygon::isInside(roi, i_d - shiftBorder_d, j_d - shiftBorder_d)) {
-          *(ptrData++) = nb;
-        } else {
-          ptrData++;
-        }
-      } else {
-        if (vpPolygon::isInside(roi, i, j)) {
-          *(ptrData++) = nb;
-        } else {
-          ptrData++;
-        }
-      }
-    }
-    ptrData += mask->widthStep - j_max + j_min;
-  }
-#endif
 }
 
 /*!
@@ -634,15 +595,11 @@ std::vector<std::vector<double> > vpMbtDistanceKltPoints::getFeaturesForDisplay(
     iP2.set_j(vpMath::round(iP.get_j() + 7));
 
 #if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
-    std::vector<double> params = {1, //KLT
-                                  iP.get_i(),
-                                  iP.get_j(),
-                                  iP2.get_i(),
-                                  iP2.get_j(),
-                                  static_cast<double>(id)};
+    std::vector<double> params = {1, // KLT
+                                  iP.get_i(), iP.get_j(), iP2.get_i(), iP2.get_j(), static_cast<double>(id)};
 #else
     std::vector<double> params;
-    params.push_back(1); //KLT
+    params.push_back(1); // KLT
     params.push_back(iP.get_i());
     params.push_back(iP.get_j());
     params.push_back(iP2.get_i());
@@ -695,14 +652,11 @@ std::vector<std::vector<double> > vpMbtDistanceKltPoints::getModelForDisplay(con
           vpMeterPixelConversion::convertPoint(camera, linesLst[i].second.get_x(), linesLst[i].second.get_y(), ip2);
 
 #if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
-          std::vector<double> params = {0, //0 for line parameters
-                                        ip1.get_i(),
-                                        ip1.get_j(),
-                                        ip2.get_i(),
-                                        ip2.get_j()};
+          std::vector<double> params = {0, // 0 for line parameters
+                                        ip1.get_i(), ip1.get_j(), ip2.get_i(), ip2.get_j()};
 #else
           std::vector<double> params;
-          params.push_back(0); //0 for line parameters
+          params.push_back(0); // 0 for line parameters
           params.push_back(ip1.get_i());
           params.push_back(ip1.get_j());
           params.push_back(ip2.get_i());
@@ -718,7 +672,7 @@ std::vector<std::vector<double> > vpMbtDistanceKltPoints::getModelForDisplay(con
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
-// Work arround to avoid warning: libvisp_mbt.a(vpMbtDistanceKltPoints.cpp.o)
+// Work around to avoid warning: libvisp_mbt.a(vpMbtDistanceKltPoints.cpp.o)
 // has no symbols
 void dummy_vpMbtDistanceKltPoints(){};
 #endif
