@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,9 +34,8 @@
  * Authors:
  * Amaury Dame
  * Aurelien Yol
- * Fabien Spindler
  *
- *****************************************************************************/
+*****************************************************************************/
 /*!
  \file vpTemplateTrackerWarpSRT.h
  \brief sRt warping function
@@ -51,9 +50,8 @@
   \class vpTemplateTrackerWarpSRT
   \ingroup group_tt_warp
 
-  This class consider the SRT (scale, rotation, translation) warping model \f$M\f$ with parameters \f$p=(s, \theta, t_u, t_v)\f$ such as
-  \f[M(p) = \left[
-  \begin{array}{ccc}
+  This class consider the SRT (scale, rotation, translation) warping model \f$M\f$ with parameters \f$p=(s, \theta, t_u,
+  t_v)\f$ such as \f[M(p) = \left[ \begin{array}{ccc}
   s * \cos(\theta) & - s * \sin(\theta) & t_u \\
   s * \sin(\theta) & s * \cos(\theta) & t_v
   \end{array}
@@ -61,8 +59,8 @@
   \f]
   with \f$s\f$ the scale, \f$\theta\f$ the rotation, and \f$t_u, t_v\f$ the translation along u and v axis in the image.
 
-  We recall that u axis is the image horizontal axis, and v axis is the image vertical axis. A point (u,v) with coordinates
-  (0,0) is located in the top left image corner.
+  We recall that u axis is the image horizontal axis, and v axis is the image vertical axis. A point (u,v) with
+  coordinates (0,0) is located in the top left image corner.
 
 */
 class VISP_EXPORT vpTemplateTrackerWarpSRT : public vpTemplateTrackerWarp
