@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -31,18 +31,13 @@
  * Description:
  * Template tracker.
  *
- * Authors:
- * Amaury Dame
- * Aurelien Yol
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <limits> // numeric_limits
 
 #include <visp3/core/vpConfig.h>
 
-#if VISP_HAVE_OPENCV_VERSION >= 0x020300
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC)
 #include <opencv2/imgproc/imgproc.hpp>
 #endif
 
@@ -181,7 +176,7 @@ void vpTemplateTrackerZone::initFromPoints(const vpImage<unsigned char> &I, cons
       vip_delaunay.push_back(vip[0]);
       initFromPoints(I, vip_delaunay, false);
     } else {
-#if VISP_HAVE_OPENCV_VERSION >= 0x020300
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC)
       // Init Delaunay
       cv::Subdiv2D subdiv(cv::Rect(0, 0, (int)I.getWidth(), (int)I.getHeight()));
       for (size_t i = 0; i < vip.size(); i++) {
@@ -337,9 +332,11 @@ bool vpTemplateTrackerZone::inZone(const double &i, const double &j, unsigned in
 
 /*!
   A zone is defined by a set of triangles. This function returns the ith
-  triangle. \param i : Index of the triangle to return. \param T : The
-  triangle corresponding to index i. \return true if the triangle with index i
-  was found, false otherwise.
+  triangle.
+  \param[in] i : Index of the triangle to return.
+  \param[out] T : The triangle corresponding to index i.
+  \exception  pException::badValue When the triangle with index i
+  was not found.
 
   The following sample code shows how to use this function:
   \code
