@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,9 +34,8 @@
  * Authors:
  * Amaury Dame
  * Aurelien Yol
- * Fabien Spindler
  *
- *****************************************************************************/
+*****************************************************************************/
 #ifndef vpTemplateTrackerMI_hh
 #define vpTemplateTrackerMI_hh
 
@@ -110,9 +109,9 @@ protected:
   std::vector<double> m_dv;
   std::vector<double> m_A;
   std::vector<double> m_dB;
-  std::vector< std::vector<double> > m_d2u;
-  std::vector< std::vector<double> > m_d2v;
-  std::vector< std::vector<double> > m_dA;
+  std::vector<std::vector<double> > m_d2u;
+  std::vector<std::vector<double> > m_d2v;
+  std::vector<std::vector<double> > m_dA;
 
 protected:
   void computeGradient();
@@ -156,8 +155,8 @@ public:
     : vpTemplateTracker(), hessianComputation(USE_HESSIEN_NORMAL), ApproxHessian(HESSIAN_0), lambda(0), temp(NULL),
       Prt(NULL), dPrt(NULL), Pt(NULL), Pr(NULL), d2Prt(NULL), PrtTout(NULL), dprtemp(NULL), PrtD(NULL), dPrtD(NULL),
       influBspline(0), bspline(0), Nc(0), Ncb(0), d2Ix(), d2Iy(), d2Ixy(), MI_preEstimation(0), MI_postEstimation(0),
-      NMI_preEstimation(0), NMI_postEstimation(0), covarianceMatrix(), computeCovariance(false),
-      m_du(), m_dv(), m_A(), m_dB(), m_d2u(), m_d2v(), m_dA()
+      NMI_preEstimation(0), NMI_postEstimation(0), covarianceMatrix(), computeCovariance(false), m_du(), m_dv(), m_A(),
+      m_dB(), m_d2u(), m_d2v(), m_dA()
   {
   }
   explicit vpTemplateTrackerMI(vpTemplateTrackerWarp *_warp);
