@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,13 +29,7 @@
  *
  * Description:
  * Pose computation.
- *
- * Authors:
- * Eric Marchand
- * Francois Chaumette
- * Aurelien Yol
- *
- *****************************************************************************/
+ */
 
 /*!
   \file vpPose.h
@@ -46,14 +39,15 @@
 #ifndef _vpPose_h_
 #define _vpPose_h_
 
+#include <visp3/core/vpCameraParameters.h>
 #include <visp3/core/vpHomogeneousMatrix.h>
+#include <visp3/core/vpPixelMeterConversion.h>
 #include <visp3/core/vpPoint.h>
 #include <visp3/core/vpRGBa.h>
 #include <visp3/vision/vpHomography.h>
 #ifdef VISP_BUILD_DEPRECATED_FUNCTIONS
 #include <visp3/core/vpList.h>
 #endif
-#include <visp3/core/vpThread.h>
 
 #include <list>
 #include <math.h>
@@ -62,6 +56,12 @@
 #include <atomic>
 #endif
 
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_17) &&                                                                     \
+    (!defined(_MSC_VER) || ((VISP_CXX_STANDARD >= VISP_CXX_STANDARD_17) && (_MSC_VER >= 1911)))
+#include <map>
+#include <optional>
+#endif
+
 #include <visp3/core/vpUniRand.h>
 
 /*!
@@ -81,7 +81,8 @@ class VISP_EXPORT vpPose
 {
 public:
   //! Methods that could be used to estimate the pose from points.
-  typedef enum {
+  typedef enum
+  {
     LAGRANGE,             /*!< Linear Lagrange approach (doesn't need an initialization) */
     DEMENTHON,            /*!< Linear Dementhon aproach (doesn't need an initialization) */
     LOWE,                 /*!< Lowe aproach based on a Levenberg Marquartd non linear
@@ -96,11 +97,15 @@ public:
                              initialization from Lagrange or Dementhon aproach */
     DEMENTHON_VIRTUAL_VS, /*!< Non linear virtual visual servoing approach
                              initialized by Dementhon approach */
-    LAGRANGE_VIRTUAL_VS   /*!< Non linear virtual visual servoing approach
+    LAGRANGE_VIRTUAL_VS,  /*!< Non linear virtual visual servoing approach
                              initialized by Lagrange approach */
+    DEMENTHON_LAGRANGE_VIRTUAL_VS, /*!< Non linear virtual visual servoing approach
+                             initialized by either Dementhon or Lagrange approach,
+                             depending on which method has the smallest residual. */
   } vpPoseMethodType;
 
-  enum RANSAC_FILTER_FLAGS {
+  enum RANSAC_FILTER_FLAGS
+  {
     NO_FILTER,
     PREFILTER_DEGENERATE_POINTS, /*!< Remove degenerate points (same 3D or 2D coordinates) before the RANSAC. */
     CHECK_DEGENERATE_POINTS      /*!< Check for degenerate points during the RANSAC. */
@@ -155,14 +160,13 @@ private:
   {
   public:
     RansacFunctor(const vpHomogeneousMatrix &cMo_, unsigned int ransacNbInlierConsensus_, const int ransacMaxTrials_,
-                  double ransacThreshold_, unsigned int initial_seed_, bool checkDegeneratePoints_,
-                  const std::vector<vpPoint> &listOfUniquePoints_, bool (*func_)(const vpHomogeneousMatrix &))
+      double ransacThreshold_, unsigned int initial_seed_, bool checkDegeneratePoints_,
+      const std::vector<vpPoint> &listOfUniquePoints_, bool (*func_)(const vpHomogeneousMatrix &))
       : m_best_consensus(), m_checkDegeneratePoints(checkDegeneratePoints_), m_cMo(cMo_), m_foundSolution(false),
-        m_func(func_), m_listOfUniquePoints(listOfUniquePoints_), m_nbInliers(0), m_ransacMaxTrials(ransacMaxTrials_),
-        m_ransacNbInlierConsensus(ransacNbInlierConsensus_), m_ransacThreshold(ransacThreshold_),
-        m_uniRand(initial_seed_)
-    {
-    }
+      m_func(func_), m_listOfUniquePoints(listOfUniquePoints_), m_nbInliers(0), m_ransacMaxTrials(ransacMaxTrials_),
+      m_ransacNbInlierConsensus(ransacNbInlierConsensus_), m_ransacThreshold(ransacThreshold_),
+      m_uniRand(initial_seed_)
+    { }
 
     void operator()() { m_foundSolution = poseRansacImpl(); }
 
@@ -192,6 +196,7 @@ private:
   };
 
 protected:
+  double dementhonSvThresh; //!< SVD threshold use for the pseudo-inverse computation in poseDementhonPlan
   double computeResidualDementhon(const vpHomogeneousMatrix &cMo);
 
   // method used in poseDementhonPlan()
@@ -206,27 +211,32 @@ public:
   void clearPoint();
 
   bool computePose(vpPoseMethodType method, vpHomogeneousMatrix &cMo, bool (*func)(const vpHomogeneousMatrix &) = NULL);
+  bool computePoseDementhonLagrangeVVS(vpHomogeneousMatrix &cMo);
   double computeResidual(const vpHomogeneousMatrix &cMo) const;
-  bool coplanar(int &coplanar_plane_type);
+  double computeResidual(const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam) const;
+  double computeResidual(const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam, vpColVector &squaredResidual) const;
+  bool coplanar(int &coplanar_plane_type, double *p_a = NULL, double *p_b = NULL, double *p_c = NULL, double *p_d = NULL);
   void displayModel(vpImage<unsigned char> &I, vpCameraParameters &cam, vpColor col = vpColor::none);
   void displayModel(vpImage<vpRGBa> &I, vpCameraParameters &cam, vpColor col = vpColor::none);
 
   void poseDementhonPlan(vpHomogeneousMatrix &cMo);
   void poseDementhonNonPlan(vpHomogeneousMatrix &cMo);
-  void poseLagrangePlan(vpHomogeneousMatrix &cMo);
+  void poseLagrangePlan(vpHomogeneousMatrix &cMo, bool *p_isPlan = NULL, double *p_a = NULL, double *p_b = NULL, double *p_c = NULL, double *p_d = NULL);
   void poseLagrangeNonPlan(vpHomogeneousMatrix &cMo);
   void poseLowe(vpHomogeneousMatrix &cMo);
   bool poseRansac(vpHomogeneousMatrix &cMo, bool (*func)(const vpHomogeneousMatrix &) = NULL);
   void poseVirtualVSrobust(vpHomogeneousMatrix &cMo);
   void poseVirtualVS(vpHomogeneousMatrix &cMo);
   void printPoint();
+  void setDementhonSvThreshold(const double &svThresh);
   void setDistanceToPlaneForCoplanarityTest(double d);
   void setLambda(double a) { lambda = a; }
   void setVvsEpsilon(const double eps)
   {
     if (eps >= 0) {
       vvsEpsilon = eps;
-    } else {
+    }
+    else {
       throw vpException(vpException::badValue, "Epsilon value must be >= 0.");
     }
   }
@@ -238,7 +248,8 @@ public:
     // Test whether or not t is > 0
     if (t > std::numeric_limits<double>::epsilon()) {
       ransacThreshold = t;
-    } else {
+    }
+    else {
       throw vpException(vpException::badValue, "The Ransac threshold must be positive as we deal with distance.");
     }
   }
@@ -268,7 +279,7 @@ public:
   {
     if (!computeCovariance)
       vpTRACE("Warning : The covariance matrix has not been computed. See "
-              "setCovarianceComputation() to do it.");
+        "setCovarianceComputation() to do it.");
 
     return covarianceMatrix;
   }
@@ -328,33 +339,115 @@ public:
     return vectorOfPoints;
   }
 
-  static void display(vpImage<unsigned char> &I, vpHomogeneousMatrix &cMo, vpCameraParameters &cam, double size,
-                      vpColor col = vpColor::none);
-  static void display(vpImage<vpRGBa> &I, vpHomogeneousMatrix &cMo, vpCameraParameters &cam, double size,
-                      vpColor col = vpColor::none);
-  static double poseFromRectangle(vpPoint &p1, vpPoint &p2, vpPoint &p3, vpPoint &p4, double lx,
-                                  vpCameraParameters &cam, vpHomogeneousMatrix &cMo);
-
-  static int computeRansacIterations(double probability, double epsilon, const int sampleSize = 4,
-                                     int maxIterations = 2000);
-
-  static void findMatch(std::vector<vpPoint> &p2D, std::vector<vpPoint> &p3D,
-                        const unsigned int &numberOfInlierToReachAConsensus, const double &threshold,
-                        unsigned int &ninliers, std::vector<vpPoint> &listInliers, vpHomogeneousMatrix &cMo,
-                        const int &maxNbTrials = 10000, bool useParallelRansac = true, unsigned int nthreads = 0,
-                        bool (*func)(const vpHomogeneousMatrix &) = NULL);
-
   static bool computePlanarObjectPoseFromRGBD(const vpImage<float> &depthMap, const std::vector<vpImagePoint> &corners,
-                                              const vpCameraParameters &colorIntrinsics,
-                                              const std::vector<vpPoint> &point3d, vpHomogeneousMatrix &cMo,
-                                              double *confidence_index = NULL);
+    const vpCameraParameters &colorIntrinsics,
+    const std::vector<vpPoint> &point3d, vpHomogeneousMatrix &cMo,
+    double *confidence_index = NULL);
 
   static bool computePlanarObjectPoseFromRGBD(const vpImage<float> &depthMap,
-                                              const std::vector<std::vector<vpImagePoint> > &corners,
-                                              const vpCameraParameters &colorIntrinsics,
-                                              const std::vector<std::vector<vpPoint> > &point3d,
-                                              vpHomogeneousMatrix &cMo, double *confidence_index = NULL,
-                                              bool coplanar_points = true);
+    const std::vector<std::vector<vpImagePoint> > &corners,
+    const vpCameraParameters &colorIntrinsics,
+    const std::vector<std::vector<vpPoint> > &point3d,
+    vpHomogeneousMatrix &cMo, double *confidence_index = NULL,
+    bool coplanar_points = true);
+  static int computeRansacIterations(double probability, double epsilon, const int sampleSize = 4,
+    int maxIterations = 2000);
+
+  static void display(vpImage<unsigned char> &I, vpHomogeneousMatrix &cMo, vpCameraParameters &cam, double size,
+    vpColor col = vpColor::none);
+  static void display(vpImage<vpRGBa> &I, vpHomogeneousMatrix &cMo, vpCameraParameters &cam, double size,
+    vpColor col = vpColor::none);
+
+  static void findMatch(std::vector<vpPoint> &p2D, std::vector<vpPoint> &p3D,
+    const unsigned int &numberOfInlierToReachAConsensus, const double &threshold,
+    unsigned int &ninliers, std::vector<vpPoint> &listInliers, vpHomogeneousMatrix &cMo,
+    const int &maxNbTrials = 10000, bool useParallelRansac = true, unsigned int nthreads = 0,
+    bool (*func)(const vpHomogeneousMatrix &) = NULL);
+
+  static double poseFromRectangle(vpPoint &p1, vpPoint &p2, vpPoint &p3, vpPoint &p4, double lx,
+    vpCameraParameters &cam, vpHomogeneousMatrix &cMo);
+
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_17) &&                                                                     \
+    (!defined(_MSC_VER) || ((VISP_CXX_STANDARD >= VISP_CXX_STANDARD_17) && (_MSC_VER >= 1911)))
+
+  /*!
+   * Compute the pose of a planar object from corresponding 2D-3D point coordinates and plane equation.
+   * Here at least 3 points are required.
+   *
+   * \param[in] plane_in_camera_frame : Plane in camera frame.
+   * \param[in] pts : Object points.
+   * \param[in] ips : Points in the image.
+   * \param[in] camera_intrinsics : Camera parameters.
+   * \param[in] cMo_init : Camera to object frame transformation used as initialization. When set to `std::nullopt`,
+   * this transformation is computed internally.
+   * \param[in] enable_vvs : When true, refine estimated pose using a virtual visual servoing scheme.
+   * \return Homogeneous matrix \f${^c}{\bf M}_o\f$ between camera frame and object frame when estimation succeed,
+   * nullopt otherwise.
+   */
+  template <typename DataId>
+  static std::optional<vpHomogeneousMatrix> computePlanarObjectPoseWithAtLeast3Points(
+    const vpPlane &plane_in_camera_frame, const std::map<DataId, vpPoint> &pts,
+    const std::map<DataId, vpImagePoint> &ips, const vpCameraParameters &camera_intrinsics,
+    std::optional<vpHomogeneousMatrix> cMo_init = std::nullopt, bool enable_vvs = true)
+  {
+    if (cMo_init && !enable_vvs) {
+      throw(vpException(
+        vpException::fatalError,
+        "It doesn't make sense to use an initialized pose without enabling VVS to compute the pose from 4 points"));
+    }
+
+    // Check if detection and model fit
+    // - The next line produces an internal compiler error with Visual Studio 2017:
+    //   modules\vision\include\visp3/vision/vpPose.h(404): fatal error C1001: An internal error has occurred in the
+    //   compiler.
+    //    To work around this problem, try simplifying or changing the program near the locations listed above.
+    //   Please choose the Technical Support command on the Visual C++
+    //    Help menu, or open the Technical Support help file for more information
+    // - Note that the next line builds with Visual Studio 2022.
+    // for ([[maybe_unused]] const auto &[ip_id, _] : ips) {
+    for (const auto &[ip_id, ip_unused] : ips) {
+      (void)ip_unused;
+      if (pts.find(ip_id) == end(pts)) {
+        throw(vpException(vpException::fatalError,
+                          "Cannot compute pose with points and image points which do not have the same IDs"));
+      }
+    }
+
+    std::vector<vpPoint> P {}, Q {};
+    // The next line in C++17 produces a build error with Visual Studio 2017, that's why we
+    // use rather C++11 to loop through std::map
+    // for (auto [pt_id, pt] : pts) {
+    for (const auto &pt_map : pts) {
+      if (ips.find(pt_map.first) != end(ips)) {
+        double x = 0, y = 0;
+        vpPoint pt = pt_map.second;
+        vpPixelMeterConversion::convertPoint(camera_intrinsics, ips.at(pt_map.first), x, y);
+        const auto Z = plane_in_camera_frame.computeZ(x, y);
+
+        pt.set_x(x);
+        pt.set_y(y);
+        pt.set_Z(Z);
+
+        Q.push_back(pt);
+        P.emplace_back(x * Z, y * Z, Z);
+      }
+    }
+
+    if (Q.size() < 3) {
+      return std::nullopt;
+    }
+
+    auto cMo = cMo_init.value_or(vpHomogeneousMatrix::compute3d3dTransformation(P, Q));
+    if (!cMo.isValid()) {
+      return std::nullopt;
+    }
+
+    return enable_vvs ? vpPose::poseVirtualVSWithDepth(Q, cMo).value_or(cMo) : cMo;
+  }
+
+  static std::optional<vpHomogeneousMatrix> poseVirtualVSWithDepth(const std::vector<vpPoint> &points,
+    const vpHomogeneousMatrix &cMo);
+#endif
 
 #if defined(VISP_BUILD_DEPRECATED_FUNCTIONS)
   /*!
