@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * Homography transformation.
- *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+ */
 
 #include <math.h>
 #include <visp3/core/vpMath.h>
@@ -47,17 +42,6 @@
 /* ------------------------------------------------------------------------ */
 const double vpHomography::sing_threshold = 0.0001;
 
-/*!
-  Compute the camera displacement between two images from the homography \f$
-  {^a}{\bf H}_b \f$ which is here an implicit parameter (*this).
-
-  \param aRb : Rotation matrix as an output \f$ {^a}{\bf R}_b \f$.
-
-  \param atb : Translation vector as an output \f$ ^a{\bf t}_b \f$.
-
-  \param n : Normal vector to the plane as an output.
-
-*/
 void vpHomography::computeDisplacement(vpRotationMatrix &aRb, vpTranslationVector &atb, vpColVector &n)
 {
 
@@ -69,26 +53,6 @@ void vpHomography::computeDisplacement(vpRotationMatrix &aRb, vpTranslationVecto
   computeDisplacement(*this, aRb, atb, n);
 }
 
-/*!
-
-  Compute the camera displacement between two images from the homography \f$
-  {^a}{\bf H}_b \f$ which is here an implicit parameter (*this).
-
-  Camera displacement between \f$ {^a}{\bf p} \f$ and \f$ {^a}{\bf p} \f$ is
-  represented as a rotation matrix \f$ {^a}{\bf R}_b \f$ and a translation
-  vector \f$ ^a{\bf t}_b \f$ from which an homogeneous matrix can be build
-  (vpHomogeneousMatrix).
-
-  \param nd : Input normal vector to the plane used to compar with the normal
-  vector \e n extracted from the homography.
-
-  \param aRb : Rotation matrix as an output \f$ {^a}{\bf R}_b \f$.
-
-  \param atb : Translation vector as an output \f$ ^a{\bf t}_b \f$.
-
-  \param n : Normal vector to the plane as an output.
-
-*/
 void vpHomography::computeDisplacement(const vpColVector &nd, vpRotationMatrix &aRb, vpTranslationVector &atb,
                                        vpColVector &n)
 {
@@ -686,9 +650,8 @@ void vpHomography::computeDisplacement(const vpHomography &aHb, vpRotationMatrix
 #endif
 }
 
-void vpHomography::computeDisplacement(const vpHomography &H, double x, double y,
-                                       std::list<vpRotationMatrix> &vR, std::list<vpTranslationVector> &vT,
-                                       std::list<vpColVector> &vN)
+void vpHomography::computeDisplacement(const vpHomography &H, double x, double y, std::list<vpRotationMatrix> &vR,
+                                       std::list<vpTranslationVector> &vT, std::list<vpColVector> &vN)
 {
 
 #ifdef DEBUG_Homographie
@@ -1263,21 +1226,21 @@ void vpHomography::computeDisplacement(const vpHomography &H, double x, double y
               << std::endl;
   }
 
-// on peut ensuite afficher les resultats...
-/* std::cout << "Analyse des resultats : "<< std::endl; */
-/* if (cas==cas1) */
-/* std::cout << "On est dans le cas 1" << std::endl; */
-/* if (cas==cas2) */
-/* std::cout << "On est dans le cas 2" << std::endl; */
-/* if (cas==cas3) */
-/* std::cout << "On est dans le cas 3" << std::endl; */
-/* if (cas==cas4) */
-/* std::cout << "On est dans le cas 4" << std::endl; */
+  // on peut ensuite afficher les resultats...
+  /* std::cout << "Analyse des resultats : "<< std::endl; */
+  /* if (cas==cas1) */
+  /* std::cout << "On est dans le cas 1" << std::endl; */
+  /* if (cas==cas2) */
+  /* std::cout << "On est dans le cas 2" << std::endl; */
+  /* if (cas==cas3) */
+  /* std::cout << "On est dans le cas 3" << std::endl; */
+  /* if (cas==cas4) */
+  /* std::cout << "On est dans le cas 4" << std::endl; */
 
-/* if (distanceFictive < 0) */
-/* std::cout << "d'<0" << std::endl; */
-/* else */
-/* std::cout << "d'>0" << std::endl; */
+  /* if (distanceFictive < 0) */
+  /* std::cout << "d'<0" << std::endl; */
+  /* else */
+  /* std::cout << "d'>0" << std::endl; */
 
 #ifdef DEBUG_Homographie
   printf("fin : Homographie_EstimationDeplacementCamera\n");
