@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * Homography estimation.
- *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+ */
 
 /*!
   \file vpHomographyMalis.cpp
@@ -66,21 +61,21 @@ const double eps = 1e-6;
  *
  ****************************************************************************
  * ENTREES :
- * int pts_ref[4]	: Definit quels sont les points de reference, ils ne
- *			  seront pas affectes par le changement de repere
- * int nb_pts		: nombre de points a changer de repere
- * double **pd	: La matrice des coordonnees des points desires
- * double **p	: La matrice des coordonnees des points courants
+ * int pts_ref[4]  : Definit quels sont les points de reference, ils ne
+ *        seront pas affectes par le changement de repere
+ * int nb_pts    : nombre de points a changer de repere
+ * double **pd  : La matrice des coordonnees des points desires
+ * double **p  : La matrice des coordonnees des points courants
  *
  *
  * SORTIES :
  *
- * double **pt_des_nr 	: La matrice des coordonnees des points desires
- *			  dans le nouveau repere.
- * double **pt_cour_nr	: La matrice des coordonnees des points courants
- *			  dans le nouveau repere
- * double **M	: ??
- * double **Mpd	: pseudo inverse de M  ..
+ * double **pt_des_nr   : La matrice des coordonnees des points desires
+ *        dans le nouveau repere.
+ * double **pt_cour_nr  : La matrice des coordonnees des points courants
+ *        dans le nouveau repere
+ * double **M  : ??
+ * double **Mpd  : pseudo inverse de M  ..
  *
  *
  ****************************************************************************
@@ -164,13 +159,13 @@ void changeFrame(unsigned int *pts_ref, unsigned int nb_pts, vpMatrix &pd, vpMat
  *
  ****************************************************************************
  * ENTREES :
- * int 	Nb_pts : nombre de points
- * double	**pd : tableau des coordonnees des points desires
- * couble	**p : tableau des coordonnees des points courants
+ * int   Nb_pts : nombre de points
+ * double  **pd : tableau des coordonnees des points desires
+ * couble  **p : tableau des coordonnees des points courants
  *
  * SORTIES :
  *
- * double **H 			matrice d homographie
+ * double **H       matrice d homographie
  *
  ****************************************************************************
  * AUTEUR : BOSSARD Nicolas.  INSA Rennes 5eme annee.
@@ -228,7 +223,7 @@ void HLM2D(unsigned int nb_pts, vpMatrix &points_des, vpMatrix &points_cour, vpM
 
   /*****
         La meilleure solution est le vecteur de V associe
-        a la valeur singuliere la plus petite en valeur	absolu.
+        a la valeur singuliere la plus petite en valeur  absolu.
         Pour cela on parcourt la matrice des valeurs singulieres
         et on repere la plus petite valeur singuliere, on en profite
         pour effectuer un controle sur le rang de la matrice : pas plus
@@ -277,14 +272,14 @@ void HLM2D(unsigned int nb_pts, vpMatrix &points_des, vpMatrix &points_cour, vpM
  *
  ****************************************************************************
  * ENTREES :
- * int 	Nb_pts : nombre de points
- * double	**pd : tableau des coordonnees des points desires
- * couble	**p : tableau des coordonnees des points courants
+ * int   Nb_pts : nombre de points
+ * double  **pd : tableau des coordonnees des points desires
+ * couble  **p : tableau des coordonnees des points courants
  *
  * SORTIES :
  *
- * double **H 			matrice d'homographie
- * double epipole[3]		epipole
+ * double **H       matrice d'homographie
+ * double epipole[3]    epipole
  *
  ****************************************************************************
  **/
@@ -479,14 +474,14 @@ void HLM3D(unsigned int nb_pts, vpMatrix &pd, vpMatrix &p, vpMatrix &H)
 
     //     estimation de a = 1,b,c ; je cherche le min de somme(i=1:n)
     //     (0.5*(ei)^2)
-    // 	  e1 = V[1][.] * b - V[3][.] = 0 ;
-    // 	  e2 = V[2][.] * c - V[3][.] = 0 ;
-    // 	  e3 = V[2][.] * b - V[3][.] * c = 0 ;
-    // 	  e4 = V[4][.] * b - V[5][.] = 0 ;
-    // 	  e5 = V[4][.] * c - V[6][.] = 0 ;
-    // 	  e6 = V[6][.] * b - V[5][.] * c = 0 ;
-    // 	  e7 = V[7][.] * b - V[8][.] = 0 ;
-    // 	  e8 = V[7][.] * c - V[9][.] = 0 ;
+    //     e1 = V[1][.] * b - V[3][.] = 0 ;
+    //     e2 = V[2][.] * c - V[3][.] = 0 ;
+    //     e3 = V[2][.] * b - V[3][.] * c = 0 ;
+    //     e4 = V[4][.] * b - V[5][.] = 0 ;
+    //     e5 = V[4][.] * c - V[6][.] = 0 ;
+    //     e6 = V[6][.] * b - V[5][.] * c = 0 ;
+    //     e7 = V[7][.] * b - V[8][.] = 0 ;
+    //     e8 = V[7][.] * c - V[9][.] = 0 ;
     d[0] = V[2][vect];
     d[1] = V[4][vect];
     d[2] = V[1][vect];
@@ -597,28 +592,6 @@ void HLM(unsigned int q_cible, const std::vector<double> &xm, const std::vector<
 
 #endif // #ifndef DOXYGEN_SHOULD_SKIP_THIS
 
-/*!
-  From couples of matched points \f$^a{\bf p}=(x_a,y_a,1)\f$ in image a
-  and \f$^b{\bf p}=(x_b,y_b,1)\f$ in image b with homogeneous coordinates,
-  computes the homography matrix by resolving \f$^a{\bf p} = ^a{\bf H}_b\;
-  ^b{\bf p}\f$ using Ezio Malis linear method (HLM) \cite Malis00b.
-
-  This method can consider points that are planar or non planar. The algorithm
-  for planar scene implemented in this file is described in Ezio Malis PhD
-  thesis \cite TheseMalis.
-
-  \param xb, yb : Coordinates vector of matched points in image b. These
-  coordinates are expressed in meters. \param xa, ya : Coordinates vector of
-  matched points in image a. These coordinates are expressed in meters. \param
-  isplanar : If true the points are assumed to be in a plane, otherwise there
-  are assumed to be non planar. \param aHb : Estimated homography that relies
-  the transformation from image a to image b.
-
-  If the boolean isplanar is true the points are assumed to be in a plane
-  otherwise there are assumed to be non planar.
-
-  \sa DLT() when the scene is planar.
-*/
 void vpHomography::HLM(const std::vector<double> &xb, const std::vector<double> &yb, const std::vector<double> &xa,
                        const std::vector<double> &ya, bool isplanar, vpHomography &aHb)
 {
