@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,11 +29,7 @@
  *
  * Description:
  * Homography estimation.
- *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+ */
 
 #include <visp3/core/vpColVector.h>
 #include <visp3/core/vpRansac.h>
@@ -74,7 +69,7 @@ bool isColinear(vpColVector &p1, vpColVector &p2, vpColVector &p3)
   return ((vpColVector::cross(p2 - p1, p3 - p1).sumSquare()) < vpEps);
 }
 
-bool vpHomography::degenerateConfiguration(vpColVector &x, unsigned int *ind, double threshold_area)
+bool vpHomography::degenerateConfiguration(const vpColVector &x, unsigned int *ind, double threshold_area)
 {
 
   unsigned int i, j, k;
@@ -137,7 +132,7 @@ x1b,y1b, x2b, y2b, ... xnb, ynb
 x1a,y1a, x2a, y2a, ... xna, yna
 leading to 2*2*n
 */
-bool vpHomography::degenerateConfiguration(vpColVector &x, unsigned int *ind)
+bool vpHomography::degenerateConfiguration(const vpColVector &x, unsigned int *ind)
 {
   for (unsigned int i = 1; i < 4; i++)
     for (unsigned int j = 0; j < i; j++)
@@ -286,35 +281,6 @@ void vpHomography::initRansac(unsigned int n, double *xb, double *yb, double *xa
   }
 }
 
-/*!
-
-  From couples of matched points \f$^a{\bf p}=(x_a,y_a,1)\f$ in image a
-  and \f$^b{\bf p}=(x_b,y_b,1)\f$ in image b with homogeneous coordinates,
-  computes the homography matrix by resolving \f$^a{\bf p} = ^a{\bf H}_b\;
-  ^b{\bf p}\f$ using Ransac algorithm.
-
-  \param xb, yb : Coordinates vector of matched points in image b. These
-  coordinates are expressed in meters. \param xa, ya : Coordinates vector of
-  matched points in image a. These coordinates are expressed in meters. \param
-  aHb : Estimated homography that relies the transformation from image a to
-  image b. \param inliers : Vector that indicates if a matched point is an
-  inlier (true) or an outlier (false). \param residual : Global residual
-  computed as \f$r = \sqrt{1/n \sum_{inliers} {\| {^a{\bf p} - {\hat{^a{\bf
-  H}_b}} {^b{\bf p}}} \|}^{2}}\f$ with \f$n\f$ the number of inliers.
-
-  \param nbInliersConsensus : Minimal number of points requested to fit the
-  estimated homography.
-
-  \param threshold : Threshold for outlier removing. A point is considered as
-  an outlier if the reprojection error \f$\| {^a{\bf p} - {\hat{^a{\bf H}_b}}
-  {^b{\bf p}}} \|\f$ is greater than this threshold.
-
-  \param normalization : When set to true, the coordinates of the points are
-  normalized. The normalization carried out is the one preconized by Hartley.
-
-  \return true if the homography could be computed, false otherwise.
-
-*/
 bool vpHomography::ransac(const std::vector<double> &xb, const std::vector<double> &yb, const std::vector<double> &xa,
                           const std::vector<double> &ya, vpHomography &aHb, std::vector<bool> &inliers,
                           double &residual, unsigned int nbInliersConsensus, double threshold, bool normalization)
