@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,17 +29,11 @@
  *
  * Description:
  * Pose computation.
- *
- * Authors:
- * Eric Marchand
- * Francois Chaumette
- *
- *****************************************************************************/
+ */
 
 /*!
-\file vpPose.cpp
-\brief Fichier contenant la classe vpPose (tout ce qui est necessaire
-pour faire du calcul de pose par difference methode
+  \file vpPose.cpp
+  \brief File containing the vpPose class, everything needed to calculate poses using different methods.
 */
 
 #include <visp3/core/vpCameraParameters.h>
@@ -49,6 +42,7 @@ pour faire du calcul de pose par difference methode
 #include <visp3/core/vpException.h>
 #include <visp3/core/vpMath.h>
 #include <visp3/core/vpMeterPixelConversion.h>
+#include <visp3/core/vpUniRand.h>
 #include <visp3/vision/vpPose.h>
 #include <visp3/vision/vpPoseException.h>
 
@@ -95,23 +89,20 @@ void vpPose::init()
 /*! Default constructor. */
 vpPose::vpPose()
   : npt(0), listP(), residual(0), lambda(0.9), vvsIterMax(200), c3d(), computeCovariance(false), covarianceMatrix(),
-    ransacNbInlierConsensus(4), ransacMaxTrials(1000), ransacInliers(), ransacInlierIndex(), ransacThreshold(0.0001),
-    distanceToPlaneForCoplanarityTest(0.001), ransacFlag(vpPose::NO_FILTER), listOfPoints(),
-    useParallelRansac(false),
-    nbParallelRansacThreads(0), // 0 means that we use C++11 (if available) to get the number of threads
-    vvsEpsilon(1e-8)
-{
-}
+  ransacNbInlierConsensus(4), ransacMaxTrials(1000), ransacInliers(), ransacInlierIndex(), ransacThreshold(0.0001),
+  distanceToPlaneForCoplanarityTest(0.001), ransacFlag(vpPose::NO_FILTER), listOfPoints(), useParallelRansac(false),
+  nbParallelRansacThreads(0), // 0 means that we use C++11 (if available) to get the number of threads
+  vvsEpsilon(1e-8), dementhonSvThresh(1e-6)
+{ }
 
-vpPose::vpPose(const std::vector<vpPoint>& lP)
-  : npt(static_cast<unsigned int>(lP.size())), listP(lP.begin(), lP.end()), residual(0), lambda(0.9), vvsIterMax(200), c3d(),
-    computeCovariance(false), covarianceMatrix(), ransacNbInlierConsensus(4), ransacMaxTrials(1000), ransacInliers(),
-    ransacInlierIndex(), ransacThreshold(0.0001), distanceToPlaneForCoplanarityTest(0.001), ransacFlag(vpPose::NO_FILTER),
-    listOfPoints(lP), useParallelRansac(false),
-    nbParallelRansacThreads(0), // 0 means that we use C++11 (if available) to get the number of threads
-    vvsEpsilon(1e-8)
-{
-}
+vpPose::vpPose(const std::vector<vpPoint> &lP)
+  : npt(static_cast<unsigned int>(lP.size())), listP(lP.begin(), lP.end()), residual(0), lambda(0.9), vvsIterMax(200),
+  c3d(), computeCovariance(false), covarianceMatrix(), ransacNbInlierConsensus(4), ransacMaxTrials(1000),
+  ransacInliers(), ransacInlierIndex(), ransacThreshold(0.0001), distanceToPlaneForCoplanarityTest(0.001),
+  ransacFlag(vpPose::NO_FILTER), listOfPoints(lP), useParallelRansac(false),
+  nbParallelRansacThreads(0), // 0 means that we use C++11 (if available) to get the number of threads
+  vvsEpsilon(1e-8), dementhonSvThresh(1e-6)
+{ }
 
 /*!
   Destructor that deletes the array of point (freed the memory).
@@ -170,6 +161,14 @@ void vpPose::addPoints(const std::vector<vpPoint> &lP)
 
 void vpPose::setDistanceToPlaneForCoplanarityTest(double d) { distanceToPlaneForCoplanarityTest = d; }
 
+void vpPose::setDementhonSvThreshold(const double &svThresh)
+{
+  if (svThresh < 0) {
+    throw vpException(vpException::badValue, "The svd threshold must be positive");
+  }
+  dementhonSvThresh = svThresh;
+}
+
 /*!
   Test the coplanarity of the set of points
 
@@ -179,9 +178,13 @@ void vpPose::setDistanceToPlaneForCoplanarityTest(double d) { distanceToPlaneFor
    3: if plane z=cst
    4: if the points are collinear.
    0: any other plane
+  \param p_a: if different from null, it will be set to equal the a coefficient of the potential plan.
+  \param p_b: if different from null, it will be set to equal the b coefficient of the potential plan.
+  \param p_c: if different from null, it will be set to equal the c coefficient of the potential plan.
+  \param p_d: if different from null, it will be set to equal the d coefficient of the potential plan.
   \return true if points are coplanar false otherwise.
 */
-bool vpPose::coplanar(int &coplanar_plane_type)
+bool vpPose::coplanar(int &coplanar_plane_type, double *p_a, double *p_b, double *p_c, double *p_d)
 {
   coplanar_plane_type = 0;
   if (npt < 2) {
@@ -192,19 +195,22 @@ bool vpPose::coplanar(int &coplanar_plane_type)
   if (npt == 3)
     return true;
 
+  // Shuffling the points to limit the risk of using points close to each other
+  std::vector<vpPoint> shuffled_listP = vpUniRand::shuffleVector<vpPoint>(listOfPoints);
+
   double x1 = 0, x2 = 0, x3 = 0, y1 = 0, y2 = 0, y3 = 0, z1 = 0, z2 = 0, z3 = 0;
 
-  std::list<vpPoint>::const_iterator it = listP.begin();
+  std::vector<vpPoint>::const_iterator it = shuffled_listP.begin();
 
   vpPoint P1, P2, P3;
 
   // Get three 3D points that are not collinear and that is not at origin
   bool degenerate = true;
   bool not_on_origin = true;
-  std::list<vpPoint>::const_iterator it_tmp;
+  std::vector<vpPoint>::const_iterator it_tmp;
 
-  std::list<vpPoint>::const_iterator it_i, it_j, it_k;
-  for (it_i = listP.begin(); it_i != listP.end(); ++it_i) {
+  std::vector<vpPoint>::const_iterator it_i, it_j, it_k;
+  for (it_i = shuffled_listP.begin(); it_i != shuffled_listP.end(); ++it_i) {
     if (degenerate == false) {
       // std::cout << "Found a non degenerate configuration" << std::endl;
       break;
@@ -212,38 +218,41 @@ bool vpPose::coplanar(int &coplanar_plane_type)
     P1 = *it_i;
     // Test if point is on origin
     if ((std::fabs(P1.get_oX()) <= std::numeric_limits<double>::epsilon()) &&
-        (std::fabs(P1.get_oY()) <= std::numeric_limits<double>::epsilon()) &&
-        (std::fabs(P1.get_oZ()) <= std::numeric_limits<double>::epsilon())) {
+      (std::fabs(P1.get_oY()) <= std::numeric_limits<double>::epsilon()) &&
+      (std::fabs(P1.get_oZ()) <= std::numeric_limits<double>::epsilon())) {
       not_on_origin = false;
-    } else {
+    }
+    else {
       not_on_origin = true;
     }
     if (not_on_origin) {
       it_tmp = it_i;
       ++it_tmp; // j = i+1
-      for (it_j = it_tmp; it_j != listP.end(); ++it_j) {
+      for (it_j = it_tmp; it_j != shuffled_listP.end(); ++it_j) {
         if (degenerate == false) {
           // std::cout << "Found a non degenerate configuration" << std::endl;
           break;
         }
         P2 = *it_j;
         if ((std::fabs(P2.get_oX()) <= std::numeric_limits<double>::epsilon()) &&
-            (std::fabs(P2.get_oY()) <= std::numeric_limits<double>::epsilon()) &&
-            (std::fabs(P2.get_oZ()) <= std::numeric_limits<double>::epsilon())) {
+          (std::fabs(P2.get_oY()) <= std::numeric_limits<double>::epsilon()) &&
+          (std::fabs(P2.get_oZ()) <= std::numeric_limits<double>::epsilon())) {
           not_on_origin = false;
-        } else {
+        }
+        else {
           not_on_origin = true;
         }
         if (not_on_origin) {
           it_tmp = it_j;
           ++it_tmp; // k = j+1
-          for (it_k = it_tmp; it_k != listP.end(); ++it_k) {
+          for (it_k = it_tmp; it_k != shuffled_listP.end(); ++it_k) {
             P3 = *it_k;
             if ((std::fabs(P3.get_oX()) <= std::numeric_limits<double>::epsilon()) &&
-                (std::fabs(P3.get_oY()) <= std::numeric_limits<double>::epsilon()) &&
-                (std::fabs(P3.get_oZ()) <= std::numeric_limits<double>::epsilon())) {
+              (std::fabs(P3.get_oY()) <= std::numeric_limits<double>::epsilon()) &&
+              (std::fabs(P3.get_oZ()) <= std::numeric_limits<double>::epsilon())) {
               not_on_origin = false;
-            } else {
+            }
+            else {
               not_on_origin = true;
             }
             if (not_on_origin) {
@@ -294,26 +303,27 @@ bool vpPose::coplanar(int &coplanar_plane_type)
   // std::cout << "a=" << a << " b=" << b << " c=" << c << " d=" << d <<
   // std::endl;
   if (std::fabs(b) <= std::numeric_limits<double>::epsilon() &&
-      std::fabs(c) <= std::numeric_limits<double>::epsilon()) {
+    std::fabs(c) <= std::numeric_limits<double>::epsilon()) {
     coplanar_plane_type = 1; // ax=d
-  } else if (std::fabs(a) <= std::numeric_limits<double>::epsilon() &&
-             std::fabs(c) <= std::numeric_limits<double>::epsilon()) {
+  }
+  else if (std::fabs(a) <= std::numeric_limits<double>::epsilon() &&
+    std::fabs(c) <= std::numeric_limits<double>::epsilon()) {
     coplanar_plane_type = 2; // by=d
-  } else if (std::fabs(a) <= std::numeric_limits<double>::epsilon() &&
-             std::fabs(b) <= std::numeric_limits<double>::epsilon()) {
+  }
+  else if (std::fabs(a) <= std::numeric_limits<double>::epsilon() &&
+    std::fabs(b) <= std::numeric_limits<double>::epsilon()) {
     coplanar_plane_type = 3; // cz=d
   }
 
   double D = sqrt(vpMath::sqr(a) + vpMath::sqr(b) + vpMath::sqr(c));
 
-  for (it = listP.begin(); it != listP.end(); ++it) {
+  for (it = shuffled_listP.begin(); it != shuffled_listP.end(); ++it) {
     P1 = *it;
     double dist = (a * P1.get_oX() + b * P1.get_oY() + c * P1.get_oZ() + d) / D;
     // std::cout << "dist= " << dist << std::endl;
 
     if (fabs(dist) > distanceToPlaneForCoplanarityTest) {
       vpDEBUG_TRACE(10, " points are not coplanar ");
-      //	TRACE(" points are not coplanar ") ;
       return false;
     }
   }
@@ -321,6 +331,24 @@ bool vpPose::coplanar(int &coplanar_plane_type)
   vpDEBUG_TRACE(10, " points are  coplanar ");
   //  vpTRACE(" points are  coplanar ") ;
 
+  // If the points are coplanar and the input/output parameters are different from NULL,
+  // getting the values of the plan coefficient and storing in the input/output parameters
+  if (p_a != NULL) {
+    *p_a = a;
+  }
+
+  if (p_b != NULL) {
+    *p_b = b;
+  }
+
+  if (p_c != NULL) {
+    *p_c = c;
+  }
+
+  if (p_d != NULL) {
+    *p_d = d;
+  }
+
   return true;
 }
 
@@ -332,6 +360,11 @@ bool vpPose::coplanar(int &coplanar_plane_type)
 
   \return The value of the sum of squared residuals in meter^2.
 
+  \note There is also the possibility to compute the residual expressed in pixel^2
+  using one of the following methods:
+  - vpPose::computeResidual(const vpHomogeneousMatrix &, const vpCameraParameters &)
+  - vpPose::computeResidual(const vpHomogeneousMatrix &, const vpCameraParameters &am, vpColVector &)
+
 */
 double vpPose::computeResidual(const vpHomogeneousMatrix &cMo) const
 {
@@ -349,6 +382,65 @@ double vpPose::computeResidual(const vpHomogeneousMatrix &cMo) const
   return (squared_error);
 }
 
+/*!
+  \brief Compute and return the sum of squared residuals expressed in pixel^2 for
+  the pose matrix \e cMo.
+
+  \param cMo : Input pose. The matrix that defines the pose to be tested.
+  \param cam : Camera parameters used to observe the points.
+
+  \return The value of the sum of squared residuals in pixel^2.
+
+  \note There is also the possibility to compute the residual expressed in meter^2 using
+  vpPose::computeResidual(const vpHomogeneousMatrix &)
+
+*/
+double vpPose::computeResidual(const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam) const
+{
+  vpColVector residuals;
+  return computeResidual(cMo, cam, residuals);
+}
+
+/*!
+  \brief Compute and return the sum of squared residuals expressed in pixel^2 for
+  the pose matrix \e cMo.
+
+  \param cMo : Input pose. The matrix that defines the pose to be tested.
+  \param cam : Camera parameters used to observe the points.
+  \param residuals: Input/output vector that will be resized and will contain the squared residuals expressed in pixel^2 of each point.
+
+  \return The value of the sum of squared residuals in pixel^2.
+
+  \note There is also the possibility to compute the residual expressed in meter^2 using
+  vpPose::computeResidual(const vpHomogeneousMatrix &)
+
+*/
+double vpPose::computeResidual(const vpHomogeneousMatrix &cMo, const vpCameraParameters &cam, vpColVector &residuals) const
+{
+  double squared_error = 0;
+  residuals.resize(static_cast<unsigned int>(listP.size()));
+  vpPoint P;
+  unsigned int i = 0;
+  for (std::list<vpPoint>::const_iterator it = listP.begin(); it != listP.end(); ++it) {
+    P = *it;
+    double x = P.get_x();
+    double y = P.get_y();
+
+    double u_initial = 0., v_initial = 0.;
+    vpMeterPixelConversion::convertPoint(cam, x, y, u_initial, v_initial);
+
+    P.track(cMo);
+
+    double u_moved = 0., v_moved = 0.;
+    vpMeterPixelConversion::convertPoint(cam, P.get_x(), P.get_y(), u_moved, v_moved);
+
+    double squaredResidual = vpMath::sqr(u_moved - u_initial) + vpMath::sqr(v_moved - v_initial);
+    residuals[i++] = squaredResidual;
+    squared_error += squaredResidual;
+  }
+  return (squared_error);
+}
+
 /*!
   Compute the pose according to the desired method which are:
   - vpPose::LAGRANGE: Linear Lagrange approach (test is done to switch between
@@ -368,14 +460,16 @@ double vpPose::computeResidual(const vpHomogeneousMatrix &cMo) const
   initialized by Dementhon approach
   - vpPose::LAGRANGE_VIRTUAL_VS: Non linear virtual visual servoing approach
   initialized by Lagrange approach
+  - vpPose::DEMENTHON_LAGRANGE_VIRTUAL_VS: Non linear virtual visual servoing approach
+  initialized by either Dementhon or Lagrange approach, depending on which method
+  has the smallest residual.
   - vpPose::RANSAC: Robust Ransac aproach (doesn't need an initialization)
 
 */
 bool vpPose::computePose(vpPoseMethodType method, vpHomogeneousMatrix &cMo, bool (*func)(const vpHomogeneousMatrix &))
 {
   if (npt < 4) {
-    throw(vpPoseException(vpPoseException::notEnoughPointError,
-                          "Not enough point (%d) to compute the pose  ", npt));
+    throw(vpPoseException(vpPoseException::notEnoughPointError, "Not enough point (%d) to compute the pose  ", npt));
   }
 
   switch (method) {
@@ -384,76 +478,88 @@ bool vpPose::computePose(vpPoseMethodType method, vpHomogeneousMatrix &cMo, bool
   case DEMENTHON_LOWE: {
     if (npt < 4) {
       throw(vpPoseException(vpPoseException::notEnoughPointError,
-                            "Dementhon method cannot be used in that case "
-                            "(at least 4 points are required)"
-                            "Not enough point (%d) to compute the pose  ", npt));
+        "Dementhon method cannot be used in that case "
+        "(at least 4 points are required)"
+        "Not enough point (%d) to compute the pose  ",
+        npt));
     }
 
-    // test si les point 3D sont coplanaires
+    // test if the 3D points are coplanar
     int coplanar_plane_type = 0;
     bool plan = coplanar(coplanar_plane_type);
     if (plan == true) {
       poseDementhonPlan(cMo);
-    } else {
+    }
+    else {
       poseDementhonNonPlan(cMo);
     }
-  } break;
+    break;
+  }
   case LAGRANGE:
   case LAGRANGE_VIRTUAL_VS:
   case LAGRANGE_LOWE: {
-    // test si les point 3D sont coplanaires
-    int coplanar_plane_type;
-    bool plan = coplanar(coplanar_plane_type);
+    // test if the 3D points are coplanar
+    double a, b, c, d; // To get the plan coefficients if the points are coplanar
+    int coplanar_plane_type = 0;
+    bool plan = coplanar(coplanar_plane_type, &a, &b, &c, &d);
 
-    if (plan == true)
-    {
+    if (plan == true) {
 
       if (coplanar_plane_type == 4) {
-        throw(vpPoseException(vpPoseException::notEnoughPointError,
-                              "Lagrange method cannot be used in that case "
-                              "(points are collinear)"));
+        throw(vpPoseException(vpPoseException::notEnoughPointError, "Lagrange method cannot be used in that case "
+          "(points are collinear)"));
       }
       if (npt < 4) {
         throw(vpPoseException(vpPoseException::notEnoughPointError,
-                              "Lagrange method cannot be used in that case "
-                              "(at least 4 points are required). "
-                              "Not enough point (%d) to compute the pose  ", npt));
+          "Lagrange method cannot be used in that case "
+          "(at least 4 points are required). "
+          "Not enough point (%d) to compute the pose  ",
+          npt));
       }
-      poseLagrangePlan(cMo);
-    } else {
+      poseLagrangePlan(cMo, &plan, &a, &b, &c, &d);
+    }
+    else {
       if (npt < 6) {
         throw(vpPoseException(vpPoseException::notEnoughPointError,
-                              "Lagrange method cannot be used in that case "
-                              "(at least 6 points are required when 3D points are non coplanar). "
-                              "Not enough point (%d) to compute the pose  ", npt));
+          "Lagrange method cannot be used in that case "
+          "(at least 6 points are required when 3D points are non coplanar). "
+          "Not enough point (%d) to compute the pose  ",
+          npt));
       }
       poseLagrangeNonPlan(cMo);
     }
-  } break;
-  case RANSAC:
+    break;
+  }
+  case RANSAC: {
     if (npt < 4) {
       throw(vpPoseException(vpPoseException::notEnoughPointError,
-                            "Ransac method cannot be used in that case "
-                            "(at least 4 points are required). "
-                            "Not enough point (%d) to compute the pose  ", npt));
+        "Ransac method cannot be used in that case "
+        "(at least 4 points are required). "
+        "Not enough point (%d) to compute the pose  ",
+        npt));
     }
-      return poseRansac(cMo, func);
-    break;
+    return poseRansac(cMo, func);
+  }
   case LOWE:
   case VIRTUAL_VS:
     break;
+  case DEMENTHON_LAGRANGE_VIRTUAL_VS: {
+    return computePoseDementhonLagrangeVVS(cMo);
+  }
   }
 
   switch (method) {
   case LAGRANGE:
   case DEMENTHON:
+  case DEMENTHON_LAGRANGE_VIRTUAL_VS:
   case RANSAC:
     break;
   case VIRTUAL_VS:
   case LAGRANGE_VIRTUAL_VS:
   case DEMENTHON_VIRTUAL_VS: {
     poseVirtualVS(cMo);
-  } break;
+    break;
+  }
   case LOWE:
   case LAGRANGE_LOWE:
   case DEMENTHON_LOWE: {
@@ -461,10 +567,109 @@ bool vpPose::computePose(vpPoseMethodType method, vpHomogeneousMatrix &cMo, bool
   } break;
   }
 
-  // If here, there was no exception thrown so return true
   return true;
 }
 
+/**
+ * @brief Method that first computes the pose \b cMo using the linear approaches of Dementhon and Lagrange
+ * and then uses the non-linear Virtual Visual Servoing approach to affine the pose which
+ * had the lowest residual.
+ *
+ * @param cMo the pose of the object with regard to the camera.
+ * @return true the pose computation was succesful.
+ * @return false an error occurred during the pose computation.
+ */
+bool vpPose::computePoseDementhonLagrangeVVS(vpHomogeneousMatrix &cMo)
+{
+  vpHomogeneousMatrix cMo_dementhon, cMo_lagrange;
+  double r_dementhon = std::numeric_limits<double>::max(), r_lagrange = std::numeric_limits<double>::max();
+  // test if the 3D points are coplanar
+  double a, b, c, d; // To get the plan coefficients if the points are coplanar
+  int coplanar_plane_type = 0;
+  bool plan = coplanar(coplanar_plane_type, &a, &b, &c, &d);
+  bool hasDementhonSucceeded(false), hasLagrangeSucceeded(false);
+  try {
+    if (plan) {
+      poseDementhonPlan(cMo_dementhon);
+    }
+    else {
+      poseDementhonNonPlan(cMo_dementhon);
+    }
+
+    r_dementhon = computeResidual(cMo_dementhon);
+    hasDementhonSucceeded = true; // We reached this point => no exception was thrown = method succeeded
+  }
+  catch (...) {
+    // An exception was thrown using the original assumption, trying we the other one
+    try {
+      if (plan) {
+        // Already tested poseDementhonPlan, now trying poseDementhonNonPlan
+        poseDementhonNonPlan(cMo_dementhon);
+      }
+      else {
+        // Already tested poseDementhonNonPlan, now trying poseDementhonPlan
+        poseDementhonPlan(cMo_dementhon);
+      }
+
+      r_dementhon = computeResidual(cMo_dementhon);
+      hasDementhonSucceeded = true; // We reached this point => no exception was thrown = method succeeded
+    }
+    catch (...) {
+      // The Dementhon method failed both with the planar and non-planar assumptions.
+      hasDementhonSucceeded = false;
+    }
+  }
+
+  try {
+    if (plan) {
+      // If plan is true, then a, b, c, d will have been set when we called coplanar.
+      poseLagrangePlan(cMo_lagrange, &plan, &a, &b, &c, &d);
+    }
+    else {
+      poseLagrangeNonPlan(cMo_lagrange);
+    }
+
+    r_lagrange = computeResidual(cMo_lagrange);
+    hasLagrangeSucceeded = true; // We reached this point => no exception was thrown = method succeeded
+  }
+  catch (...) {
+    // An exception was thrown using the original assumption, trying we the other one
+    try {
+      if (plan) {
+        // Already tested poseLagrangePlan, now trying poseLagrangeNonPlan
+        poseLagrangeNonPlan(cMo_lagrange);
+      }
+      else {
+        // Already tested poseLagrangeNonPlan, now trying poseLagrangePlan
+        // Because plan is false, then a, b, c, d will not have
+        // been initialized when calling coplanar
+        // We are expecting that the call to poseLagrangePlan will throw an exception
+        // because coplanar return false.
+        poseLagrangePlan(cMo_lagrange, &plan, &a, &b, &c, &d);
+      }
+
+      r_lagrange = computeResidual(cMo_lagrange);
+      hasLagrangeSucceeded = true; // We reached this point => no exception was thrown = method succeeded
+    }
+    catch (...) {
+      // The Lagrange method both failed with the planar and non-planar assumptions.
+      hasLagrangeSucceeded = false;
+    }
+  }
+
+  if ((hasDementhonSucceeded || hasLagrangeSucceeded)) {
+    // At least one of the linear methods managed to compute an initial pose.
+    // We initialize cMo with the method that had the lowest residual
+    cMo = (r_dementhon < r_lagrange) ? cMo_dementhon : cMo_lagrange;
+    // We now use the non-linear Virtual Visual Servoing method to improve the estimated cMo
+    return computePose(vpPose::VIRTUAL_VS, cMo);
+  }
+  else {
+    // None of the linear methods manage to compute an initial pose
+    return false;
+  }
+}
+
 void vpPose::printPoint()
 {
   vpPoint P;
@@ -487,7 +692,7 @@ void vpPose::printPoint()
    and z-axis respectively.
  */
 void vpPose::display(vpImage<unsigned char> &I, vpHomogeneousMatrix &cMo, vpCameraParameters &cam, double size,
-                     vpColor col)
+  vpColor col)
 {
   vpDisplay::displayFrame(I, cMo, cam, size, col);
 }
@@ -562,7 +767,7 @@ gives us the proportion of the rectangle
 \return int : OK if no pb occurs
 */
 double vpPose::poseFromRectangle(vpPoint &p1, vpPoint &p2, vpPoint &p3, vpPoint &p4, double lx, vpCameraParameters &cam,
-                                 vpHomogeneousMatrix &cMo)
+  vpHomogeneousMatrix &cMo)
 {
 
   std::vector<double> rectx(4);
