@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,12 +29,7 @@
  *
  * Description:
  * Pose computation.
- *
- * Authors:
- * Eric Marchand
- * Francois Chaumette
- *
- *****************************************************************************/
+ */
 
 #include <visp3/vision/vpPose.h>
 
@@ -43,10 +37,10 @@
 #define DEBUG_LEVEL2 0
 
 /**********************************************************************/
-/*	FONCTION 		:    CalculTranslation       */
-/*	ROLE  			: Calcul de la translation entre la   */
+/*  FONCTION     :    CalculTranslation       */
+/*  ROLE        : Calcul de la translation entre la   */
 /*                                camera et l'outil connaissant la    */
-/*                                rotation			      */
+/*                                rotation            */
 /**********************************************************************/
 
 static void calculTranslation(vpMatrix &a, vpMatrix &b, unsigned int nl, unsigned int nc1, unsigned int nc3,
@@ -73,8 +67,8 @@ static void calculTranslation(vpMatrix &a, vpMatrix &b, unsigned int nl, unsigne
 
     vpMatrix cta;
     vpMatrix ctb;
-    cta = ct * a; /* C^T A	*/
-    ctb = ct * b; /* C^T B	*/
+    cta = ct * a; /* C^T A  */
+    ctb = ct * b; /* C^T B  */
 
 #if (DEBUG_LEVEL2)
     {
@@ -123,8 +117,8 @@ static void calculTranslation(vpMatrix &a, vpMatrix &b, unsigned int nl, unsigne
 //   FONCTION LAGRANGE :
 //   -------------------
 // Resolution d'un systeme lineaire de la forme A x1 + B x2 = 0
-//  		sous la contrainte || x1 || = 1
-//  		ou A est de dimension nl x nc1 et B nl x nc2
+//      sous la contrainte || x1 || = 1
+//      ou A est de dimension nl x nc1 et B nl x nc2
 //*********************************************************************
 
 //#define EPS 1.e-5
@@ -205,7 +199,7 @@ static void lagrange(vpMatrix &a, vpMatrix &b, vpColVector &x1, vpColVector &x2)
     //    vpMatrix v ;
     e.svd(x1, ata); // destructif sur e
     // calcul du vecteur propre de E correspondant a la valeur propre min.
-    /* calcul de SVmax	*/
+    /* calcul de SVmax  */
     imin = 0;
     // FC : Pourquoi calculer SVmax ??????
     //     double  svm = 0.0;
@@ -213,7 +207,7 @@ static void lagrange(vpMatrix &a, vpMatrix &b, vpColVector &x1, vpColVector &x2)
     //    {
     //      if (x1[i] > svm) { svm = x1[i]; imin = i; }
     //    }
-    //    svm *= EPS;	/* pour le rang	*/
+    //    svm *= EPS;  /* pour le rang  */
 
     for (i = 0; i < x1.getRows(); i++)
       if (x1[i] < x1[imin])
@@ -248,118 +242,61 @@ static void lagrange(vpMatrix &a, vpMatrix &b, vpColVector &x1, vpColVector &x2)
 //#undef EPS
 
 /*!
-\brief  Compute the pose of a planar object using Lagrange approach.
+  \brief  Compute the pose of a planar object using Lagrange approach.
 
-\param cMo : Estimated pose. No initialisation is requested to estimate cMo.
+  \param cMo : Estimated pose. No initialisation is requested to estimate cMo.
+  \param p_isPlan : if different from NULL, indicates if the object is planar or not.
+  \param p_a : if different from NULL, the a coefficient of the plan formed by the points.
+  \param p_b : if different from NULL, the b coefficient of the plan formed by the points.
+  \param p_c : if different from NULL, the c coefficient of the plan formed by the points.
+  \param p_d : if different from NULL, the d coefficient of the plan formed by the points.
 */
 
-void vpPose::poseLagrangePlan(vpHomogeneousMatrix &cMo)
+void vpPose::poseLagrangePlan(vpHomogeneousMatrix &cMo, bool *p_isPlan, double *p_a, double *p_b, double *p_c, double *p_d)
 {
 #if (DEBUG_LEVEL1)
   std::cout << "begin vpPose::PoseLagrangePlan(...) " << std::endl;
 #endif
   // determination of the plane equation a X + b Y + c Z + d = 0
-  // FC : long copy/paste from vpPose::coplanar. To be improved...
-  vpPoint P1, P2, P3;
-  double x1 = 0, x2 = 0, x3 = 0, y1 = 0, y2 = 0, y3 = 0, z1 = 0, z2 = 0, z3 = 0;
+  double a, b, c, d;
 
-  // Get three 3D points that are not collinear and that are not at origin
-  // FC : I think one point could be at origin (to be checked)
-
-  bool degenerate = true;
-  bool not_on_origin = true;
-  std::list<vpPoint>::const_iterator it_tmp;
-
-  std::list<vpPoint>::const_iterator it_i, it_j, it_k;
-  for (it_i = listP.begin(); it_i != listP.end(); ++it_i) {
-    if (degenerate == false) {
-      // std::cout << "Found a non degenerate configuration" << std::endl;
-      break;
+  // Checking if coplanar has already been called and if the plan coefficients have been given
+  if((p_isPlan != NULL) && (p_a != NULL) && (p_b != NULL) && (p_c != NULL) && (p_d != NULL))
+  {
+    if(*p_isPlan)
+    {
+      // All the pointers towards the plan coefficients are different from NULL => using them in the rest of the method
+      a = *p_a;
+      b = *p_b;
+      c = *p_c;
+      d = *p_d;
     }
-    P1 = *it_i;
-    // Test if point is on origin
-    if ((std::fabs(P1.get_oX()) <= std::numeric_limits<double>::epsilon()) &&
-        (std::fabs(P1.get_oY()) <= std::numeric_limits<double>::epsilon()) &&
-        (std::fabs(P1.get_oZ()) <= std::numeric_limits<double>::epsilon())) {
-      not_on_origin = false;
-    } else {
-      not_on_origin = true;
+    else
+    {
+      // The call to coplanar that was performed outside vpPose::poseLagrangePlan indicated that the points are not coplanar.
+      throw vpException(vpException::fatalError, "Called vpPose::poseLagrangePlan but the call to vpPose::coplanar done outside the method indicated that the points are not coplanar");
     }
-    if (not_on_origin) {
-      it_tmp = it_i;
-      ++it_tmp; // j = i+1
-      for (it_j = it_tmp; it_j != listP.end(); ++it_j) {
-        if (degenerate == false) {
-          // std::cout << "Found a non degenerate configuration" << std::endl;
-          break;
-        }
-        P2 = *it_j;
-        if ((std::fabs(P2.get_oX()) <= std::numeric_limits<double>::epsilon()) &&
-            (std::fabs(P2.get_oY()) <= std::numeric_limits<double>::epsilon()) &&
-            (std::fabs(P2.get_oZ()) <= std::numeric_limits<double>::epsilon())) {
-          not_on_origin = false;
-        } else {
-          not_on_origin = true;
-        }
-        if (not_on_origin) {
-          it_tmp = it_j;
-          ++it_tmp; // k = j+1
-          for (it_k = it_tmp; it_k != listP.end(); ++it_k) {
-            P3 = *it_k;
-            if ((std::fabs(P3.get_oX()) <= std::numeric_limits<double>::epsilon()) &&
-                (std::fabs(P3.get_oY()) <= std::numeric_limits<double>::epsilon()) &&
-                (std::fabs(P3.get_oZ()) <= std::numeric_limits<double>::epsilon())) {
-              not_on_origin = false;
-            } else {
-              not_on_origin = true;
-            }
-            if (not_on_origin) {
-              x1 = P1.get_oX();
-              x2 = P2.get_oX();
-              x3 = P3.get_oX();
-
-              y1 = P1.get_oY();
-              y2 = P2.get_oY();
-              y3 = P3.get_oY();
-
-              z1 = P1.get_oZ();
-              z2 = P2.get_oZ();
-              z3 = P3.get_oZ();
-
-              vpColVector a_b(3), b_c(3), cross_prod;
-              a_b[0] = x1 - x2;
-              a_b[1] = y1 - y2;
-              a_b[2] = z1 - z2;
-              b_c[0] = x2 - x3;
-              b_c[1] = y2 - y3;
-              b_c[2] = z2 - z3;
-
-              cross_prod = vpColVector::crossProd(a_b, b_c);
-              if (cross_prod.sumSquare() <= std::numeric_limits<double>::epsilon())
-                degenerate = true; // points are collinear
-              else
-                degenerate = false;
-            }
-            if (degenerate == false)
-              break;
-          }
-        }
-      }
+  }
+  else
+  {
+    // At least one of the coefficient is a NULL pointer => calling coplanar by ourselves
+    int coplanarType;
+    bool areCoplanar = coplanar(coplanarType, &a, &b, &c, &d);
+    if(!areCoplanar)
+    {
+      throw vpException(vpException::fatalError, "Called vpPose::poseLagrangePlan but call to vpPose::coplanar indicates that the points are not coplanar");
     }
   }
-  double a = y1 * z2 - y1 * z3 - y2 * z1 + y2 * z3 + y3 * z1 - y3 * z2;
-  double b = -x1 * z2 + x1 * z3 + x2 * z1 - x2 * z3 - x3 * z1 + x3 * z2;
-  double c = x1 * y2 - x1 * y3 - x2 * y1 + x2 * y3 + x3 * y1 - x3 * y2;
-  double d = -x1 * y2 * z3 + x1 * y3 * z2 + x2 * y1 * z3 - x2 * y3 * z1 - x3 * y1 * z2 + x3 * y2 * z1;
 
-  if (c < 0.0) {  // imposing c >= 0
+
+  if (c < 0.0) { // imposing c >= 0
     a = -a;
     b = -b;
     c = -c;
     d = -d;
   }
   // to have (a,b,c) as a unit vector if it was not the case
-  double n = 1.0/sqrt(a*a+ b*b + c*c);  // Not possible to have a NaN...
+  double n = 1.0 / sqrt(a * a + b * b + c * c); // Not possible to have a NaN...
   a *= n;
   b *= n;
   c *= n;
@@ -372,17 +309,16 @@ void vpPose::poseLagrangePlan(vpHomogeneousMatrix &cMo)
   r3[1] = b;
   r3[2] = c;
   // build r1 as a unit vector orthogonal to r3
-  double n1 = sqrt(1.0-a*a);
-  double n2 = sqrt(1.0-b*b);
-  if (n1 >= n2){
+  double n1 = sqrt(1.0 - a * a);
+  double n2 = sqrt(1.0 - b * b);
+  if (n1 >= n2) {
     r1[0] = n1;
-    r1[1] = -a*b/n1;
-    r1[2] = -a*c/n1;
-  }
-  else{
-    r1[0] = -a*b/n2;
+    r1[1] = -a * b / n1;
+    r1[2] = -a * c / n1;
+  } else {
+    r1[0] = -a * b / n2;
     r1[1] = n2;
-    r1[2] = -b*c/n2;
+    r1[2] = -b * c / n2;
   }
   // double norm = r1[0]*r1[0] + r1[1]*r1[1] + r1[2]*r1[2];
   // double crossprod = r1[0]*r3[0] + r1[1]*r3[1] + r1[2]*r3[2];
@@ -391,7 +327,7 @@ void vpPose::poseLagrangePlan(vpHomogeneousMatrix &cMo)
   r2 = vpColVector::crossProd(r3, r1);
 
   vpHomogeneousMatrix fMo;
-  for (unsigned int i=0;i<3;i++){
+  for (unsigned int i = 0; i < 3; i++) {
     fMo[0][i] = r1[i];
     fMo[1][i] = r2[i];
     fMo[2][i] = r3[i];
@@ -463,7 +399,7 @@ void vpPose::poseLagrangePlan(vpHomogeneousMatrix &cMo)
   }
 #endif
 
-  if (X2[5] < 0.0) { /* to obtain Zo > 0	*/
+  if (X2[5] < 0.0) { /* to obtain Zo > 0  */
     for (unsigned int i = 0; i < 3; i++)
       X1[i] = -X1[i];
     for (unsigned int i = 0; i < 6; i++)
@@ -475,7 +411,7 @@ void vpPose::poseLagrangePlan(vpHomogeneousMatrix &cMo)
   }
   for (unsigned int i = 0; i < 3; i++) {
     X2[i] -= (s * X1[i]);
-  } /* X1^T X2 = 0	*/
+  } /* X1^T X2 = 0  */
 
   // s = 0.0;
   // for (i=0;i<3;i++)  {s += (X2[i]*X2[i]);}
@@ -498,7 +434,7 @@ void vpPose::poseLagrangePlan(vpHomogeneousMatrix &cMo)
   s = 1.0 / sqrt(s);
   for (unsigned int i = 0; i < 3; i++) {
     X2[i] *= s;
-  } /* X2^T X2 = 1	*/
+  } /* X2^T X2 = 1  */
 
   calculTranslation(A, B, nl, 3, 3, X1, X2);
 
@@ -513,13 +449,13 @@ void vpPose::poseLagrangePlan(vpHomogeneousMatrix &cMo)
   cMf[0][2] = (X1[1] * X2[2]) - (X1[2] * X2[1]);
   cMf[1][2] = (X1[2] * X2[0]) - (X1[0] * X2[2]);
   cMf[2][2] = (X1[0] * X2[1]) - (X1[1] * X2[0]);
-  /* calcul de la matrice de passage	*/
+  /* calcul de la matrice de passage  */
   for (unsigned int i = 0; i < 3; i++) {
     cMf[i][0] = X1[i];
     cMf[i][1] = X2[i];
     cMf[i][3] = X2[i + 3];
   }
-  //std::cout << "cMf : "  << std::endl << cMf  << std::endl;
+  // std::cout << "cMf : "  << std::endl << cMf  << std::endl;
 
   // Apply the transform to go back to object frame
   cMo = cMf * fMo;
@@ -603,9 +539,9 @@ void vpPose::poseLagrangeNonPlan(vpHomogeneousMatrix &cMo)
     lagrange(a, b, X1, X2);
     //  if (err != OK)
     {
-      //      std::cout << "in (CLagrange.cc)Lagrange returns " ;
-      //    PrintError(err) ;
-      //    return err ;
+        //      std::cout << "in (CLagrange.cc)Lagrange returns " ;
+        //    PrintError(err) ;
+        //    return err ;
     }
 
 #if (DEBUG_LEVEL2)
@@ -615,7 +551,7 @@ void vpPose::poseLagrangeNonPlan(vpHomogeneousMatrix &cMo)
     }
 #endif
 
-    if (X2[8] < 0.0) { /* car Zo > 0	*/
+    if (X2[8] < 0.0) { /* car Zo > 0  */
       X1 *= -1;
       X2 *= -1;
     }
@@ -625,7 +561,7 @@ void vpPose::poseLagrangeNonPlan(vpHomogeneousMatrix &cMo)
     }
     for (i = 0; i < 3; i++) {
       X2[i] -= (s * X1[i]);
-    } /* X1^T X2 = 0	*/
+    } /* X1^T X2 = 0  */
 
     // s = 0.0;
     // for (i=0;i<3;i++)  {s += (X2[i]*X2[i]);}
@@ -649,7 +585,7 @@ void vpPose::poseLagrangeNonPlan(vpHomogeneousMatrix &cMo)
     s = 1.0 / sqrt(s);
     for (i = 0; i < 3; i++) {
       X2[i] *= s;
-    } /* X2^T X2 = 1	*/
+    } /* X2^T X2 = 1  */
 
     X2[3] = (X1[1] * X2[2]) - (X1[2] * X2[1]);
     X2[4] = (X1[2] * X2[0]) - (X1[0] * X2[2]);
