@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,12 +29,7 @@
  *
  * Description:
  * Pose computation.
- *
- * Authors:
- * Eric Marchand
- * Francois Chaumette
- *
- *****************************************************************************/
+ */
 
 #include <float.h>
 #include <limits> // numeric_limits
@@ -43,7 +37,7 @@
 #include <string.h>
 
 // besoin de la librairie mathematique, en particulier des
-// fonctions de minimisation de Levenberg Marquartd
+// fonctions de minimization de Levenberg Marquartd
 #include <visp3/vision/vpLevenbergMarquartd.h>
 #include <visp3/vision/vpPose.h>
 
@@ -60,22 +54,22 @@
 // ------------------------------------------------------------------------
 
 /*
- * MACRO	: MIJ
+ * MACRO  : MIJ
  *
- * ENTREE	:
- * m		Matrice.
- * i		Indice ligne   de l'element.
- * j		Indice colonne de l'element.
- * s		Taille en nombre d'elements d'une ligne de la matrice "m".
+ * ENTREE  :
+ * m    Matrice.
+ * i    Indice ligne   de l'element.
+ * j    Indice colonne de l'element.
+ * s    Taille en nombre d'elements d'une ligne de la matrice "m".
  *
- * DESCRIPTION	:
+ * DESCRIPTION  :
  * La macro-instruction calcule l'adresse de l'element de la "i"eme ligne et
  * de la "j"eme colonne de la matrice "m", soit &m[i][j].
  *
- * RETOUR	:
+ * RETOUR  :
  * L'adresse de m[i][j] est retournee.
  *
- * HISTORIQUE	:
+ * HISTORIQUE  :
  * 1.00 - 11/02/93 - Original.
  */
 #define MIJ(m, i, j, s) ((m) + ((long)(i) * (long)(s)) + (long)(j))
@@ -113,25 +107,25 @@ void eval_function(int npt, double *xc, double *f)
 }
 
 /*
- * PROCEDURE	: fcn
+ * PROCEDURE  : fcn
  *
- * ENTREES	:
- * m		Nombre d'equations.
- * n		Nombre de variables.
- * xc		Valeur courante des parametres.
- * fvecc	Resultat de l'evaluation de la fonction.
- * ldfjac	Plus grande dimension de la matrice jac.
- * iflag	Choix du calcul de la fonction ou du jacobien.
+ * ENTREES  :
+ * m    Nombre d'equations.
+ * n    Nombre de variables.
+ * xc    Valeur courante des parametres.
+ * fvecc  Resultat de l'evaluation de la fonction.
+ * ldfjac  Plus grande dimension de la matrice jac.
+ * iflag  Choix du calcul de la fonction ou du jacobien.
  *
- * SORTIE	:
- * jac		Jacobien de la fonction.
+ * SORTIE  :
+ * jac    Jacobien de la fonction.
  *
- * DESCRIPTION	:
+ * DESCRIPTION  :
  * La procedure calcule la fonction et le jacobien.
  * Si iflag == 1, la procedure calcule la fonction en "xc" et le resultat est
- * 		  stocke dans "fvecc" et "fjac" reste inchange.
+ *       stocke dans "fvecc" et "fjac" reste inchange.
  * Si iflag == 2, la procedure calcule le jacobien en "xc" et le resultat est
- * 		  stocke dans "fjac" et "fvecc" reste inchange.
+ *       stocke dans "fjac" et "fvecc" reste inchange.
  *
  *  HISTORIQUE     :
  * 1.00 - xx/xx/xx - Original.
@@ -173,10 +167,10 @@ void fcn(int m, int n, double *xc, double *fvecc, double *jac, int ldfjac, int i
 
     for (int i = 0; i < npt; i++) {
       double x = XO[i];
-      double y = YO[i]; /* coordonnees du point i	*/
+      double y = YO[i]; /* coordonnees du point i  */
       double z = ZO[i];
 
-      /* coordonnees du point i dans le repere camera	*/
+      /* coordonnees du point i dans le repere camera  */
       double rx = rd[0][0] * x + rd[0][1] * y + rd[0][2] * z + xc[0];
       double ry = rd[1][0] * x + rd[1][1] * y + rd[1][2] * z + xc[1];
       double rz = rd[2][0] * x + rd[2][1] * y + rd[2][2] * z + xc[2];
@@ -248,7 +242,7 @@ void fcn(int m, int n, double *xc, double *fvecc, double *jac, int ldfjac, int i
         *MIJ(jac, 5, npt + i, ldfjac) = 0.0;
       }
     }
-  } /* fin else if iflag ==2	*/
+  } /* fin else if iflag ==2  */
 }
 
 /*!
@@ -271,14 +265,14 @@ void vpPose::poseLowe(vpHomogeneousMatrix &cMo)
   int tst_lmder;
   double f[2 * NBPTMAX], sol[NBR_PAR];
   double tol, jac[NBR_PAR][2 * NBPTMAX], wa[2 * NBPTMAX + 50];
-  //  double	u[3];	/* vecteur de rotation */
-  //  double	rd[3][3]; /* matrice de rotation */
+  //  double  u[3];  /* vecteur de rotation */
+  //  double  rd[3][3]; /* matrice de rotation */
 
-  n = NBR_PAR;                                  /* nombres d'inconnues	*/
-  m = (int)(2 * npt);                           /* nombres d'equations	*/
-  lwa = 2 * NBPTMAX + 50;                       /* taille du vecteur de travail	*/
-  ldfjac = 2 * NBPTMAX;                         /* nombre d'elements max sur une ligne	*/
-  tol = std::numeric_limits<double>::epsilon(); /* critere d'arret	*/
+  n = NBR_PAR;                                  /* nombres d'inconnues  */
+  m = (int)(2 * npt);                           /* nombres d'equations  */
+  lwa = 2 * NBPTMAX + 50;                       /* taille du vecteur de travail  */
+  ldfjac = 2 * NBPTMAX;                         /* nombre d'elements max sur une ligne  */
+  tol = std::numeric_limits<double>::epsilon(); /* critere d'arret  */
 
   //  c = cam ;
   // for (i=0;i<3;i++)
@@ -306,7 +300,7 @@ void vpPose::poseLowe(vpHomogeneousMatrix &cMo)
   tst_lmder = lmder1(&fcn, m, n, sol, f, &jac[0][0], ldfjac, tol, &info, ipvt, lwa, wa);
   if (tst_lmder == -1) {
     std::cout << " in CCalculPose::PoseLowe(...) : ";
-    std::cout << "pb de minimisation,  returns FATAL_ERROR";
+    std::cout << "pb de minimization,  returns FATAL_ERROR";
     // return FATAL_ERROR ;
   }
 
@@ -320,8 +314,8 @@ void vpPose::poseLowe(vpHomogeneousMatrix &cMo)
 
   vpRotationMatrix rd(u);
   cMo.insert(rd);
-//  rot_mat(u,rd);
-//  for (i=0;i<3;i++) for (j=0;j<3;j++) cMo[i][j] = rd[i][j];
+  //  rot_mat(u,rd);
+  //  for (i=0;i<3;i++) for (j=0;j<3;j++) cMo[i][j] = rd[i][j];
 
 #if (DEBUG_LEVEL1)
   std::cout << "end CCalculPose::PoseLowe(...) " << std::endl;
