@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,13 +29,7 @@
  *
  * Description:
  * Pose computation.
- *
- * Authors:
- * Eric Marchand
- * Aurelien Yol
- * Souriya Trinh
- *
- *****************************************************************************/
+ */
 
 /*!
   \file vpPoseRansac.cpp
@@ -68,11 +61,13 @@ namespace
 struct CompareObjectPointDegenerate {
   bool operator()(const vpPoint &point1, const vpPoint &point2) const
   {
-    const double dist1 = point1.get_oX()*point1.get_oX() + point1.get_oY()*point1.get_oY() + point1.get_oZ()*point1.get_oZ();
-    const double dist2 = point2.get_oX()*point2.get_oX() + point2.get_oY()*point2.get_oY() + point2.get_oZ()*point2.get_oZ();
-    if (dist1 - dist2 < -3*eps*eps)
+    const double dist1 =
+        point1.get_oX() * point1.get_oX() + point1.get_oY() * point1.get_oY() + point1.get_oZ() * point1.get_oZ();
+    const double dist2 =
+        point2.get_oX() * point2.get_oX() + point2.get_oY() * point2.get_oY() + point2.get_oZ() * point2.get_oZ();
+    if (dist1 - dist2 < -3 * eps * eps)
       return true;
-    if (dist1 - dist2 > 3*eps*eps)
+    if (dist1 - dist2 > 3 * eps * eps)
       return false;
 
     if (point1.oP[0] - point2.oP[0] < -eps)
@@ -98,11 +93,11 @@ struct CompareObjectPointDegenerate {
 struct CompareImagePointDegenerate {
   bool operator()(const vpPoint &point1, const vpPoint &point2) const
   {
-    const double dist1 = point1.get_x()*point1.get_x() + point1.get_y()*point1.get_y();
-    const double dist2 = point2.get_x()*point2.get_x() + point2.get_y()*point2.get_y();
-    if (dist1 - dist2 < -2*eps*eps)
+    const double dist1 = point1.get_x() * point1.get_x() + point1.get_y() * point1.get_y();
+    const double dist2 = point2.get_x() * point2.get_x() + point2.get_y() * point2.get_y();
+    if (dist1 - dist2 < -2 * eps * eps)
       return true;
-    if (dist1 - dist2 > 2*eps*eps)
+    if (dist1 - dist2 > 2 * eps * eps)
       return false;
 
     if (point1.p[0] - point2.p[0] < -eps)
@@ -132,7 +127,7 @@ struct FindDegeneratePoint {
 
   vpPoint m_pt;
 };
-}
+} // namespace
 
 bool vpPose::RansacFunctor::poseRansacImpl()
 {
@@ -154,7 +149,6 @@ bool vpPose::RansacFunctor::poseRansacImpl()
     // degenerate point if the flag is set
     std::vector<vpPoint> cur_inliers;
 
-    vpHomogeneousMatrix cMo_lagrange, cMo_dementhon;
     // Use a temporary variable because if not, the cMo passed in parameters
     // will be modified when
     // we compute the pose for the minimal sample sets but if the pose is not
@@ -204,49 +198,23 @@ bool vpPose::RansacFunctor::poseRansacImpl()
       continue;
     }
 
-    // Flags set if pose computation is OK
-    bool is_valid_lagrange = false;
-    bool is_valid_dementhon = false;
-
-    // Set maximum value for residuals
-    double r_lagrange = DBL_MAX;
-    double r_dementhon = DBL_MAX;
+    bool is_pose_valid = false;
+    double r_min = DBL_MAX;
 
     try {
-      poseMin.computePose(vpPose::LAGRANGE, cMo_lagrange);
-      r_lagrange = poseMin.computeResidual(cMo_lagrange);
-      is_valid_lagrange = true;
-    } catch (...) { }
-
-    try {
-      poseMin.computePose(vpPose::DEMENTHON, cMo_dementhon);
-      r_dementhon = poseMin.computeResidual(cMo_dementhon);
-      is_valid_dementhon = true;
-    } catch (...) { }
+      is_pose_valid = poseMin.computePose(vpPose::DEMENTHON_LAGRANGE_VIRTUAL_VS, cMo_tmp);
+      r_min = poseMin.computeResidual(cMo_tmp);
+    } catch (...) {
+    }
 
     // If residual returned is not a number (NAN), set valid to false
-    if (vpMath::isNaN(r_lagrange)) {
-      is_valid_lagrange = false;
-      r_lagrange = DBL_MAX;
+    if (vpMath::isNaN(r_min)) {
+      is_pose_valid = false;
     }
 
-    if (vpMath::isNaN(r_dementhon)) {
-      is_valid_dementhon = false;
-      r_dementhon = DBL_MAX;
-    }
-
-    // If at least one pose computation is OK,
-    // we can continue, otherwise pick another random set
-    if (is_valid_lagrange || is_valid_dementhon) {
-      double r;
-      if (r_lagrange < r_dementhon) {
-        r = r_lagrange;
-        cMo_tmp = cMo_lagrange;
-      } else {
-        r = r_dementhon;
-        cMo_tmp = cMo_dementhon;
-      }
-      r = sqrt(r) / (double)nbMinRandom; // FS should be r = sqrt(r / (double)nbMinRandom);
+    // If at pose computation is OK we can continue, otherwise pick another random set
+    if (is_pose_valid) {
+      double r = sqrt(r_min) / (double)nbMinRandom; // FS should be r = sqrt(r_min / (double)nbMinRandom);
       // Filter the pose using some criterion (orientation angles,
       // translations, etc.)
       bool isPoseValid = true;
@@ -432,11 +400,11 @@ bool vpPose::poseRansac(vpHomogeneousMatrix &cMo, bool (*func)(const vpHomogeneo
       }
     }
 
-    for (auto& worker : ransacWorkers) {
+    for (auto &worker : ransacWorkers) {
       threadpool.emplace_back(&RansacFunctor::operator(), &worker);
     }
 
-    for (auto& th : threadpool) {
+    for (auto &th : threadpool) {
       th.join();
     }
 
@@ -512,57 +480,18 @@ bool vpPose::poseRansac(vpHomogeneousMatrix &cMo, bool (*func)(const vpHomogeneo
         ransacInlierIndex.push_back((unsigned int)mapOfUniquePointIndex[*it_index]);
       }
 
-      // Flags set if pose computation is OK
-      bool is_valid_lagrange = false;
-      bool is_valid_dementhon = false;
+      pose.setCovarianceComputation(computeCovariance);
+      pose.computePose(vpPose::DEMENTHON_LAGRANGE_VIRTUAL_VS, cMo);
 
-      // Set maximum value for residuals
-      double r_lagrange = DBL_MAX;
-      double r_dementhon = DBL_MAX;
-
-      try {
-        pose.computePose(vpPose::LAGRANGE, cMo_lagrange);
-        r_lagrange = pose.computeResidual(cMo_lagrange);
-        is_valid_lagrange = true;
-      } catch (...) { }
-
-      try {
-        pose.computePose(vpPose::DEMENTHON, cMo_dementhon);
-        r_dementhon = pose.computeResidual(cMo_dementhon);
-        is_valid_dementhon = true;
-      } catch (...) { }
-
-      // If residual returned is not a number (NAN), set valid to false
-      if (vpMath::isNaN(r_lagrange)) {
-        is_valid_lagrange = false;
-        r_lagrange = DBL_MAX;
+      // In some rare cases, the final pose could not respect the pose
+      // criterion even  if the 4 minimal points picked respect the pose
+      // criterion.
+      if (func != NULL && !func(cMo)) {
+        return false;
       }
 
-      if (vpMath::isNaN(r_dementhon)) {
-        is_valid_dementhon = false;
-        r_dementhon = DBL_MAX;
-      }
-
-      if (is_valid_lagrange || is_valid_dementhon) {
-        if (r_lagrange < r_dementhon) {
-          cMo = cMo_lagrange;
-        } else {
-          cMo = cMo_dementhon;
-        }
-
-        pose.setCovarianceComputation(computeCovariance);
-        pose.computePose(vpPose::VIRTUAL_VS, cMo);
-
-        // In some rare cases, the final pose could not respect the pose
-        // criterion even  if the 4 minimal points picked respect the pose
-        // criterion.
-        if (func != NULL && !func(cMo)) {
-          return false;
-        }
-
-        if (computeCovariance) {
-          covarianceMatrix = pose.covarianceMatrix;
-        }
+      if (computeCovariance) {
+        covarianceMatrix = pose.covarianceMatrix;
       }
     } else {
       return false;
@@ -662,20 +591,17 @@ int vpPose::computeRansacIterations(double probability, double epsilon, const in
 void vpPose::findMatch(std::vector<vpPoint> &p2D, std::vector<vpPoint> &p3D,
                        const unsigned int &numberOfInlierToReachAConsensus, const double &threshold,
                        unsigned int &ninliers, std::vector<vpPoint> &listInliers, vpHomogeneousMatrix &cMo,
-                       const int &maxNbTrials,
-                       bool useParallelRansac, unsigned int nthreads,
+                       const int &maxNbTrials, bool useParallelRansac, unsigned int nthreads,
                        bool (*func)(const vpHomogeneousMatrix &))
 {
   vpPose pose;
 
-  int nbPts = 0;
   for (unsigned int i = 0; i < p2D.size(); i++) {
     for (unsigned int j = 0; j < p3D.size(); j++) {
       vpPoint pt(p3D[j].getWorldCoordinates());
       pt.set_x(p2D[i].get_x());
       pt.set_y(p2D[i].get_y());
       pose.addPoint(pt);
-      nbPts++;
     }
   }
 
@@ -688,7 +614,7 @@ void vpPose::findMatch(std::vector<vpPoint> &p2D, std::vector<vpPoint> &p3D,
   } else {
     pose.setUseParallelRansac(useParallelRansac);
     pose.setNbParallelRansacThreads(nthreads);
-    //Since we add duplicate points, we need to check for degenerate configuration
+    // Since we add duplicate points, we need to check for degenerate configuration
     pose.setRansacFilterFlag(vpPose::CHECK_DEGENERATE_POINTS);
     pose.setRansacMaxTrials(maxNbTrials);
     pose.setRansacNbInliersToReachConsensus(numberOfInlierToReachAConsensus);
