@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,17 +29,14 @@
  *
  * Description:
  * Pose computation.
- *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+ */
 
 /*!
   \file vpPoseVirtualVisualServoing.cpp
   \brief Compute the pose using virtual visual servoing approach
 */
 
+#include <visp3/core/vpConfig.h>
 #include <visp3/core/vpExponentialMap.h>
 #include <visp3/core/vpPoint.h>
 #include <visp3/core/vpRobust.h>
@@ -52,7 +48,6 @@
   This approach is described in \cite Marchand02c.
 
 */
-
 void vpPose::poseVirtualVS(vpHomogeneousMatrix &cMo)
 {
   try {
@@ -264,3 +259,94 @@ void vpPose::poseVirtualVSrobust(vpHomogeneousMatrix &cMo)
     throw;
   }
 }
+
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_17) &&                                                                     \
+    (!defined(_MSC_VER) || ((VISP_CXX_STANDARD >= VISP_CXX_STANDARD_17) && (_MSC_VER >= 1911)))
+/*!
+ * Compute the pose by virtual visual servoing using x,y and Z point coordinates as visual features.
+ * We recall that x,y are the coordinates of a point in the image plane which are obtained by perspective
+ * projection, while Z is the 3D coordinate of the point along the camera frame Z-axis.
+ *
+ * \param[in] cMo : Pose initial value used to initialize the non linear pose estimation algorithm.
+ * \param[in] points : A vector of points with [x,y,Z] values used as visual features.
+ * \return Estimated pose when the minimization converged, of std::nullopt when it failed.
+ */
+std::optional<vpHomogeneousMatrix> vpPose::poseVirtualVSWithDepth(const std::vector<vpPoint> &points, const vpHomogeneousMatrix &cMo)
+{
+  auto residu_1{1e8}, r{1e8 - 1};
+  const auto lambda{0.9}, vvsEpsilon{1e-8};
+  const unsigned int vvsIterMax{200};
+
+  const unsigned int nb = static_cast<unsigned int>(points.size());
+  vpMatrix L(3 * nb, 6);
+  vpColVector err(3 * nb);
+  vpColVector sd(3 * nb), s(3 * nb);
+
+  // create sd
+  for (auto i = 0u; i < points.size(); i++) {
+    sd[3 * i] = points[i].get_x();
+    sd[3 * i + 1] = points[i].get_y();
+    sd[3 * i + 2] = points[i].get_Z();
+  }
+
+  auto cMoPrev = cMo;
+  auto iter = 0u;
+  while (std::fabs(residu_1 - r) > vvsEpsilon) {
+    residu_1 = r;
+
+    // Compute the interaction matrix and the error
+    for (auto i = 0u; i < points.size(); i++) {
+      // forward projection of the 3D model for a given pose
+      // change frame coordinates
+      // perspective projection
+      vpColVector cP, p;
+      points.at(i).changeFrame(cMo, cP);
+      points.at(i).projection(cP, p);
+
+      const auto x = s[3 * i] = p[0];
+      const auto y = s[3 * i + 1] = p[1];
+      const auto Z = s[3 * i + 2] = cP[2];
+      L[3 * i][0] = -1 / Z;
+      L[3 * i][1] = 0;
+      L[3 * i][2] = x / Z;
+      L[3 * i][3] = x * y;
+      L[3 * i][4] = -(1 + vpMath::sqr(x));
+      L[3 * i][5] = y;
+
+      L[3 * i + 1][0] = 0;
+      L[3 * i + 1][1] = -1 / Z;
+      L[3 * i + 1][2] = y / Z;
+      L[3 * i + 1][3] = 1 + vpMath::sqr(y);
+      L[3 * i + 1][4] = -x * y;
+      L[3 * i + 1][5] = -x;
+
+      L[3 * i + 2][0] = 0;
+      L[3 * i + 2][1] = 0;
+      L[3 * i + 2][2] = -1;
+      L[3 * i + 2][3] = -y * Z;
+      L[3 * i + 2][4] = x * Z;
+      L[3 * i + 2][5] = -0;
+    }
+    err = s - sd;
+
+    // compute the residual
+    r = err.sumSquare();
+
+    // compute the pseudo inverse of the interaction matrix
+    vpMatrix Lp;
+    L.pseudoInverse(Lp, 1e-16);
+
+    // compute the VVS control law
+    const auto v = -lambda * Lp * err;
+
+    // update the pose
+    cMoPrev = vpExponentialMap::direct(v).inverse() * cMoPrev;
+
+    if (iter++ > vvsIterMax) {
+      return std::nullopt;
+    }
+  }
+  return cMoPrev;
+}
+
+#endif
