@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,18 +29,14 @@
  *
  * Description:
  * Test saving / loading learning files for vpKeyPoint class.
- *
- * Authors:
- * Souriya Trinh
- *
- *****************************************************************************/
+ */
 
 #include <iomanip>
 #include <iostream>
 
 #include <visp3/core/vpConfig.h>
 
-#if defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020301)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_FEATURES2D) && defined(HAVE_OPENCV_VIDEO)
 
 #include <visp3/core/vpException.h>
 #include <visp3/core/vpImage.h>
@@ -67,7 +62,8 @@ void usage(const char *name, const char *badparam, const std::string &opath, con
 Test save / load learning files for vpKeyPoint class.\n\
 \n\
 SYNOPSIS\n\
-  %s [-c] [-d] [-h]\n", name);
+  %s [-c] [-d] [-h]\n",
+          name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                               \n\
@@ -79,7 +75,8 @@ OPTIONS:                                               \n\
      learning files will be written.\n\
 \n\
   -h\n\
-     Print the help.\n", opath.c_str(), user.c_str());
+     Print the help.\n",
+          opath.c_str(), user.c_str());
 
   if (badparam)
     fprintf(stdout, "\nERROR: Bad parameter [%s]\n", badparam);
@@ -284,8 +281,7 @@ bool compareDescriptors(const cv::Mat &descriptors1, const cv::Mat &descriptors2
   return true;
 }
 
-template<typename Type>
-void run_test(const std::string &env_ipath, const std::string &opath,  vpImage<Type> &I)
+template <typename Type> void run_test(const std::string &env_ipath, const std::string &opath, vpImage<Type> &I)
 {
   std::string filename;
   // Set the path location of the image sequence
@@ -441,14 +437,18 @@ void run_test(const std::string &env_ipath, const std::string &opath,  vpImage<T
     std::cout << "Saving / loading learning files with binary descriptor are ok !" << std::endl;
   }
 
-
 // Test with floating point descriptor
-#if defined(VISP_HAVE_OPENCV_NONFREE) || \
-  ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(VISP_HAVE_OPENCV_XFEATURES2D) || \
-   (VISP_HAVE_OPENCV_VERSION >= 0x030411 && CV_MAJOR_VERSION < 4) || (VISP_HAVE_OPENCV_VERSION >= 0x040400))
+#if defined(VISP_HAVE_OPENCV_NONFREE) ||                                                                               \
+    ((VISP_HAVE_OPENCV_VERSION >= 0x030000) && defined(VISP_HAVE_OPENCV_XFEATURES2D) ||                                \
+     (VISP_HAVE_OPENCV_VERSION >= 0x030411 && CV_MAJOR_VERSION < 4) || (VISP_HAVE_OPENCV_VERSION >= 0x040400))
   {
-#if !((VISP_HAVE_OPENCV_VERSION == 0x040504) && (defined(__APPLE__) && defined(__MACH__))) // OpenCV != 4.5.4 on macOS
-    std::string keypointName = "SIFT"; // SIFT is known unstable with OpenCV 4.5.4
+#if (VISP_HAVE_OPENCV_VERSION != 0x040504) && (VISP_HAVE_OPENCV_VERSION != 0x040505) &&                                \
+    (VISP_HAVE_OPENCV_VERSION != 0x040600) && (VISP_HAVE_OPENCV_VERSION != 0x040700) &&                                \
+    (defined(__APPLE__) && defined(__MACH__))
+    // SIFT is known to be unstable with OpenCV 4.5.4 and 4.5.5 on macOS (see #1048)
+    // Same for OpenCV 4.6.0 (see #1106) where it produces an Illegal Instruction error when OpenCV 4.6.0 is
+    // installed with brew. It seems working when OpenCV is build from source
+    std::string keypointName = "SIFT";
     keyPoints.setDetector(keypointName);
     keyPoints.setExtractor(keypointName);
 
@@ -690,19 +690,19 @@ int main(int argc, const char **argv)
 
   } catch (const vpException &e) {
     std::cerr << e.what() << std::endl;
-    return -1;
+    return EXIT_FAILURE;
   }
 
   std::cout << "Saving / loading learning files are ok !" << std::endl;
   std::cout << "testKeyPoint-7 is ok !" << std::endl;
-  return 0;
+  return EXIT_SUCCESS;
 }
 #else
 int main()
 {
   std::cerr << "You need OpenCV library." << std::endl;
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 
 #endif
