@@ -1,7 +1,6 @@
-/****************************************************************************
- *
+/*
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +13,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -30,8 +29,7 @@
  *
  * Description:
  * Test RANSAC 3D pose estimation method.
- *
- *****************************************************************************/
+ */
 
 #include <visp3/core/vpConfig.h>
 
@@ -51,7 +49,7 @@
 
 namespace
 {
-
+#if (VISP_HAVE_DATASET_VERSION >= 0x030300)
 bool samePoints(const vpPoint &pt1, const vpPoint &pt2)
 {
   return vpMath::equal(pt1.get_oX(), pt2.get_oX(), std::numeric_limits<double>::epsilon()) &&
@@ -86,19 +84,12 @@ bool checkInlierPoints(const std::vector<vpPoint> &vectorOfFoundInlierPoints,
                    "inlier point!"
                 << std::endl;
       std::cerr << "Returned inliers: oX=" << std::setprecision(std::numeric_limits<double>::max_digits10)
-                << vectorOfFoundInlierPoints[i].get_oX()
-                << ", oY=" << vectorOfFoundInlierPoints[i].get_oY()
-                << ", oZ=" << vectorOfFoundInlierPoints[i].get_oZ()
-                << " ; x=" << vectorOfFoundInlierPoints[i].get_x()
-                << ", y=" << vectorOfFoundInlierPoints[i].get_y()
-                << std::endl;
-      const vpPoint& pt = bunnyModelPoints_noisy[vectorOfFoundInlierIndex[i]];
-      std::cerr << "Object points: oX=" << std::setprecision(std::numeric_limits<double>::max_digits10)
-                << pt.get_oX()
-                << ", oY=" << pt.get_oY()
-                << ", oZ=" << pt.get_oZ()
-                << " ; x=" << pt.get_x()
-                << ", y=" << pt.get_y()
+                << vectorOfFoundInlierPoints[i].get_oX() << ", oY=" << vectorOfFoundInlierPoints[i].get_oY()
+                << ", oZ=" << vectorOfFoundInlierPoints[i].get_oZ() << " ; x=" << vectorOfFoundInlierPoints[i].get_x()
+                << ", y=" << vectorOfFoundInlierPoints[i].get_y() << std::endl;
+      const vpPoint &pt = bunnyModelPoints_noisy[vectorOfFoundInlierIndex[i]];
+      std::cerr << "Object points: oX=" << std::setprecision(std::numeric_limits<double>::max_digits10) << pt.get_oX()
+                << ", oY=" << pt.get_oY() << ", oZ=" << pt.get_oZ() << " ; x=" << pt.get_x() << ", y=" << pt.get_y()
                 << std::endl;
       return false;
     }
@@ -141,8 +132,8 @@ void readBunnyModelPoints(const std::string &filename, std::vector<vpPoint> &bun
 }
 
 bool testRansac(const std::vector<vpPoint> &bunnyModelPoints_original,
-                const std::vector<vpPoint> &bunnyModelPoints_noisy_original,
-                size_t nb_model_points, bool test_duplicate, bool test_degenerate)
+                const std::vector<vpPoint> &bunnyModelPoints_noisy_original, size_t nb_model_points,
+                bool test_duplicate, bool test_degenerate)
 {
   std::vector<vpPoint> bunnyModelPoints = bunnyModelPoints_original;
   std::vector<vpPoint> bunnyModelPoints_noisy = bunnyModelPoints_noisy_original;
@@ -153,22 +144,10 @@ bool testRansac(const std::vector<vpPoint> &bunnyModelPoints_original,
   }
 
   vpPose ground_truth_pose, real_pose;
+  vpHomogeneousMatrix cMo_estimated;
   ground_truth_pose.addPoints(bunnyModelPoints);
   real_pose.addPoints(bunnyModelPoints_noisy);
-
-  vpHomogeneousMatrix cMo_dementhon, cMo_lagrange;
-  real_pose.computePose(vpPose::DEMENTHON, cMo_dementhon);
-  real_pose.computePose(vpPose::LAGRANGE, cMo_lagrange);
-  double r_dementhon = real_pose.computeResidual(cMo_dementhon);
-  double r_lagrange = real_pose.computeResidual(cMo_lagrange);
-
-  vpHomogeneousMatrix cMo_estimated;
-  if (r_lagrange < r_dementhon) {
-    cMo_estimated = cMo_lagrange;
-  } else {
-    cMo_estimated = cMo_dementhon;
-  }
-  real_pose.computePose(vpPose::VIRTUAL_VS, cMo_estimated);
+  real_pose.computePose(vpPose::DEMENTHON_LAGRANGE_VIRTUAL_VS, cMo_estimated);
   double r_vvs = ground_truth_pose.computeResidual(cMo_estimated);
 
   std::cout << "\ncMo estimated using VVS on data with small gaussian noise:\n" << cMo_estimated << std::endl;
@@ -239,7 +218,7 @@ bool testRansac(const std::vector<vpPoint> &bunnyModelPoints_original,
     vectorOfIndex[i] = i;
   }
 
-  //std::random_shuffle(vectorOfIndex.begin(), vectorOfIndex.end()); // std::random_shuffle is deprecated in C++14
+  // std::random_shuffle(vectorOfIndex.begin(), vectorOfIndex.end()); // std::random_shuffle is deprecated in C++14
   std::random_device rng;
   std::mt19937 urng(rng());
   std::shuffle(vectorOfIndex.begin(), vectorOfIndex.end(), urng);
@@ -265,7 +244,8 @@ bool testRansac(const std::vector<vpPoint> &bunnyModelPoints_original,
   pose_ransac_parallel2.setRansacFilterFlag(vpPose::PREFILTER_DEGENERATE_POINTS);
   pose_ransac.setRansacFilterFlag(vpPose::PREFILTER_DEGENERATE_POINTS);
   pose_ransac2.setRansacFilterFlag(vpPose::PREFILTER_DEGENERATE_POINTS);
-  for (std::vector<vpPoint>::const_iterator it = bunnyModelPoints_noisy.begin(); it != bunnyModelPoints_noisy.end(); ++it) {
+  for (std::vector<vpPoint>::const_iterator it = bunnyModelPoints_noisy.begin(); it != bunnyModelPoints_noisy.end();
+       ++it) {
     pose.addPoint(*it);
   }
   // Test addPoints
@@ -325,18 +305,7 @@ bool testRansac(const std::vector<vpPoint> &bunnyModelPoints_original,
   double r_RANSAC_estimated_2 = ground_truth_pose.computeResidual(cMo_estimated_RANSAC_2);
   std::cout << "Corresponding residual (" << ransac_iterations << " iterations): " << r_RANSAC_estimated_2 << std::endl;
 
-  pose.computePose(vpPose::DEMENTHON, cMo_dementhon);
-  pose.computePose(vpPose::LAGRANGE, cMo_lagrange);
-  r_dementhon = pose.computeResidual(cMo_dementhon);
-  r_lagrange = pose.computeResidual(cMo_lagrange);
-
-  if (r_lagrange < r_dementhon) {
-    cMo_estimated = cMo_lagrange;
-  } else {
-    cMo_estimated = cMo_dementhon;
-  }
-
-  pose.computePose(vpPose::VIRTUAL_VS, cMo_estimated);
+  pose.computePose(vpPose::DEMENTHON_LAGRANGE_VIRTUAL_VS, cMo_estimated);
   std::cout << "\ncMo estimated with only VVS on noisy data:\n" << cMo_estimated << std::endl;
 
   double r_estimated = ground_truth_pose.computeResidual(cMo_estimated);
@@ -475,16 +444,19 @@ bool testRansac(const std::vector<vpPoint> &bunnyModelPoints_original,
 
   return true;
 }
-} //namespace
+#endif
+} // namespace
 
-TEST_CASE("Print RANSAC number of iterations", "[ransac_pose]") {
+TEST_CASE("Print RANSAC number of iterations", "[ransac_pose]")
+{
   const int sample_sizes[] = {2, 3, 4, 5, 6, 7, 8};
   const double epsilon[] = {0.05, 0.1, 0.2, 0.25, 0.3, 0.4, 0.5};
 
   // Format output
   const std::string spacing = "       ";
 
-  std::cout << spacing << " outliers percentage\n" << "nb pts\\";
+  std::cout << spacing << " outliers percentage\n"
+            << "nb pts\\";
   for (int cpt2 = 0; cpt2 < 7; cpt2++) {
     std::cout << std::setfill(' ') << std::setw(5) << epsilon[cpt2] << " ";
   }
@@ -508,7 +480,9 @@ TEST_CASE("Print RANSAC number of iterations", "[ransac_pose]") {
   std::cout << std::endl;
 }
 
-TEST_CASE("RANSAC pose estimation tests", "[ransac_pose]") {
+#if (VISP_HAVE_DATASET_VERSION >= 0x030300)
+TEST_CASE("RANSAC pose estimation tests", "[ransac_pose]")
+{
   const std::vector<size_t> model_sizes = {10, 20, 50, 100, 200, 500, 1000, 0, 0};
   const std::vector<bool> duplicates = {false, false, false, false, false, false, false, false, true};
   const std::vector<bool> degenerates = {false, false, false, false, false, false, true, true, true};
@@ -522,8 +496,7 @@ TEST_CASE("RANSAC pose estimation tests", "[ransac_pose]") {
   CHECK(bunnyModelPoints.size() == bunnyModelPoints_noisy_original.size());
 
   for (size_t i = 0; i < model_sizes.size(); i++) {
-    std::cout << "\n\n==============================================================================="
-              << std::endl;
+    std::cout << "\n\n===============================================================================" << std::endl;
     if (model_sizes[i] == 0) {
       std::cout << "Test on " << bunnyModelPoints_noisy_original.size() << " model points." << std::endl;
     } else {
@@ -534,8 +507,9 @@ TEST_CASE("RANSAC pose estimation tests", "[ransac_pose]") {
     CHECK(testRansac(bunnyModelPoints, bunnyModelPoints_noisy_original, model_sizes[i], duplicates[i], degenerates[i]));
   }
 }
+#endif
 
-int main(int argc, char* argv[])
+int main(int argc, char *argv[])
 {
 #if defined(__mips__) || defined(__mips) || defined(mips) || defined(__MIPS__)
   // To avoid Debian test timeout
@@ -561,8 +535,5 @@ int main(int argc, char* argv[])
 #endif
 }
 #else
-int main()
-{
-  return 0;
-}
+int main() { return EXIT_SUCCESS; }
 #endif
