@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Filip Novotny
  *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \file vpFeatureMomentAreaNormalized.h
   \brief Implementation of the interaction matrix computation for
@@ -85,14 +85,15 @@ class VISP_EXPORT vpFeatureMomentAreaNormalized : public vpFeatureMoment
 public:
   /*!
   Initializes the feature with information about the database of moment
-  primitives, the object plane and feature database. \param database : Moment
-  database. The database of moment primitives (first parameter) is mandatory.
-  It is used to access different moment values later used to compute the final
-  matrix. \param A : Plane coefficient in a \f$ A \times x+B \times y + C =
-  \frac{1}{Z} \f$ plane. \param B : Plane coefficient in a \f$ A \times x+B
-  \times y + C = \frac{1}{Z} \f$ plane. \param C : Plane coefficient in a \f$
-  A \times x+B \times y + C = \frac{1}{Z} \f$ plane. \param featureMoments :
-  Feature database.
+  primitives, the object plane and feature database.
+  \param database : Moment database. The database of moment primitives (first parameter) is mandatory.
+  It is used to access different moment values later used to compute the final matrix.
+  \param A : Plane coefficient in a \f$ A \times x+B \times y + C =
+  \frac{1}{Z} \f$ plane.
+  \param B : Plane coefficient in a \f$ A \times x+B
+  \times y + C = \frac{1}{Z} \f$ plane.
+  \param C : Plane coefficient in a \f$ A \times x+B \times y + C = \frac{1}{Z} \f$ plane.
+  \param featureMoments : Feature database.
 
   */
   vpFeatureMomentAreaNormalized(vpMomentDatabase &database, double A_, double B_, double C_,
@@ -120,54 +121,55 @@ class vpMomentDatabase;
   \ingroup group_visual_features
 
   \brief Functionality computation for normalized surface moment feature.
-Computes the interaction matrix associated with vpMomentAreaNormalized.
+  Computes the interaction matrix associated with vpMomentAreaNormalized.
 
   The interaction matrix for the moment has the following form:
   - In the discrete case:
   \f[
   L_{a_n} =
-{
- \left[ \begin {array}{c} a_{{n}}Ae_{{2,0}}+a_{{n}}Be_{{1,1}}
-\\ \noalign{\medskip}a_{{n}}Ae_{{1,1}}+a_{{n}}Be_{{0,2}}
-\\ \noalign{\medskip}-a_{{n}}C+Bw_{{x}}-Aw_{{y}}\\ \noalign{\medskip}-
- \left( e_{{2,0}}+2\,e_{{0,2}} \right) y_{{g}}-e_{{2,1}}-x_{{g}}e_{{1,
-1}}+\eta_{{1,1}}e_{{1,0}}-e_{{0,3}}+\eta_{{0,2}}e_{{0,1}}
-\\ \noalign{\medskip} \left( 2\,e_{{2,0}}+e_{{0,2}} \right) x_{{g}}+e_
-{{3,0}}+y_{{g}}e_{{1,1}}-\eta_{{2,0}}e_{{1,0}}+e_{{1,2}}-\eta_{{1,1}}e
-_{{0,1}}\\ \noalign{\medskip}0\end {array} \right]
-
-}^t
-
+  {
+  \left[
+  \begin {array}{c}
+  a_{{n}}Ae_{{2,0}}+a_{{n}}Be_{{1,1}} \\
+  \noalign{\medskip}a_{{n}}Ae_{{1,1}}+a_{{n}}Be_{{0,2}} \\
+  \noalign{\medskip}-a_{{n}}C+Bw_{{x}}-Aw_{{y}} \\
+  \noalign{\medskip}- \left( e_{{2,0}}+2\,e_{{0,2}} \right) y_{{g}}-e_{{2,1}}-x_{{g}}e_{{1,1}}+\eta_{{1,1}}e_{{1,0}}-e_{{0,3}}+\eta_{{0,2}}e_{{0,1}} \\
+  \noalign{\medskip} \left( 2\,e_{{2,0}}+e_{{0,2}} \right) x_{{g}}+e_{{3,0}}+y_{{g}}e_{{1,1}}-\eta_{{2,0}}e_{{1,0}}+e_{{1,2}}-\eta_{{1,1}}e_{{0,1}} \\
+  \noalign{\medskip}0
+  \end {array}
+  \right]
+  }^t
   \f]
   - In the dense case:
   \f[
   L_{a_n} =
-{
- \left[ \begin {array}{c} 1/2\,a_{{n}}A\\ \noalign{\medskip}1/2\,a_{{n
-}}B\\ \noalign{\medskip}-a_{{n}}C-3/2\,Ax_{{n}}-3/2\,By_{{n}}
-\\ \noalign{\medskip}-3/2\,y_{{n}}\\ \noalign{\medskip}3/2\,x_{{n}}
-\\ \noalign{\medskip}0\end {array} \right]
-
-}^t
-
+  {
+  \left[
+  \begin {array}{c}
+  1/2\,a_{{n}}A \\
+  \noalign{\medskip}1/2\,a_{{n}}B \\
+  \noalign{\medskip}-a_{{n}}C-3/2\,Ax_{{n}}-3/2\,By_{{n}} \\
+  \noalign{\medskip}-3/2\,y_{{n}} \\
+  \noalign{\medskip}3/2\,x_{{n}} \\
+  \noalign{\medskip}0
+  \end {array}
+  \right]
+  }^t
   \f]
-with:
+  with:
     - \f$e_{i,j}=\frac{\mu_{i,j}}{NA}\f$
     - \f$NA=\mu_{2,0}+\mu_{0,2}\f$
     - \f$\eta\f$ is the centered and normalized moment.
   To do so, one must derive it and obtain a combination of interaction
-matrices by using (1). It allows to compute the interaction matrix for \f$ a_n
-\f$.
+  matrices by using (1). It allows to compute the interaction matrix for \f$ a_n \f$.
 
   The interaction matrix computed is single-dimension (no selection possible)
-and can be obtained by calling
-vpFeatureMomentGravityCenterNormalized::interaction.
+  and can be obtained by calling vpFeatureMomentGravityCenterNormalized::interaction.
 
-  This feature is often used in moment-based visual servoing to control the
-depth parameter.
+  This feature is often used in moment-based visual servoing to control the depth parameter.
 
   Minimum vpMomentObject order needed to compute this feature: 1 in dense mode
-and 3 in discrete mode.
+  and 3 in discrete mode.
 
   This feature depends on:
   - vpMomentCentered
@@ -180,14 +182,13 @@ class VISP_EXPORT vpFeatureMomentAreaNormalized : public vpFeatureMoment
 public:
   /*!
   Initializes the feature with information about the database of moment
-  primitives, the object plane and feature database. \param data_base : Moment
-  database. The database of moment primitives (first parameter) is mandatory.
-  It is used to access different moment values later used to compute the final
-  matrix. \param A_ : Plane coefficient in a \f$ A \times x+B \times y + C =
-  \frac{1}{Z} \f$ plane. \param B_ : Plane coefficient in a \f$ A \times x+B
-  \times y + C = \frac{1}{Z} \f$ plane. \param C_ : Plane coefficient in a \f$
-  A \times x+B \times y + C = \frac{1}{Z} \f$ plane. \param featureMoments :
-  Feature database.
+  primitives, the object plane and feature database.
+  \param data_base : Moment database. The database of moment primitives (first parameter) is mandatory.
+  It is used to access different moment values later used to compute the final matrix.
+  \param A_ : Plane coefficient in a \f$ A \times x+B \times y + C = \frac{1}{Z} \f$ plane.
+  \param B_ : Plane coefficient in a \f$ A \times x+B \times y + C = \frac{1}{Z} \f$ plane.
+  \param C_ : Plane coefficient in a \f$ A \times x+B \times y + C = \frac{1}{Z} \f$ plane.
+  \param featureMoments : Feature database.
 
   */
   vpFeatureMomentAreaNormalized(vpMomentDatabase &data_base, double A_, double B_, double C_,
