@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Filip Novotny
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpFeatureMomentDatabase.h
@@ -78,20 +78,19 @@ between moment primitives and moment features:
 \code
 #include <visp3/core/vpPoint.h>
 
-#include <visp3/core/vpMomentObject.h>
 #include <visp3/core/vpMomentBasic.h>
 #include <visp3/core/vpMomentCInvariant.h>
 #include <visp3/core/vpMomentCentered.h>
-#include <visp3/core/vpMomentCInvariant.h>
-#include <visp3/core/vpMomentGravityCenter.h>
 #include <visp3/core/vpMomentDatabase.h>
+#include <visp3/core/vpMomentGravityCenter.h>
+#include <visp3/core/vpMomentObject.h>
 
-#include <visp3/visual_features/vpFeatureMomentCInvariant.h>
-#include <visp3/visual_features/vpFeatureMomentBasic.h>
-#include <visp3/visual_features/vpFeatureMomentCentered.h>
-#include <visp3/visual_features/vpFeatureMomentDatabase.h>
 #include <iostream>
 #include <vector>
+#include <visp3/visual_features/vpFeatureMomentBasic.h>
+#include <visp3/visual_features/vpFeatureMomentCInvariant.h>
+#include <visp3/visual_features/vpFeatureMomentCentered.h>
+#include <visp3/visual_features/vpFeatureMomentDatabase.h>
 
 int main()
 {
@@ -158,11 +157,11 @@ int main()
 class VISP_EXPORT vpFeatureMomentDatabase
 {
 private:
-  struct cmp_str {
+  struct vpCmpStr_t {
     bool operator()(const char *a, const char *b) const { return std::strcmp(a, b) < 0; }
     char *operator=(const char *) { return NULL; } // Only to avoid a warning under Visual with /Wall flag
   };
-  std::map<const char *, vpFeatureMoment *, cmp_str> featureMomentsDataBase;
+  std::map<const char *, vpFeatureMoment *, vpCmpStr_t> featureMomentsDataBase;
   void add(vpFeatureMoment &featureMoment, char *name);
 
 public:
