@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Filip Novotny
  *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \file vpFeatureMomentGravityCenter.h
   \brief Implementation of the interaction matrix computation for
@@ -65,17 +65,17 @@ following methods: vpFeatureMomentGravityCenter::selectXg for \f$ L_{x_{g}}
 following code demonstrates a selection of \f$ L_{y_{g}} \f$:
 
   \code
-#include <visp3/core/vpMomentObject.h>
-#include <visp3/core/vpMomentBasic.h>
-#include <visp3/core/vpMomentGravityCenter.h>
-#include <visp3/core/vpMomentDatabase.h>
-#include <visp3/core/vpPoint.h>
-#include <visp3/visual_features/vpFeatureMoment.h>
-#include <visp3/visual_features/vpFeatureMomentDatabase.h>
-#include <visp3/visual_features/vpFeatureMomentGravityCenter.h>
-#include <visp3/visual_features/vpFeatureMomentBasic.h>
 #include <iostream>
 #include <vector>
+#include <visp3/core/vpMomentBasic.h>
+#include <visp3/core/vpMomentDatabase.h>
+#include <visp3/core/vpMomentGravityCenter.h>
+#include <visp3/core/vpMomentObject.h>
+#include <visp3/core/vpPoint.h>
+#include <visp3/visual_features/vpFeatureMoment.h>
+#include <visp3/visual_features/vpFeatureMomentBasic.h>
+#include <visp3/visual_features/vpFeatureMomentDatabase.h>
+#include <visp3/visual_features/vpFeatureMomentGravityCenter.h>
 
 int main()
 {
@@ -99,7 +99,7 @@ int main()
                         //only contain the basic moment.
   vpMomentBasic bm; //basic moment (this particular moment is nothing
                     //more than a shortcut to the vpMomentObject)
-  vpMomentGravityCenter	gc; //gravity center
+  vpMomentGravityCenter  gc; //gravity center
 
   bm.linkTo(mdb); //add basic moment to moment database
   gc.linkTo(mdb); //add gravity center to moment database
@@ -153,14 +153,13 @@ class VISP_EXPORT vpFeatureMomentGravityCenter : public vpFeatureMoment
 public:
   /*!
   Initializes the feature with information about the database of moment
-  primitives, the object plane and feature database. \param database : Moment
-  database. The database of moment primitives (first parameter) is mandatory.
-  It is used to access different moment values later used to compute the final
-  matrix. \param A_ : Plane coefficient in a \f$ A \times x+B \times y + C =
-  \frac{1}{Z} \f$ plane. \param B_ : Plane coefficient in a \f$ A \times x+B
-  \times y + C = \frac{1}{Z} \f$ plane. \param C_ : Plane coefficient in a \f$
-  A \times x+B \times y + C = \frac{1}{Z} \f$ plane. \param featureMoments :
-  Feature database.
+  primitives, the object plane and feature database.
+  \param database : Moment database. The database of moment primitives (first parameter) is mandatory.
+  It is used to access different moment values later used to compute the final matrix.
+  \param A_ : Plane coefficient in a \f$ A \times x+B \times y + C = \frac{1}{Z} \f$ plane.
+  \param B_ : Plane coefficient in a \f$ A \times x+B \times y + C = \frac{1}{Z} \f$ plane.
+  \param C_ : Plane coefficient in a \f$ A \times x+B \times y + C = \frac{1}{Z} \f$ plane.
+  \param featureMoments : Feature database.
   */
   vpFeatureMomentGravityCenter(vpMomentDatabase &database, double A_, double B_, double C_,
                                vpFeatureMomentDatabase *featureMoments = NULL)
@@ -224,14 +223,13 @@ class VISP_EXPORT vpFeatureMomentGravityCenter : public vpFeatureMoment
 public:
   /*!
   Initializes the feature with information about the database of moment
-  primitives, the object plane and feature database. \param data_base : Moment
-  database. The database of moment primitives (first parameter) is mandatory.
-  It is used to access different moment values later used to compute the final
-  matrix. \param A_ : Plane coefficient in a \f$ A \times x+B \times y + C =
-  \frac{1}{Z} \f$ plane. \param B_ : Plane coefficient in a \f$ A \times x+B
-  \times y + C = \frac{1}{Z} \f$ plane. \param C_ : Plane coefficient in a \f$
-  A \times x+B \times y + C = \frac{1}{Z} \f$ plane. \param featureMoments :
-  Feature database.
+  primitives, the object plane and feature database.
+  \param data_base : Moment database. The database of moment primitives (first parameter) is mandatory.
+  It is used to access different moment values later used to compute the final matrix.
+  \param A_ : Plane coefficient in a \f$ A \times x+B \times y + C = \frac{1}{Z} \f$ plane.
+  \param B_ : Plane coefficient in a \f$ A \times x+B \times y + C = \frac{1}{Z} \f$ plane.
+  \param C_ : Plane coefficient in a \f$ A \times x+B \times y + C = \frac{1}{Z} \f$ plane.
+  \param featureMoments : Feature database.
   */
   vpFeatureMomentGravityCenter(vpMomentDatabase &data_base, double A_, double B_, double C_,
                                vpFeatureMomentDatabase *featureMoments = NULL)
