@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Odile Bourquardez
  *
- *****************************************************************************/
+*****************************************************************************/
 
 /*!
   \file vpFeatureBuilderVanishingPoint.cpp
@@ -66,13 +66,13 @@ void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpPoint &p, unsi
   if ((vpFeatureVanishingPoint::selectX() & select) || (vpFeatureVanishingPoint::selectY() & select)) {
     s.set_x(p.get_x());
     s.set_y(p.get_y());
-  }
-  else if((vpFeatureVanishingPoint::selectOneOverRho() & select) || (vpFeatureVanishingPoint::selectAlpha() & select)) {
+  } else if ((vpFeatureVanishingPoint::selectOneOverRho() & select) ||
+             (vpFeatureVanishingPoint::selectAlpha() & select)) {
     double x = p.get_x();
     double y = p.get_y();
 
-    s.setOneOverRho( 1. / sqrt(x * x  + y * y) );
-    s.setAlpha( atan2(y, x) );
+    s.setOneOverRho(1. / sqrt(x * x + y * y));
+    s.setAlpha(atan2(y, x));
   }
 }
 
@@ -93,9 +93,11 @@ void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpPoint &p, unsi
   vpFeatureVanishingPoint::selectOneOverRho() or vpFeatureVanishingPoint::selectAlpha() to build
   \f$ {\bf s} = (1/\rho, \alpha) \f$ visual feature.
 
-  \warning An exception is thrown if the two lines are parallel when cartesian coordinates \f$ {\bf s} = (x, y) \f$ are used.
+  \warning An exception is thrown if the two lines are parallel when cartesian coordinates \f$ {\bf s} = (x, y) \f$ are
+  used.
 */
-void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpFeatureLine &L1, const vpFeatureLine &L2, unsigned int select)
+void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpFeatureLine &L1, const vpFeatureLine &L2,
+                              unsigned int select)
 {
   if ((vpFeatureVanishingPoint::selectX() & select) || (vpFeatureVanishingPoint::selectY() & select)) {
     double rho_l = L1.getRho();
@@ -113,8 +115,9 @@ void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpFeatureLine &L
       vpCERROR << "There is no vanishing point : the lines are parallel in the "
                   "image plane"
                << std::endl;
-      throw(vpFeatureException(vpFeatureException::badInitializationError, "There is no vanishing point : the lines are "
-                                                                           "parallel in the image plane"));
+      throw(vpFeatureException(vpFeatureException::badInitializationError,
+                               "There is no vanishing point : the lines are "
+                               "parallel in the image plane"));
     }
 
     double y = (rho_r * c_l - rho_l * c_r) / (-s_l * c_r + s_r * c_l);
@@ -122,18 +125,18 @@ void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpFeatureLine &L
 
     s.set_x(x);
     s.set_y(y);
-  }
-  else if((vpFeatureVanishingPoint::selectOneOverRho() & select) || (vpFeatureVanishingPoint::selectAlpha() & select)) {
-    double rho_1   = L1.getRho();
+  } else if ((vpFeatureVanishingPoint::selectOneOverRho() & select) ||
+             (vpFeatureVanishingPoint::selectAlpha() & select)) {
+    double rho_1 = L1.getRho();
     double theta_1 = L1.getTheta();
-    double rho_2   = L2.getRho();
+    double rho_2 = L2.getRho();
     double theta_2 = L2.getTheta();
 
     double theta_diff = theta_1 - theta_2;
 
-    double denom = sqrt( rho_1*rho_1 + rho_2*rho_2 - 2*rho_1*rho_2 * cos(theta_diff) );
+    double denom = sqrt(rho_1 * rho_1 + rho_2 * rho_2 - 2 * rho_1 * rho_2 * cos(theta_diff));
     double one_over_rho = sin(theta_diff) / denom;
-    double alpha = atan2( rho_1 * cos(theta_2) - rho_2 * cos(theta_1), rho_2*sin(theta_1) - rho_1 * sin(theta_2));
+    double alpha = atan2(rho_1 * cos(theta_2) - rho_2 * cos(theta_1), rho_2 * sin(theta_1) - rho_1 * sin(theta_2));
 
     s.setOneOverRho(one_over_rho);
     s.setAlpha(alpha);
@@ -157,7 +160,8 @@ void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpFeatureLine &L
   vpFeatureVanishingPoint::selectOneOverRho() or vpFeatureVanishingPoint::selectAlpha() to build
   \f$ {\bf s} = (1/\rho, \alpha) \f$ visual feature.
 
-  \warning An exception is thrown if the two lines are parallel when cartesian coordinates \f$ {\bf s} = (x, y) \f$ are used.
+  \warning An exception is thrown if the two lines are parallel when cartesian coordinates \f$ {\bf s} = (x, y) \f$ are
+  used.
 
 */
 void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpLine &L1, const vpLine &L2, unsigned int select)
@@ -186,10 +190,9 @@ void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpLine &L1, cons
   vpFeatureVanishingPoint::selectOneOverRho() or vpFeatureVanishingPoint::selectAlpha() to build
   \f$ {\bf s} = (1/\rho, \alpha) \f$ visual feature.
 */
-void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpCameraParameters &cam,
-                              const vpImagePoint &line1_ip1, const vpImagePoint &line1_ip2,
-                              const vpImagePoint &line2_ip1, const vpImagePoint &line2_ip2,
-                              unsigned int select)
+void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpCameraParameters &cam, const vpImagePoint &line1_ip1,
+                              const vpImagePoint &line1_ip2, const vpImagePoint &line2_ip1,
+                              const vpImagePoint &line2_ip2, unsigned int select)
 {
   double x1 = 0, y1 = 0;
   double x2 = 0, y2 = 0;
@@ -198,52 +201,51 @@ void vpFeatureBuilder::create(vpFeatureVanishingPoint &s, const vpCameraParamete
   vpPixelMeterConversion::convertPoint(cam, line1_ip1, x1, y1);
   vpPixelMeterConversion::convertPoint(cam, line1_ip2, x2, y2);
 
-  double theta_1 = atan2(-(x1-x2), y1 - y2);
-  double rho_1 = ( (x1+x2)*cos(theta_1) + (y1+y2)*sin(theta_1) ) / 2.;
+  double theta_1 = atan2(-(x1 - x2), y1 - y2);
+  double rho_1 = ((x1 + x2) * cos(theta_1) + (y1 + y2) * sin(theta_1)) / 2.;
 
   // Second line
   vpPixelMeterConversion::convertPoint(cam, line2_ip1, x1, y1);
   vpPixelMeterConversion::convertPoint(cam, line2_ip2, x2, y2);
 
-  double theta_2 = atan2(-(x1-x2), y1 - y2);
-  double rho_2 = ( (x1+x2)*cos(theta_2) + (y1+y2)*sin(theta_2) ) / 2.;
+  double theta_2 = atan2(-(x1 - x2), y1 - y2);
+  double rho_2 = ((x1 + x2) * cos(theta_2) + (y1 + y2) * sin(theta_2)) / 2.;
 
   if ((vpFeatureVanishingPoint::selectX() & select) || (vpFeatureVanishingPoint::selectY() & select)) {
     double min = 0.0001;
     double theta_diff = theta_1 - theta_2;
 
     if (fabs(theta_diff) < min || fabs(fabs(theta_diff) - M_PI) < min || fabs(fabs(theta_diff) - 2 * M_PI) < min) {
-      throw(vpException(vpException::fatalError, "There is no vanishing point : the lines are parallel in the image plane"));
+      throw(vpException(vpException::fatalError,
+                        "There is no vanishing point : the lines are parallel in the image plane"));
     }
 
-    double x = (sin(theta_1) * rho_2 - sin(theta_2)*rho_1 ) / sin(theta_diff);
-    double y = (cos(theta_2) * rho_1 - cos(theta_1)*rho_2 ) / sin(theta_diff);
+    double x = (sin(theta_1) * rho_2 - sin(theta_2) * rho_1) / sin(theta_diff);
+    double y = (cos(theta_2) * rho_1 - cos(theta_1) * rho_2) / sin(theta_diff);
 
     s.set_x(x);
     s.set_y(y);
-  }
-  else if((vpFeatureVanishingPoint::selectOneOverRho() & select)) {
+  } else if ((vpFeatureVanishingPoint::selectOneOverRho() & select)) {
     double theta_diff = theta_1 - theta_2;
-    double denom = sqrt( rho_1*rho_1 + rho_2*rho_2 - 2*rho_1*rho_2 * cos(theta_diff) );
+    double denom = sqrt(rho_1 * rho_1 + rho_2 * rho_2 - 2 * rho_1 * rho_2 * cos(theta_diff));
     double one_over_rho = sin(theta_diff) / denom;
-//    if (one_over_rho < 0) {
-//      one_over_rho = -one_over_rho;
-//    }
-    double alpha = atan2( rho_1 * cos(theta_2) - rho_2 * cos(theta_1), rho_2*sin(theta_1) - rho_1 * sin(theta_2));
+    //    if (one_over_rho < 0) {
+    //      one_over_rho = -one_over_rho;
+    //    }
+    double alpha = atan2(rho_1 * cos(theta_2) - rho_2 * cos(theta_1), rho_2 * sin(theta_1) - rho_1 * sin(theta_2));
 
     s.setOneOverRho(one_over_rho);
     s.setAlpha(alpha);
-  }
-  else if((vpFeatureVanishingPoint::selectAtanOneOverRho() & select)) {
+  } else if ((vpFeatureVanishingPoint::selectAtanOneOverRho() & select)) {
     double theta_diff = theta_1 - theta_2;
-    double denom = sqrt( rho_1*rho_1 + rho_2*rho_2 - 2*rho_1*rho_2 * cos(theta_diff) );
-    double alpha = atan2( rho_1 * cos(theta_2) - rho_2 * cos(theta_1), rho_2*sin(theta_1) - rho_1 * sin(theta_2));
+    double denom = sqrt(rho_1 * rho_1 + rho_2 * rho_2 - 2 * rho_1 * rho_2 * cos(theta_diff));
+    double alpha = atan2(rho_1 * cos(theta_2) - rho_2 * cos(theta_1), rho_2 * sin(theta_1) - rho_1 * sin(theta_2));
     double one_over_rho = sin(theta_diff) / denom;
     double atan_one_over_rho = atan2(sin(theta_diff), denom);
 
-//    if (one_over_rho < 0) {
-//      one_over_rho = -one_over_rho;
-//    }
+    //    if (one_over_rho < 0) {
+    //      one_over_rho = -one_over_rho;
+    //    }
 
     s.setOneOverRho(one_over_rho);
     s.setAtanOneOverRho(atan_one_over_rho);
