@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Filip Novotny
  *
- *****************************************************************************/
+*****************************************************************************/
 
 #include <visp3/core/vpMomentCentered.h>
 #include <visp3/core/vpMomentGravityCenter.h>
@@ -70,12 +70,13 @@ void vpFeatureMomentAlpha::compute_interaction()
   if (!found_FeatureMoment_centered)
     throw vpException(vpException::notInitialized, "vpFeatureMomentCentered not found");
 
-  double u11 = momentCentered.get(1,1);
-  double u20_u02 = momentCentered.get(2,0)-momentCentered.get(0,2);
-  double dinv = 1 / (4*u11*u11 + u20_u02*u20_u02);
+  double u11 = momentCentered.get(1, 1);
+  double u20_u02 = momentCentered.get(2, 0) - momentCentered.get(0, 2);
+  double dinv = 1 / (4 * u11 * u11 + u20_u02 * u20_u02);
   interaction_matrices[0].resize(1, 6);
-  interaction_matrices[0] = (u20_u02*dinv) * featureMomentCentered.interaction(1,1) +
-                            (u11*dinv) * (featureMomentCentered.interaction(0,2)-featureMomentCentered.interaction(2,0));
+  interaction_matrices[0] =
+      (u20_u02 * dinv) * featureMomentCentered.interaction(1, 1) +
+      (u11 * dinv) * (featureMomentCentered.interaction(0, 2) - featureMomentCentered.interaction(2, 0));
 }
 
 #else // #ifdef VISP_MOMENTS_COMBINE_MATRICES
