@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -34,7 +34,7 @@
  * Authors:
  * Manikandan Bakthavatchalam
  *
- *****************************************************************************/
+*****************************************************************************/
 #include <cassert>
 #include <limits>
 #include <limits> // numeric_limits
@@ -69,11 +69,11 @@ void vpFeatureMomentArea::compute_interaction()
   if (mobj.getType() == vpMomentObject::DISCRETE) {
     // Get centered moments
     bool found_centered;
-    const vpFeatureMomentCentered &momentCentered =
-        static_cast<const vpFeatureMomentCentered &>(featureMomentsDataBase->get("vpFeatureMomentCentered", found_centered));
+    const vpFeatureMomentCentered &momentCentered = static_cast<const vpFeatureMomentCentered &>(
+        featureMomentsDataBase->get("vpFeatureMomentCentered", found_centered));
     if (!found_centered)
       throw vpException(vpException::notInitialized, "vpFeatureMomentCentered not found");
-    interaction_matrices[0] = momentCentered.interaction(2,0) + momentCentered.interaction(0,2);
+    interaction_matrices[0] = momentCentered.interaction(2, 0) + momentCentered.interaction(0, 2);
   } else {
     // Get Xg and Yg
     bool found_xgyg;
