@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -29,48 +29,37 @@
  * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  *
  * Description:
- * Exception that can be emited by the vpServo class and its derivates.
+ * Exception that can be emitted by the vpServo class and its derivatives.
  *
- * Authors:
- * Eric Marchand
- *
- *****************************************************************************/
+*****************************************************************************/
 
 #ifndef _vpServoException_h_
 #define _vpServoException_h_
 
 /*!
-  \file vpServoException.h
-  \brief error that can be emited by the vpServo class and its derivates
-*/
+ * \file vpServoException.h
+ * \brief error that can be emitted by the vpServo class and its derivatives
+ */
 
 #include <visp3/core/vpException.h>
 
-#include <iostream> /* Classe std::ostream.    */
-#include <string>   /* Classe string.     */
-
-/* -------------------------------------------------------------------------
- */
-/* --- CLASS ---------------------------------------------------------------
- */
-/* -------------------------------------------------------------------------
- */
+#include <iostream>
+#include <string>
 
 /*!
-  \class vpServoException
-  \brief Error that can be emited by the vpServo class and its derivates.
-  \author Eric Marchand   (Eric.Marchand@irisa.fr) Irisa / Inria Rennes
+ * \class vpServoException
+ * \brief Error that can be emitted by the vpServo class and its derivatives.
  */
 class VISP_EXPORT vpServoException : public vpException
 {
 public:
   /*!
-
-  \brief Lists the possible error than can be emmited while calling
-  vpServo member
- */
-  enum errorServoCodeEnum {
-    //! Current or desired feature list is empty
+   * \brief Lists the possible error than can be emitted while calling
+   * vpServo member
+   */
+  enum errorServoCodeEnum
+  {
+//! Current or desired feature list is empty
     noFeatureError,
     //! No degree of freedom is available to achieve the secondary task.
     noDofFree,
@@ -81,6 +70,9 @@ public:
   };
 
 public:
+  /*!
+   * Constructor.
+   */
   vpServoException(int id, const char *format, ...)
   {
     this->code = id;
@@ -89,8 +81,16 @@ public:
     setMessage(format, args);
     va_end(args);
   }
-  vpServoException(int id, const std::string &msg) : vpException(id, msg) { ; }
-  explicit vpServoException(int id) : vpException(id) { ; }
+
+  /*!
+   * Constructor.
+   */
+  vpServoException(int id, const std::string &msg) : vpException(id, msg) { }
+
+  /*!
+   * Constructor.
+   */
+  explicit vpServoException(int id) : vpException(id) { }
 };
 
 #endif
