@@ -22,13 +22,13 @@ int main(int argc, const char **argv)
     vpDisplayX d(I);
 #elif defined(VISP_HAVE_GDI)
     vpDisplayGDI d(I);
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV d(I);
 #endif
 
     //! [Create base detector]
     vpDetectorBase *detector = NULL;
-//! [Create base detector]
+    //! [Create base detector]
 
 #if (defined(VISP_HAVE_ZBAR) && defined(VISP_HAVE_DMTX))
     int opt_barcode = 0; // 0=QRCode, 1=DataMatrix
@@ -39,7 +39,7 @@ int main(int argc, const char **argv)
       else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
         std::cout << "Usage: " << argv[0] << " [--code-type <0 for QR code | 1 for DataMatrix code>] [--help] [-h]"
                   << std::endl;
-        return 0;
+        return EXIT_SUCCESS;
       }
     }
     //! [Create detector]
