@@ -7,7 +7,7 @@
 
 int main(int argc, const char **argv)
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020101)
+#if defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_FEATURES2D)
   //! [Select method]
   int method = 0;
 
@@ -139,5 +139,5 @@ int main(int argc, const char **argv)
   (void)argc;
   (void)argv;
 #endif
-  return 0;
+  return EXIT_SUCCESS;
 }
