@@ -10,7 +10,7 @@
 
 int main(int argc, char **argv)
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020400)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_FEATURES2D)
   //! [MBT code]
   try {
     std::string videoname = "teabox.mp4";
@@ -20,7 +20,7 @@ int main(int argc, char **argv)
         videoname = std::string(argv[i + 1]);
       else if (std::string(argv[i]) == "--help") {
         std::cout << "\nUsage: " << argv[0] << " [--name <video name>] [--help]\n" << std::endl;
-        return 0;
+        return EXIT_SUCCESS;
       }
     }
     std::string parentname = vpIoTools::getParent(videoname);
@@ -31,8 +31,8 @@ int main(int argc, char **argv)
 
     std::cout << "Video name: " << videoname << std::endl;
     std::cout << "Tracker requested config files: " << objectname << ".[init,"
-              << "xml,"
-              << "cao or wrl]" << std::endl;
+      << "xml,"
+      << "cao or wrl]" << std::endl;
     std::cout << "Tracker optional config files: " << objectname << ".[ppm]" << std::endl;
 
     vpImage<unsigned char> I;
@@ -47,11 +47,11 @@ int main(int argc, char **argv)
     vpDisplayX display;
 #elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display;
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display;
 #else
     std::cout << "No image viewer is available..." << std::endl;
-    return 0;
+    return EXIT_FAILURE;
 #endif
 
     display.init(I, 100, 100, "Model-based edge tracker");
@@ -68,7 +68,8 @@ int main(int argc, char **argv)
       me.setMaskSize(5);
       me.setMaskNumber(180);
       me.setRange(8);
-      me.setThreshold(10000);
+      me.setLikelihoodThresholdType(vpMe::NORMALIZED_THRESHOLD);
+      me.setThreshold(20);
       me.setMu1(0.5);
       me.setMu2(0.5);
       me.setSampleStep(4);
@@ -91,10 +92,10 @@ int main(int argc, char **argv)
     tracker.setDisplayFeatures(true);
     tracker.initClick(I, objectname + ".init", true);
     tracker.track(I);
-//! [MBT code]
+    //! [MBT code]
 
-//! [Keypoint selection]
-#if (defined(VISP_HAVE_OPENCV_NONFREE) || defined(VISP_HAVE_OPENCV_XFEATURES2D)) || \
+    //! [Keypoint selection]
+#if (defined(VISP_HAVE_OPENCV_NONFREE) || defined(VISP_HAVE_OPENCV_XFEATURES2D)) ||                                    \
     (VISP_HAVE_OPENCV_VERSION >= 0x030411 && CV_MAJOR_VERSION < 4) || (VISP_HAVE_OPENCV_VERSION >= 0x040400)
     std::string detectorName = "SIFT";
     std::string extractorName = "SIFT";
@@ -112,10 +113,11 @@ int main(int argc, char **argv)
     vpKeyPoint keypoint_learning;
     //! [Keypoint declaration]
     if (usexml) {
-//! [Keypoint xml config]
+      //! [Keypoint xml config]
       keypoint_learning.loadConfigFile(configurationFile);
       //! [Keypoint xml config]
-    } else {
+    }
+    else {
       //! [Keypoint code config]
       keypoint_learning.setDetector(detectorName);
       keypoint_learning.setExtractor(extractorName);
@@ -164,7 +166,8 @@ int main(int argc, char **argv)
     vpKeyPoint keypoint_detection;
     if (usexml) {
       keypoint_detection.loadConfigFile(configurationFile);
-    } else {
+    }
+    else {
       keypoint_detection.setDetector(detectorName);
       keypoint_detection.setExtractor(extractorName);
       keypoint_detection.setMatcher(matcherName);
@@ -213,7 +216,8 @@ int main(int argc, char **argv)
     }
     if (!click_done)
       vpDisplay::getClick(I);
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 #else
@@ -222,5 +226,5 @@ int main(int argc, char **argv)
   std::cout << "Install OpenCV and rebuild ViSP to use this example." << std::endl;
 #endif
 
-  return 0;
+  return EXIT_SUCCESS;
 }
