@@ -8,7 +8,7 @@
 #include <visp3/mbt/vpMbEdgeTracker.h>
 #include <visp3/vision/vpKeyPoint.h>
 
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020400)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_FEATURES2D)
 void learnCube(const vpImage<unsigned char> &I, vpMbEdgeTracker &tracker, vpKeyPoint &keypoint_learning, int id)
 {
   //! [Keypoints reference detection]
@@ -46,7 +46,7 @@ void learnCube(const vpImage<unsigned char> &I, vpMbEdgeTracker &tracker, vpKeyP
 
 int main(int argc, char **argv)
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020400)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_FEATURES2D)
   //! [MBT code]
   try {
     std::string videoname = "cube.mp4";
@@ -56,7 +56,7 @@ int main(int argc, char **argv)
         videoname = std::string(argv[i + 1]);
       else if (std::string(argv[i]) == "--help") {
         std::cout << "\nUsage: " << argv[0] << " [--name <video name>] [--help]\n" << std::endl;
-        return 0;
+        return EXIT_SUCCESS;
       }
     }
     std::string parentname = vpIoTools::getParent(videoname);
@@ -67,8 +67,8 @@ int main(int argc, char **argv)
 
     std::cout << "Video name: " << videoname << std::endl;
     std::cout << "Tracker requested config files: " << objectname << ".[init,"
-              << "xml,"
-              << "cao or wrl]" << std::endl;
+      << "xml,"
+      << "cao or wrl]" << std::endl;
     std::cout << "Tracker optional config files: " << objectname << ".[ppm]" << std::endl;
 
     vpImage<unsigned char> I;
@@ -87,7 +87,8 @@ int main(int argc, char **argv)
       me.setMaskSize(5);
       me.setMaskNumber(180);
       me.setRange(7);
-      me.setThreshold(5000);
+      me.setLikelihoodThresholdType(vpMe::NORMALIZED_THRESHOLD);
+      me.setThreshold(20);
       me.setMu1(0.5);
       me.setMu2(0.5);
       me.setSampleStep(4);
@@ -120,27 +121,27 @@ int main(int argc, char **argv)
       orb_learning->setNLevels(1);
     }
 #endif
-//! [Keypoint declaration]
+    //! [Keypoint declaration]
 
 #if defined(VISP_HAVE_X11)
     vpDisplayX display;
 #elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display;
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display;
 #else
     std::cout << "No image viewer is available..." << std::endl;
-    return 0;
+    return EXIT_FAILURE;
 #endif
 
     /*
      * Start the part of the code dedicated to object learning from 3 images
      */
-    std::string imageName[] = {"cube0001.png", "cube0150.png", "cube0200.png"};
-    vpHomogeneousMatrix initPoseTab[] = {
+    std::string imageName [] = { "cube0001.png", "cube0150.png", "cube0200.png" };
+    vpHomogeneousMatrix initPoseTab [] = {
         vpHomogeneousMatrix(0.02143385294, 0.1098083886, 0.5127439561, 2.087159614, 1.141775176, -0.4701291124),
         vpHomogeneousMatrix(0.02651282185, -0.03713587374, 0.6873765919, 2.314744454, 0.3492296488, -0.1226054828),
-        vpHomogeneousMatrix(0.02965448956, -0.07283091786, 0.7253526051, 2.300529617, -0.4286674806, 0.1788761025)};
+        vpHomogeneousMatrix(0.02965448956, -0.07283091786, 0.7253526051, 2.300529617, -0.4286674806, 0.1788761025) };
     for (int i = 0; i < 3; i++) {
       vpImageIo::read(I, imageName[i]);
       if (i == 0) {
@@ -172,7 +173,8 @@ int main(int argc, char **argv)
       vpDisplay::displayText(I, 10, 10, "Learning step: keypoints are detected on visible cube faces", vpColor::red);
       if (i < 2) {
         vpDisplay::displayText(I, 30, 10, "Click to continue the learning...", vpColor::red);
-      } else {
+      }
+      else {
         vpDisplay::displayText(I, 30, 10, "Click to continue with the detection...", vpColor::red);
       }
 
@@ -187,7 +189,7 @@ int main(int argc, char **argv)
     /*
      * Start the part of the code dedicated to detection and localization
      */
-    //! [Init keypoint detection]
+     //! [Init keypoint detection]
     vpKeyPoint keypoint_detection("ORB", "ORB", "BruteForce-Hamming");
 #if (VISP_HAVE_OPENCV_VERSION < 0x030000)
     keypoint_detection.setDetectorParameter("ORB", "nLevels", 1);
@@ -213,13 +215,13 @@ int main(int argc, char **argv)
     g.setFileName(videoname);
     g.open(I);
 
-#if defined VISP_HAVE_X11
+#if defined(VISP_HAVE_X11)
     vpDisplayX display2;
-#elif defined VISP_HAVE_GTK
+#elif defined(VISP_HAVE_GTK)
     vpDisplayGTK display2;
-#elif defined VISP_HAVE_GDI
+#elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display2;
-#else
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display2;
 #endif
     display2.init(IMatching, 50, 50, "Display matching between learned and current images");
@@ -287,7 +289,7 @@ int main(int argc, char **argv)
         //! [Display model image matching]
         vpCameraParameters cam2;
         cam2.initPersProjWithoutDistortion(cam.get_px(), cam.get_py(), cam.get_u0() + I.getWidth(),
-                                           cam.get_v0() + I.getHeight());
+          cam.get_v0() + I.getHeight());
         tracker.setCameraParameters(cam2);
         tracker.setPose(IMatching, cMo);
         tracker.display(IMatching, cMo, cam2, vpColor::red, 2);
@@ -310,7 +312,8 @@ int main(int argc, char **argv)
 
     if (!click_done)
       vpDisplay::getClick(IMatching);
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 #else
@@ -319,5 +322,5 @@ int main(int argc, char **argv)
   std::cout << "Install OpenCV and rebuild ViSP to use this example." << std::endl;
 #endif
 
-  return 0;
+  return EXIT_SUCCESS;
 }
