@@ -12,21 +12,19 @@
 
 int main(int argc, char **argv)
 {
-#if defined(VISP_HAVE_REALSENSE2) && (RS2_API_VERSION > ((2 * 10000) + (31 * 100) + 0)) && (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
+#if defined(VISP_HAVE_REALSENSE2) && (RS2_API_VERSION > ((2 * 10000) + (31 * 100) + 0)) &&                             \
+    (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
   std::vector<std::pair<std::string, std::string> > type_serial_nb;
   std::vector<bool> cam_found;
 
   for (int i = 0; i < argc; i++) {
     if (std::string(argv[i]) == "--T265") {
       type_serial_nb.push_back(std::make_pair("T265", std::string(argv[i + 1])));
-    }
-    else if (std::string(argv[i]) == "--D435") {
+    } else if (std::string(argv[i]) == "--D435") {
       type_serial_nb.push_back(std::make_pair("D435", std::string(argv[i + 1])));
-    }
-    else if (std::string(argv[i]) == "--SR300") {
+    } else if (std::string(argv[i]) == "--SR300") {
       type_serial_nb.push_back(std::make_pair("SR300", std::string(argv[i + 1])));
-    }
-    else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
+    } else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
       std::cout << "\nUsage: " << argv[0]
                 << " [--T265 <serial number>] [--D435 <serial number>] [--SR300 <serial number>]\n"
                 << "\nExample to use 2 T265 cameras:\n"
@@ -36,20 +34,20 @@ int main(int argc, char **argv)
                 << "\nExample to use 2 T265 and 1 D435 cameras:\n"
                 << "  " << argv[0] << " --T265 11622110511 --T265 11622110433 --D435 752112070408 \n"
                 << std::endl;
-      return 0;
+      return EXIT_SUCCESS;
     }
   }
 
   rs2::config T265_cfg, D435_cfg;
-  std::vector< vpRealSense2 > g(type_serial_nb.size());
-  std::vector< vpImage<unsigned char> > I(type_serial_nb.size());
+  std::vector<vpRealSense2> g(type_serial_nb.size());
+  std::vector<vpImage<unsigned char> > I(type_serial_nb.size());
 
 #ifdef VISP_HAVE_X11
-  std::vector< vpDisplayX > d(type_serial_nb.size());
+  std::vector<vpDisplayX> d(type_serial_nb.size());
 #elif defined(VISP_HAVE_GDI)
-  std::vector< vpDisplayGDI > d(type_serial_nb.size());
-#elif defined(VISP_HAVE_OPENCV)
-  std::vector< vpDisplayOpenCV > d(type_serial_nb.size());
+  std::vector<vpDisplayGDI> d(type_serial_nb.size());
+#elif defined(HAVE_OPENCV_HIGHGUI)
+  std::vector<vpDisplayOpenCV> d(type_serial_nb.size());
 #else
   std::cout << "No image viewer is available..." << std::endl;
 #endif
@@ -63,17 +61,16 @@ int main(int argc, char **argv)
       T265_cfg.enable_stream(RS2_STREAM_FISHEYE, 1, RS2_FORMAT_Y8);
       T265_cfg.enable_stream(RS2_STREAM_FISHEYE, 2, RS2_FORMAT_Y8);
       cam_found.push_back(g[i].open(T265_cfg));
-      if(!cam_found.back()) {
+      if (!cam_found.back()) {
         std::cout << "Device with ID: " << type_serial_nb[i].second << " not found." << std::endl;
       }
-    }
-    else { // D435 or SR300
+    } else { // D435 or SR300
       D435_cfg.enable_device(type_serial_nb[i].second);
       D435_cfg.disable_stream(RS2_STREAM_DEPTH);
       D435_cfg.disable_stream(RS2_STREAM_INFRARED);
       D435_cfg.enable_stream(RS2_STREAM_COLOR, 640, 480, RS2_FORMAT_RGBA8, 30);
       cam_found.push_back(g[i].open(D435_cfg));
-      if(!cam_found.back()) {
+      if (!cam_found.back()) {
         std::cout << "Device with ID: " << type_serial_nb[i].second << " not found." << std::endl;
       }
     }
@@ -87,7 +84,7 @@ int main(int argc, char **argv)
 
 #if defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV)
           if (!d[i].isInitialised()) {
-            d[i].init(I[i], static_cast<int>(100*i), static_cast<int>(100*i), "T265 left image");
+            d[i].init(I[i], static_cast<int>(100 * i), static_cast<int>(100 * i), "T265 left image");
           }
 #endif
         }
@@ -97,7 +94,7 @@ int main(int argc, char **argv)
 
 #if defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV)
           if (!d[i].isInitialised()) {
-            d[i].init(I[i], static_cast<int>(100*i), static_cast<int>(100*i), type_serial_nb[i].first.c_str());
+            d[i].init(I[i], static_cast<int>(100 * i), static_cast<int>(100 * i), type_serial_nb[i].first.c_str());
           }
 #endif
         }
@@ -107,27 +104,28 @@ int main(int argc, char **argv)
         clicked = vpDisplay::getClick(I[i], false);
       }
 
-      if(clicked) {
+      if (clicked) {
         break;
       }
     }
 
-    if(clicked) {
+    if (clicked) {
       break;
     }
-
   }
 #else
-  (void) argc;
-  (void) argv;
+  (void)argc;
+  (void)argv;
 #if !(defined(VISP_HAVE_REALSENSE2))
   std::cout << "Install librealsense version > 2.31.0, configure and build ViSP again to use this example" << std::endl;
 #endif
 #if !(RS2_API_VERSION > ((2 * 10000) + (31 * 100) + 0))
-  std::cout << "librealsense is detected but its version is too old. Install librealsense version > 2.31.0, configure and build ViSP again to use this example" << std::endl;
+  std::cout << "librealsense is detected but its version is too old. Install librealsense version > 2.31.0, configure "
+               "and build ViSP again to use this example"
+            << std::endl;
 #endif
 #if (VISP_CXX_STANDARD < VISP_CXX_STANDARD_11)
-  std::cout << "This turorial should be built with c++11 support" << std::endl;
+  std::cout << "This tutorial should be built with c++11 support" << std::endl;
 #endif
 #endif
   return EXIT_SUCCESS;
