@@ -15,7 +15,7 @@
  */
 int main(int argc, char **argv)
 {
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020100)
+#if defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO)
   try {
     std::string videoname = "video.mp4";
 
@@ -23,10 +23,10 @@ int main(int argc, char **argv)
       if (std::string(argv[i]) == "--name")
         videoname = std::string(argv[i + 1]);
       else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
-        std::cout << "\nUsage: " << argv[0]
-                  << " [--name <video name> (default: " << videoname << ")]"
-                  << " [--help] [-h]\n" << std::endl;
-        return 0;
+        std::cout << "\nUsage: " << argv[0] << " [--name <video name> (default: " << videoname << ")]"
+                  << " [--help] [-h]\n"
+                  << std::endl;
+        return EXIT_SUCCESS;
       }
     }
 
@@ -48,7 +48,7 @@ int main(int argc, char **argv)
     vpDisplayX d(I);
 #elif defined(VISP_HAVE_GDI)
     vpDisplayGDI d(I);
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV d(I);
 #else
     std::cout << "No image viewer is available..." << std::endl;
@@ -68,7 +68,7 @@ int main(int argc, char **argv)
       vpDisplay::display(I);
       vpDisplay::displayText(I, 20, 20, "Click to quit", vpColor::red);
       std::stringstream ss;
-      ss << "Frame: " << cpt ++;
+      ss << "Frame: " << cpt++;
       vpDisplay::displayText(I, 40, 20, ss.str(), vpColor::red);
       vpDisplay::flush(I);
       if (vpDisplay::getClick(I, false))
@@ -86,4 +86,5 @@ int main(int argc, char **argv)
   (void)argv;
   std::cout << "Install OpenCV and rebuild ViSP to use this example." << std::endl;
 #endif
+  return EXIT_SUCCESS;
 }
