@@ -7,6 +7,10 @@
 #include <visp3/io/vpVideoWriter.h>
 #include <visp3/sensor/vpV4l2Grabber.h>
 
+#if defined(HAVE_OPENCV_VIDEOIO)
+#include <opencv2/videoio.hpp>
+#endif
+
 /*!
  This example allows to record a video from a camera.
  It only requires that ViSP is build with OpenCV.
@@ -24,10 +28,10 @@
     ./tutorial-video-recorder --device 0 --name image.jpeg
 
  */
-int main(int argc, const char *argv[])
+int main(int argc, const char *argv [])
 {
-#if ((defined(VISP_HAVE_V4L2) || (VISP_HAVE_OPENCV_VERSION >= 0x020100)) &&                                            \
-     (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV) || defined(VISP_HAVE_GTK)))
+#if ((defined(VISP_HAVE_V4L2) || defined(HAVE_OPENCV_VIDEOIO)) &&                                            \
+     (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI) || defined(HAVE_OPENCV_HIGHGUI) || defined(VISP_HAVE_GTK)))
   std::string opt_videoname = "video-recorded.mpg";
   int opt_device = 0;
 
@@ -37,10 +41,9 @@ int main(int argc, const char *argv[])
     else if (std::string(argv[i]) == "--name")
       opt_videoname = std::string(argv[i + 1]);
     else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
-      std::cout << "\nUsage: " << argv[0]
-                << " [--device <device number>] [--name <video name>] [--help][-h]\n"
-                << std::endl;
-      return 0;
+      std::cout << "\nUsage: " << argv[0] << " [--device <device number>] [--name <video name>] [--help][-h]\n"
+        << std::endl;
+      return EXIT_SUCCESS;
     }
   }
 
@@ -59,11 +62,11 @@ int main(int argc, const char *argv[])
     g.setScale(1); // Acquire full resolution images
     g.open(I);
     g.acquire(I);
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_VIDEOIO)
     cv::VideoCapture g(opt_device);
     if (!g.isOpened()) { // check if we succeeded
       std::cout << "Failed to open the camera" << std::endl;
-      return -1;
+      return EXIT_FAILURE;
     }
     cv::Mat frame;
     g >> frame; // get a new frame from camera
@@ -76,7 +79,7 @@ int main(int argc, const char *argv[])
     vpDisplayX d;
 #elif defined(VISP_HAVE_GDI)
     vpDisplayGDI d;
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV d;
 #elif defined(VISP_HAVE_GTK)
     vpDisplayGTK d;
@@ -84,10 +87,12 @@ int main(int argc, const char *argv[])
     d.init(I, 0, 0, "Camera view");
     vpVideoWriter writer;
 
-#if VISP_HAVE_OPENCV_VERSION >= 0x030000
+#if defined(HAVE_OPENCV_VIDEOIO)
+#if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
     writer.setCodec(cv::VideoWriter::fourcc('P', 'I', 'M', '1')); // MPEG-1 codec
-#elif VISP_HAVE_OPENCV_VERSION >= 0x020100
+#else
     writer.setCodec(CV_FOURCC('P', 'I', 'M', '1'));
+#endif
 #endif
     writer.setFileName(opt_videoname);
     writer.open(I);
@@ -96,7 +101,7 @@ int main(int argc, const char *argv[])
     for (;;) {
 #if defined(VISP_HAVE_V4L2)
       g.acquire(I);
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_VIDEOIO)
       g >> frame;
       vpImageConvert::convert(frame, I);
 #endif
@@ -105,7 +110,8 @@ int main(int argc, const char *argv[])
         vpDisplay::displayText(I, 10, 10, "A click to start recording", vpColor::green);
         if (vpDisplay::getClick(I, false))
           recording = true;
-      } else {
+      }
+      else {
         writer.saveFrame(I);
         vpDisplay::displayText(I, 10, 10, "Recording: A click to stop and exit", vpColor::red);
         if (vpDisplay::getClick(I, false))
@@ -115,7 +121,8 @@ int main(int argc, const char *argv[])
       vpDisplay::flush(I);
     }
     std::cout << "The video was recorded in \"" << opt_videoname << "\"" << std::endl;
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 #else
@@ -123,4 +130,5 @@ int main(int argc, const char *argv[])
   (void)argv;
   std::cout << "Install OpenCV and rebuild ViSP to use this example." << std::endl;
 #endif
+  return EXIT_SUCCESS;
 }
