@@ -15,7 +15,7 @@ void display(vpImage<unsigned char> &I, const std::string &title)
 {
 #if defined(VISP_HAVE_X11)
   vpDisplayX d(I);
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
   vpDisplayOpenCV d(I);
 #elif defined(VISP_HAVE_GTK)
   vpDisplayGTK d(I);
@@ -27,7 +27,7 @@ void display(vpImage<unsigned char> &I, const std::string &title)
   std::cout << "No image viewer is available..." << std::endl;
 #endif
 
-  vpDisplay::setTitle(I, title.c_str());
+  vpDisplay::setTitle(I, title);
   vpDisplay::display(I);
   vpDisplay::displayText(I, 15, 15, "Click to continue...", vpColor::red);
   vpDisplay::flush(I);
@@ -46,7 +46,7 @@ int main(int argc, char **argv)
   try {
     if (argc != 2) {
       printf("Usage: %s <image name.[pgm,ppm,jpeg,png,bmp]>\n", argv[0]);
-      return -1;
+      return EXIT_FAILURE;
     }
     //! [vpImage construction]
     vpImage<unsigned char> I;
@@ -54,9 +54,10 @@ int main(int argc, char **argv)
 
     try {
       vpImageIo::read(I, argv[1]);
-    } catch (...) {
+    }
+    catch (...) {
       std::cout << "Cannot read image \"" << argv[1] << "\"" << std::endl;
-      return -1;
+      return EXIT_FAILURE;
     }
 
     display(I, "Original image");
@@ -67,7 +68,7 @@ int main(int argc, char **argv)
     //! [Gaussian blur]
     display(F, "Blur (default)");
 
-    vpImageFilter::gaussianBlur(I, F, 7, 2);
+    vpImageFilter::gaussianBlur(I, F, 7, 2.);
     display(F, "Blur (var=2)");
 
     //! [Gradients x]
@@ -82,12 +83,10 @@ int main(int argc, char **argv)
     //! [Gradients y]
     display(dIy, "Gradient dIy");
 
-//! [Canny]
-#if (VISP_HAVE_OPENCV_VERSION >= 0x020100)
+    //! [Canny]
     vpImage<unsigned char> C;
-    vpImageFilter::canny(I, C, 5, 15, 3);
+    vpImageFilter::canny(I, C, 5, -1., 3);
     display(C, "Canny");
-#endif
     //! [Canny]
 
     //! [Convolution kernel]
@@ -117,9 +116,10 @@ int main(int argc, char **argv)
       display(pyr[i], "Pyramid");
     }
     //! [Gaussian pyramid]
-    return 0;
-  } catch (const vpException &e) {
+    return EXIT_SUCCESS;
+  }
+  catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
-    return 1;
+    return EXIT_FAILURE;
   }
 }
