@@ -7,7 +7,7 @@ int main()
     vpImage<vpRGBa> I;
     vpImageIo::read(I, "monkey.jpeg");
     vpImageIo::write(I, "monkey.png");
-  } catch (vpException &e) {
+  } catch (const vpException &e) {
     std::cout << e.getMessage() << std::endl;
   } catch (...) {
     std::cout << "Unsupported image format" << std::endl;
