@@ -88,7 +88,7 @@ int main(int argc, const char **argv)
   vpDisplayX d, d2;
 #elif defined(VISP_HAVE_GDI)
   vpDisplayGDI d, d2;
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
   vpDisplayOpenCV d, d2;
 #endif
   d.init(I_bin, 0, 0, "After binarisation");
@@ -132,11 +132,9 @@ int main(int argc, const char **argv)
   vpDisplay::flush(I_bin);
   vpDisplay::flush(I_draw_contours);
   vpDisplay::getClick(I_draw_contours);
-
-  return EXIT_SUCCESS;
 #else
   (void)argc;
   (void)argv;
-  return 0;
 #endif
+  return EXIT_SUCCESS;
 }
