@@ -55,13 +55,13 @@ int main(int argc, const char **argv)
   //! [Read]
   vpImage<vpRGBa> I_color;
   vpImageIo::read(I_color, input_filename);
-//! [Read]
+  //! [Read]
 
 #ifdef VISP_HAVE_X11
   vpDisplayX d, d2, d3, d4, d5, d6;
 #elif defined(VISP_HAVE_GDI)
   vpDisplayGDI d, d2, d3, d4, d5, d6;
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
   vpDisplayOpenCV d, d2, d3, d4, d5, d6;
 #endif
   d.init(I_color, 0, 0, "Input color image");
@@ -110,11 +110,9 @@ int main(int argc, const char **argv)
   vpDisplay::flush(I_clahe);
   vpDisplay::flush(I_unsharp);
   vpDisplay::getClick(I_unsharp);
-
-  return EXIT_SUCCESS;
 #else
   (void)argc;
   (void)argv;
-  return 0;
 #endif
+  return EXIT_SUCCESS;
 }
