@@ -1,7 +1,7 @@
 /****************************************************************************
  *
  * ViSP, open source Visual Servoing Platform software.
- * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
+ * Copyright (C) 2005 - 2023 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  * GPL, please contact Inria about acquiring a ViSP Professional
  * Edition License.
  *
- * See http://visp.inria.fr for more information.
+ * See https://visp.inria.fr for more information.
  *
  * This software was developed at:
  * Inria Rennes - Bretagne Atlantique
@@ -33,10 +33,7 @@
  *   eye-in-hand control
  *   velocity computed in the camera frame
  *
- * Authors:
- * Fabien Spindler
- *
- *****************************************************************************/
+*****************************************************************************/
 /*!
   \example tutorial-flir-ptu-ibvs.cpp
 
@@ -62,21 +59,20 @@
 
 #include <visp3/core/vpCameraParameters.h>
 #include <visp3/core/vpXmlParserCamera.h>
+#include <visp3/detection/vpDetectorAprilTag.h>
 #include <visp3/gui/vpDisplayGDI.h>
 #include <visp3/gui/vpDisplayX.h>
+#include <visp3/gui/vpPlot.h>
 #include <visp3/io/vpImageIo.h>
-#include <visp3/sensor/vpFlyCaptureGrabber.h>
 #include <visp3/robot/vpRobotFlirPtu.h>
-#include <visp3/detection/vpDetectorAprilTag.h>
+#include <visp3/sensor/vpFlyCaptureGrabber.h>
 #include <visp3/visual_features/vpFeatureBuilder.h>
 #include <visp3/visual_features/vpFeaturePoint.h>
 #include <visp3/vs/vpServo.h>
 #include <visp3/vs/vpServoDisplay.h>
-#include <visp3/gui/vpPlot.h>
-
-#if defined(VISP_HAVE_FLIR_PTU_SDK) && defined(VISP_HAVE_FLYCAPTURE) && \
-  (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI))
 
+#if defined(VISP_HAVE_FLIR_PTU_SDK) && defined(VISP_HAVE_FLYCAPTURE) &&                                                \
+    (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI))
 
 int main(int argc, char **argv)
 {
@@ -95,47 +91,50 @@ int main(int argc, char **argv)
   for (int i = 1; i < argc; i++) {
     if ((std::string(argv[i]) == "--portname" || std::string(argv[i]) == "-p") && (i + 1 < argc)) {
       opt_portname = std::string(argv[i + 1]);
-    }
-    else if ((std::string(argv[i]) == "--baudrate" || std::string(argv[i]) == "-b") && (i + 1 < argc)) {
+    } else if ((std::string(argv[i]) == "--baudrate" || std::string(argv[i]) == "-b") && (i + 1 < argc)) {
       opt_baudrate = std::atoi(argv[i + 1]);
-    }
-    else if ((std::string(argv[i]) == "--network" || std::string(argv[i]) == "-n")) {
+    } else if ((std::string(argv[i]) == "--network" || std::string(argv[i]) == "-n")) {
       opt_network = true;
-    }
-    else if (std::string(argv[i]) == "--extrinsic" && i + 1 < argc) {
+    } else if (std::string(argv[i]) == "--extrinsic" && i + 1 < argc) {
       opt_extrinsic = std::string(argv[i + 1]);
-    }
-    else if (std::string(argv[i]) == "--constant-gain" || std::string(argv[i]) == "-g") {
-      opt_constant_gain = std::stod(argv[i + 1]);;
-    }
-    else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
+    } else if (std::string(argv[i]) == "--constant-gain" || std::string(argv[i]) == "-g") {
+      opt_constant_gain = std::stod(argv[i + 1]);
+      ;
+    } else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
       std::cout << "SYNOPSIS" << std::endl
                 << "  " << argv[0] << " [--portname <portname>] [--baudrate <rate>] [--network] "
-                << "[--extrinsic <extrinsic.yaml>] [--constant-gain] [--help] [-h]" << std::endl << std::endl;
+                << "[--extrinsic <extrinsic.yaml>] [--constant-gain] [--help] [-h]" << std::endl
+                << std::endl;
       std::cout << "DESCRIPTION" << std::endl
                 << "  --portname, -p <portname>" << std::endl
-                << "    Set serial or tcp port name." << std::endl << std::endl
+                << "    Set serial or tcp port name." << std::endl
+                << std::endl
                 << "  --baudrate, -b <rate>" << std::endl
-                << "    Set serial communication baud rate. Default: " << opt_baudrate << "." << std::endl << std::endl
+                << "    Set serial communication baud rate. Default: " << opt_baudrate << "." << std::endl
+                << std::endl
                 << "  --network, -n" << std::endl
-                << "    Get PTU network information (Hostname, IP, Gateway) and exit. " << std::endl << std::endl
+                << "    Get PTU network information (Hostname, IP, Gateway) and exit. " << std::endl
+                << std::endl
                 << "  --extrinsic <extrinsic.yaml>" << std::endl
                 << "    YAML file containing extrinsic camera parameters as a vpHomogeneousMatrix." << std::endl
                 << "    It corresponds to the homogeneous transformation eMc, between end-effector" << std::endl
-                << "    and camera frame." << std::endl << std::endl
+                << "    and camera frame." << std::endl
+                << std::endl
                 << "  --constant-gain, -g" << std::endl
-                << "    Constant gain value. Default value: " << opt_constant_gain << std::endl << std::endl
+                << "    Constant gain value. Default value: " << opt_constant_gain << std::endl
+                << std::endl
                 << "  --help, -h" << std::endl
-                << "    Print this helper message. " << std::endl << std::endl;
+                << "    Print this helper message. " << std::endl
+                << std::endl;
       std::cout << "EXAMPLE" << std::endl
                 << "  - How to get network IP" << std::endl
-             #ifdef _WIN32
+#ifdef _WIN32
                 << "    $ " << argv[0] << " --portname COM1 --network" << std::endl
                 << "    Try to connect FLIR PTU to port: COM1 with baudrate: 9600" << std::endl
-             #else
+#else
                 << "    $ " << argv[0] << " --portname /dev/ttyUSB0 --network" << std::endl
                 << "    Try to connect FLIR PTU to port: /dev/ttyUSB0 with baudrate: 9600" << std::endl
-             #endif
+#endif
                 << "       PTU HostName: PTU-5" << std::endl
                 << "       PTU IP      : 169.254.110.254" << std::endl
                 << "       PTU Gateway : 0.0.0.0" << std::endl
@@ -152,10 +151,10 @@ int main(int argc, char **argv)
     std::cout << "Try to connect FLIR PTU to port: " << opt_portname << " with baudrate: " << opt_baudrate << std::endl;
     robot.connect(opt_portname, opt_baudrate);
 
-    if(opt_network) {
-      std::cout << "PTU HostName: " << robot.getNetworkHostName() <<std::endl;
-      std::cout << "PTU IP      : " << robot.getNetworkIP() <<std::endl;
-      std::cout << "PTU Gateway : " << robot.getNetworkGateway() <<std::endl;
+    if (opt_network) {
+      std::cout << "PTU HostName: " << robot.getNetworkHostName() << std::endl;
+      std::cout << "PTU IP      : " << robot.getNetworkIP() << std::endl;
+      std::cout << "PTU Gateway : " << robot.getNetworkGateway() << std::endl;
       return EXIT_SUCCESS;
     }
 
@@ -167,9 +166,7 @@ int main(int argc, char **argv)
     // Get camera extrinsics
     vpTranslationVector etc;
     vpRotationMatrix eRc;
-    eRc <<  0,  0, 1,
-           -1,  0, 0,
-            0, -1, 0;
+    eRc << 0, 0, 1, -1, 0, 0, 0, -1, 0;
     etc << -0.1, -0.123, 0.035;
     vpHomogeneousMatrix eMc(etc, eRc);
 
@@ -288,8 +285,7 @@ int main(int argc, char **argv)
     }
     std::cout << "Stop the robot " << std::endl;
     robot.setRobotState(vpRobot::STATE_STOP);
-  }
-  catch (const vpRobotException & e) {
+  } catch (const vpRobotException &e) {
     std::cout << "Catch Flir Ptu exception: " << e.getMessage() << std::endl;
     robot.setRobotState(vpRobot::STATE_STOP);
   }
@@ -305,6 +301,6 @@ int main()
 #if !defined(VISP_HAVE_FLIR_PTU_SDK)
   std::cout << "Install FLIR PTU SDK." << std::endl;
 #endif
-  return 0;
+  return EXIT_SUCCESS;
 }
 #endif
