@@ -1,23 +1,23 @@
 //! \example mbot-apriltag-ibvs.cpp
+#include <visp3/core/vpMomentAreaNormalized.h>
+#include <visp3/core/vpMomentBasic.h>
+#include <visp3/core/vpMomentCentered.h>
+#include <visp3/core/vpMomentDatabase.h>
+#include <visp3/core/vpMomentGravityCenter.h>
+#include <visp3/core/vpMomentGravityCenterNormalized.h>
+#include <visp3/core/vpMomentObject.h>
+#include <visp3/core/vpPixelMeterConversion.h>
+#include <visp3/core/vpPoint.h>
 #include <visp3/core/vpSerial.h>
 #include <visp3/core/vpXmlParserCamera.h>
-#include <visp3/core/vpMomentObject.h>
-#include <visp3/core/vpPoint.h>
-#include <visp3/core/vpMomentBasic.h>
-#include <visp3/core/vpMomentGravityCenter.h>
-#include <visp3/core/vpMomentDatabase.h>
-#include <visp3/core/vpMomentCentered.h>
-#include <visp3/core/vpMomentAreaNormalized.h>
-#include <visp3/core/vpMomentGravityCenterNormalized.h>
-#include <visp3/core/vpPixelMeterConversion.h>
 #include <visp3/detection/vpDetectorAprilTag.h>
 #include <visp3/gui/vpDisplayX.h>
-#include <visp3/sensor/vpV4l2Grabber.h>
 #include <visp3/io/vpImageIo.h>
+#include <visp3/robot/vpUnicycle.h>
+#include <visp3/sensor/vpV4l2Grabber.h>
 #include <visp3/visual_features/vpFeatureMomentAreaNormalized.h>
 #include <visp3/visual_features/vpFeatureMomentGravityCenterNormalized.h>
 #include <visp3/vs/vpServo.h>
-#include <visp3/robot/vpUnicycle.h>
 
 int main(int argc, const char **argv)
 {
@@ -84,7 +84,7 @@ int main(int argc, const char **argv)
   // if motor right: led 4 blue
 
   vpSerial *serial = NULL;
-  if (! serial_off) {
+  if (!serial_off) {
     serial = new vpSerial("/dev/ttyAMA0", 115200);
 
     serial->write("LED_RING=0,0,0,0\n");  // Switch off all led
@@ -130,16 +130,22 @@ int main(int argc, const char **argv)
     if (display_on)
       lambda.initStandard(2.5, 0.4, 30); // lambda(0)=2.5, lambda(oo)=0.4 and lambda'(0)=30
     else
-      lambda.initStandard(4, 0.4, 30);   // lambda(0)=4, lambda(oo)=0.4 and lambda'(0)=30
+      lambda.initStandard(4, 0.4, 30); // lambda(0)=4, lambda(oo)=0.4 and lambda'(0)=30
 
     vpUnicycle robot;
     task.setServo(vpServo::EYEINHAND_L_cVe_eJe);
     task.setInteractionMatrixType(vpServo::CURRENT);
     task.setLambda(lambda);
     vpRotationMatrix cRe;
-    cRe[0][0] = 0; cRe[0][1] = -1; cRe[0][2] =  0;
-    cRe[1][0] = 0; cRe[1][1] =  0; cRe[1][2] = -1;
-    cRe[2][0] = 1; cRe[2][1] =  0; cRe[2][2] =  0;
+    cRe[0][0] = 0;
+    cRe[0][1] = -1;
+    cRe[0][2] = 0;
+    cRe[1][0] = 0;
+    cRe[1][1] = 0;
+    cRe[1][2] = -1;
+    cRe[2][0] = 1;
+    cRe[2][1] = 0;
+    cRe[2][2] = 0;
 
     vpHomogeneousMatrix cMe(vpTranslationVector(), cRe);
     vpVelocityTwistMatrix cVe(cMe);
@@ -154,8 +160,8 @@ int main(int argc, const char **argv)
     double Z_d = 0.4;
 
     // Define the desired polygon corresponding the the AprilTag CLOCKWISE
-    double X[4] = {tagSize/2.,  tagSize/2., -tagSize/2., -tagSize/2.};
-    double Y[4] = {tagSize/2., -tagSize/2., -tagSize/2.,  tagSize/2.};
+    double X[4] = {tagSize / 2., tagSize / 2., -tagSize / 2., -tagSize / 2.};
+    double Y[4] = {tagSize / 2., -tagSize / 2., -tagSize / 2., tagSize / 2.};
     std::vector<vpPoint> vec_P, vec_P_d;
 
     for (int i = 0; i < 4; i++) {
@@ -167,15 +173,16 @@ int main(int argc, const char **argv)
 
     vpMomentObject m_obj(3), m_obj_d(3);
     vpMomentDatabase mdb, mdb_d;
-    vpMomentBasic mb_d;                                // Here only to get the desired area m00
+    vpMomentBasic mb_d; // Here only to get the desired area m00
     vpMomentGravityCenter mg, mg_d;
     vpMomentCentered mc, mc_d;
-    vpMomentAreaNormalized man(0, Z_d), man_d(0, Z_d); // Declare normalized area. Desired area parameter will be updated below with m00
-    vpMomentGravityCenterNormalized mgn, mgn_d;        // Declare normalized gravity center
+    vpMomentAreaNormalized man(0, Z_d),
+        man_d(0, Z_d); // Declare normalized area. Desired area parameter will be updated below with m00
+    vpMomentGravityCenterNormalized mgn, mgn_d; // Declare normalized gravity center
 
     // Desired moments
-    m_obj_d.setType(vpMomentObject::DENSE_POLYGON);    // Consider the AprilTag as a polygon
-    m_obj_d.fromVector(vec_P_d);                       // Initialize the object with the points coordinates
+    m_obj_d.setType(vpMomentObject::DENSE_POLYGON); // Consider the AprilTag as a polygon
+    m_obj_d.fromVector(vec_P_d);                    // Initialize the object with the points coordinates
 
     mb_d.linkTo(mdb_d);       // Add basic moments to database
     mg_d.linkTo(mdb_d);       // Add gravity center to database
@@ -194,8 +201,8 @@ int main(int argc, const char **argv)
     // Update an moment with the desired area
     man_d.setDesiredArea(area);
 
-    man_d.compute();          // Compute area normalized moment AFTER centered moments
-    mgn_d.compute();          // Compute gravity center normalized moment AFTER area normalized moment
+    man_d.compute(); // Compute area normalized moment AFTER centered moments
+    mgn_d.compute(); // Compute gravity center normalized moment AFTER area normalized moment
 
     // Desired plane
     double A = 0.0;
@@ -236,12 +243,12 @@ int main(int argc, const char **argv)
       }
 
       if (detector.getNbObjects() == 1) {
-        if (! serial_off) {
+        if (!serial_off) {
           serial->write("LED_RING=2,0,10,0\n"); // Switch on led 2 to green: tag detected
         }
 
         // Update current points used to compute the moments
-        std::vector< vpImagePoint > vec_ip = detector.getPolygon(0);
+        std::vector<vpImagePoint> vec_ip = detector.getPolygon(0);
         vec_P.clear();
         for (size_t i = 0; i < vec_ip.size(); i++) { // size = 4
           double x = 0, y = 0;
@@ -254,23 +261,26 @@ int main(int argc, const char **argv)
 
         // Display visual features
         vpDisplay::displayPolygon(I, vec_ip, vpColor::green, 3); // Current polygon used to compure an moment
-        vpDisplay::displayCross(I, detector.getCog(0), 15, vpColor::green, 3); // Current polygon used to compure an moment
-        vpDisplay::displayLine(I, 0, cam.get_u0(), I.getHeight()-1, cam.get_u0(), vpColor::red, 3); // Vertical line as desired x position
+        vpDisplay::displayCross(I, detector.getCog(0), 15, vpColor::green,
+                                3); // Current polygon used to compure an moment
+        vpDisplay::displayLine(I, 0, cam.get_u0(), I.getHeight() - 1, cam.get_u0(), vpColor::red,
+                               3); // Vertical line as desired x position
 
         // Current moments
         m_obj.setType(vpMomentObject::DENSE_POLYGON); // Consider the AprilTag as a polygon
         m_obj.fromVector(vec_P);                      // Initialize the object with the points coordinates
 
-        mg.linkTo(mdb);           // Add gravity center to database
-        mc.linkTo(mdb);           // Add centered moments to database
-        man.linkTo(mdb);          // Add area normalized to database
-        mgn.linkTo(mdb);          // Add gravity center normalized to database
-        mdb.updateAll(m_obj);     // All of the moments must be updated, not just an_d
-        mg.compute();             // Compute gravity center moment
-        mc.compute();             // Compute centered moments AFTER gravity center
-        man.setDesiredArea(area); // Since desired area was init at 0, because unknow at contruction, need to be updated here
-        man.compute();            // Compute area normalized moment AFTER centered moment
-        mgn.compute();            // Compute gravity center normalized moment AFTER area normalized moment
+        mg.linkTo(mdb);       // Add gravity center to database
+        mc.linkTo(mdb);       // Add centered moments to database
+        man.linkTo(mdb);      // Add area normalized to database
+        mgn.linkTo(mdb);      // Add gravity center normalized to database
+        mdb.updateAll(m_obj); // All of the moments must be updated, not just an_d
+        mg.compute();         // Compute gravity center moment
+        mc.compute();         // Compute centered moments AFTER gravity center
+        man.setDesiredArea(
+            area);     // Since desired area was init at 0, because unknow at contruction, need to be updated here
+        man.compute(); // Compute area normalized moment AFTER centered moment
+        mgn.compute(); // Compute gravity center normalized moment AFTER area normalized moment
 
         s_mgn.update(A, B, C);
         s_mgn.compute_interaction();
@@ -288,29 +298,28 @@ int main(int argc, const char **argv)
         task.print();
         double radius = 0.0325;
         double L = 0.0725;
-        double motor_left  = (-v[0] - L * v[1]) / radius;
-        double motor_right = ( v[0] - L * v[1]) / radius;
+        double motor_left = (-v[0] - L * v[1]) / radius;
+        double motor_right = (v[0] - L * v[1]) / radius;
         std::cout << "motor left vel: " << motor_left << " motor right vel: " << motor_right << std::endl;
-        if (! serial_off) {
-//          serial->write("LED_RING=3,0,0,10\n"); // Switch on led 3 to blue: motor left servoed
-//          serial->write("LED_RING=4,0,0,10\n"); // Switch on led 4 to blue: motor right servoed
+        if (!serial_off) {
+          //          serial->write("LED_RING=3,0,0,10\n"); // Switch on led 3 to blue: motor left servoed
+          //          serial->write("LED_RING=4,0,0,10\n"); // Switch on led 4 to blue: motor right servoed
         }
         std::stringstream ss;
-        double rpm_left  = motor_left  * 30. / M_PI;
+        double rpm_left = motor_left * 30. / M_PI;
         double rpm_right = motor_right * 30. / M_PI;
         ss << "MOTOR_RPM=" << vpMath::round(rpm_left) << "," << vpMath::round(rpm_right) << "\n";
         std::cout << "Send: " << ss.str() << std::endl;
-        if (! serial_off) {
+        if (!serial_off) {
           serial->write(ss.str());
         }
-      }
-      else {
+      } else {
         // stop the robot
-        if (! serial_off) {
+        if (!serial_off) {
           serial->write("LED_RING=2,10,0,0\n"); // Switch on led 2 to red: tag not detected
-//          serial->write("LED_RING=3,0,0,0\n");  // Switch on led 3 to blue: motor left not servoed
-//          serial->write("LED_RING=4,0,0,0\n");  // Switch on led 4 to blue: motor right not servoed
-          serial->write("MOTOR_RPM=0,-0\n");    // Stop the robot
+          //          serial->write("LED_RING=3,0,0,0\n");  // Switch on led 3 to blue: motor left not servoed
+          //          serial->write("LED_RING=4,0,0,0\n");  // Switch on led 4 to blue: motor right not servoed
+          serial->write("MOTOR_RPM=0,-0\n"); // Stop the robot
         }
       }
 
@@ -325,7 +334,7 @@ int main(int argc, const char **argv)
         break;
     }
 
-    if (! serial_off) {
+    if (!serial_off) {
       serial->write("LED_RING=0,0,0,0\n"); // Switch off all led
     }
 
@@ -336,12 +345,12 @@ int main(int argc, const char **argv)
 
     if (display_on)
       delete d;
-    if (! serial_off) {
+    if (!serial_off) {
       delete serial;
     }
   } catch (const vpException &e) {
     std::cerr << "Catch an exception: " << e.getMessage() << std::endl;
-    if (! serial_off) {
+    if (!serial_off) {
       serial->write("LED_RING=1,10,0,0\n"); // Switch on led 1 to red
     }
   }
