@@ -4,8 +4,8 @@
   Example that shows how to simulate a visual servoing on a Pioneer mobile
   robot equipped with a camera. The current visual features that are used are
   s = (x, log(Z/Z*)). The desired one are s* = (x*, 0), with:
-  - x the abscisse of the point measured at each iteration
-  - x* the desired abscisse position of the point (x* = 0)
+  - x the abscise of the point measured at each iteration
+  - x* the desired abscise position of the point (x* = 0)
   - Z the depth of the point measured at each iteration
   - Z* the desired depth of the point equal to the initial one.
 
