@@ -15,18 +15,22 @@ int main()
   std::cout << "Debug level 3 active: " << vpDEBUG_ENABLE(3) << std::endl;
 
   // C-like trace printings if VP_TRACE defined
-  vpTRACE("C-like trace");              // std::cout
-  vpTRACE(1, "C-like trace level 1");   // std::cout
+  vpTRACE("C-like trace");            // std::cout
+  vpTRACE(1, "C-like trace level 1"); // std::cout
 
   vpERROR_TRACE("C-like error trace");            // std::cerr
-  vpERROR_TRACE(1, "C-like error trace level 1"); // std::cerr if VP_DEBUG_MODE value is >= 1
+  vpERROR_TRACE(1, "C-like error trace level 1"); // std::cerr if
+                                                  // VP_DEBUG_MODE value is >=
+                                                  // 1
 
   // C-like debug printings if VP_DEBUG defined
-  vpDEBUG_TRACE ("C-like debug trace"); // stdout
+  vpDEBUG_TRACE("C-like debug trace");  // stdout
   vpDERROR_TRACE("C-like error trace"); // stderr
 
-  vpDEBUG_TRACE (2, "C-like debug trace level 2"); // std::cout if VP_DEBUG_MODE value >= 2
-  vpDERROR_TRACE(2, "C-like error trace level 2"); // std::cerr if VP_DEBUG_MODE value >= 2
+  vpDEBUG_TRACE(2,
+                "C-like debug trace level 2"); // std::cout if VP_DEBUG_MODE value >= 2
+  vpDERROR_TRACE(2,
+                 "C-like error trace level 2"); // std::cerr if VP_DEBUG_MODE value >= 2
 
   // C++-like trace printings if VP_TRACE defined
   vpCTRACE << "C++-like trace" << std::endl;       // std::cout
