@@ -17,7 +17,7 @@ int main()
     vpDisplayX d(I, 0, 0, "Camera view");
 #elif defined(VISP_HAVE_GDI)
     vpDisplayGDI d(I, 0, 0, "Camera view");
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV d(I, 0, 0, "Camera view");
 #else
     std::cout << "No image viewer is available..." << std::endl;
