@@ -9,7 +9,7 @@
 int main(int argc, const char *argv[])
 {
 //! [Check 3rd party]
-#ifdef VISP_HAVE_OPENCV
+#if (defined(HAVE_OPENCV_HIGHGUI) && defined(HAVE_OPENCV_VIDEOIO) || defined(VISP_HAVE_V4L2)) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_VIDEO)
   //! [Check 3rd party]
   try {
     std::string opt_videoname = "video-postcard.mp4";
@@ -26,7 +26,7 @@ int main(int argc, const char *argv[])
         std::cout << "Usage: " << argv[0]
                   << " [--videoname <video name>] [--subsample <scale factor>] [--init-by-click]"
                   << " [--help] [-h]" << std::endl;
-        return 0;
+        return EXIT_SUCCESS;
       }
     }
 
@@ -42,11 +42,7 @@ int main(int argc, const char *argv[])
     //! [Acquire]
 
     //! [Convert to OpenCV image]
-#if (VISP_HAVE_OPENCV_VERSION < 0x020408)
-    IplImage *cvI = NULL;
-#else
     cv::Mat cvI;
-#endif
     vpImageConvert::convert(I, cvI);
     //! [Convert to OpenCV image]
 
@@ -149,7 +145,7 @@ int main(int argc, const char *argv[])
         break;
 
       vpDisplay::flush(I);
-      if (! reader.isVideoFormat()) {
+      if (!reader.isVideoFormat()) {
         vpTime::wait(t, 40);
       }
     }
@@ -157,20 +153,14 @@ int main(int argc, const char *argv[])
 
     //! [Wait click]
     vpDisplay::getClick(I);
-//! [Wait click]
-
-//! [Release IplImage]
-#if (VISP_HAVE_OPENCV_VERSION < 0x020408)
-    cvReleaseImage(&cvI);
-#endif
-    //! [Release IplImage]
-
-    return 0;
+    //! [Wait click]
   } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
+    return EXIT_FAILURE;
   }
 #else
   (void)argc;
   (void)argv;
 #endif
+  return EXIT_SUCCESS;
 }
