@@ -13,7 +13,7 @@
 
 int main(int argc, char **argv)
 {
-#if defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020300)
+#if defined(VISP_HAVE_OPENCV)
   try {
     std::string opt_videoname = "teabox.mp4";
     int opt_tracker = vpMbGenericTracker::EDGE_TRACKER;
@@ -24,18 +24,17 @@ int main(int argc, char **argv)
       else if (std::string(argv[i]) == "--tracker" && i + 1 < argc)
         opt_tracker = atoi(argv[i + 1]);
       else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
-        std::cout << "\nUsage: " << argv[0]
-                  << " [--name <video name>] [--tracker <1=egde|2=keypoint|3=hybrid>]"
-                  << " [--help] [-h]\n"
-                  << std::endl;
+        std::cout << "\nUsage: " << argv[0] << " [--name <video name>] [--tracker <1=egde|2=keypoint|3=hybrid>]"
+          << " [--help] [-h]\n"
+          << std::endl;
         return EXIT_SUCCESS;
       }
     }
 
     if (opt_tracker < 1 || opt_tracker > 3) {
       std::cerr << "Wrong tracker type. Correct values are: "
-                   "1=egde|2=keypoint|3=hybrid."
-                << std::endl;
+        "1=egde|2=keypoint|3=hybrid."
+        << std::endl;
       return EXIT_SUCCESS;
     }
 
@@ -62,28 +61,27 @@ int main(int argc, char **argv)
     vpDisplayX display;
 #elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display;
-#else
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display;
 #endif
     display.init(I, 100, 100, "Model-based tracker");
 
     //! [Constructor]
     vpMbGenericTracker tracker(1, opt_tracker);
-//! [Constructor]
+    //! [Constructor]
 
 #if !defined(VISP_HAVE_MODULE_KLT)
     if (opt_tracker >= 2) {
-      std::cout << "KLT and hybrid model-based tracker are not available "
-                   "since visp_klt module is missing"
-                << std::endl;
+      std::cout << "KLT and hybrid model-based tracker are not available since visp_klt module is missing"
+        << std::endl;
       return EXIT_SUCCESS;
     }
 #endif
 
-//! [Set parameters]
+    //! [Set parameters]
     //! [Load config file]
     tracker.loadConfigFile(objectname + ".xml");
-//! [Load config file]
+    //! [Load config file]
 #if 0
     // Corresponding parameters manually set to have an example code
     if (opt_tracker == 1 || opt_tracker == 3) {
@@ -91,14 +89,15 @@ int main(int argc, char **argv)
       me.setMaskSize(5);
       me.setMaskNumber(180);
       me.setRange(8);
-      me.setThreshold(10000);
+      me.setLikelihoodThresholdType(vpMe::NORMALIZED_THRESHOLD);
+      me.setThreshold(20);
       me.setMu1(0.5);
       me.setMu2(0.5);
       me.setSampleStep(4);
       tracker.setMovingEdge(me);
     }
 
-#ifdef VISP_HAVE_MODULE_KLT
+#if defined(VISP_HAVE_MODULE_KLT) && defined(VISP_HAVE_OPENCV) && defined(HAVE_OPENCV_IMGPROC) && defined(HAVE_OPENCV_VIDEO)
     if (opt_tracker == 2 || opt_tracker == 3) {
       vpKltOpencv klt_settings;
       tracker.setKltMaskBorder(5);
@@ -157,7 +156,8 @@ int main(int argc, char **argv)
       }
     }
     vpDisplay::getClick(I);
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cerr << "Catch a ViSP exception: " << e.what() << std::endl;
   }
 
