@@ -11,7 +11,7 @@
 
 int main(int argc, char **argv)
 {
-#if defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100)
+#if defined(VISP_HAVE_OPENCV)
   try {
     std::string videoname = "teabox.mp4";
 
@@ -20,7 +20,7 @@ int main(int argc, char **argv)
         videoname = std::string(argv[i + 1]);
       else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
         std::cout << "\nUsage: " << argv[0] << " [--name <video name>] [--help] [-h]\n" << std::endl;
-        return 0;
+        return EXIT_SUCCESS;
       }
     }
     std::string parentname = vpIoTools::getParent(videoname);
@@ -31,8 +31,8 @@ int main(int argc, char **argv)
 
     std::cout << "Video name: " << videoname << std::endl;
     std::cout << "Tracker requested config files: " << objectname << ".[init,"
-              << "xml,"
-              << "cao or wrl]" << std::endl;
+      << "xml,"
+      << "cao or wrl]" << std::endl;
     std::cout << "Tracker optional config files: " << objectname << ".[ppm]" << std::endl;
 
     //! [Image]
@@ -51,11 +51,11 @@ int main(int argc, char **argv)
     vpDisplayX display;
 #elif defined(VISP_HAVE_GDI)
     vpDisplayGDI display;
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV display;
 #else
     std::cout << "No image viewer is available..." << std::endl;
-    return 0;
+    return EXIT_FAILURE;
 #endif
 
     display.init(I, 100, 100, "Model-based edge tracker");
@@ -64,7 +64,7 @@ int main(int argc, char **argv)
     vpMbEdgeTracker tracker;
     //! [Constructor]
     bool usexml = false;
-//! [Load xml]
+    //! [Load xml]
     if (vpIoTools::checkFilename(objectname + ".xml")) {
       tracker.loadConfigFile(objectname + ".xml");
       usexml = true;
@@ -76,7 +76,8 @@ int main(int argc, char **argv)
       me.setMaskSize(5);
       me.setMaskNumber(180);
       me.setRange(8);
-      me.setThreshold(10000);
+      me.setLikelihoodThresholdType(vpMe::NORMALIZED_THRESHOLD);
+      me.setThreshold(20);
       me.setMu1(0.5);
       me.setMu2(0.5);
       me.setSampleStep(4);
@@ -135,7 +136,8 @@ int main(int argc, char **argv)
         break;
     }
     vpDisplay::getClick(I);
-  } catch (const vpException &e) {
+  }
+  catch (const vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
   }
 #ifdef VISP_HAVE_OGRE
