@@ -100,7 +100,7 @@ int main()
     robot.set_fMo(wMo);
     bool ret = robot.initialiseCameraRelativeToObject(cMo);
     if (ret == false)
-      return 0; // Not able to set the position
+      return EXIT_FAILURE; // Not able to set the position
     robot.setDesiredCameraPosition(cdMo);
 
     vpImage<unsigned char> Iint(480, 640, 255);
@@ -108,7 +108,7 @@ int main()
     vpDisplayX displayInt(Iint, 700, 0, "Internal view");
 #elif defined(VISP_HAVE_GDI)
     vpDisplayGDI displayInt(Iint, 700, 0, "Internal view");
-#elif defined(VISP_HAVE_OPENCV)
+#elif defined(HAVE_OPENCV_HIGHGUI)
     vpDisplayOpenCV displayInt(Iint, 700, 0, "Internal view");
 #else
     std::cout << "No image viewer is available..." << std::endl;
